@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -57,15 +57,8 @@
  * we need a mechanism to reset a context (e.g. because a context is destroyed and it's ID might be reused)
  */
 
-#define RENDERSTATE_DISABLED -1
-#define RENDERSTATE_INIT      0
-#define RENDERSTATE_ENABLED   1
-#define RENDERSTATE_RENDERING 2
-#define RENDERSTATE_MODIFIED  3
-
-
 #include "GemBase.h"
-#include "GemCache.h"
+#include "Gem/Cache.h"
 
 /////////////////////////////////////////////////////////
 //
@@ -77,7 +70,8 @@
 /////////////////////////////////////////////////////////
 GemBase :: GemBase()
   : gem_amRendering(false), m_cache(NULL), m_modified(true),
-    m_enabled(true)
+    m_out1(NULL),
+    m_enabled(true), m_state(INIT)
 {
   m_out1 = outlet_new(this->x_obj, 0);
 }
@@ -103,15 +97,19 @@ GemBase :: ~GemBase()
 /////////////////////////////////////////////////////////
 void GemBase :: gem_startstopMess(int state)
 {
+  // for now, this is important, as it is the only way to call the stopRendering
+#if 1
   if (state && !gem_amRendering){
     m_enabled = isRunnable();
     if(m_enabled) {
       startRendering();
+      m_state=RENDERING;
     }
   }
   else if (!state && gem_amRendering){
     if(m_enabled) {
       stopRendering();
+      m_state=ENABLED;
     }
   }
 
@@ -122,6 +120,9 @@ void GemBase :: gem_startstopMess(int state)
   t_atom ap[1];
   SETFLOAT(ap, state);
   outlet_anything(this->m_out1, gensym("gem_state"), 1, ap);
+#else
+  post("gem_startstopMess(%d) called...please report this to the upstream developers", state);
+#endif
 }
 
 /////////////////////////////////////////////////////////
@@ -131,48 +132,30 @@ void GemBase :: gem_startstopMess(int state)
 void GemBase :: gem_renderMess(GemCache* cache, GemState*state)
 {
   m_cache=cache;
-  if(m_cache->m_magic!=GEMCACHE_MAGIC)
+  if(m_cache && m_cache->m_magic!=GEMCACHE_MAGIC)
     m_cache=NULL;
-#ifdef GEM_MULTICONTEXT
-  if(RENDERSTATE_INIT==*m_state) {
+  if(INIT==m_state) {
     if(isRunnable()) {
-      *m_state=RENDERSTATE_ENABLED;
+      m_state=ENABLED;
     } else {
-      *m_state=RENDERSTATE_DISABLED;
+      m_state=DISABLED;
     }
   }
-  if(RENDERSTATE_MODIFIED==*m_state) {
+  if(MODIFIED==m_state) {
     stopRendering();
-    *m_state=RENDERSTATE_ENABLED;
+    m_state=ENABLED;
   }
-  if(RENDERSTATE_ENABLED==*m_state) {
+  if(ENABLED==m_state) {
     startRendering();
-    *m_state=RENDERSTATE_RENDERING;
+    m_state=RENDERING;
   }
-  if(RENDERSTATE_RENDERING==*m_state) {
-    if(state)render(state);
-    continueRender(state);
-    if(state)postrender(state);
-  }
-#else
-  if (!gem_amRendering){ // init Rendering if not done yet
-    m_enabled=isRunnable();
-
-    if(m_enabled)
-      startRendering();
-
+  if(RENDERING==m_state) {
     gem_amRendering=true;
-  }
-  if(m_enabled) {
     if(state)render(state);
     continueRender(state);
     if(state)postrender(state);
-  } else {
-    continueRender(state);
   }
-
   m_modified=false;
-#endif
 }
 
 void GemBase :: continueRender(GemState*state){
@@ -194,8 +177,15 @@ void GemBase :: setModified()
 {
   if (m_cache&& (m_cache->m_magic!=GEMCACHE_MAGIC))
     m_cache=NULL;
-  if (m_cache) m_cache->dirty = 1;
+  if (m_cache) m_cache->dirty = true;
   m_modified=true;
+  switch(m_state) {
+  case DISABLED:
+  case INIT:
+    break;
+  default:
+    m_state=MODIFIED;
+  }
 }
 
 /////////////////////////////////////////////////////////
@@ -204,8 +194,11 @@ void GemBase :: setModified()
 /////////////////////////////////////////////////////////
 void GemBase :: realStopRendering()
 {
-    stopRendering();
-    m_cache = NULL;
+  /* no idea what this function is for; ask the user when it appears */
+  post("realStopRendering() called...please report this to the upstream developers");
+  stopRendering();
+  m_cache = NULL;
+  m_state=ENABLED;
 }
 
 
@@ -219,6 +212,10 @@ bool GemBase :: isRunnable()
   return true;
 }
 
+enum GemBase::RenderState GemBase::getState(void) {
+  return m_state;
+}
+
 
 
 
@@ -228,17 +225,18 @@ bool GemBase :: isRunnable()
 /////////////////////////////////////////////////////////
 void GemBase :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&GemBase::gem_MessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&GemBase::gem_MessCallback),
     	    gensym("gem_state"), A_GIMME, A_NULL);
 }
 void GemBase :: gem_MessCallback(void *data, t_symbol *s, int argc, t_atom *argv)
 {
-  if (argc==1 && argv->a_type==A_FLOAT){
-    GetMyClass(data)->gem_startstopMess(atom_getint(argv));  // start rendering (forget this !?)
-  } else if (argc==2 && argv->a_type==A_POINTER && (argv+1)->a_type==A_POINTER){
-
+  if (argc==2 && argv->a_type==A_POINTER && (argv+1)->a_type==A_POINTER){
     GetMyClass(data)->gem_renderMess((GemCache *)argv->a_w.w_gpointer, (GemState *)(argv+1)->a_w.w_gpointer);
+#if 1
+  } else if (argc==1 && argv->a_type==A_FLOAT){
+    GetMyClass(data)->gem_startstopMess(atom_getint(argv));  // start rendering (forget this !?)
+#endif
   } else {
-    GetMyClass(data)->error("wrong arguments...");
+    GetMyClass(data)->error("wrong arguments in GemTrigger...");
   }
 }
