@@ -5,25 +5,23 @@
   The base class for all of the gem objects
 
   Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-  Copyright (c) Gnther Geiger.
-  Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+  Copyright (c) Günther Geiger.
+  Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
   For information on usage and redistribution, and for a DISCLAIMER OF ALL
   WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 	
   -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_GEMBASE_H_
-#define INCLUDE_GEMBASE_H_
+#ifndef _INCLUDE__GEM_BASE_GEMBASE_H_
+#define _INCLUDE__GEM_BASE_GEMBASE_H_
 
-#include "Base/GemGL.h"
+#include "Gem/GemGL.h"
+#include "Gem/ContextData.h"
 
 #include "Base/CPPExtern.h"
-#include "Base/GemState.h"
-
-#include "Base/GemContextData.h"
 
 class GemCache;
-
+class GemState;
 /*-----------------------------------------------------------------
   -------------------------------------------------------------------
   CLASS
@@ -75,6 +73,7 @@ class GEM_EXTERN GemBase : public CPPExtern
 
   //////////
   // has rendering started ?
+  // deprecated, use 'getState()==RENDERING' instead
   bool            gem_amRendering;
     	
   //////////
@@ -113,7 +112,7 @@ class GEM_EXTERN GemBase : public CPPExtern
   void	    	realStopRendering();
   void            gem_startstopMess(int state);
   void            gem_renderMess(GemCache* state, GemState* state2);
-  	    	
+
   static inline GemBase *GetMyClass(void *data) {return((GemBase *)((Obj_header *)data)->data);}
 
   friend class    gemhead;
@@ -128,8 +127,13 @@ class GEM_EXTERN GemBase : public CPPExtern
   /* whether the object is internally disabled or not 
    * objects are to be disabled, if the system cannot make use of them, e.g. because of unsupported openGL features
    */
-  bool  m_enabled;
-  GemContextData<int>m_state;
+  gem::ContextData<bool>m_enabled;
+
+  enum RenderState {INIT, ENABLED, DISABLED, RENDERING, MODIFIED};
+  gem::ContextData<enum RenderState>m_state;
+
+ protected:
+  enum RenderState getState(void);
 
 };
 
