@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -26,11 +26,11 @@
 //
 /////////////////////////////////////////////////////////
 GemGluObj :: GemGluObj(t_floatarg size, t_floatarg slices, t_floatarg stacks)
-    	   : GemShape(size)
+  : GemShape(size),
+    m_numSlices((int)slices),m_numStacks((int)stacks),
+    m_sliceInlet(NULL)
 {
     m_drawType = (GLenum) GL_FILL;
-    m_numSlices=(int)slices;
-    m_numStacks=(int)stacks;
     if(m_numSlices<=0)m_numSlices=10;
     if(m_numStacks<=0)m_numStacks=m_numSlices;
     
@@ -98,7 +98,7 @@ void GemGluObj :: typeMess(t_symbol *type)
 /////////////////////////////////////////////////////////
 void GemGluObj :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&GemGluObj::numSlicesMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&GemGluObj::numSlicesMessCallback),
     	    gensym("numslices"), A_GIMME, A_NULL);
 }
 void GemGluObj :: numSlicesMessCallback(void *data, t_symbol*, int argc, t_atom*argv)
