@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
@@ -18,7 +18,8 @@
 
 #include "GemPixDualObj.h"
 
-#include "GemCache.h"
+#include "Gem/Cache.h"
+#include "Gem/State.h"
 
 #include <string.h>
 #include <stdio.h>
@@ -32,7 +33,11 @@
 //
 /////////////////////////////////////////////////////////
 GemPixDualObj :: GemPixDualObj()
-  : m_cacheRight(NULL), m_pixRightValid(-1) //, m_pixRight(NULL) changed DH 8/5/02
+  : m_cacheRight(NULL),
+    m_pixRight(NULL),// was dsiabled by DH 8/5/02
+    m_pixRightValid(-1),
+    org_pixRightValid(-1),
+    m_inlet(NULL)
 {
     m_inlet = inlet_new(this->x_obj, &this->x_obj->ob_pd, gensym("gem_state"), gensym("gem_right"));
     memset(&m_pixRight, 0, sizeof(m_pixRight));
@@ -198,15 +203,14 @@ void GemPixDualObj :: stopRendering()
 /////////////////////////////////////////////////////////
 void GemPixDualObj :: rightRender(GemState *statePtr)
 {
-  if (!statePtr || !statePtr->image) {
+  if (!statePtr || !statePtr->get(GemState::_PIX, m_pixRight) || !m_pixRight) {
     m_pixRightValid = 0;
     m_pixRight = 0;
     return;
   }
   
   m_pixRightValid = 1;
-  m_pixRight = statePtr->image;
-  if (statePtr->image->newimage)setPixModified(); // force the left arm to create a new image
+  if (m_pixRight->newimage)setPixModified(); // force the left arm to create a new image
 }
 
 /////////////////////////////////////////////////////////
@@ -215,7 +219,7 @@ void GemPixDualObj :: rightRender(GemState *statePtr)
 /////////////////////////////////////////////////////////
 void GemPixDualObj :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&GemPixDualObj::gem_rightMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&GemPixDualObj::gem_rightMessCallback),
     	    gensym("gem_right"), A_GIMME, A_NULL);
 }
 void GemPixDualObj :: gem_rightMessCallback(void *data, t_symbol *s, int argc, t_atom *argv)
