@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2006 IOhannes m zmoelnig. forum::fr::umlute
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -16,7 +16,8 @@
 /////////////////////////////////////////////////////////
 
 #include "GemPixObj.h"
-#include "GemCache.h"
+#include "Gem/Cache.h"
+#include "Gem/State.h"
 
 /////////////////////////////////////////////////////////
 //
@@ -24,13 +25,12 @@
 //
 /////////////////////////////////////////////////////////
 GemPixObj :: GemPixObj() : 
+  cachedPixBlock(pixBlock()),
   orgPixBlock(NULL), m_processOnOff(1),
-  m_simd(GEM_SIMD_NONE)
+  m_simd(GemSIMD::getCPU())
 {
     cachedPixBlock.newimage=0;
     cachedPixBlock.newfilm =0;
-
-    m_simd=GemSIMD::getCPU();
 }
 
 
@@ -53,79 +53,83 @@ void GemPixObj :: render(GemState *state){
   //   change formats, sizes, databuffer, whatever
   // the data is restored in the <postrender> call,
   // so that the objects can rely on their (buffered) images
-  if (!state || !state->image || !&state->image->image)return;
-  cachedPixBlock.newimage=state->image->newimage;
-  if (!state->image->newimage) {
-    state->image = &cachedPixBlock;
+  pixBlock*image=NULL;
+  if (!state || !state->get(GemState::_PIX, image))return;
+  if(!image || 
+     !&image->image)  return;
+  cachedPixBlock.newimage=image->newimage;
+  if (!image->newimage) {
+    image = &cachedPixBlock;
   } else {
-    orgPixBlock = state->image;
-    cachedPixBlock.newimage = state->image->newimage;
-    cachedPixBlock.newfilm = state->image->newfilm; //added for newfilm copy from cache cgc 6-21-03
-    state->image->image.copy2ImageStruct(&cachedPixBlock.image);
-    state->image = &cachedPixBlock;
+    orgPixBlock = image;
+    cachedPixBlock.newimage = image->newimage;
+    cachedPixBlock.newfilm = image->newfilm; //added for newfilm copy from cache cgc 6-21-03
+    image->image.copy2ImageStruct(&cachedPixBlock.image);
+    image = &cachedPixBlock;
     if (m_processOnOff){
-      switch(state->image->image.format){
+      switch(image->image.format){
       case GL_RGBA:
       case GL_BGRA_EXT:
-	switch(m_simd){
-	case(GEM_SIMD_MMX):
-	  processRGBAMMX(state->image->image);
-	  break;
-	case(GEM_SIMD_SSE2):
-	  processRGBASSE2(state->image->image);
-	  break;
-	case(GEM_SIMD_ALTIVEC):
-	  processRGBAAltivec(state->image->image);
-	  break;
-	default:
-	  processRGBAImage(state->image->image);
-	}
-	break;
+        switch(m_simd){
+        case(GEM_SIMD_MMX):
+          processRGBAMMX(image->image);
+          break;
+        case(GEM_SIMD_SSE2):
+          processRGBASSE2(image->image);
+          break;
+        case(GEM_SIMD_ALTIVEC):
+          processRGBAAltivec(image->image);
+          break;
+        default:
+          processRGBAImage(image->image);
+        }
+        break;
       case GL_RGB:
       case GL_BGR_EXT:
-	processRGBImage(state->image->image);
-	break;
+        processRGBImage(image->image);
+        break;
       case GL_LUMINANCE:
-	switch(m_simd){
-	case(GEM_SIMD_MMX):
-	  processGrayMMX(state->image->image);
-	  break;
-	case(GEM_SIMD_SSE2):
-	  processGraySSE2(state->image->image);
-	  break;
-	case(GEM_SIMD_ALTIVEC):
-	  processGrayAltivec(state->image->image);
-	  break;
-	default:
-	  processGrayImage(state->image->image);
-	}
-	break;
+        switch(m_simd){
+        case(GEM_SIMD_MMX):
+          processGrayMMX(image->image);
+          break;
+        case(GEM_SIMD_SSE2):
+          processGraySSE2(image->image);
+          break;
+        case(GEM_SIMD_ALTIVEC):
+          processGrayAltivec(image->image);
+          break;
+        default:
+          processGrayImage(image->image);
+        }
+        break;
       case GL_YCBCR_422_GEM:
-	switch(m_simd){
-	case(GEM_SIMD_MMX):
-	  processYUVMMX(state->image->image);
-	  break;
-	case(GEM_SIMD_SSE2):
-	  processYUVSSE2(state->image->image);
-	  break;
-	case(GEM_SIMD_ALTIVEC):
-	  processYUVAltivec(state->image->image);
-	  break;
-	default:
-	  processYUVImage(state->image->image);
-	}
-  break;
+        switch(m_simd){
+        case(GEM_SIMD_MMX):
+          processYUVMMX(image->image);
+          break;
+        case(GEM_SIMD_SSE2):
+          processYUVSSE2(image->image);
+          break;
+        case(GEM_SIMD_ALTIVEC):
+          processYUVAltivec(image->image);
+          break;
+        default:
+          processYUVImage(image->image);
+        }
+        break;
       default:
-        processImage(state->image->image);
+        processImage(image->image);
       }
     }
   }
+  state->set(GemState::_PIX, image);
 }
 
 //////////
 // get the original state back
 void GemPixObj :: postrender(GemState *state){
-  state->image = orgPixBlock;
+  state->set(GemState::_PIX, orgPixBlock);
 }
 
 /////////////////////////////////////////////////////////
@@ -207,8 +211,8 @@ void GemPixObj :: processOnOff(int on)
 /////////////////////////////////////////////////////////
 void GemPixObj :: obj_setupCallback(t_class *classPtr)
 {
-    class_addfloat(classPtr, (t_method)&GemPixObj::floatMessCallback);    
-    class_addmethod(classPtr, (t_method)&GemPixObj::simdMessCallback,
+    class_addfloat(classPtr, reinterpret_cast<t_method>(&GemPixObj::floatMessCallback));    
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&GemPixObj::simdMessCallback),
 		  gensym("simd"), A_DEFFLOAT, A_NULL);
 }
 void GemPixObj :: floatMessCallback(void *data, float n)
