@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -16,6 +16,7 @@
 /////////////////////////////////////////////////////////
 
 #include "GemShape.h"
+#include "Gem/State.h"
 #include <ctype.h>
 /////////////////////////////////////////////////////////
 //
@@ -27,7 +28,10 @@
 /////////////////////////////////////////////////////////
 GemShape :: GemShape(t_floatarg size)
   : m_linewidth(1.0f), m_size((float)size), m_drawType(GL_DEFAULT_GEM), m_blend(0),
-    m_inlet(NULL)
+    m_inlet(NULL),
+    m_texType(0), m_texNum(0),
+    m_texCoords(NULL),
+    m_lighting(false)
 {
   if (m_size == 0.f)m_size = 1.f;
 
@@ -36,7 +40,10 @@ GemShape :: GemShape(t_floatarg size)
 }
 GemShape :: GemShape()
   : m_linewidth(1.0f), m_size(1.0f), m_drawType(GL_DEFAULT_GEM), m_blend(0), 
-    m_inlet(NULL)
+    m_inlet(NULL),
+    m_texType(0), m_texNum(0),
+    m_texCoords(NULL),
+    m_lighting(false)
 {
   // no size inlet
 }
@@ -57,15 +64,24 @@ GemShape :: ~GemShape()
 void GemShape :: SetVertex(GemState* state,float x, float y, float z, float tx, float ty,int curCoord)
 {
 	int i;
-     if (state->numTexCoords) {
+
+  TexCoord*texcoords=NULL;
+  int numCoords = 0;
+  int numUnits = 0;
+
+  state->get(GemState::_GL_TEX_NUMCOORDS, numCoords);
+  state->get(GemState::_GL_TEX_UNITS, numUnits);
+
+
+  if (numCoords) {
     tx=state->texCoordX(curCoord);
     ty=state->texCoordY(curCoord);
   }
-
-  if (state->multiTexUnits) {
-      for( i=0; i<state->multiTexUnits; i++) {
+  
+  if (numUnits) {
+    for( i=0; i<numUnits; i++) {
       glMultiTexCoord2fARB(GL_TEXTURE0+i, tx, ty);
-      }
+    }
   } else { // no multitexturing!
     glTexCoord2f(tx, ty);
 	}
@@ -77,13 +93,21 @@ void GemShape :: SetVertex(GemState* state,float x, float y, float z,
                            int curCoord)
 {
 	int i;
-  if (state->numTexCoords) {
+  int numCoords = 0;
+  int numUnits = 0;
+
+  state->get(GemState::_GL_TEX_NUMCOORDS, numCoords);
+  state->get(GemState::_GL_TEX_UNITS, numUnits);
+
+
+
+  if (numCoords) {
     s*=state->texCoordX(curCoord);
     t*=state->texCoordY(curCoord);
   }
 
-  if (state->multiTexUnits) {
-    for( i=0; i<state->multiTexUnits; i++)
+  if (numUnits) {
+    for( i=0; i<numUnits; i++)
       glMultiTexCoord4fARB(GL_TEXTURE0+i, s, t, r, q);
   } else { // no multitexturing!
     glTexCoord4f(s, t, r, q);
@@ -163,7 +187,7 @@ void GemShape :: blendMess(float blend)
 
 void GemShape :: render(GemState *state)
 {
-  if (m_drawType == GL_LINE_LOOP)
+  if (m_drawType == GL_LINE_LOOP || m_drawType == GL_LINE_STRIP || m_drawType == GL_LINES)
     glLineWidth(m_linewidth);
 
   if (m_blend) {
@@ -173,6 +197,16 @@ void GemShape :: render(GemState *state)
     glHint(GL_POLYGON_SMOOTH_HINT,GL_DONT_CARE); 
   }
 
+  m_texType=0;
+  m_texNum =0;
+  m_texCoords=NULL;
+  m_lighting=false;
+
+  state->get(GemState::_GL_TEX_COORDS, m_texCoords);
+  state->get(GemState::_GL_TEX_TYPE, m_texType);
+  state->get(GemState::_GL_TEX_NUMCOORDS, m_texNum);
+  state->get(GemState::_GL_LIGHTING, m_lighting);
+
   renderShape(state);
 
   // LATER try to restore the original state
@@ -181,7 +215,7 @@ void GemShape :: render(GemState *state)
     glDisable(GL_BLEND);
   }
 
-  if (m_drawType == GL_LINE_LOOP)
+  if (m_drawType == GL_LINE_LOOP || m_drawType == GL_LINE_STRIP || m_drawType == GL_LINES)
     glLineWidth(1.0);
 }
 
@@ -191,13 +225,13 @@ void GemShape :: render(GemState *state)
 /////////////////////////////////////////////////////////
 void GemShape :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&GemShape::linewidthMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&GemShape::linewidthMessCallback),
     	    gensym("width"), A_FLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&GemShape::typeMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&GemShape::typeMessCallback),
     	    gensym("draw"), A_SYMBOL, A_NULL);
-    class_addmethod(classPtr, (t_method)&GemShape::blendMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&GemShape::blendMessCallback),
     	    gensym("blend"), A_FLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&GemShape::sizeMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&GemShape::sizeMessCallback),
     	    gensym("ft1"), A_FLOAT, A_NULL);
 }
 void GemShape :: linewidthMessCallback(void *data, t_floatarg linewidth)
