@@ -5,15 +5,15 @@ LOG
     Base class for shapes
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_GEMSHAPE_H_
-#define INCLUDE_GEMSHAPE_H_
+#ifndef _INCLUDE__GEM_BASE_GEMSHAPE_H_
+#define _INCLUDE__GEM_BASE_GEMSHAPE_H_
 
 #include "Base/GemBase.h"
 
@@ -33,6 +33,7 @@ DESCRIPTION
     "width" - the line width when drawing with lines
     
 -----------------------------------------------------------------*/
+class TexCoord;
 class GEM_EXTERN GemShape : public GemBase
 {
     public:
@@ -132,6 +133,12 @@ class GEM_EXTERN GemShape : public GemBase
     	static void 	typeMessCallback(void *data, t_symbol *type);
     	static void 	sizeMessCallback(void *data, t_floatarg size);
     	static void 	blendMessCallback(void *data, t_floatarg size);
+
+
+ protected:
+      int m_texType, m_texNum;
+      TexCoord*m_texCoords;
+      bool m_lighting;
 };
 
 #endif	// for header file
