@@ -5,15 +5,15 @@ LOG
 
     include file for VertexArrays
 
-    Copyright (c) 2004 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) 2004-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
 
-#ifndef INCLUDE_GEMVERTEX_H_
-#define INCLUDE_GEMVERTEX_H_
+#ifndef _INCLUDE__GEM_BASE_GEMVERTEX_H_
+#define _INCLUDE__GEM_BASE_GEMVERTEX_H_
 
 #include "Base/GemBase.h"
 
@@ -34,4 +34,4 @@ class GEM_EXTERN GemVertex : public GemBase {
 };
 
 
-#endif /* INCLUDE_GEMVERTEX_H_ */
+#endif /* _INCLUDE__GEM_BASE_GEMVERTEX_H_ */
