@@ -5,41 +5,39 @@ GEM - Graphics Environment for Multimedia
 create a window
 
 Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-Copyright (c) Gnther Geiger. geiger@epy.co.at
-Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+Copyright (c) Günther Geiger. geiger@epy.co.at
+Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 For information on usage and redistribution, and for a DISCLAIMER OF ALL
 WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_GEMWINCREATE_H_
-#define INCLUDE_GEMWINCREATE_H_
-#include "Base/config.h"
+#ifndef _INCLUDE__GEM_BASE_GEMWINCREATE_H_
+#define _INCLUDE__GEM_BASE_GEMWINCREATE_H_
+#include "Gem/GemConfig.h"
+#include "Gem/GemGL.h"
 
-#include "GemGL.h"
-#ifdef __unix__
+#if defined _WIN32
+# include <windows.h>
+#elif defined __APPLE__
+# import <AGL/agl.h>
+#elif defined __linux__ || defined HAVE_GL_GLX_H
 # ifdef HAVE_LIBXXF86VM
 #  include <X11/extensions/xf86vmode.h>
 # endif
-#elif defined __APPLE__
-# import <AGL/agl.h>
-#elif defined __WIN32__
-# include <windows.h>
 #else
 # error Define OS specific window creation
 #endif
 
-#include "Base/GemExportDef.h"
+#include "Gem/ExportDef.h"
 
 // I hate Microsoft...I shouldn't have to do this!
-#ifdef __WIN32__
+#ifdef _WIN32
 # pragma warning( disable : 4244 )
 # pragma warning( disable : 4305 )
 # pragma warning( disable : 4091 )
 #endif
 
-#include "m_pd.h"
-
 #include <string.h>
 
 /*-----------------------------------------------------------------
@@ -59,33 +57,20 @@ class GEM_EXTERN WindowInfo
   // Constructor
   WindowInfo() :
     fs(0), 
-#ifdef __unix__
-    dpy(NULL), win(0), cmap(0), context(NULL), delete_atom(0), have_border(false)
-#elif defined __WIN32__
-    win(NULL), dc(NULL), context(NULL)
+#if defined _WIN32
+    win(NULL), dc(NULL), context(NULL),
 #elif defined __APPLE__
     pWind(NULL), context(NULL), offscreen(NULL), pixelSize(32),
-    pixMap(NULL), rowBytes(0), baseAddr(NULL)
+    pixMap(NULL), rowBytes(0), baseAddr(NULL),
+#elif defined __linux__ || defined HAVE_GL_GLX_H
+    dpy(NULL), win(0), screen(0), cmap(0), context(NULL), delete_atom(0), have_border(false),
+#else
 #endif
+    have_constContext(0)
     {}
   int         fs;                 // FullScreen
-  int         have_constContext;  // 1 if we have a constant context
   
-#ifdef __unix__
-  Display     *dpy;               // X Display
-  Window      win;                // X Window
-  int         screen;             // X Screen
-  Colormap    cmap;               // X color map
-  GLXContext  context;            // OpenGL context
-  Atom        delete_atom;
-
-  bool        have_border;
-
-#ifdef HAVE_LIBXXF86VM
-  XF86VidModeModeInfo deskMode; // originale ModeLine of the Desktop
-#endif
-
-#elif defined __WIN32__
+#if defined _WIN32
 
   HWND        win;                // Window handle
   HDC         dc;                 // Device context handle
@@ -103,9 +88,26 @@ class GEM_EXTERN WindowInfo
     void 		*baseAddr;	// 
     short		fontList;	// Font
 
+#elif defined __linux__ || defined HAVE_GL_GLX_H
+
+  Display     *dpy;               // X Display
+  Window      win;                // X Window
+  int         screen;             // X Screen
+  Colormap    cmap;               // X color map
+  GLXContext  context;            // OpenGL context
+  Atom        delete_atom;
+
+  bool        have_border;
+
+# ifdef HAVE_LIBXXF86VM
+  XF86VidModeModeInfo deskMode; // originale ModeLine of the Desktop
+# endif
+
+
 #else
-#error Define OS specific window data
+# error Define OS specific window data
 #endif
+  int         have_constContext;  // 1 if we have a constant context
 };
 
 /*-----------------------------------------------------------------
@@ -173,12 +175,12 @@ class GEM_EXTERN WindowHints
 
   //////////
   // The GLXcontext to share rendering with
-#ifdef __unix__
-    GLXContext  shared;
-#elif defined __WIN32__
+#if defined _WIN32
     HGLRC       shared;
 #elif defined __APPLE__
     AGLContext	shared;
+#elif defined __linux__ || defined HAVE_GL_GLX_H
+    GLXContext  shared;
 #else
 #error Define OS specific OpenGL context
 #endif
