@@ -7,26 +7,23 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
-
-#ifdef __WIN32__
+#include "Gem/GemConfig.h"
+#ifdef _WIN32
 
 # include "GemWinCreate.h"
 
 # include <stdlib.h>
 
-# ifdef HAVE_QUICKTIME
-#  include <QTML.h>
-#  include <Movies.h>
-# endif /* HAVE_QUICKTIME */
+# include "Gem/Event.h"
+# include "Gem/GemGL.h"
 
-# include "GemEvent.h"
-# include "GemGL.h"
+#include "Gem/RTE.h"
 
 GEM_EXTERN void gemAbortRendering();
 
@@ -402,25 +399,6 @@ void gemWinMakeCurrent(WindowInfo&nfo)
 }
 
 bool initGemWin(void) {
-# ifdef HAVE_QUICKTIME
-	OSErr		err = noErr;
-
-	// Initialize QuickTime Media Layer
-	err = InitializeQTML(0);
-	if (err)
-    {
-      error("GEM Man: Could not initialize quicktime: error %d\n", err);
-      return 0;
-    }	
-	// Initialize QuickTime
-	EnterMovies();
-	if (err)
-    {
-      error("GEM Man: Could not initialize quicktime: error %d\n", err);
-      return 0;
-    }	
-	post("Gem Man: QT init OK");
-# endif /* HAVE_QUICKTIME */
   return 1;
 }
 
