@@ -7,17 +7,19 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
-#ifdef __unix__
+#include "Gem/GemConfig.h"
+#if defined __linux__ || defined HAVE_GL_GLX_H
 
-#include "GemEvent.h"
-#include "GemMan.h"
+
+#include "Gem/Event.h"
+#include "Gem/Manager.h"
 
 #include "GemWinCreate.h"
 
@@ -464,12 +466,13 @@ GEM_EXTERN void dispatchGemWindowMessages(WindowInfo &win)
           triggerMotionEvent(eb->x, eb->y); 
           if(!win.have_border) {
             int err=XSetInputFocus(win.dpy, win.win, RevertToParent, CurrentTime);
+            err=0;
           }
           break; 
         case KeyPress:
           if (XLookupString(kb,keystring,2,&keysym_return,NULL)==0) {
             //modifier key:use keysym
-            triggerKeyboardEvent(XKeysymToString(keysym_return), kb->keycode, 1);
+            //triggerKeyboardEvent(XKeysymToString(keysym_return), kb->keycode, 1);
           }
           if ( (keysym_return & 0xff00)== 0xff00 ) {
             //non alphanumeric key: use keysym
