@@ -7,27 +7,34 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2005 Georg Holzmann <grh@mur.at>
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
+/*
+ * FIXXME: check how font handling behaves with multiple contexts 
+ */
+
 #include "TextBase.h"
+#include "Gem/Settings.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef __WIN32__
+#ifdef _WIN32
 # include <io.h>
+# define close _close
+typedef unsigned __int8 uint8_t;
 #else
 # include <unistd.h>
 #endif
 
-char *TextBase::DEFAULT_FONT = (char*)"vera.ttf";
+std::string TextBase::DEFAULT_FONT = "vera.ttf";
 
 /////////////////////////////////////////////////////////
 //
@@ -39,26 +46,29 @@ char *TextBase::DEFAULT_FONT = (char*)"vera.ttf";
 /////////////////////////////////////////////////////////
 #ifdef FTGL
 TextBase :: TextBase(int argc, t_atom *argv)
-  : m_dist(1), m_valid(0), m_fontSize(20), m_fontDepth(20), m_precision(1.f),
-    m_widthJus(CENTER), m_heightJus(MIDDLE), m_depthJus(HALFWAY), m_font(NULL), m_fontname(NULL)
+  :
+  m_dist(1), m_valid(0), m_fontSize(20), m_fontDepth(20), m_precision(1.f),
+  m_widthJus(CENTER), m_heightJus(MIDDLE), m_depthJus(HALFWAY), 
+  m_inlet(NULL),
+  m_font(NULL), m_fontname(NULL)
 {
   // initial text
+  GemSettings::get("font.face", DEFAULT_FONT);
+  GemSettings::get("font.size", m_fontSize);
+
+
   m_theText.push_back(L"gem");
   makeLineDist();
   if(argc)textMess(argc, argv);
-  
-  if (getenv("GEM_DEFAULT_FONT"))
-    {
-      DEFAULT_FONT = getenv("GEM_DEFAULT_FONT");
-    }
-  
 
   m_inlet = inlet_new(this->x_obj, &this->x_obj->ob_pd, gensym("float"), gensym("ft1"));
 }
 
 void TextBase :: startRendering(void) {
-  if(m_fontname)
-    fontNameMess(m_fontname->s_name);
+  if(NULL==m_font) {
+    if(m_fontname)
+      fontNameMess(m_fontname->s_name);
+  }
 }
 
 
@@ -70,7 +80,7 @@ void TextBase :: renderLine(const char*line, float dist) {
   float x1=0, y1=0, z1=0, x2=0, y2=0, z2=0;
 #if 0
   startpost("renderline: "); {
-    char*c=(char*)line;
+    const char*c=line;
     while(c) {
       startpost("%c (%x)", c, c);
       c++;
@@ -115,7 +125,7 @@ void TextBase :: render(GemState *)
 void TextBase :: setFontSize(t_float size){
   m_fontSize = size;
   if (!m_font)return;
-  if (! m_font->FaceSize((int)m_fontSize) ) {
+  if (! m_font->FaceSize(static_cast<int>(m_fontSize)) ) {
     error("unable to set fontsize !");
   }
   setModified();
@@ -134,37 +144,33 @@ void TextBase :: setPrecision(float prec)
 // fontNameMess
 //
 ////////////////////////////////////////////////////////
-void TextBase :: fontNameMess(const char *filename){
+void TextBase :: fontNameMess(const std::string filename){
   m_valid = 0;
-  char buf[MAXPDSTRING];
-  char buf2[MAXPDSTRING];
-  char *bufptr=NULL;
+  const char *bufptr=NULL;
   int fd=-1;
 
-  if(!filename){
+  if(filename.empty()){
     error("no font-file specified");
     return;
   }
-  if ((fd=open_via_path(canvas_getdir(getCanvas())->s_name, (char*)filename, "", buf2, &bufptr, MAXPDSTRING, 1))>=0){
-    close(fd);
-    sprintf(buf, "%s/%s", buf2, bufptr);
-  } else
-    canvas_makefilename(getCanvas(), (char *)filename, buf, MAXPDSTRING);
+  std::string fn = findFile(filename);
+  bufptr=fn.c_str();
 
   /* try to open the file */
-  FILE*file = fopen(buf, "r");
+  FILE*file = fopen(bufptr, "r");
   if (!file) {
-    error("cannot find font-file '%s'", buf);
+    error("cannot find font-file '%s'", bufptr);
     return;
   }
   fclose(file);
 
   /* now read font */
-  if (makeFont(buf)==NULL){
-    error("unable to open font '%s'", buf);
+  if(m_font)delete m_font; m_font=NULL;
+  if (makeFont(bufptr)==NULL){
+    error("unable to open font '%s'", bufptr);
     return;
   }
-  m_fontname=gensym((char*)filename);
+  m_fontname=gensym(filename.c_str());
 
   setFontSize(m_fontSize);
   m_font->Depth(m_fontDepth);
@@ -201,7 +207,7 @@ void TextBase :: setPrecision(float prec)
 // fontNameMess
 //
 /////////////////////////////////////////////////////////
-void TextBase :: fontNameMess(const char *filename)
+void TextBase :: fontNameMess(const std::string s)
 {}
 
 /////////////////////////////////////////////////////////
@@ -315,13 +321,68 @@ void TextBase :: breakLine(wstring line)
   setModified();
 }
 
+static const uint8_t utf8d[] = {
+  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
+  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
+  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
+  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
+
+  070,070,070,070,070,070,070,070,070,070,070,070,070,070,070,070,
+  050,050,050,050,050,050,050,050,050,050,050,050,050,050,050,050,
+  030,030,030,030,030,030,030,030,030,030,030,030,030,030,030,030,
+  030,030,030,030,030,030,030,030,030,030,030,030,030,030,030,030,
+  204,204,188,188,188,188,188,188,188,188,188,188,188,188,188,188,
+  188,188,188,188,188,188,188,188,188,188,188,188,188,188,188,188,
+  174,158,158,158,158,158,158,158,158,158,158,158,158,142,126,126,
+  111, 95, 95, 95, 79,207,207,207,207,207,207,207,207,207,207,207,
+
+  0,1,1,1,8,7,6,4,5,4,3,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+  1,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+  1,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,1,1,1,1,1,1,1,1,
+  1,4,4,1,1,1,1,1,1,1,1,1,1,1,1,1,1,4,4,4,1,1,1,1,1,1,1,1,1,1,1,1,
+  1,1,1,4,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,1,8,7,6,4,5,4,3,2,1,1,1,1,
+
+};
+
+static std::wstring toWstring(const char*str) throw(int){
+  std::wstring result;
+
+  wchar_t unic = 0;
+  uint8_t data, byte, stat = 9;
+
+  int len=0;
+
+  while((byte=*str++)) {
+    data = utf8d[ byte ];
+    stat = utf8d[ 256 + (stat << 4) + (data >> 4) ];
+    byte = (byte ^ (uint8_t)(data << 4));
+
+    unic = (unic << 6) | byte;
+
+    if (!stat) {
+      // unic is now a proper code point, we just print it out.
+      result+=unic;
+      unic = 0;
+    }
+
+    if (stat == 1) {
+      // the byte is not allowed here; the state would have to
+      // be reset to continue meaningful reading of the string
+
+      throw(len);
+    }
+
+    len++;
+  }
+
+  return result;
+}
+
 void TextBase :: textMess(int argc, t_atom *argv)
 {
   m_theText.clear();
   if ( argc < 1 ) {return; }
 
-  char tmp_char[MAXPDSTRING];
-
   wstring line = L"";
   int i=0;
 
@@ -329,17 +390,27 @@ void TextBase :: textMess(int argc, t_atom *argv)
   for (i = 0; i < argc; ++i)
     {
       string newtext;
-      unsigned int j;
       if (A_FLOAT == argv[i].a_type) {
-        atom_string(&argv[i], tmp_char, MAXPDSTRING);
-        newtext = tmp_char;
+        char str[MAXPDSTRING];
+        char*sp=str;
+
+        atom_string(&argv[i], str, MAXPDSTRING);
+        while(*sp) {
+          unsigned char c=*sp++;
+          line+=c;
+        }
       } else {
-        newtext = atom_getsymbol(&argv[i])->s_name;
-      }
-      //line += newtext;
-      for(j=0; j<newtext.length(); j++) {
-        unsigned char c=newtext[j];
-        line += c;
+        char*sp=atom_getsymbol(&argv[i])->s_name;
+        try {
+          std::wstring ws=toWstring(sp);
+          line+=ws;
+        } catch (int i) {
+            i=0;
+          while(*sp) {
+            unsigned char c=*sp++;
+            line+=c;
+          }
+        }
       }
       if(argc-1>i)line += L' ';
     }
@@ -423,9 +494,9 @@ void TextBase :: stringMess(int argc, t_atom *argv)
       verbose(1, "invalid character %d: using ' ' instead", v);
       v=32;
     }
-    line += (wchar_t)(v);
+    line += static_cast<wchar_t>(v);
   }
-  line += (wchar_t)'\0';
+  line += L'\0';
 
   breakLine(line);
 }
@@ -438,23 +509,23 @@ void TextBase :: stringMess(int argc, t_atom *argv)
 void TextBase :: obj_setupCallback(t_class *classPtr)
 {
 
-  class_addlist(classPtr, (t_method)&TextBase::textMessCallback);
+  class_addlist(classPtr, reinterpret_cast<t_method>(&TextBase::textMessCallback));
 
-  class_addmethod(classPtr, (t_method)&TextBase::textMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&TextBase::textMessCallback),
 		  gensym("text"), A_GIMME, A_NULL);
   //-- moocow
-  class_addmethod(classPtr, (t_method)&TextBase::stringMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&TextBase::stringMessCallback),
 		  gensym("string"), A_GIMME, A_NULL);
   //-- /moocow
-  class_addmethod(classPtr, (t_method)&TextBase::precisionMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&TextBase::precisionMessCallback),
 		  gensym("precision"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&TextBase::fontNameMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&TextBase::fontNameMessCallback),
 		  gensym("font"), A_SYMBOL, A_NULL);
-  class_addmethod(classPtr, (t_method)&TextBase::justifyMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&TextBase::justifyMessCallback),
 		  gensym("justify"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&TextBase::fontSizeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&TextBase::fontSizeMessCallback),
 		  gensym("ft1"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&TextBase::linedistMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&TextBase::linedistMessCallback),
 		  gensym("linedist"), A_FLOAT, A_NULL);
 }
 void TextBase :: textMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
