@@ -5,32 +5,37 @@
   A text
 
   Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-  Copyright (c) Gnther Geiger. geiger@epy.co.at
-  Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+  Copyright (c) Günther Geiger. geiger@epy.co.at
+  Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
   Copyright (c) 2005 Georg Holzmann <grh@mur.at>
   For information on usage and redistribution, and for a DISCLAIMER OF ALL
   WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
   -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_TEXTBASE_H_
-#define INCLUDE_TEXTBASE_H_
+#ifndef _INCLUDE__GEM_BASE_TEXTBASE_H_
+#define _INCLUDE__GEM_BASE_TEXTBASE_H_
 
 
-#ifdef __WIN32__
+#ifdef _WIN32
 # pragma warning( disable : 4786 )
 # pragma warning( disable : 4788 )
 #endif
 
+#include "Gem/GemConfig.h"
+
 #include "Base/GemBase.h"
-#include "Base/config.h"
 
 #include <vector>
 #include <string>
 
 #ifdef FTGL
 # define FONT_SCALE 0.2/3.0
-# include "FTFont.h"
+# ifdef HAVE_FTGL_FTGL_H
+#  include "FTGL/ftgl.h"
+# else
+#  include "FTFont.h"
+# endif
 #else
 # define FONT_SCALE 1.0
 #endif
@@ -54,7 +59,7 @@ using std::wstring;
   -----------------------------------------------------------------*/
 class GEM_EXTERN TextBase : public GemBase
 {
-  CPPEXTERN_HEADER(TextBase, GemBase)
+  CPPEXTERN_HEADER(TextBase, GemBase);
 
     public:
 
@@ -89,7 +94,7 @@ class GEM_EXTERN TextBase : public GemBase
 
   //////////
   // The font to use
-  virtual void  fontNameMess(const char *filename);
+  virtual void  fontNameMess(const std::string filename);
 
   //////////
   // set line distance
@@ -178,7 +183,7 @@ class GEM_EXTERN TextBase : public GemBase
 
     //////////
     // The default font name
-    static char *DEFAULT_FONT;
+    static std::string DEFAULT_FONT;
  
     //////////
     // The font structure
