@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -20,12 +20,32 @@
 #include <Carbon/Carbon.h>
 #endif
 
-#include "Base/GemMan.h"
-#include "Base/GemState.h"
-#include "Base/GemCache.h"
+#include "Gem/Manager.h"
+#include "Gem/State.h"
+#include "Gem/Cache.h"
 #include "Base/GemBase.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(gemhead, t_floatarg, A_DEFFLOAT)
+#include "Gem/GLStack.h"
+#include "RTE/MessageCallbacks.h"
+#include "Gem/Exception.h"
+
+#include <stdio.h>
+
+#ifdef _MSC_VER  /* This is only for Microsoft's compiler, not cygwin, e.g. */
+# define snprintf _snprintf
+#endif
+
+CPPEXTERN_NEW_WITH_GIMME(gemhead);
+
+
+static std::string float2str(t_float v) {
+  std::string s;
+  char buf[1000];
+  snprintf(buf, 1000, "%g", v);
+  s=buf;
+  return s;
+}
+
 
 /////////////////////////////////////////////////////////
 //
@@ -35,17 +55,51 @@ CPPEXTERN_NEW_WITH_ONE_ARG(gemhead, t_floatarg, A_DEFFLOAT)
 // Constructor
 //
 /////////////////////////////////////////////////////////
-gemhead :: gemhead(t_floatarg priority)
-    	 : m_cache(NULL), m_renderOn(1)
+gemhead :: gemhead(int argc, t_atom*argv) :
+  gemreceive(gensym("__gem_render")),
+  m_cache(new GemCache(this)), m_renderOn(1)
 {
-    // register with Gem
-    if (priority == 0)
-		priority = 50;
-    m_priority=(int)priority;
-    GemMan::addObj(this, m_priority);
+  if(m_fltin)inlet_free(m_fltin);  m_fltin=NULL;
 
-    m_cache = new GemCache(this);
-    m_out1 = outlet_new(this->x_obj, 0);
+  m_basename=m_name->s_name;
+  float priority=50.;
+#if 1
+  switch(argc) {
+  case 2:
+    if(argv[0].a_type == A_FLOAT && argv[1].a_type == A_SYMBOL) {
+      priority=atom_getfloat(argv+0);
+      m_basename+=atom_getsymbol(argv+1)->s_name;
+    } else if(argv[1].a_type == A_FLOAT && argv[0].a_type == A_SYMBOL) {
+      priority=atom_getfloat(argv+1);
+      m_basename+=atom_getsymbol(argv+0)->s_name;
+    } else if(argv[1].a_type == A_FLOAT && argv[0].a_type == A_FLOAT) {
+      priority=atom_getfloat(argv+0);
+      m_basename+=::float2str(atom_getfloat  (argv+1));
+    }
+    break;
+  case 1:
+    if(argv[0].a_type == A_FLOAT) {
+      priority=atom_getfloat(argv+0);
+    } else if(argv[0].a_type == A_SYMBOL) {
+      m_basename+=atom_getsymbol(argv+0)->s_name;
+    }
+    break;
+  case 0:
+    priority=50.f;
+    break;
+  default:
+    throw(GemException("invalid arguments: 'gemhead [<priority> [<basereceivename>]]'"));
+  }
+#else
+  if(argc==0) 
+    priority=50.;
+  else if(argv[0].a_type == A_FLOAT) {
+    priority=atom_getfloat(argv);
+  } else 
+    throw(GemException("invalid arguments: 'gemhead [<priority>]'"));
+#endif
+  m_priority=priority+1;
+  setMess(priority);
 }
 
 /////////////////////////////////////////////////////////
@@ -54,11 +108,10 @@ gemhead :: gemhead(t_floatarg priority)
 /////////////////////////////////////////////////////////
 gemhead :: ~gemhead()
 {
-    GemMan::removeObj(this, m_priority);
     if (m_cache)
         stopRendering();
     if(m_cache)delete m_cache;
-    outlet_free(m_out1);
+    m_cache=NULL;
 }
 
 /////////////////////////////////////////////////////////
@@ -84,14 +137,16 @@ void gemhead :: renderGL(GemState *state)
   glMaterialfv(GL_FRONT_AND_BACK, GL_SPECULAR, s_color);
   glMaterialfv(GL_FRONT_AND_BACK, GL_SHININESS, shininess);
 
-  glPushMatrix();
+  gem::GLStack*stacks=NULL;
   if(state)
   {
     state->reset();
-
     // set the state dirty flag
-    state->dirty = m_cache->dirty;
+    state->set(GemState::_DIRTY, m_cache->dirty);
     state->VertexDirty=m_cache->vertexDirty;
+
+    state->get(GemState::_GL_STACKS, stacks);
+    if(stacks)stacks->push();
   }
 
   // are we profiling and need to send new images?
@@ -100,15 +155,15 @@ void gemhead :: renderGL(GemState *state)
 
   t_atom ap[2];
   ap->a_type=A_POINTER;
-  ap->a_w.w_gpointer=(t_gpointer *)m_cache;  // the cache ?
+  ap->a_w.w_gpointer=reinterpret_cast<t_gpointer*>(m_cache);  // the cache ?
   (ap+1)->a_type=A_POINTER;
-  (ap+1)->a_w.w_gpointer=(t_gpointer *)state;
-  outlet_anything(this->m_out1, gensym("gem_state"), 2, ap);
+  (ap+1)->a_w.w_gpointer=reinterpret_cast<t_gpointer*>(state);
+  outlet_anything(this->m_outlet, gensym("gem_state"), 2, ap);
 
-  m_cache->dirty = 0;
-  m_cache->vertexDirty=0;
-
-  glPopMatrix();
+  m_cache->dirty = false;
+  m_cache->vertexDirty=false;
+  state->get(GemState::_GL_STACKS, stacks);
+  if(stacks)stacks->pop();
 }
 
 
@@ -146,14 +201,43 @@ void gemhead :: renderOnOff(int state)
 // setPriority
 //
 /////////////////////////////////////////////////////////
-void gemhead :: setMess(int priority)
+void gemhead :: setMess(t_float priority)
 {
-  if (priority == 0)priority=50;
-  GemMan::removeObj(this, m_priority);
-  GemMan::addObj(this, (int)priority);
+  if (0.==priority)priority=50.;
+
+  if(priority==m_priority)
+    return;
+
   m_priority=priority;
+
+  std::string rcv=m_basename;
+  if(priority<0.f)
+    rcv=m_basename+"_osd";
+
+  gemreceive::priorityMess(priority);
+  gemreceive::nameMess(gensym(rcv.c_str()));
 }
 
+void gemhead :: receive(t_symbol*s, int argc, t_atom*argv) {
+  if(m_renderOn && gensym("gem_state")==s) {
+    if(1==argc && A_FLOAT==argv->a_type) {
+      int i=atom_getint(argv);
+      switch(i) {
+      case 0:
+        stopRendering();
+        break;
+      default:
+        startRendering();
+      }
+    } else if (2==argc && A_POINTER==argv[0].a_type && A_POINTER==argv[1].a_type) {
+      GemCache*cache=reinterpret_cast<GemCache*>(argv[0].a_w.w_gpointer);
+      GemState*state=reinterpret_cast<GemState*>(argv[1].a_w.w_gpointer);
+      renderGL(state);
+    }
+  } else {
+    // not for us...
+  }
+}
 
 
 /////////////////////////////////////////////////////////
@@ -165,7 +249,7 @@ void gemhead :: outputRenderOnOff(int state)
   // continue sending out the cache message
   t_atom ap[1];
   SETFLOAT(ap, state);
-  outlet_anything(this->m_out1, gensym("gem_state"), 1, ap);
+  outlet_anything(this->m_outlet, gensym("gem_state"), 1, ap);
 }
 
 /////////////////////////////////////////////////////////
@@ -195,20 +279,7 @@ void gemhead :: stopRendering()
 /////////////////////////////////////////////////////////
 void gemhead :: obj_setupCallback(t_class *classPtr)
 {
-    class_addbang(classPtr, (t_method)&gemhead::bangMessCallback);
-    class_addfloat(classPtr, (t_method)&gemhead::intMessCallback);
-    class_addmethod(classPtr, (t_method)&gemhead::setMessCallback,
-		    gensym("set"), A_FLOAT, A_NULL);
-}
-void gemhead :: bangMessCallback(void *data)
-{
-    GetMyClass(data)->bangMess();
-}
-void gemhead :: intMessCallback(void *data, t_floatarg n)
-{
-    GetMyClass(data)->renderOnOff((int)n);
-}
-void gemhead :: setMessCallback(void *data, t_floatarg n)
-{
-    GetMyClass(data)->setMess((int)n);
+  CPPEXTERN_MSG0(classPtr, "bang", bangMess);
+  CPPEXTERN_MSG1(classPtr, "float", renderOnOff, int);
+  CPPEXTERN_MSG1(classPtr, "set", setMess, int);
 }
