@@ -5,14 +5,14 @@ LOG
     Respond to mouse events
     
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_GEMKEYNAME_H_
-#define INCLUDE_GEMKEYNAME_H_
+#ifndef _INCLUDE__GEM_CONTROLS_GEMKEYNAME_H_
+#define _INCLUDE__GEM_CONTROLS_GEMKEYNAME_H_
 
 #include "Base/CPPExtern.h"
 
@@ -29,7 +29,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN gemkeyname : public CPPExtern
 {
-    CPPEXTERN_HEADER(gemkeyname, CPPExtern)
+    CPPEXTERN_HEADER(gemkeyname, CPPExtern);
 
     public:
 
