@@ -1,7 +1,7 @@
 /* ------------------------------------------------------------------
  * GEM - Graphics Environment for Multimedia
  *
- *  Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+ *  Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
  *	zmoelnig@iem.kug.ac.at
  *  For information on usage and redistribution, and for a DISCLAIMER
  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -9,8 +9,8 @@
  * ------------------------------------------------------------------
  */
 
-#ifndef INCLUDE_GEM_GLGETPOINTERV_H_
-#define INCLUDE_GEM_GLGETPOINTERV_H_
+#ifndef _INCLUDE__GEM_CONTROLS_GEMLIST_MATRIX_H_
+#define _INCLUDE__GEM_CONTROLS_GEMLIST_MATRIX_H_
 
 #include "Base/GemBase.h"
 
@@ -25,7 +25,7 @@
 
 class GEM_EXTERN gemlist_matrix : public GemBase
 {
-  CPPEXTERN_HEADER(gemlist_matrix, GemBase)
+  CPPEXTERN_HEADER(gemlist_matrix, GemBase);
 
     public:
   // Constructor
