@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -18,10 +18,10 @@
 
 #include "gemmouse.h"
 
-#include "Base/GemEvent.h"
-#include "Base/GemMan.h"
+#include "Gem/Event.h"
+#include "Gem/Manager.h"
 
-CPPEXTERN_NEW_WITH_GIMME(gemmouse)
+CPPEXTERN_NEW_WITH_GIMME(gemmouse);
 
 /////////////////////////////////////////////////////////
 //
@@ -107,8 +107,8 @@ void gemmouse :: mouseMotion(int x, int y)
     break;
   }
 
-  outlet_float(m_outYPos, (t_float)(y*scaley));
-  outlet_float(m_outXPos, (t_float)(x*scalex));
+  outlet_float(m_outYPos, static_cast<t_float>(y*scaley));
+  outlet_float(m_outXPos, static_cast<t_float>(x*scalex));
 }
 
 /////////////////////////////////////////////////////////
@@ -118,9 +118,9 @@ void gemmouse :: mouseMotion(int x, int y)
 void gemmouse :: mouseButton(int which, int state, int x, int y)
 {
   switch (which){
-  case 0: outlet_float(m_outLBut, (t_float)state); break;
-  case 1: outlet_float(m_outMBut, (t_float)state); break;
-  case 2: outlet_float(m_outRBut, (t_float)state); break;
+  case 0: outlet_float(m_outLBut, static_cast<t_float>(state)); break;
+  case 1: outlet_float(m_outMBut, static_cast<t_float>(state)); break;
+  case 2: outlet_float(m_outRBut, static_cast<t_float>(state)); break;
   }
 }
 
@@ -140,13 +140,13 @@ void gemmouse :: obj_setupCallback(t_class *)
 { }
 void gemmouse :: mouseMotionCallback(int x, int y, void *data)
 {
-    ((gemmouse *)data)->mouseMotion(x, y);
+    (reinterpret_cast<gemmouse*>(data))->mouseMotion(x, y);
 }
 void gemmouse :: mouseButtonCallback(int which, int state, int x, int y, void *data)
 {
-    ((gemmouse *)data)->mouseButton(which, state, x, y);
+    (reinterpret_cast<gemmouse*>(data))->mouseButton(which, state, x, y);
 }
 void gemmouse :: mouseWheelCallback(int axis, int value, void *data)
 {
-    ((gemmouse *)data)->mouseWheel(axis, value);
+    (reinterpret_cast<gemmouse*>(data))->mouseWheel(axis, value);
 }
