@@ -5,15 +5,15 @@ LOG
     Respond to mouse events
     
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_GEMMOUSE_H_
-#define INCLUDE_GEMMOUSE_H_
+#ifndef _INCLUDE__GEM_CONTROLS_GEMMOUSE_H_
+#define _INCLUDE__GEM_CONTROLS_GEMMOUSE_H_
 
 #include "Base/CPPExtern.h"
 
@@ -33,7 +33,7 @@ enum t_mousescale { NONE, WIDTH, HEIGHT, BOTH };
 
 class GEM_EXTERN gemmouse : public CPPExtern
 {
-    CPPEXTERN_HEADER(gemmouse, CPPExtern)
+    CPPEXTERN_HEADER(gemmouse, CPPExtern);
 
     public:
 
