@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,17 +16,17 @@
 
 #include "gemwin.h"
 
-#include "Base/GemGL.h"
+#include "Gem/GemGL.h"
  
 #ifdef __APPLE__
 # include <Carbon/Carbon.h>
 # include <AvailabilityMacros.h>
 #endif // __APPLE__
 
-#include "Base/GemMath.h"
-#include "Base/GemMan.h"
+#include "Utils/GemMath.h"
+#include "Gem/Manager.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(gemwin, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(gemwin, t_floatarg, A_DEFFLOAT);
 
 static bool StillHaveGemWin(bool up) {
   static int ref_counter = 0;
@@ -51,16 +51,16 @@ static bool StillHaveGemWin(bool up) {
 //
 /////////////////////////////////////////////////////////
 gemwin :: gemwin(t_floatarg framespersecond)
+  : m_FrameRate(NULL)
 {
   if(!StillHaveGemWin(true)) {
     /* this is the only [gemwin] */
     GemMan::resetState();
-    if (framespersecond <= 0.)
-      framespersecond = 20.;
-    GemMan::frameRate((float)framespersecond);
+    if (framespersecond > 0.)
+      GemMan::frameRate(framespersecond);
   } else {
     if(framespersecond>0.)
-      GemMan::frameRate((float)framespersecond);
+      GemMan::frameRate(framespersecond);
   }
 
   m_FrameRate       = outlet_new(this->x_obj, 0);
@@ -266,7 +266,7 @@ void gemwin :: colorMess(float red, float green, float blue, float alpha)
 /////////////////////////////////////////////////////////
 void gemwin :: clearmaskMess(float bitmask)
 {
-  GemMan::m_clear_mask = (GLbitfield) bitmask;
+  GemMan::m_clear_mask = static_cast<GLbitfield>(bitmask);
 }
 
 /////////////////////////////////////////////////////////
@@ -379,7 +379,7 @@ void gemwin :: fogModeMess(int mode)
 /////////////////////////////////////////////////////////
 void gemwin :: cursorMess(float setting)
 {
-  GemMan :: cursorOnOff((int)setting);
+  GemMan :: cursorOnOff(static_cast<int>(setting));
 }
 
 /////////////////////////////////////////////////////////
@@ -388,7 +388,7 @@ void gemwin :: cursorMess(float setting)
 /////////////////////////////////////////////////////////
 void gemwin :: topmostMess(float topmost)
 {
-  GemMan::topmostOnOff((int) topmost);
+  GemMan::topmostOnOff(static_cast<int>(topmost));
 }
 
 
@@ -432,91 +432,91 @@ void gemwin :: fsaaMess(int value)
 /////////////////////////////////////////////////////////
 void gemwin :: obj_setupCallback(t_class *classPtr)
 {
-  class_addbang(classPtr, (t_method)&gemwin::bangMessCallback);
-  class_addfloat(classPtr, (t_method)&gemwin::floatMessCallback);
+  class_addbang(classPtr, reinterpret_cast<t_method>(&gemwin::bangMessCallback));
+  class_addfloat(classPtr, reinterpret_cast<t_method>(&gemwin::floatMessCallback));
 
-  class_addmethod(classPtr, (t_method)&gemwin::renderMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::renderMessCallback),
 		  gensym("render"), A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::titleMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::titleMessCallback),
 		  gensym("title"), A_DEFSYM ,A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::createMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::createMessCallback),
 		  gensym("create"), A_DEFSYM ,A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::createStereoMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::createStereoMessCallback),
 		  gensym("createStereo"), A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::createStereoMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::createStereoMessCallback),
 		  gensym("createstereo"), A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::bufferMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::bufferMessCallback),
 		  gensym("buffer"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::fullscreenMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::fullscreenMessCallback),
 		  gensym("fullscreen"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::menuBarMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::menuBarMessCallback),
 		  gensym("menubar"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::secondscreenMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::secondscreenMessCallback),
 		  gensym("secondscreen"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::dimensionsMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::dimensionsMessCallback),
 		  gensym("dimen"), A_FLOAT, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::offsetMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::offsetMessCallback),
 		  gensym("offset"), A_FLOAT, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::colorMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::colorMessCallback),
 		  gensym("color"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::clearmaskMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::clearmaskMessCallback),
 		  gensym("clearmask"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::perspectiveMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::perspectiveMessCallback),
 		  gensym("perspec"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::viewMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::viewMessCallback),
 		  gensym("view"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::fogMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::fogMessCallback),
 		  gensym("fog"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::fogColorMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::fogColorMessCallback),
 		  gensym("fogcolor"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::fogModeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::fogModeMessCallback),
 		  gensym("fogmode"), A_FLOAT, A_NULL);
 
-  class_addmethod(classPtr, (t_method)&gemwin::ambientMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::ambientMessCallback),
 		  gensym("ambient"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::specularMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::specularMessCallback),
 		  gensym("specular"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::shininessMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::shininessMessCallback),
 		  gensym("shininess"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::cursorMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::cursorMessCallback),
 		  gensym("cursor"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::blurMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::blurMessCallback),
 		  gensym("blur"), A_FLOAT, A_NULL);
 
   // just call GemMan directly
-  class_addmethod(classPtr, (t_method)&gemwin::resetMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::resetMessCallback),
 		  gensym("reset"), A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::destroyMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::destroyMessCallback),
 		  gensym("destroy"), A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::printMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::printMessCallback),
 		  gensym("print"), A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::profileMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::profileMessCallback), 
 		  gensym("profile"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::lightingMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::lightingMessCallback), 
 		  gensym("lighting"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::stereoMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::stereoMessCallback), 
 		  gensym("stereo"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::stereoSepMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::stereoSepMessCallback), 
 		  gensym("stereoSep"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::stereoFocMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::stereoFocMessCallback), 
 		  gensym("stereoFoc"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::stereoSepMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::stereoSepMessCallback), 
 		  gensym("stereosep"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::stereoFocMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::stereoFocMessCallback), 
 		  gensym("stereofoc"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::stereoLineMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::stereoLineMessCallback), 
 		  gensym("stereoLine"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::stereoLineMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::stereoLineMessCallback), 
 		  gensym("stereoline"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::borderMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::borderMessCallback), 
 		  gensym("border"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::frameMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::frameMessCallback),
 		  gensym("frame"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::fpsMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::fpsMessCallback),
 		  gensym("fps"), A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::topmostMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::topmostMessCallback),
 		  gensym("topmost"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&gemwin::fsaaMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&gemwin::fsaaMessCallback),
 		  gensym("FSAA"), A_FLOAT, A_NULL);
 }
 void gemwin :: printMessCallback(void *)
@@ -525,11 +525,11 @@ void gemwin :: printMessCallback(void *)
 }
 void gemwin :: profileMessCallback(void *, t_floatarg state)
 {
-  GemMan::m_profile = (int)state;
+  GemMan::m_profile = static_cast<int>(state);
 }
 void gemwin :: lightingMessCallback(void *, t_floatarg state)
 {
-  GemMan::lightingOnOff((int)state);
+  GemMan::lightingOnOff(static_cast<int>(state));
 }
 void gemwin :: fogMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
 {
@@ -555,7 +555,7 @@ void gemwin :: fogColorMessCallback(void *data, t_symbol*s,int argc, t_atom*argv
     red=  atom_getfloat(argv);
     green=atom_getfloat(argv+1);
     blue= atom_getfloat(argv+2);
-    GetMyClass(data)->fogColorMess((float)red, (float)green, (float)blue, (float)alpha);
+    GetMyClass(data)->fogColorMess(static_cast<float>(red), static_cast<float>(green), static_cast<float>(blue), static_cast<float>(alpha));
     break;
   default:
     GetMyClass(data)->error("\"fogcolor\" expects 3 or 4 values");
@@ -563,11 +563,11 @@ void gemwin :: fogColorMessCallback(void *data, t_symbol*s,int argc, t_atom*argv
 }
 void gemwin :: fogModeMessCallback(void *data, t_float val)
 {
-  GetMyClass(data)->fogModeMess((int)val);
+  GetMyClass(data)->fogModeMess(static_cast<int>(val));
 }
 void gemwin :: stereoMessCallback(void *data, t_floatarg state)
 {
-  int mode = (int)state;
+  int mode = static_cast<int>(state);
   if (mode<0 || mode>3){
     GetMyClass(data)->error("possible stereo-modes are: 0, 1, 2, 3");
     return;
@@ -589,7 +589,7 @@ void gemwin :: stereoLineMessCallback(void *, t_floatarg state)
 }
 void gemwin :: borderMessCallback(void *, t_floatarg state)
 {
-  GemMan::m_border = (int)state;
+  GemMan::m_border = static_cast<int>(state);
 }
 void gemwin :: destroyMessCallback(void *)
 {
@@ -601,7 +601,7 @@ void gemwin :: resetMessCallback(void *)
 }
 void gemwin :: frameMessCallback(void *, t_floatarg rate)
 {
-  GemMan::frameRate((float)rate);
+  GemMan::frameRate(static_cast<float>(rate));
 }
 void gemwin :: perspectiveMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
 {
@@ -645,17 +645,17 @@ void gemwin :: viewMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
       break;
 
     case 5 :
-      theta	= (float)DEG2RAD * atom_getfloat(&argv[4]);
+      theta	= static_cast<float>(DEG2RAD) * atom_getfloat(&argv[4]);
 		
     case 4 :
-      azimuth = (float)DEG2RAD * atom_getfloat(&argv[3]);
+      azimuth = static_cast<float>(DEG2RAD) * atom_getfloat(&argv[3]);
 		
       // just have position
     case 3 :
       {
-	const float dx =  (float)(cos(theta) * sinf(azimuth));
-	const float dy =  (float)(sin(theta));
-	const float dz = -(float)(cos(theta) * cosf(azimuth));
+	const float dx =  static_cast<float>(cos(theta) * sinf(azimuth));
+	const float dy =  static_cast<float>(sin(theta));
+	const float dz = -static_cast<float>(cos(theta) * cosf(azimuth));
 
 	GemMan::m_lookat[0] = atom_getfloat(&argv[0]);		// eyex
 	GemMan::m_lookat[1] = atom_getfloat(&argv[1]);		// eyey
@@ -682,7 +682,7 @@ void gemwin :: bangMessCallback(void *data)
 }
 void gemwin :: floatMessCallback(void *data, t_float state)
 {
-  GetMyClass(data)->intMess((int)state);
+  GetMyClass(data)->intMess(static_cast<int>(state));
 }
 void gemwin :: renderMessCallback(void *data)
 {
@@ -704,27 +704,27 @@ void gemwin :: createStereoMessCallback(void *data)
 }
 void gemwin :: bufferMessCallback(void *data, t_floatarg buf)
 {
-  GetMyClass(data)->bufferMess((int)buf);
+  GetMyClass(data)->bufferMess(static_cast<int>(buf));
 }
 void gemwin :: fullscreenMessCallback(void *data, t_floatarg on)
 {
-  GetMyClass(data)->fullscreenMess((int)on);
+  GetMyClass(data)->fullscreenMess(static_cast<int>(on));
 }
 void gemwin :: menuBarMessCallback(void *data, t_floatarg on)
 {
-  GetMyClass(data)->menuBarMess((int)on);
+  GetMyClass(data)->menuBarMess(static_cast<int>(on));
 }
 void gemwin :: secondscreenMessCallback(void *data, t_floatarg on)
 {
-  GetMyClass(data)->secondscreenMess((int)on);
+  GetMyClass(data)->secondscreenMess(static_cast<int>(on));
 }
 void gemwin :: dimensionsMessCallback(void *data, t_floatarg width, t_floatarg height)
 {
-  GetMyClass(data)->dimensionsMess((int)width, (int)height);
+  GetMyClass(data)->dimensionsMess(static_cast<int>(width), static_cast<int>(height));
 }
 void gemwin :: offsetMessCallback(void *data, t_floatarg x, t_floatarg y)
 {
-  GetMyClass(data)->offsetMess((int)x, (int)y);
+  GetMyClass(data)->offsetMess(static_cast<int>(x), static_cast<int>(y));
 }
 void gemwin :: colorMessCallback(void *data, t_symbol*s, int argc, t_atom*argv)
 {
@@ -736,7 +736,7 @@ void gemwin :: colorMessCallback(void *data, t_symbol*s, int argc, t_atom*argv)
     red=  atom_getfloat(argv);
     green=atom_getfloat(argv+1);
     blue= atom_getfloat(argv+2);
-    GetMyClass(data)->colorMess((float)red, (float)green, (float)blue, (float)alpha);
+    GetMyClass(data)->colorMess(static_cast<float>(red), static_cast<float>(green), static_cast<float>(blue), static_cast<float>(alpha));
     break;
   default:
     GetMyClass(data)->error("\"color\" expects 3 or 4 values");
@@ -744,7 +744,7 @@ void gemwin :: colorMessCallback(void *data, t_symbol*s, int argc, t_atom*argv)
 }
 void gemwin :: clearmaskMessCallback(void *data, t_floatarg bitmask)
 {
-  GetMyClass(data)->clearmaskMess((float)bitmask);
+  GetMyClass(data)->clearmaskMess(static_cast<float>(bitmask));
 }
 void gemwin :: ambientMessCallback(void *data, t_symbol*s,int argc, t_atom*argv)
 {
@@ -756,7 +756,7 @@ void gemwin :: ambientMessCallback(void *data, t_symbol*s,int argc, t_atom*argv)
     red=  atom_getfloat(argv);
     green=atom_getfloat(argv+1);
     blue= atom_getfloat(argv+2);
-    GetMyClass(data)->ambientMess((float)red, (float)green, (float)blue, (float)alpha);
+    GetMyClass(data)->ambientMess(static_cast<float>(red), static_cast<float>(green), static_cast<float>(blue), static_cast<float>(alpha));
     break;
   default:
     GetMyClass(data)->error("\"ambient\" expects 3 or 4 values");
@@ -772,7 +772,7 @@ void gemwin :: specularMessCallback(void *data, t_symbol*s,int argc, t_atom*argv
     red=  atom_getfloat(argv);
     green=atom_getfloat(argv+1);
     blue= atom_getfloat(argv+2);
-    GetMyClass(data)->specularMess((float)red, (float)green, (float)blue, (float)alpha);
+    GetMyClass(data)->specularMess(static_cast<float>(red), static_cast<float>(green), static_cast<float>(blue), static_cast<float>(alpha));
     break;
   default:
     GetMyClass(data)->error("\"specular\" expects 3 or 4 values");
@@ -780,19 +780,19 @@ void gemwin :: specularMessCallback(void *data, t_symbol*s,int argc, t_atom*argv
 }
 void gemwin :: shininessMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->shininessMess((float)val);
+  GetMyClass(data)->shininessMess(static_cast<float>(val));
 }
 void gemwin :: cursorMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->cursorMess((float)val);
+  GetMyClass(data)->cursorMess(static_cast<float>(val));
 }
 void gemwin :: topmostMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->topmostMess((float)val);
+  GetMyClass(data)->topmostMess(static_cast<float>(val));
 }
 void gemwin :: blurMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->blurMess((float)val);
+  GetMyClass(data)->blurMess(static_cast<float>(val));
 }
 void gemwin :: fpsMessCallback(void *data)
 {
@@ -801,6 +801,6 @@ void gemwin :: fpsMessCallback(void *data)
 
 void gemwin :: fsaaMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->fsaaMess((int) val);
+  GetMyClass(data)->fsaaMess(static_cast<int>(val));
 }
 
