@@ -5,15 +5,15 @@
   Interface for the window manager
 
   Copyright (c) 1997-200 Mark Danks.
-  Copyright (c) Gnther Geiger. geiger@epy.co.at
-  Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+  Copyright (c) Günther Geiger. geiger@epy.co.at
+  Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
   For information on usage and redistribution, and for a DISCLAIMER OF ALL
   WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
   -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_GEMWIN_H_
-#define INCLUDE_GEMWIN_H_
+#ifndef _INCLUDE__GEM_CONTROLS_GEMWIN_H_
+#define _INCLUDE__GEM_CONTROLS_GEMWIN_H_
 
 #include "Base/CPPExtern.h"
 
@@ -68,7 +68,7 @@
   -----------------------------------------------------------------*/
 class GEM_EXTERN gemwin : public CPPExtern
 {
-  CPPEXTERN_HEADER(gemwin, CPPExtern)
+  CPPEXTERN_HEADER(gemwin, CPPExtern);
     
     public:
     
