@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -17,9 +17,9 @@
 #include "colorSquare.h"
 #include <string.h>
 
-#include "Base/GemState.h"
+#include "Gem/State.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(colorSquare, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(colorSquare, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -61,30 +61,30 @@ void colorSquare :: renderShape(GemState *state)
 {
   if(m_drawType==GL_DEFAULT_GEM)m_drawType=GL_QUADS;
 
-  if (!state->lighting) glShadeModel(GL_SMOOTH);
+  if (!GemShape::m_lighting) glShadeModel(GL_SMOOTH);
 
   glNormal3f(0.0f, 0.0f, 1.0f);
-    if (state->texture && state->numTexCoords)
+    if (GemShape::m_texType && GemShape::m_texNum)
     {
         int curCoord = 0;
 
 	    glBegin(m_drawType);
-	    	glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	    	glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
             glColor3fv(m_color[0]);
                 glVertex3f(-m_size, -m_size, 0.0f);
 
-	        if (state->numTexCoords > 1) curCoord = 1;
-	    	glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	        if (GemShape::m_texNum > 1) curCoord = 1;
+	    	glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
             glColor3fv(m_color[1]);
                 glVertex3f( m_size, -m_size, 0.0f);
 
-	        if (state->numTexCoords > 2) curCoord = 2;
-	    	glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	        if (GemShape::m_texNum > 2) curCoord = 2;
+	    	glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
             glColor3fv(m_color[2]);
                 glVertex3f( m_size,  m_size, 0.0f);
 
-	        if (state->numTexCoords > 3) curCoord = 3;
-	    	glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	        if (GemShape::m_texNum > 3) curCoord = 3;
+	    	glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
             glColor3fv(m_color[3]);
                 glVertex3f(-m_size,  m_size, 0.0f);
 	    glEnd();
@@ -114,7 +114,7 @@ void colorSquare :: renderShape(GemState *state)
 /////////////////////////////////////////////////////////
 void colorSquare :: postrenderShape(GemState *state)
 {
-    if (!state->lighting) glShadeModel(GL_FLAT);
+    if (!GemShape::m_lighting) glShadeModel(GL_FLAT);
 }
 
 /////////////////////////////////////////////////////////
@@ -134,28 +134,28 @@ void colorSquare :: vertColorMess(int whichVert, float r, float g, float b)
 /////////////////////////////////////////////////////////
 void colorSquare :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&colorSquare::vert0MessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&colorSquare::vert0MessCallback),
     	    gensym("vert0"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&colorSquare::vert1MessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&colorSquare::vert1MessCallback),
     	    gensym("vert1"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&colorSquare::vert2MessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&colorSquare::vert2MessCallback),
     	    gensym("vert2"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&colorSquare::vert3MessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&colorSquare::vert3MessCallback),
     	    gensym("vert3"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
 }
 void colorSquare :: vert0MessCallback(void *data, t_floatarg r, t_floatarg g, t_floatarg b)
 {
-    GetMyClass(data)->vertColorMess(0, (float)r, (float)g, (float)b);
+    GetMyClass(data)->vertColorMess(0, r, g, b);
 }
 void colorSquare :: vert1MessCallback(void *data, t_floatarg r, t_floatarg g, t_floatarg b)
 {
-    GetMyClass(data)->vertColorMess(1, (float)r, (float)g, (float)b);
+    GetMyClass(data)->vertColorMess(1, r, g, b);
 }
 void colorSquare :: vert2MessCallback(void *data, t_floatarg r, t_floatarg g, t_floatarg b)
 {
-    GetMyClass(data)->vertColorMess(2, (float)r, (float)g, (float)b);
+    GetMyClass(data)->vertColorMess(2, r, g, b);
 }
 void colorSquare :: vert3MessCallback(void *data, t_floatarg r, t_floatarg g, t_floatarg b)
 {
-    GetMyClass(data)->vertColorMess(3, (float)r, (float)g, (float)b);
+    GetMyClass(data)->vertColorMess(3, r, g, b);
 }
