@@ -7,17 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "cube.h"
-#include "Base/GemState.h"
+#include "Gem/State.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(cube, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(cube, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -74,32 +74,32 @@ void cube :: renderShape(GemState *state)
 	        }
 	    glLineWidth(1.0);
     }
-	else if (state->texture && state->numTexCoords)
+	else if (GemShape::m_texType && GemShape::m_texNum)
     {
 	    glBegin(m_drawType);
 	        for (int i = 0; i < 6; i++)
 	        {
 				int curCoord = 0;
 	            glNormal3fv(&n[i][0]);
-				glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+				glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
 //    	        glTexCoord2f(0.0, 0.0);
 		        glVertex3f(v[faces[i][0]][0] * m_size, v[faces[i][0]][1] * m_size, v[faces[i][0]][2] * m_size);
 				
-				if (state->numTexCoords > 1)
+				if (GemShape::m_texNum > 1)
 					curCoord = 1;
-	    		glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	    		glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
 //    	        glTexCoord2f(1.0, 0.0);
 		        glVertex3f(v[faces[i][1]][0] * m_size, v[faces[i][1]][1] * m_size, v[faces[i][1]][2] * m_size);
 				
-				if (state->numTexCoords > 2)
+				if (GemShape::m_texNum > 2)
 					curCoord = 2;
-	    		glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	    		glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
 //    	        glTexCoord2f(1.0, 1.0);
 		        glVertex3f(v[faces[i][2]][0] * m_size, v[faces[i][2]][1] * m_size, v[faces[i][2]][2] * m_size);
 				
-				if (state->numTexCoords > 3)
+				if (GemShape::m_texNum > 3)
 					curCoord = 3;
-				glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+				glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
 //    	        glTexCoord2f(0.0, 1.0);
 		        glVertex3f(v[faces[i][3]][0] * m_size, v[faces[i][3]][1] * m_size, v[faces[i][3]][2] * m_size);
 	        }
