@@ -19,11 +19,10 @@
 ////////////////////////////////////////////////////////
 
 #include "cuboid.h"
-#ifdef __APPLE__
+#include "Gem/State.h"
 #include "string.h"
-#endif
 
-CPPEXTERN_NEW_WITH_THREE_ARGS(cuboid, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT )
+CPPEXTERN_NEW_WITH_THREE_ARGS(cuboid, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT );
 
 /////////////////////////////////////////////////////////
 //
@@ -92,32 +91,32 @@ void cuboid :: renderShape(GemState *state)
 	        }
 	    glLineWidth(1.0);
     }
-	else if (state->texture && state->numTexCoords)
+	else if (GemShape::m_texType && GemShape::m_texNum)
     {
 	    glBegin(m_drawType);
 	        for (int i = 0; i < 6; i++)
 	        {
 				int curCoord = 0;
 	            glNormal3fv(&n[i][0]);
-				glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+				glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
 //    	        glTexCoord2f(0.0, 0.0);
 		        glVertex3f(v[faces[i][0]][0] * m_size, v[faces[i][0]][1] * m_sizey, v[faces[i][0]][2] * m_sizez);
 				
-				if (state->numTexCoords > 1)
+				if (GemShape::m_texNum > 1)
 					curCoord = 1;
-	    		glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	    		glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
 //    	        glTexCoord2f(1.0, 0.0);
 		        glVertex3f(v[faces[i][1]][0] * m_size, v[faces[i][1]][1] * m_sizey, v[faces[i][1]][2] * m_sizez);
 				
-				if (state->numTexCoords > 2)
+				if (GemShape::m_texNum > 2)
 					curCoord = 2;
-	    		glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	    		glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
 //    	        glTexCoord2f(1.0, 1.0);
 		        glVertex3f(v[faces[i][2]][0] * m_size, v[faces[i][2]][1] * m_sizey, v[faces[i][2]][2] * m_sizez);
 				
-				if (state->numTexCoords > 3)
+				if (GemShape::m_texNum > 3)
 					curCoord = 3;
-				glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+				glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
 //    	        glTexCoord2f(0.0, 1.0);
 		        glVertex3f(v[faces[i][3]][0] * m_size, v[faces[i][3]][1] * m_sizey, v[faces[i][3]][2] * m_sizez);
 	        }
@@ -166,18 +165,18 @@ void cuboid :: widthMess(float sizez)
 /////////////////////////////////////////////////////////
 void cuboid :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&cuboid::heightMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&cuboid::heightMessCallback),
     	    gensym("ft2"), A_FLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&cuboid::widthMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&cuboid::widthMessCallback),
 	    gensym("ft3"), A_FLOAT, A_NULL);
 }
 
 void cuboid :: heightMessCallback(void *data, t_floatarg size)
 {
-    GetMyClass(data)->heightMess((float)size);  
+    GetMyClass(data)->heightMess(size);  
 }
 
 void cuboid :: widthMessCallback(void *data, t_floatarg size)
 {
-    GetMyClass(data)->widthMess((float)size);  
+    GetMyClass(data)->widthMess(size);  
 }
