@@ -5,15 +5,15 @@ LOG
     A curve3d
 
     Copyright (c) 1997-1998 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
     -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_curve3d_H_
-#define INCLUDE_curve3d_H_
+#ifndef _INCLUDE__GEM_GEOS_CURVE_D_H_
+#define _INCLUDE__GEM_GEOS_CURVE_D_H_
 
 #include "Base/GemShape.h"
 
@@ -34,7 +34,7 @@ LOG
 
 class GEM_EXTERN curve3d : public GemShape
 {
-  CPPEXTERN_HEADER(curve3d, GemShape)
+  CPPEXTERN_HEADER(curve3d, GemShape);
 
     public:
 
@@ -65,10 +65,12 @@ class GEM_EXTERN curve3d : public GemShape
   void gridMess(int gridX, int gridY);
   void setMess(int X,int Y,float posX, float posY,float posZ);
 
+  enum C3dDrawType{LINE, FILL, POINT, LINE1, LINE2, LINE3, LINE4, 
+	CONTROL_FILL, CONTROL_POINT, CONTROL_LINE, CONTROL_LINE1, CONTROL_LINE2} 
+  m_drawType;
+
   virtual void	typeMess(t_symbol *type);
  
-  GLenum	    	m_drawType;
-		
   t_float3		*m_posXYZ; // attention, valeur critique
 
  private:
