@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "cylinder.h"
+#include "Gem/State.h"
 
-CPPEXTERN_NEW_WITH_TWO_ARGS(cylinder, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS(cylinder, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 #define normal3f glNormal3f
 
@@ -28,18 +29,23 @@ CPPEXTERN_NEW_WITH_TWO_ARGS(cylinder, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFF
 // Constructor
 //
 /////////////////////////////////////////////////////////
-cylinder :: cylinder(t_floatarg size,t_floatarg slize)
-  : GemGluObj(size,slize)
+  cylinder :: cylinder(t_floatarg size,t_floatarg slize)
+    : GemGluObj(size,slize),
+      baseRadius(size),
+      topRadius(size),
+      height(size*2),
+      slices(slize),
+      stacks(slize)
 { }
 
-/////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////
 // Destructor
 //
 /////////////////////////////////////////////////////////
 cylinder :: ~cylinder()
 { }
 
-/////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////
 // render
 //
 /////////////////////////////////////////////////////////
@@ -58,16 +64,26 @@ void cylinder :: render(GemState *state)
   GLdouble da, r, dr, dz;
   GLfloat x, y, z, nz;
   GLint i, j;
-  GLboolean orientation = true; /* INSIDE */
+  GLboolean orientation = false; /* true=INSIDE */
   GLfloat nsign = (orientation)?-1.0:1.0;
 
+  TexCoord*texCoords=NULL;
+  int texType=0;
+  int texNum=0;
+  bool lighting=false;
+  state->get(GemState::_GL_TEX_COORDS, texCoords);
+  state->get(GemState::_GL_TEX_TYPE, texType);
+  state->get(GemState::_GL_TEX_NUMCOORDS, texNum);
+  state->get(GemState::_GL_LIGHTING, lighting);
+
+
   GLfloat xsize = 1.0, xsize0 = 0.0;
   GLfloat ysize = 1.0, ysize0 = 0.0;
-  if(state->texture && state->numTexCoords>=3){
-    xsize0 = state->texCoords[0].s;
-    xsize  = state->texCoords[1].s-xsize0;
-    ysize0 = state->texCoords[1].t;
-    ysize  = state->texCoords[2].t-ysize0;
+  if(texType && texNum>=3){
+    xsize0 = texCoords[0].s;
+    xsize  = texCoords[1].s-xsize0;
+    ysize0 = texCoords[1].t;
+    ysize  = texCoords[2].t-ysize0;
   }
     
   glPushMatrix();
@@ -89,9 +105,9 @@ void cylinder :: render(GemState *state)
       z = 0.0;
       r = baseRadius;
       for (j = 0; j <= stacks; j++) {
-	glVertex3f(x * r, y * r, z);
-	z += dz;
-	r += dr;
+        glVertex3f(x * r, y * r, z);
+        z += dz;
+        r += dr;
       }
     }
     glEnd();
@@ -102,37 +118,37 @@ void cylinder :: render(GemState *state)
       z = 0.0;
       r = baseRadius;
       for (j = 0; j <= stacks; j++) {
-	glBegin(GL_LINE_LOOP);
-	for (i = 0; i < slices; i++) {
-	  x = cos(i * da);
-	  y = sin(i * da);
-	  normal3f(x * nsign, y * nsign, nz * nsign);
-	  glVertex3f(x * r, y * r, z);
-	}
-	glEnd();
-	z += dz;
-	r += dr;
+        glBegin(GL_LINE_LOOP);
+        for (i = 0; i < slices; i++) {
+          x = cos(i * da);
+          y = sin(i * da);
+          normal3f(x * nsign, y * nsign, nz * nsign);
+          glVertex3f(x * r, y * r, z);
+        }
+        glEnd();
+        z += dz;
+        r += dr;
       }
     }
     else {
       /* draw one ring at each end */
       if (baseRadius != 0.0) {
-	glBegin(GL_LINE_LOOP);
-	for (i = 0; i < slices; i++) {
-	  x = cos(i * da);
-	  y = sin(i * da);
-	  normal3f(x * nsign, y * nsign, nz * nsign);
-	  glVertex3f(x * baseRadius, y * baseRadius, 0.0);
-	}
-	glEnd();
-	glBegin(GL_LINE_LOOP);
-	for (i = 0; i < slices; i++) {
-	  x = cos(i * da);
-	  y = sin(i * da);
-	  normal3f(x * nsign, y * nsign, nz * nsign);
-	  glVertex3f(x * topRadius, y * topRadius, height);
-	}
-	glEnd();
+        glBegin(GL_LINE_LOOP);
+        for (i = 0; i < slices; i++) {
+          x = cos(i * da);
+          y = sin(i * da);
+          normal3f(x * nsign, y * nsign, nz * nsign);
+          glVertex3f(x * baseRadius, y * baseRadius, 0.0);
+        }
+        glEnd();
+        glBegin(GL_LINE_LOOP);
+        for (i = 0; i < slices; i++) {
+          x = cos(i * da);
+          y = sin(i * da);
+          normal3f(x * nsign, y * nsign, nz * nsign);
+          glVertex3f(x * topRadius, y * topRadius, height);
+        }
+        glEnd();
       }
     }
     /* draw length lines */
@@ -156,32 +172,32 @@ void cylinder :: render(GemState *state)
       GLfloat s = 0.0;
       glBegin(GL_QUAD_STRIP);
       for (i = 0; i <= slices; i++) {
-	GLfloat x, y;
-	if (i == slices) {
-	  x = sin(0.0);
-	  y = cos(0.0);
-	}
-	else {
-	  x = sin(i * da);
-	  y = cos(i * da);
-	}
-	if (nsign == 1.0) {
-	  normal3f(x * nsign, y * nsign, nz * nsign);
-	  if(state->texture)glTexCoord2f(s*xsize+xsize0, t*ysize+ysize0);
-	  glVertex3f(x * r, y * r, z);
-	  normal3f(x * nsign, y * nsign, nz * nsign);
-	  if(state->texture)glTexCoord2f(s*xsize+xsize0, (t + dt)*ysize+ysize0);
-	  glVertex3f(x * (r + dr), y * (r + dr), z + dz);
-	}
-	else {
-	  normal3f(x * nsign, y * nsign, nz * nsign);
-	  if(state->texture)glTexCoord2f(s*xsize+xsize0, t*ysize+ysize0);
-	  glVertex3f(x * r, y * r, z);
-	  normal3f(x * nsign, y * nsign, nz * nsign);
-	  if(state->texture)glTexCoord2f(s*xsize+xsize0, (t + dt)*ysize+ysize0);
-	  glVertex3f(x * (r + dr), y * (r + dr), z + dz);
-	}
-	s += ds;
+        GLfloat x, y;
+        if (i == slices) {
+          x = sin(0.0);
+          y = cos(0.0);
+        }
+        else {
+          x = sin(i * da);
+          y = cos(i * da);
+        }
+        if (nsign == 1.0) {
+          normal3f(x * nsign, y * nsign, nz * nsign);
+          if(texType)glTexCoord2f(s*xsize+xsize0, t*ysize+ysize0);
+          glVertex3f(x * r, y * r, z);
+          normal3f(x * nsign, y * nsign, nz * nsign);
+          if(texType)glTexCoord2f(s*xsize+xsize0, (t + dt)*ysize+ysize0);
+          glVertex3f(x * (r + dr), y * (r + dr), z + dz);
+        }
+        else {
+          normal3f(x * nsign, y * nsign, nz * nsign);
+          if(texType)glTexCoord2f(s*xsize+xsize0, t*ysize+ysize0);
+          glVertex3f(x * r, y * r, z);
+          normal3f(x * nsign, y * nsign, nz * nsign);
+          if(texType)glTexCoord2f(s*xsize+xsize0, (t + dt)*ysize+ysize0);
+          glVertex3f(x * (r + dr), y * (r + dr), z + dz);
+        }
+        s += ds;
       }			/* for slices */
       glEnd();
       r += dr;
