@@ -7,22 +7,24 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 /////////////////////////////////////////////////////////
-// 2105:forum::fr::umlute:2000
+// 2105:forum::für::umläute:2000
 /////////////////////////////////////////////////////////
 // added the gluPartialDisk
 /////////////////////////////////////////////////////////
 
 #include "disk.h"
+#include "Gem/State.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(disk)
+CPPEXTERN_NEW_WITH_GIMME(disk);
 
 /////////////////////////////////////////////////////////
 //
@@ -42,12 +44,12 @@ disk :: disk(int argc, t_atom *argv)
   switch(argc){
   case 3:
     size = atom_getfloat(&argv[0]);
-    numSlices = (int)atom_getfloat(&argv[1]);
+    numSlices = atom_getint(&argv[1]);
     m_innerRadius = atom_getfloat(&argv[2]);
     break;
   case 2:
     size = atom_getfloat(&argv[0]);
-    numSlices = (int)atom_getfloat(&argv[1]);
+    numSlices = atom_getint(&argv[1]);
     break;
   case 1:
     size = atom_getfloat(&argv[0]);
@@ -90,15 +92,26 @@ void disk :: render(GemState *state)
   GLfloat da, dr;
 
   GLenum orientation = true; /* GLU_INSIDE; */
-  GLboolean normals = (state->lighting);
+
+  TexCoord*texCoords=NULL;
+  int texType=0;
+  int texNum=0;
+  bool lighting=false;
+  state->get(GemState::_GL_TEX_COORDS, texCoords);
+  state->get(GemState::_GL_TEX_TYPE, texType);
+  state->get(GemState::_GL_TEX_NUMCOORDS, texNum);
+  state->get(GemState::_GL_LIGHTING, lighting);
+
+
+  GLboolean normals = (lighting);
 
   GLfloat xsize = 1.0, xsize0 = 0.0;
   GLfloat ysize = 1.0, ysize0 = 0.0;
-  if(state->texture && state->numTexCoords>=3){
-      xsize0 = state->texCoords[0].s;
-      xsize  = state->texCoords[1].s-xsize0;
-      ysize0 = state->texCoords[1].t;
-      ysize  = state->texCoords[2].t-ysize0;
+  if(texType && texNum>=3){
+      xsize0 = texCoords[0].s;
+      xsize  = texCoords[1].s-xsize0;
+      ysize0 = texCoords[1].t;
+      ysize  = texCoords[2].t-ysize0;
   }
 
   //gluDisk(m_thing, m_innerRadius, m_size, m_numSlices, m_numSlices);
@@ -112,7 +125,7 @@ void disk :: render(GemState *state)
   }
 
   da = 2.0 * M_PI / m_numSlices;
-  dr = (m_size - m_innerRadius) / (GLfloat) loops;
+  dr = (m_size - m_innerRadius) / static_cast<GLfloat>(loops);
 
   GLfloat dtc = 2.0f * m_size;
   GLfloat sa, ca;
@@ -136,9 +149,9 @@ void disk :: render(GemState *state)
 	    GLfloat a=(s == m_numSlices)?0.0:(s * da);
 	    sa = sin(a);
 	    ca = cos(a);
-	    if(state->texture)glTexCoord2f((0.5 + sa * r2 / dtc)*xsize+xsize0, (0.5 + ca * r2 / dtc)*ysize+ysize0);
+	    if(texType)glTexCoord2f((0.5 + sa * r2 / dtc)*xsize+xsize0, (0.5 + ca * r2 / dtc)*ysize+ysize0);
 	    glVertex2f(r2 * sa, r2 * ca);
-	    if(state->texture)glTexCoord2f((0.5 + sa * r1 / dtc)*xsize+xsize0, (0.5 + ca * r1 / dtc)*ysize+ysize0);
+	    if(texType)glTexCoord2f((0.5 + sa * r1 / dtc)*xsize+xsize0, (0.5 + ca * r1 / dtc)*ysize+ysize0);
 	    glVertex2f(r1 * sa, r1 * ca);
 	  }
 	  glEnd();
@@ -149,9 +162,9 @@ void disk :: render(GemState *state)
 	    GLfloat a=(s==m_numSlices)?0.0:s * da;
 	    sa = sin(a);
 	    ca = cos(a);
-	    if(state->texture)glTexCoord2f((0.5 - sa * r2 / dtc)*xsize+xsize0, (0.5 + ca * r2 / dtc)*ysize+ysize0);
+	    if(texType)glTexCoord2f((0.5 - sa * r2 / dtc)*xsize+xsize0, (0.5 + ca * r2 / dtc)*ysize+ysize0);
 	    glVertex2f(r2 * sa, r2 * ca);
-	    if(state->texture)glTexCoord2f((0.5 - sa * r1 / dtc)*xsize+xsize0, (0.5 + ca * r1 / dtc)*ysize+ysize0);
+	    if(texType)glTexCoord2f((0.5 - sa * r1 / dtc)*xsize+xsize0, (0.5 + ca * r1 / dtc)*ysize+ysize0);
 	    glVertex2f(r1 * sa, r1 * ca);
 	  }
 	  glEnd();
@@ -169,7 +182,7 @@ void disk :: render(GemState *state)
 	glBegin(GL_LINE_LOOP);
 	for (s = 0; s < m_numSlices; s++) {
 	  GLfloat a = s * da;
-	  if(state->texture)glTexCoord2f((0.5+r*sin(a)/dtc)*xsize+xsize0, (0.5+r*cos(a)/dtc)*ysize+ysize0);
+	  if(texType)glTexCoord2f((0.5+r*sin(a)/dtc)*xsize+xsize0, (0.5+r*cos(a)/dtc)*ysize+ysize0);
 	  glVertex2f(r * sin(a), r * cos(a));
 	}
 	glEnd();
@@ -182,7 +195,7 @@ void disk :: render(GemState *state)
 	glBegin(GL_LINE_STRIP);
 	for (l = 0; l <= loops; l++) {
 	  GLfloat r = m_innerRadius + l * dr;
-	  if(state->texture)glTexCoord2f((0.5+r*x/dtc)*xsize+xsize0, (0.5+r*y/dtc)*ysize+ysize0);
+	  if(texType)glTexCoord2f((0.5+r*x/dtc)*xsize+xsize0, (0.5+r*y/dtc)*ysize+ysize0);
 	  glVertex2f(r * x, r * y);
 	}
 	glEnd();
@@ -201,7 +214,7 @@ void disk :: render(GemState *state)
 	for (l = 0; l <= loops; l++) {
 	  GLfloat r = m_innerRadius * l * dr;
 	  glVertex2f(r * x, r * y);
-	  if(state->texture)glTexCoord2f((0.5+r*x/dtc)*xsize+xsize0, (0.5+r*y/dtc)*ysize+ysize0);
+	  if(texType)glTexCoord2f((0.5+r*x/dtc)*xsize+xsize0, (0.5+r*y/dtc)*ysize+ysize0);
 	}
       }
       glEnd();
@@ -240,7 +253,7 @@ void disk :: render(GemState *state)
 /////////////////////////////////////////////////////////
 void disk :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&disk::innerRadiusCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&disk::innerRadiusCallback),
     	    gensym("inner"), A_FLOAT, A_NULL); 
 }
 void disk :: innerRadiusCallback(void *data, t_floatarg radius)
