@@ -7,19 +7,25 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
+#ifdef __GNUC__
+# warning LATER fix upsidedown
+// LATER think about textures without images (or not: use GLSL for that)
+#endif
+
 #include "imageVert.h"
+#include "Gem/State.h"
 
-CPPEXTERN_NEW(imageVert)
+CPPEXTERN_NEW(imageVert);
 
-  /////////////////////////////////////////////////////////
+/////////////////////////////////////////////////////////
 //
 // imageVert
 //
@@ -107,7 +113,7 @@ void imageVert :: processRGBAPix(imageStruct &image, int texture)
     while(yCount--) {
       int xCount = xSize;
       float xCurrent = -.5f;
-    	    
+
       glBegin(GL_QUAD_STRIP);
       while(xCount--) {
 	unsigned char *oneDown = data - yStride;
@@ -314,10 +320,18 @@ void imageVert :: processYUVPix(imageStruct &image, int texture)
 /////////////////////////////////////////////////////////
 void imageVert :: render(GemState *state)
 {
-  // always want to render
-  if (!state->image) return;
+  pixBlock*img=NULL;
+  int texType=0;
+  bool dl = false;
 
-  if (state->image->newimage) m_rebuildList = 1;
+  state->get(GemState::_PIX, img);
+  state->get(GemState::_GL_TEX_TYPE, texType);
+  state->get(GemState::_GL_DISPLAYLIST, dl);
+
+  // always want to render
+  if (!img) return;
+
+  if (img->newimage) m_rebuildList = 1;
 
   if (!m_dispList){
     m_dispList=glGenLists(1);
@@ -325,22 +339,22 @@ void imageVert :: render(GemState *state)
   }
 
   // can we build a display list?
-  if (!state->inDisplayList && m_rebuildList)
+  if (!dl && m_rebuildList)
     {
       glNewList(m_dispList, GL_COMPILE_AND_EXECUTE);
-      if (state->image->image.format == GL_RGBA || state->image->image.format == GL_BGRA_EXT)	//tigital
-	processRGBAPix(state->image->image, state->texture);
+      if (img->image.format == GL_RGBA || img->image.format == GL_BGRA_EXT)	//tigital
+	processRGBAPix(img->image, texType);
       else
-	processGrayPix(state->image->image, state->texture);
+	processGrayPix(img->image, texType);
       glEndList();
       m_rebuildList = 0;
     }
   // nope, but our current one isn't valid
   else if (m_rebuildList) {
-    if (state->image->image.format == GL_RGBA || state->image->image.format == GL_BGRA_EXT)	//tigital
-      processRGBAPix(state->image->image, state->texture);
+    if (img->image.format == GL_RGBA || img->image.format == GL_BGRA_EXT)	//tigital
+      processRGBAPix(img->image, texType);
     else
-      processGrayPix(state->image->image, state->texture);
+      processGrayPix(img->image, texType);
   }
   // the display list has already been built
   else glCallList(m_dispList);
