@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "model.h"
- 
-CPPEXTERN_NEW_WITH_ONE_ARG(model, t_symbol *, A_DEFSYM)
+ #include "Gem/State.h"
+
+CPPEXTERN_NEW_WITH_ONE_ARG(model, t_symbol *, A_DEFSYM);
 
   /////////////////////////////////////////////////////////
 //
@@ -60,6 +61,11 @@ void model :: cleanModel()
       glDeleteLists(m_dispList, 1);
       m_dispList = 0;
     }
+  if(m_model) {
+    glmDelete(m_model);
+    m_model=NULL;
+  }
+
 }
 
 /////////////////////////////////////////////////////////
@@ -155,7 +161,7 @@ void model :: openMess(t_symbol *filename)
   cleanModel();
     
   char buf[MAXPDSTRING];
-  canvas_makefilename(getCanvas(), filename->s_name, buf, MAXPDSTRING);
+  canvas_makefilename(const_cast<t_canvas*>(getCanvas()), filename->s_name, buf, MAXPDSTRING);
   // read the object in
   m_model = glmReadOBJ(buf);
   if (!m_model){
@@ -235,19 +241,19 @@ void model :: startRendering()
 /////////////////////////////////////////////////////////
 void model :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&model::openMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&model::openMessCallback),
 		  gensym("open"), A_SYMBOL, A_NULL);
-  class_addmethod(classPtr, (t_method)&model::rescaleMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&model::rescaleMessCallback),
 		  gensym("rescale"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&model::smoothMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&model::smoothMessCallback),
 		  gensym("smooth"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&model::reverseMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&model::reverseMessCallback),
 		  gensym("revert"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&model::materialMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&model::materialMessCallback),
 		  gensym("material"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&model::textureMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&model::textureMessCallback),
 		  gensym("texture"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&model::groupMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&model::groupMessCallback),
 		  gensym("group"), A_FLOAT, A_NULL);
 
 }
@@ -257,7 +263,7 @@ void model :: openMessCallback(void *data, t_symbol *filename)
 }
 void model :: rescaleMessCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->rescaleMess((int)state);
+  GetMyClass(data)->rescaleMess(static_cast<int>(state));
 }
 void model :: smoothMessCallback(void *data, t_floatarg smooth)
 {
@@ -265,18 +271,18 @@ void model :: smoothMessCallback(void *data, t_floatarg smooth)
 }
 void model :: reverseMessCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->reverseMess((int)state);
+  GetMyClass(data)->reverseMess(static_cast<int>(state));
 }
 void model :: textureMessCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->textureMess((int)state);
+  GetMyClass(data)->textureMess(static_cast<int>(state));
 }
 void model :: materialMessCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->materialMess((int)state);
+  GetMyClass(data)->materialMess(static_cast<int>(state));
 }
 
 void model :: groupMessCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->groupMess((int)state);
+  GetMyClass(data)->groupMess(static_cast<int>(state));
 }
