@@ -5,15 +5,15 @@ LOG
     read in a model file
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_MODEL_H_
-#define INCLUDE_MODEL_H_
+#ifndef _INCLUDE__GEM_GEOS_MODEL_H_
+#define _INCLUDE__GEM_GEOS_MODEL_H_
 
 #include "Base/GemBase.h"
 #include "model_loader.h"
@@ -34,7 +34,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN model : public GemBase
 {
-    CPPEXTERN_HEADER(model, GemBase)
+    CPPEXTERN_HEADER(model, GemBase);
 
     public:
 
