@@ -83,7 +83,7 @@ _glmNormalize(GLfloat* v)
 
   if (!(v))return;
 
-  l = (GLfloat)sqrt(v[0]*v[0] + v[1]*v[1] + v[2]*v[2]);
+  l = static_cast<GLfloat>(sqrt(v[0]*v[0] + v[1]*v[1] + v[2]*v[2]));
   v[0] /= l;
   v[1] /= l;
   v[2] /= l;
@@ -144,7 +144,7 @@ _glmWeldVectors(GLfloat* vectors, GLuint* numvectors, GLfloat epsilon)
   duplicate:
     /* set the first component of this vector to point at the correct
        index into the new copies array */
-    vectors[3 * i + 0] = (GLfloat)j;
+    vectors[3 * i + 0] = static_cast<GLfloat>(j);
   }
 
   *numvectors = copied-1;
@@ -270,16 +270,22 @@ _glmReadMTL(GLMmodel* model, char* name)
     switch(buf[0]) {
     case '#':               /* comment */
       /* eat up rest of line */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        verbose(1, "_glmReadMTL() failed reading comment"); continue;
+      }
       break;
     case 'n':               /* newmtl */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        error("_glmReadMTL() failed reading new material"); goto mtlread_failed;
+      }
       nummaterials++;
       sscanf(buf, "%s %s", buf, buf);
       break;
     default:
       /* eat up rest of line */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        verbose(1, "_glmReadMTL() failed reading"); continue;
+      }
       break;
     }
   }
@@ -314,10 +320,14 @@ _glmReadMTL(GLMmodel* model, char* name)
     switch(buf[0]) {
     case '#':               /* comment */
       /* eat up rest of line */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        verbose(1, "_glmReadMTL() really failed reading comment"); continue;
+      }
       break;
     case 'n':               /* newmtl */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        error("_glmReadMTL() really failed reading new material"); goto mtlread_failed;
+      }
       sscanf(buf, "%s %s", buf, buf);
       nummaterials++;
       model->materials[nummaterials].name = strdup(buf);
@@ -350,17 +360,24 @@ _glmReadMTL(GLMmodel* model, char* name)
         break;
       default:
         /* eat up rest of line */
-        fgets(buf, sizeof(buf), file);
+        if(NULL==fgets(buf, sizeof(buf), file)) {
+          verbose(1, "_glmReadMTL() really failed reading K"); continue;
+        }
         break;
       }
       break;
     default:
       /* eat up rest of line */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        verbose(1, "_glmReadMTL() really failed reading"); continue;
+      }
       break;
     }
   }
   return 0;
+ mtlread_failed:
+  if(file)fclose(file);
+  return -1;
 }
 
 /* glmWriteMTL: write a wavefront material library file
@@ -369,7 +386,7 @@ _glmReadMTL(GLMmodel* model, char* name)
  * modelpath  - pathname of the model being written
  * mtllibname - name of the material library to be written
  */
-static GLint
+static GLboolean
 _glmWriteMTL(GLMmodel* model, char* modelpath, char* mtllibname)
 {
   FILE* file;
@@ -388,7 +405,7 @@ _glmWriteMTL(GLMmodel* model, char* modelpath, char* mtllibname)
   file = fopen(filename, "w");
   if (!file) {
     error("_glmWriteMTL() failed: can't open file \"%s\".",filename);
-    return -1;
+    return GL_FALSE;
   }
   free(filename);
 
@@ -414,7 +431,7 @@ _glmWriteMTL(GLMmodel* model, char* modelpath, char* mtllibname)
     fprintf(file, "Ns %f\n", material->shininess / 128.0 * 1000.0);
     fprintf(file, "\n");
   }
-  return 0;
+  return GL_TRUE;
 }
 
 
@@ -424,7 +441,7 @@ _glmWriteMTL(GLMmodel* model, char* modelpath, char* mtllibname)
  * model - properly initialized GLMmodel structure
  * file  - (fopen'd) file descriptor
  */
-static GLint
+static GLboolean
 _glmFirstPass(GLMmodel* model, FILE* file)
 {
   GLuint  numvertices;        /* number of vertices in model */
@@ -443,23 +460,31 @@ _glmFirstPass(GLMmodel* model, FILE* file)
     switch(buf[0]) {
     case '#':               /* comment */
       /* eat up rest of line */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        verbose(1, "_glmFirstPass() failed reading comment"); continue;
+      }
       break;
     case 'v':               /* v, vn, vt */
       switch(buf[1]) {
       case '\0':          /* vertex */
         /* eat up rest of line */
-        fgets(buf, sizeof(buf), file);
+        if(NULL==fgets(buf, sizeof(buf), file)) {
+          error("_glmFirstPass() failed reading vertex"); return GL_FALSE;
+        }
         numvertices++;
         break;
       case 'n':           /* normal */
         /* eat up rest of line */
-        fgets(buf, sizeof(buf), file);
+        if(NULL==fgets(buf, sizeof(buf), file)) {
+          error("_glmFirstPass() failed reading normals"); return GL_FALSE;
+        }
         numnormals++;
         break;
       case 't':           /* texcoord */
         /* eat up rest of line */
-        fgets(buf, sizeof(buf), file);
+        if(NULL==fgets(buf, sizeof(buf), file)) {
+          error("_glmFirstPass() failed reading texcoords"); return GL_FALSE;
+        }
         numtexcoords++;
         break;
       default:
@@ -469,18 +494,24 @@ _glmFirstPass(GLMmodel* model, FILE* file)
       }
       break;
     case 'm':
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        error("_glmFirstPass() failed reading material"); return GL_FALSE;
+      }
       sscanf(buf, "%s %s", buf, buf);
       model->mtllibname = strdup(buf);
       _glmReadMTL(model, buf);
       break;
     case 'u':
       /* eat up rest of line */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        verbose(1, "_glmFirstPass() failed reading u"); continue;
+      }
       break;
     case 'g':               /* group */
       /* eat up rest of line */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        error("_glmFirstPass() failed reading groups"); return GL_FALSE;
+      }
 #if SINGLE_STRING_GROUP_NAMES
       sscanf(buf, "%s", buf);
 #else
@@ -538,7 +569,9 @@ _glmFirstPass(GLMmodel* model, FILE* file)
 
     default:
       /* eat up rest of line */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        verbose(1, "_glmFirstPass() failed reading"); continue;
+      }
       break;
     }
   }
@@ -556,7 +589,26 @@ _glmFirstPass(GLMmodel* model, FILE* file)
     group->numtriangles = 0;
     group = group->next;
   }
-  return 0;
+  return GL_TRUE;
+}
+
+static GLuint fixIndex(GLint current, GLuint baseindex) {
+  GLint idx=baseindex;
+
+  /* i'm not sure whether >=0 or >0 is valid...
+   * for now, i assume >0 (so if current==0 it resolves to baseindex)
+   */
+
+  if(current>0)
+    return (GLuint)(current);
+ 
+  idx=(baseindex+current);
+  if(idx>0)
+    return (GLuint)idx;
+  else {
+    verbose(1, "unable to fix negative index %d @ %d", current, baseindex);
+    return baseindex;
+  }
 }
 
 /* glmSecondPass: second pass at a Wavefront OBJ file that gets all
@@ -565,7 +617,7 @@ _glmFirstPass(GLMmodel* model, FILE* file)
  * model - properly initialized GLMmodel structure
  * file  - (fopen'd) file descriptor
  */
-static GLvoid
+static GLboolean
 _glmSecondPass(GLMmodel* model, FILE* file)
 {
   GLuint  numvertices;        /* number of vertices in model */
@@ -577,7 +629,7 @@ _glmSecondPass(GLMmodel* model, FILE* file)
   GLfloat*    texcoords;          /* array of texture coordinates */
   GLMgroup* group;            /* current group pointer */
   GLuint  material;           /* current material */
-  GLuint  v, n, t;
+  int  v, n, t;
   char        buf[128];
 
   /* set the pointer shortcuts */
@@ -595,7 +647,9 @@ _glmSecondPass(GLMmodel* model, FILE* file)
     switch(buf[0]) {
     case '#':               /* comment */
       /* eat up rest of line */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        verbose(1, "_glmSecondPass() failed reading"); continue;
+      }
       break;
     case 'v':               /* v, vn, vt */
       switch(buf[1]) {
@@ -622,13 +676,17 @@ _glmSecondPass(GLMmodel* model, FILE* file)
       }
       break;
     case 'u':
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        error("_glmSecondPass() failed reading material"); return GL_FALSE;
+      }
       sscanf(buf, "%s %s", buf, buf);
       group->material = material = _glmFindMaterial(model, buf);
       break;
     case 'g':               /* group */
       /* eat up rest of line */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        error("_glmSecondPass() failed reading group"); return GL_FALSE;
+      }
 #if SINGLE_STRING_GROUP_NAMES
       sscanf(buf, "%s", buf);
 #else
@@ -644,90 +702,90 @@ _glmSecondPass(GLMmodel* model, FILE* file)
          if (strstr(buf, "//")) {
            /* v//n */
              sscanf(buf, "%d//%d", &v, &n);
-           T(numtriangles).vindices[0] = v;
-           T(numtriangles).nindices[0] = n;
-           fscanf(file, "%d//%d", (int*)&v, (int*)&n);
-           T(numtriangles).vindices[1] = v;
-           T(numtriangles).nindices[1] = n;
-           fscanf(file, "%d//%d", (int*)&v, (int*)&n);
-           T(numtriangles).vindices[2] = v;
-           T(numtriangles).nindices[2] = n;
+           T(numtriangles).vindices[0] = fixIndex(v,numvertices);
+           T(numtriangles).nindices[0] = fixIndex(n,numnormals);
+           fscanf(file, "%d//%d", &v, &n);
+           T(numtriangles).vindices[1] = fixIndex(v,numvertices);
+           T(numtriangles).nindices[1] = fixIndex(n, numnormals);
+           fscanf(file, "%d//%d", &v, &n);
+           T(numtriangles).vindices[2] = fixIndex(v,numvertices);
+           T(numtriangles).nindices[2] = fixIndex(n, numnormals);
            group->triangles[group->numtriangles++] = numtriangles;
            numtriangles++;
-           while(fscanf(file, "%d//%d", (int*)&v, (int*)&n) > 0) {
+           while(fscanf(file, "%d//%d", &v, &n) > 0) {
              T(numtriangles).vindices[0] = T(numtriangles-1).vindices[0];
              T(numtriangles).nindices[0] = T(numtriangles-1).nindices[0];
              T(numtriangles).vindices[1] = T(numtriangles-1).vindices[2];
              T(numtriangles).nindices[1] = T(numtriangles-1).nindices[2];
-             T(numtriangles).vindices[2] = v;
-             T(numtriangles).nindices[2] = n;
+             T(numtriangles).vindices[2] = fixIndex(v,numvertices);
+             T(numtriangles).nindices[2] = fixIndex(n, numnormals);
              group->triangles[group->numtriangles++] = numtriangles;
              numtriangles++;
            }
          } else if (sscanf(buf, "%d/%d/%d", &v, &t, &n) == 3) {
            /* v/t/n */
-           T(numtriangles).vindices[0] = v;
-           T(numtriangles).uvtindices[0] = t;
-           T(numtriangles).nindices[0] = n;
-           fscanf(file, "%d/%d/%d", (int*)&v, (int*)&t, (int*)&n);
-           T(numtriangles).vindices[1] = v;
-           T(numtriangles).uvtindices[1] = t;
-           T(numtriangles).nindices[1] = n;
-           fscanf(file, "%d/%d/%d", (int*)&v, (int*)&t, (int*)&n);
-           T(numtriangles).vindices[2] = v;
-           T(numtriangles).uvtindices[2] = t;
-           T(numtriangles).nindices[2] = n;
+           T(numtriangles).vindices[0] = fixIndex(v,numvertices);
+           T(numtriangles).uvtindices[0] = fixIndex(t, numtexcoords);
+           T(numtriangles).nindices[0] = fixIndex(n, numnormals);
+           fscanf(file, "%d/%d/%d", &v, &t, &n);
+           T(numtriangles).vindices[1] = fixIndex(v, numvertices);
+           T(numtriangles).uvtindices[1] = fixIndex(t, numtexcoords);
+           T(numtriangles).nindices[1] = fixIndex(n, numnormals);
+           fscanf(file, "%d/%d/%d", &v, &t, &n);
+           T(numtriangles).vindices[2] = fixIndex(v, numvertices);
+           T(numtriangles).uvtindices[2] = fixIndex(t, numtexcoords);
+           T(numtriangles).nindices[2] = fixIndex(n, numnormals);
            group->triangles[group->numtriangles++] = numtriangles;
            numtriangles++;
-           while(fscanf(file, "%d/%d/%d", (int*)&v, (int*)&t, (int*)&n) > 0) {
+           while(fscanf(file, "%d/%d/%d", &v, &t, &n) > 0) {
              T(numtriangles).vindices[0] = T(numtriangles-1).vindices[0];
              T(numtriangles).uvtindices[0] = T(numtriangles-1).uvtindices[0];
              T(numtriangles).nindices[0] = T(numtriangles-1).nindices[0];
              T(numtriangles).vindices[1] = T(numtriangles-1).vindices[2];
              T(numtriangles).uvtindices[1] = T(numtriangles-1).uvtindices[2];
              T(numtriangles).nindices[1] = T(numtriangles-1).nindices[2];
-             T(numtriangles).vindices[2] = v;
-             T(numtriangles).uvtindices[2] = t;
-             T(numtriangles).nindices[2] = n;
+             T(numtriangles).vindices[2] = fixIndex(v, numvertices);
+             T(numtriangles).uvtindices[2] = fixIndex(t, numtexcoords);
+             T(numtriangles).nindices[2] = fixIndex(n, numnormals);
              group->triangles[group->numtriangles++] = numtriangles;
              numtriangles++;
            }
          } else if (sscanf(buf, "%d/%d", &v, &t) == 2) {
            /* v/t */
-           T(numtriangles).vindices[0] = v;
-           T(numtriangles).uvtindices[0] = t;
-           fscanf(file, "%d/%d", (int*)&v, (int*)&t);
-           T(numtriangles).vindices[1] = v;
-           T(numtriangles).uvtindices[1] = t;
-           fscanf(file, "%d/%d", (int*)&v, (int*)&t);
-           T(numtriangles).vindices[2] = v;
-           T(numtriangles).uvtindices[2] = t;
+           T(numtriangles).vindices[0] = fixIndex(v, numvertices);
+           T(numtriangles).uvtindices[0] = fixIndex(t, numtexcoords);
+           fscanf(file, "%d/%d", &v, &t);
+           T(numtriangles).vindices[1] = fixIndex(v, numvertices);
+           T(numtriangles).uvtindices[1] = fixIndex(t, numtexcoords);
+           fscanf(file, "%d/%d", &v, &t);
+           T(numtriangles).vindices[2] = fixIndex(v, numvertices);
+           T(numtriangles).uvtindices[2] = fixIndex(t, numtexcoords);
            group->triangles[group->numtriangles++] = numtriangles;
            numtriangles++;
-           while(fscanf(file, "%d/%d", (int*)&v, (int*)&t) > 0) {
+           while(fscanf(file, "%d/%d", &v, &t) > 0) {
              T(numtriangles).vindices[0] = T(numtriangles-1).vindices[0];
              T(numtriangles).uvtindices[0] = T(numtriangles-1).uvtindices[0];
              T(numtriangles).vindices[1] = T(numtriangles-1).vindices[2];
              T(numtriangles).uvtindices[1] = T(numtriangles-1).uvtindices[2];
-             T(numtriangles).vindices[2] = v;
-             T(numtriangles).uvtindices[2] = t;
+             T(numtriangles).vindices[2] = fixIndex(v, numvertices);
+             T(numtriangles).uvtindices[2] = fixIndex(t, numtexcoords);
              group->triangles[group->numtriangles++] = numtriangles;
              numtriangles++;
            }
          } else {
            /* v */
            sscanf(buf, "%d", &v);
-           T(numtriangles).vindices[0] = v;
-           fscanf(file, "%d", (int*)&v);
-           T(numtriangles).vindices[1] = v;
-           fscanf(file, "%d", (int*)&v);
-           T(numtriangles).vindices[2] = v;
+           T(numtriangles).vindices[0] = fixIndex(v, numvertices);
+           fscanf(file, "%d", &v);
+           T(numtriangles).vindices[1] = fixIndex(v, numvertices);
+           fscanf(file, "%d", &v);
+           T(numtriangles).vindices[2] = fixIndex(v, numvertices);
            group->triangles[group->numtriangles++] = numtriangles;
            numtriangles++;
-           while(fscanf(file, "%d", (int*)&v) > 0) {
+           while(fscanf(file, "%d", &v) > 0) {
              T(numtriangles).vindices[0] = T(numtriangles-1).vindices[0];
              T(numtriangles).vindices[1] = T(numtriangles-1).vindices[2];
-             T(numtriangles).vindices[2] = v;
+             T(numtriangles).vindices[2] = fixIndex(v, numvertices);
              group->triangles[group->numtriangles++] = numtriangles;
              numtriangles++;
            }
@@ -736,7 +794,9 @@ _glmSecondPass(GLMmodel* model, FILE* file)
 
     default:
       /* eat up rest of line */
-      fgets(buf, sizeof(buf), file);
+      if(NULL==fgets(buf, sizeof(buf), file)) {
+        verbose(1, "_glmSecondPass() failed reading"); continue;
+      }
       break;
     }
   }
@@ -747,6 +807,8 @@ _glmSecondPass(GLMmodel* model, FILE* file)
           numnormals   * 3*sizeof(GLfloat) * (numnormals ? 1 : 0) +
           numtexcoords * 3*sizeof(GLfloat) * (numtexcoords ? 1 : 0) +
           numtriangles * sizeof(GLMtriangle));
+
+  return GL_TRUE;
 }
 
 
@@ -1382,7 +1444,10 @@ glmReadOBJ(char* filename)
 
   /* make a first pass through the file to get a count of the number
      of vertices, normals, texcoords & triangles */
-  _glmFirstPass(model, file);
+  if(GL_FALSE==_glmFirstPass(model, file)){
+    error("glmReadOBJ() failed: can't parse file \"%s\".", filename);
+    goto readobj_failed;
+  }
 
   /* allocate memory */
   model->vertices = (GLfloat*)malloc(sizeof(GLfloat) *
@@ -1401,7 +1466,10 @@ glmReadOBJ(char* filename)
   /* rewind to beginning of file and read in the data this pass */
   rewind(file);
 
-  _glmSecondPass(model, file);
+  if(GL_FALSE==_glmSecondPass(model, file)) {
+    error("glmReadOBJ() failed: can't parse file \"%s\".", filename);
+    goto readobj_failed;
+  }
 
   /* close the file */
   fclose(file);
@@ -1409,6 +1477,11 @@ glmReadOBJ(char* filename)
   glmTexture(model, GLM_TEX_DEFAULT, 1.0, 1.0);
 
   return model;
+
+ readobj_failed:
+  glmDelete(model);
+  if(file)fclose(file);
+  return NULL;
 }
 
 /* glmWriteOBJ: Writes a model description in Wavefront .OBJ format to
@@ -1911,9 +1984,9 @@ glmWeld(GLMmodel* model, GLfloat epsilon)
   verbose(1, "glmWeld(): %d redundant vertices.", model->numvertices - numvectors - 1);
 
   for (i = 0; i < model->numtriangles; i++) {
-    T(i).vindices[0] = (GLuint)vectors[3 * T(i).vindices[0] + 0];
-    T(i).vindices[1] = (GLuint)vectors[3 * T(i).vindices[1] + 0];
-    T(i).vindices[2] = (GLuint)vectors[3 * T(i).vindices[2] + 0];
+    T(i).vindices[0] = static_cast<GLuint>(vectors[3 * T(i).vindices[0] + 0]);
+    T(i).vindices[1] = static_cast<GLuint>(vectors[3 * T(i).vindices[1] + 0]);
+    T(i).vindices[2] = static_cast<GLuint>(vectors[3 * T(i).vindices[2] + 0]);
   }
 
   /* free space for old vertices */
@@ -1978,7 +2051,9 @@ glmReadPPM(char* filename, int* width, int* height)
 
   /* grab first two chars of the file and make sure that it has the
      correct magic cookie for a raw PPM file. */
-  fgets(head, 70, fp);
+  if(NULL==fgets(head, 70, fp)) {
+    error("_glmReadPPM() failed reading header"); return NULL;
+  }
   if (strncmp(head, "P6", 2)) {
     error("%s: Not a raw PPM file", filename);
     return NULL;
@@ -1987,7 +2062,9 @@ glmReadPPM(char* filename, int* width, int* height)
   /* grab the three elements in the header (width, height, maxval). */
   i = 0;
   while(i < 3) {
-    fgets(head, 70, fp);
+    if(NULL==fgets(head, 70, fp)) {
+      error("_glmReadPPM() failed header info"); return NULL;
+    }
     if (head[0] == '#')     /* skip comments. */
       continue;
     if (i == 0)
@@ -2000,8 +2077,15 @@ glmReadPPM(char* filename, int* width, int* height)
 
   /* grab all the image data in one fell swoop. */
   image = (unsigned char*)malloc(sizeof(unsigned char)*w*h*3);
-  fread(image, sizeof(unsigned char), w*h*3, fp);
+  size_t count = fread(image, sizeof(unsigned char), w*h*3, fp);
   fclose(fp);
+  if(count!=static_cast<size_t>(w*h*3)) {
+    error("_glmReadPPM failed to read all bytes");
+    *width=*height=0;
+    free(image);
+    image=NULL;
+    return NULL;
+  }
 
   *width = w;
   *height = h;
