@@ -7,17 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 #include "multimodel.h"
-
+#include "Gem/State.h"
 #include <stdio.h>
 
-CPPEXTERN_NEW_WITH_FOUR_ARGS(multimodel, t_symbol *, A_DEFSYM, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_FOUR_ARGS(multimodel, t_symbol *, A_DEFSYM, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
   multimodel::multiModelCache *multimodel::s_modelCache = NULL;
 
@@ -36,19 +36,22 @@ multimodel :: multimodel(t_symbol *filename, t_floatarg baseModel,
     m_rescaleModel(1),
     m_textype(GLM_TEX_DEFAULT),
     m_rebuild(true),
-	m_currentH(1.f), m_currentW(1.f)
+    m_currentH(1.f), m_currentW(1.f)
 {
   inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("mdl_num"));
 
   // make sure that there are some characters
   if (filename->s_name[0]) { 
-    if (skipRate == 0) {
-      if (topModel == 0)
-        openMess(filename, 0, (int)baseModel, 1);
+    int skipRatei=static_cast<int>(skipRate);
+    int topModeli=static_cast<int>(topModel);
+    int baseModeli=static_cast<int>(baseModel);
+    if (skipRatei == 0) {
+      if (topModeli == 0)
+        openMess(filename, 0, baseModeli, 1);
       else
-        openMess(filename, (int)baseModel, (int)topModel, 1);
+        openMess(filename, baseModeli, topModeli, 1);
     }
-    else openMess(filename, (int)baseModel, (int)topModel, (int)skipRate);
+    else openMess(filename, baseModeli, topModeli, skipRatei);
   }
 }
 
@@ -70,27 +73,27 @@ void multimodel :: cleanMultimodel()
   if (m_numModels) {
     // decrement the reference count
     m_loadedCache->refCount--;
-
+    
     // If the refCount == 0, then destroy the cache
     if (m_loadedCache->refCount == 0) {
       // find the cache
       multiModelCache *ptr = s_modelCache;
-            
+      
       // if the loaded cache is the first cache in the list
       if (m_loadedCache == s_modelCache) {
-	s_modelCache = m_loadedCache->next;
-	delete m_loadedCache;
+        s_modelCache = m_loadedCache->next;
+        delete m_loadedCache;
       }
       else {
-	while (ptr && ptr->next != m_loadedCache) ptr = ptr->next;
-	if (!ptr) error("unable to find model cache!");
-	else {
-	  ptr->next = m_loadedCache->next;
-	  delete m_loadedCache;
-	}
+        while (ptr && ptr->next != m_loadedCache) ptr = ptr->next;
+        if (!ptr) error("unable to find model cache!");
+        else {
+          ptr->next = m_loadedCache->next;
+          delete m_loadedCache;
+        }
       }
     }
-
+    
     m_loadedCache = NULL;
     m_numModels = 0;
   }
@@ -170,7 +173,7 @@ void multimodel :: openMess(t_symbol *filename, int baseModel, int topModel, int
 
   int realNum = baseModel;
   char bufName[MAXPDSTRING];
-  canvas_makefilename(getCanvas(), preName, bufName, MAXPDSTRING);
+  canvas_makefilename(const_cast<t_canvas*>(getCanvas()), preName, bufName, MAXPDSTRING);
 
   for (i = 0; i < m_numModels; i++, realNum += skipRate) {
     char newName[256];
@@ -215,7 +218,7 @@ void multimodel :: openMess(t_symbol *filename, int baseModel, int topModel, int
 
   post("loaded models: %s %s from %d to %d skipping %d",
        bufName, postName, baseModel, topModel, skipRate);
-  this->setModified();
+  setModified();
 }
 /////////////////////////////////////////////////////////
 // buildList
@@ -229,8 +232,8 @@ void multimodel :: buildList()
 
   i=0;
   while(i<m_numModels){
+    glmTexture(m_loadedCache->realmodels[i], m_textype, m_currentW, m_currentH);
     m_loadedCache->models[i]=glmList( m_loadedCache->realmodels[i], GLM_SMOOTH | GLM_TEXTURE);
-    glmTexture(m_loadedCache->realmodels[i], m_textype, m_currentH, m_currentW);
 
     i++;
   }
@@ -262,7 +265,8 @@ void multimodel :: textureMess(int state)
 void multimodel :: startRendering()
 {
   // build a display list
-  buildList();
+  //  buildList();
+  m_rebuild=true;
 }
 /////////////////////////////////////////////////////////
 // render
@@ -271,13 +275,13 @@ void multimodel :: startRendering()
 void multimodel :: render(GemState *state)
 {
   if (!m_numModels || !m_loadedCache) return;
-  if (state && (m_currentH != state->texCoordX(2) || m_currentW != state->texCoordY(2)))
+  if (state && (m_currentW != state->texCoordX(2) || m_currentH != state->texCoordY(2)))
     {
       m_rebuild=true;
     }
   if(m_rebuild) {
-    m_currentH = state->texCoordX(2);
-    m_currentW = state->texCoordY(2);
+    m_currentW = state->texCoordX(2);
+    m_currentH = state->texCoordY(2);
     buildList();
     m_rebuild=false;
   }
@@ -313,7 +317,7 @@ void multimodel :: changeModel(int modelNum)
       return;
     }
   m_curModel = modelNum;
-  this->setModified();
+  //  setModified();
 }
 
 /////////////////////////////////////////////////////////
@@ -322,37 +326,41 @@ void multimodel :: changeModel(int modelNum)
 /////////////////////////////////////////////////////////
 void multimodel :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&multimodel::openMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&multimodel::openMessCallback),
 		  gensym("open"), A_SYMBOL, A_FLOAT, A_DEFFLOAT, A_DEFFLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&multimodel::changeModelCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&multimodel::changeModelCallback),
 		  gensym("mdl_num"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&multimodel::rescaleMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&multimodel::rescaleMessCallback),
 		  gensym("rescale"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&multimodel::textureMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&multimodel::textureMessCallback),
 		  gensym("texture"), A_FLOAT, A_NULL);
 }
 void multimodel :: openMessCallback(void *data, t_symbol *filename, t_floatarg baseModel,
 				    t_floatarg topModel, t_floatarg skipRate)
 {
-  if ((int)skipRate == 0)
+  int skipRatei=static_cast<int>(skipRate);
+  int topModeli=static_cast<int>(topModel);
+  int baseModeli=static_cast<int>(baseModel);
+
+  if (skipRatei == 0)
     {
-      if ((int)topModel == 0)
-	GetMyClass(data)->openMess(filename, 0, (int)topModel, 0);
+      if (topModeli == 0)
+	GetMyClass(data)->openMess(filename, 0, topModeli, 0);
       else
-	GetMyClass(data)->openMess(filename, (int)baseModel, (int)topModel, 0);
+	GetMyClass(data)->openMess(filename, baseModeli, topModeli, 0);
     }
   else
-    GetMyClass(data)->openMess(filename, (int)baseModel, (int)topModel, (int)skipRate);
+    GetMyClass(data)->openMess(filename, baseModeli, topModeli, skipRatei);
 }
 void multimodel :: changeModelCallback(void *data, t_floatarg modelNum)
 {
-  GetMyClass(data)->changeModel((int)modelNum);
+  GetMyClass(data)->changeModel(static_cast<int>(modelNum));
 }
 void multimodel :: rescaleMessCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->rescaleMess((int)state);
+  GetMyClass(data)->rescaleMess(static_cast<int>(state));
 }
 void multimodel :: textureMessCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->textureMess((int)state);
+  GetMyClass(data)->textureMess(static_cast<int>(state));
 }
