@@ -5,15 +5,15 @@
   Load multiple images
 
   Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-  Copyright (c) Gnther Geiger. geiger@epy.co.at
-  Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+  Copyright (c) Günther Geiger. geiger@epy.co.at
+  Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
   For information on usage and redistribution, and for a DISCLAIMER OF ALL
   WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
   -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_MULTIMODEL_H_
-#define INCLUDE_MULTIMODEL_H_
+#ifndef _INCLUDE__GEM_GEOS_MULTIMODEL_H_
+#define _INCLUDE__GEM_GEOS_MULTIMODEL_H_
 
 #include "Base/GemBase.h"
 #include <string.h>
@@ -35,7 +35,7 @@
   -----------------------------------------------------------------*/
 class GEM_EXTERN multimodel : public GemBase
 {
-  CPPEXTERN_HEADER(multimodel, GemBase)
+  CPPEXTERN_HEADER(multimodel, GemBase);
 
     public:
 
@@ -54,8 +54,10 @@ class GEM_EXTERN multimodel : public GemBase
           { modelName = strdup(_modelName); }
         ~multiModelCache()
           { delete modelName;
-            for (int i = 0; i < numModels; i++)
+            for (int i = 0; i < numModels; i++) {
+              glmDelete(realmodels[i]);
               glDeleteLists(models[i], 1);
+            }
             delete [] models;
           }
         int                 refCount;
