@@ -10,12 +10,11 @@
  *    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
  *
  */
-#ifndef INCLUDE_NEWWAVE_H_
-#define INCLUDE_NEWWAVE_H_
+#ifndef _INCLUDE__GEM_GEOS_NEWWAVE_H_
+#define _INCLUDE__GEM_GEOS_NEWWAVE_H_
 
 #include "Base/GemShape.h"
-#include "Base/GemState.h"
-#include "Base/GemFuncUtil.h"
+#include "Utils/Functions.h"
 
 #ifdef __ppc__
 #undef sqrt
@@ -38,7 +37,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN newWave : public GemShape
 {
-  CPPEXTERN_HEADER(newWave, GemShape)
+  CPPEXTERN_HEADER(newWave, GemShape);
 
     public:
 
