@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,11 +16,11 @@
 
 #include "primTri.h"
 
-#include "Base/Matrix.h"
-#include "Base/GemState.h"
+#include "Utils/Matrix.h"
+#include "Gem/State.h"
 #include <string.h>
 
-CPPEXTERN_NEW_WITH_ONE_ARG(primTri, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(primTri, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -75,26 +75,26 @@ void primTri :: renderShape(GemState *state)
 	float norm[3];
 	Matrix::generateNormal(mVectors[0], mVectors[1], mVectors[2], norm);
     glNormal3fv(norm);
-	if (!state->lighting)
+	if (!GemShape::m_lighting)
 		glShadeModel(GL_SMOOTH);
 
-    if (state->texture && state->numTexCoords)
+    if (GemShape::m_texType && GemShape::m_texNum)
     {
         int curCoord = 0;
 	    glBegin(m_drawType);
-	        glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	        glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
 			glColor4fv(mColors[0]);
    	        glVertex3fv(mVectors[0]);
 
-	        if (state->numTexCoords > 1)
+	        if (GemShape::m_texNum > 1)
 				curCoord = 1;
-	    	glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	    	glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
 			glColor4fv(mColors[1]);
    	        glVertex3fv(mVectors[1]);
 
-	        if (state->numTexCoords > 2)
+	        if (GemShape::m_texNum > 2)
 				curCoord = 2;
-	    	glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	    	glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
 			glColor4fv(mColors[2]);
    	        glVertex3fv(mVectors[2]);
 	    glEnd();
@@ -116,7 +116,7 @@ void primTri :: renderShape(GemState *state)
 	    glEnd();
     }
 
-	if (!state->lighting)
+	if (!GemShape::m_lighting)
 		glShadeModel(GL_FLAT);
 }
 
@@ -146,31 +146,31 @@ void primTri :: typeMess(t_symbol *type)
 /////////////////////////////////////////////////////////
 void primTri :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&primTri::vect1MessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&primTri::vect1MessCallback),
     	    gensym("vect1"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&primTri::vect2MessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&primTri::vect2MessCallback),
     	    gensym("vect2"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&primTri::vect3MessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&primTri::vect3MessCallback),
     	    gensym("vect3"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&primTri::col1MessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&primTri::col1MessCallback),
     	    gensym("col1"), A_GIMME, A_NULL); 
-    class_addmethod(classPtr, (t_method)&primTri::col2MessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&primTri::col2MessCallback),
     	    gensym("col2"), A_GIMME, A_NULL); 
-    class_addmethod(classPtr, (t_method)&primTri::col3MessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&primTri::col3MessCallback),
     	    gensym("col3"), A_GIMME, A_NULL); 
 }
 
 void primTri :: vect1MessCallback(void *data, t_floatarg x, t_floatarg y, t_floatarg z)
 {
-    GetMyClass(data)->vectMess(0, (float)x, (float)y, (float)z);
+    GetMyClass(data)->vectMess(0, x, y, z);
 }
 void primTri :: vect2MessCallback(void *data, t_floatarg x, t_floatarg y, t_floatarg z)
 {
-    GetMyClass(data)->vectMess(1, (float)x, (float)y, (float)z);
+    GetMyClass(data)->vectMess(1, x, y, z);
 }
 void primTri :: vect3MessCallback(void *data, t_floatarg x, t_floatarg y, t_floatarg z)
 {
-    GetMyClass(data)->vectMess(2, (float)x, (float)y, (float)z);
+    GetMyClass(data)->vectMess(2, x, y, z);
 }
 
 void primTri :: col1MessCallback(void *data, t_symbol *, int argc, t_atom *argv)
