@@ -5,15 +5,15 @@ LOG
     A triangle primitive with 6 inlets
 
     Copyright (c) 1997-2000 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PRIMTRI_H_
-#define INCLUDE_PRIMTRI_H_
+#ifndef _INCLUDE__GEM_GEOS_PRIMTRI_H_
+#define _INCLUDE__GEM_GEOS_PRIMTRI_H_
 
 #include "Base/GemBase.h"
 #include "Base/GemShape.h"
@@ -33,7 +33,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN primTri : public GemShape
 {
-    CPPEXTERN_HEADER(primTri, GemShape)
+    CPPEXTERN_HEADER(primTri, GemShape);
 
     public:
 
