@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,10 +16,10 @@
 
 #include "rectangle.h"
 
-#include "Base/GemState.h"
+#include "Gem/State.h"
 #include <string.h>
 
-CPPEXTERN_NEW_WITH_TWO_ARGS(rectangle, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS(rectangle, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -62,7 +62,7 @@ void rectangle :: renderShape(GemState *state)
 
   glNormal3f(0.0f, 0.0f, 1.0f);
 
-  if (state->texture && state->numTexCoords)
+  if (GemShape::m_texType && GemShape::m_texNum)
 		{
 			glBegin(m_drawType);
 			SetVertex(state, -m_size,  -m_height, 0.0f,0.,0.,0);
@@ -122,11 +122,11 @@ void rectangle :: typeMess(t_symbol *type)
 /////////////////////////////////////////////////////////
 void rectangle :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&rectangle::heightMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&rectangle::heightMessCallback),
     	    gensym("ft2"), A_FLOAT, A_NULL);
 }
 
 void rectangle :: heightMessCallback(void *data, t_floatarg size)
 {
-    GetMyClass(data)->heightMess((float)size);
+    GetMyClass(data)->heightMess(size);
 }
