@@ -10,17 +10,16 @@
  *    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
  *
  */
-#ifndef INCLUDE_RIPPLE_H_
-#define INCLUDE_RIPPLE_H_
+#ifndef _INCLUDE__GEM_GEOS_RIPPLE_H_
+#define _INCLUDE__GEM_GEOS_RIPPLE_H_
 
 #include "Base/GemShape.h"
-#include "Base/GemState.h"
-#include "Base/GemMan.h"
+#include "Gem/Manager.h"
 #include <string.h>
 #include <math.h>
 
 #ifdef __ppc__
-#include "Base/GemFuncUtil.h"
+#include "Utils/Functions.h"
 #undef sqrt
 #define sqrt fast_sqrtf
 #endif
@@ -56,21 +55,21 @@ typedef struct {
 } RIPPLE_VERTEX;
 
 /*-----------------------------------------------------------------
--------------------------------------------------------------------
-CLASS
-    ripple
+  -------------------------------------------------------------------
+  CLASS
+  ripple
     
-    based on the SGI demo distort
+  based on the SGI demo distort
 
-KEYWORDS
-    geo
+  KEYWORDS
+  geo
     
-DESCRIPTION
+  DESCRIPTION
 
------------------------------------------------------------------*/
+  -----------------------------------------------------------------*/
 class GEM_EXTERN ripple : public GemShape
 {
-  CPPEXTERN_HEADER(ripple, GemShape)
+  CPPEXTERN_HEADER(ripple, GemShape);
 
     public:
 
@@ -86,54 +85,51 @@ class GEM_EXTERN ripple : public GemShape
 
   //////////
   // The height of the object
-  short		size, ctrX, ctrY;
-  void	    	heightMess(float height);
+  short		m_ctrX, m_ctrY;
+  void	 	heightMess(float height);
   void		ctrXMess(float center);
   void		ctrYMess(float center);
   //////////
   // Do the rendering
   virtual void 	renderShape(GemState *state);
   
-    	//////////
-    	// How the object should be drawn
-    	virtual void	typeMess(t_symbol *type);
-        void	ripple_dynamics();
-        void	ripple_init();
-        float	ripple_distance( int gx, int gy, int cx, int cy);
-        int	ripple_max_distance( int gx, int gy );
-        void	ripple_grab();
-        void	ripple_bang();
-        void	precalc_ripple_vector();
-        void	precalc_ripple_amp();
+  //////////
+  // How the object should be drawn
+  virtual void	typeMess(t_symbol *type);
+  void	ripple_dynamics();
+  void	ripple_init();
+  float	ripple_distance( int gx, int gy, int cx, int cy);
+  int	ripple_max_distance( int gx, int gy );
+  void	ripple_bang();
+  void	precalc_ripple_vector();
+  void	precalc_ripple_amp();
 		
-    	//////////
-    	// The height of the object
-        GLfloat	    	m_height;
+  //////////
+  // The height of the object
+  GLfloat	    	m_height;
 
-        //////////
-        // The height inlet
-        t_inlet         *m_inletH;
-        t_inlet		*inletcX;
-        t_inlet		*inletcY;
+  //////////
+  // The height inlet
+  t_inlet   *m_inletH;
+  t_inlet		*m_inletcX;
+  t_inlet		*m_inletcY;
   
   //////////
   // getStuff
-  int m_grid_sizeX, m_grid_sizeY;
+  int m_gridX, m_gridY;
   
-  int		alreadyInit;
-  float		xsize, ysize, ysize0;
-  RIPPLE_VECTOR ripple_vector[GRID_MAX_X][GRID_MAX_Y];
-  RIPPLE_AMP ripple_amp[RIPPLE_LENGTH];
-  RIPPLE_VERTEX ripple_vertex[GRID_MAX_X][GRID_MAX_Y];
+  bool		m_alreadyInit;
+  float		m_sizeX, m_sizeY, m_sizeY0;
+  RIPPLE_VECTOR m_rippleVector[GRID_MAX_X][GRID_MAX_Y];
+  RIPPLE_AMP m_rippleAmp[RIPPLE_LENGTH];
+  RIPPLE_VERTEX m_rippleVertex[GRID_MAX_X][GRID_MAX_Y];
 
-  int cx[RIPPLE_COUNT];
-  int cy[RIPPLE_COUNT];
-  int t[RIPPLE_COUNT];
-  int max[RIPPLE_COUNT];
-
-  int ripple_max;
-  int grab;	/* index of grabbed mass point */
+  int m_cx[RIPPLE_COUNT];
+  int m_cy[RIPPLE_COUNT];
+  int m_t[RIPPLE_COUNT];
+  int m_max[RIPPLE_COUNT];
 
+  int m_rippleMax;
  private:
 
   //////////
