@@ -12,11 +12,12 @@
  */
 
 #include "rubber.h"
+#include "Gem/State.h"
 
 #define GRID_SIZE_X  32
 #define GRID_SIZE_Y  32
 
-CPPEXTERN_NEW_WITH_TWO_ARGS(rubber, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS(rubber, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -30,8 +31,10 @@ rubber :: rubber( t_floatarg gridX, t_floatarg gridY )
   : GemShape(1.0), m_height(0.0), m_speed(0), m_grab(-1),
     m_alreadyInit(0), m_springKS(0.3), m_drag(0.5), m_mass(NULL), m_spring(NULL)
 {
-  m_grid_sizeX = (gridX>0.)?(int)gridX:GRID_SIZE_X;
-  m_grid_sizeY = (gridY>0.)?(int)gridY:GRID_SIZE_Y;
+  int gridXi=static_cast<int>(gridX);
+  int gridYi=static_cast<int>(gridY);
+  m_grid_sizeX = (gridXi>0)?gridXi:GRID_SIZE_X;
+  m_grid_sizeY = (gridYi>0)?gridYi:GRID_SIZE_Y;
 
   // the height inlet
   m_inletH = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("Ht"));
@@ -138,17 +141,17 @@ void rubber :: renderShape(GemState *state)
 {
   int k, i, j;
      
-  if (state->texture && state->numTexCoords>=3) {
+  if (GemShape::m_texType && GemShape::m_texNum>=3) {
 
-    if ((xsize  != state->texCoords[1].s) ||
-        (ysize  != state->texCoords[1].t) ||
-        (ysize0 != state->texCoords[2].t))
+    if ((xsize  != GemShape::m_texCoords[1].s) ||
+        (ysize  != GemShape::m_texCoords[1].t) ||
+        (ysize0 != GemShape::m_texCoords[2].t))
       m_alreadyInit = 0;
     
     if (!m_alreadyInit)  {
-      xsize  = state->texCoords[1].s;
-      ysize0 = state->texCoords[2].t;
-      ysize  = state->texCoords[1].t;
+      xsize  = GemShape::m_texCoords[1].s;
+      ysize0 = GemShape::m_texCoords[2].t;
+      ysize  = GemShape::m_texCoords[1].t;
 
       rubber_init();
       m_alreadyInit = 1;
@@ -353,16 +356,16 @@ void rubber :: typeMess(t_symbol *type)
 /////////////////////////////////////////////////////////
 void rubber :: obj_setupCallback(t_class *classPtr)
 {
-  class_addbang(classPtr, (t_method)&rubber::bangMessCallback);
-  class_addmethod(classPtr, (t_method)&rubber::heightMessCallback,
+  class_addbang(classPtr, reinterpret_cast<t_method>(&rubber::bangMessCallback));
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&rubber::heightMessCallback),
                   gensym("Ht"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&rubber::ctrXMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&rubber::ctrXMessCallback),
                   gensym("cX"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&rubber::ctrYMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&rubber::ctrYMessCallback),
                   gensym("cY"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&rubber::dragMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&rubber::dragMessCallback),
                   gensym("drag"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&rubber::springMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&rubber::springMessCallback),
                   gensym("spring"), A_FLOAT, A_NULL);
 }
 void rubber :: bangMessCallback(void *data)
@@ -371,15 +374,15 @@ void rubber :: bangMessCallback(void *data)
 }
 void rubber :: heightMessCallback(void *data, t_floatarg height)
 {
-  GetMyClass(data)->heightMess((float)height);
+  GetMyClass(data)->heightMess(height);
 }
 void rubber :: ctrXMessCallback(void *data, t_floatarg center)
 {
-  GetMyClass(data)->ctrXMess((float)center);
+  GetMyClass(data)->ctrXMess(center);
 }
 void rubber :: ctrYMessCallback(void *data, t_floatarg center)
 {
-  GetMyClass(data)->ctrYMess((float)center);
+  GetMyClass(data)->ctrYMess(center);
 }
 void rubber :: dragMessCallback(void *data, t_floatarg drag)
 {
