@@ -11,19 +11,18 @@
  *    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
  *
  */
-#ifndef INCLUDE_RUBBER_H_
-#define INCLUDE_RUBBER_H_
+#ifndef _INCLUDE__GEM_GEOS_RUBBER_H_
+#define _INCLUDE__GEM_GEOS_RUBBER_H_
 
 #include "Base/GemShape.h"
-#include "Base/GemState.h"
-#include "Base/GemMan.h"
+#include "Gem/Manager.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
 
 #ifdef __ppc__
-#include "Base/GemFuncUtil.h"
+#include "Utils/Functions.h"
 #undef sqrt
 #define sqrt fast_sqrtf
 #endif
@@ -55,7 +54,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN rubber : public GemShape
 {
-  CPPEXTERN_HEADER(rubber, GemShape)
+  CPPEXTERN_HEADER(rubber, GemShape);
 
     public:
 
