@@ -7,16 +7,16 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "sphere.h"
-
-CPPEXTERN_NEW_WITH_TWO_ARGS(sphere, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+#include "Gem/State.h"
+CPPEXTERN_NEW_WITH_TWO_ARGS(sphere, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -66,28 +66,35 @@ void sphere :: createSphere(GemState *state)
     GLfloat rho, drho, theta, dtheta;
     GLfloat s, t, ds, dt;
     GLint i, j, imin, imax;
-  //  GLboolean normals = (state->lighting)?GL_TRUE:GL_FALSE;
     GLenum orientation = true; /* GLU_INSIDE; */
     GLfloat nsign = (orientation)?-1.0:1.0;
 
     GLfloat xsize = 1.0, xsize0 = 0.0;
     GLfloat ysize = 1.0, ysize0 = 0.0;
 
+    TexCoord*texCoords=NULL;
+    int texNum=0;
+    int texType=0;
+    state->get(GemState::_GL_TEX_COORDS, texCoords);
+    state->get(GemState::_GL_TEX_TYPE, texType);
+    state->get(GemState::_GL_TEX_NUMCOORDS, texNum);
+
+
     if(m_drawType==GL_DEFAULT_GEM)m_drawType=GL_FILL;
 
     if(m_x)delete[]m_x;m_x=NULL;
     if(m_y)delete[]m_y;m_y=NULL;
     if(m_z)delete[]m_z;m_z=NULL;
 
-    if(state->texture){
-        xsize0 = state->texCoords[0].s;
-        xsize  = state->texCoords[1].s-xsize0;
-        ysize0 = state->texCoords[1].t;
-        ysize  = state->texCoords[2].t-ysize0;
+    if(texType && texNum>=3){
+        xsize0 = texCoords[0].s;
+        xsize  = texCoords[1].s-xsize0;
+        ysize0 = texCoords[1].t;
+        ysize  = texCoords[2].t-ysize0;
     }
 
-    drho = M_PI / (GLfloat) stacks;
-    dtheta = 2.0 * M_PI / (GLfloat) slices;
+    drho = M_PI / static_cast<GLfloat>(stacks);
+    dtheta = 2.0 * M_PI / static_cast<GLfloat>(slices);
 
     int src;
 
@@ -99,7 +106,7 @@ void sphere :: createSphere(GemState *state)
 
         src = 0;
         
-        if (!state->texture) {
+        if (!texType) {
             /* draw +Z end as a triangle fan */
             
             for (j = 0; j <= slices; j++) {
@@ -114,7 +121,7 @@ void sphere :: createSphere(GemState *state)
         ds = 1.0 / slices;
         dt = 1.0 / stacks;
         t = 1.0;			/* because loop now runs from 0 */
-        if (state->texture) {
+        if (texType) {
             imin = 0;
             imax = stacks;
         }
@@ -141,7 +148,7 @@ void sphere :: createSphere(GemState *state)
             }
         }
 
-        if (!state->texture) {
+        if (!texType) {
             /* draw -Z end as a triangle fan */
             
             rho = M_PI - drho;
@@ -227,24 +234,31 @@ void sphere :: render(GemState *state)
   GLfloat rho, drho, dtheta;
   GLfloat s, t, ds, dt;
   GLint i, j, imin, imax;
-  GLboolean normals = (state->lighting)?GL_TRUE:GL_FALSE;
   GLenum orientation = true; /* GLU_INSIDE; */
   GLfloat nsign = (orientation)?-1.0:1.0;
 
-  int src;
-  src = 0;
+  int src=0;
 
-    GLfloat xsize = 1.0, xsize0 = 0.0;
+  TexCoord*texCoords=NULL;
+  int texType=0;
+  int texNum=0;
+  bool lighting=false;
+  state->get(GemState::_GL_TEX_COORDS, texCoords);
+  state->get(GemState::_GL_TEX_TYPE, texType);
+  state->get(GemState::_GL_TEX_NUMCOORDS, texNum);
+  state->get(GemState::_GL_LIGHTING, lighting);
+
+  GLfloat xsize = 1.0, xsize0 = 0.0;
   GLfloat ysize = 1.0, ysize0 = 0.0;
-  if(state->texture && state->numTexCoords>=3){
-      xsize0 = state->texCoords[0].s;
-      xsize  = state->texCoords[1].s-xsize0;
-      ysize0 = state->texCoords[1].t;
-      ysize  = state->texCoords[2].t-ysize0;
+  if(texType && texNum>=3){
+    xsize0 = texCoords[0].s;
+    xsize  = texCoords[1].s-xsize0;
+    ysize0 = texCoords[1].t;
+    ysize  = texCoords[2].t-ysize0;
   }
     
-  drho = M_PI / (GLfloat) stacks;
-  dtheta = 2.0 * M_PI / (GLfloat) slices;
+  drho = M_PI / static_cast<GLfloat>(stacks);
+  dtheta = 2.0 * M_PI / static_cast<GLfloat>(slices);
 
   /* texturing: s goes from 0.0/0.25/0.5/0.75/1.0 at +y/+x/-y/-x/+y axis */
   /* t goes from -1.0/+1.0 at z = -radius/+radius (linear along longitudes) */
@@ -252,7 +266,7 @@ void sphere :: render(GemState *state)
 
   //if anything changed then the geometry is rebuilt
   if (stacks != oldStacks || slices != oldSlices || 
-      m_drawType != oldDrawType || state->texture!=oldTexture){
+      m_drawType != oldDrawType || texType!=oldTexture){
 
       //call the sphere creation function to fill the array
       createSphere(state);
@@ -260,18 +274,18 @@ void sphere :: render(GemState *state)
       oldStacks = stacks;
       oldSlices = slices;
       oldDrawType = m_drawType;
-      oldTexture = state->texture;
+      oldTexture = texType;
   }
  
   if (m_drawType == GL_FILL) {
     src = 0;
-    if (!state->texture) {
+    if (!texType) {
       /* draw +Z end as a triangle fan */
       glBegin(GL_TRIANGLE_FAN);
       glNormal3f(0.0, 0.0, 1.0);
       glVertex3f(0.0, 0.0, nsign * radius);
       for (j = 0; j <= slices; j++) {
-			if (normals)
+			if (lighting)
 				glNormal3f(m_x[src] * nsign, m_y[src] * nsign, m_z[src] * nsign);
 			glVertex3f(m_x[src] * radius, m_y[src] * radius, m_z[src] * radius);
 			src++;
@@ -282,7 +296,7 @@ void sphere :: render(GemState *state)
     ds = 1.0 / slices;
     dt = 1.0 / stacks;
     t = 1.0;			/* because loop now runs from 0 */
-    if (state->texture) {
+    if (texType) {
       imin = 0;
       imax = stacks;
     }
@@ -297,15 +311,15 @@ void sphere :: render(GemState *state)
       s = 0.0;
       for (j = 0; j <= slices; j++) {
 
-		if (normals)
+		if (lighting)
 			glNormal3f(m_x[src] * nsign, m_y[src] * nsign, m_z[src] * nsign);
-		if(state->texture)
+		if(texType)
 			glTexCoord2f(s*xsize+xsize0, t*ysize+ysize0);
 		glVertex3f(m_x[src] * radius, m_y[src] * radius, m_z[src] * radius);
 		src++;
-		if (normals)
+		if (lighting)
 			glNormal3f(m_x[src] * nsign, m_y[src] * nsign, m_z[src] * nsign);
-		if(state->texture)
+		if(texType)
 			glTexCoord2f(s*xsize+xsize0, (t - dt)*ysize+ysize0);
 		s += ds;
 		glVertex3f(m_x[src] * radius, m_y[src] * radius, m_z[src] * radius);
@@ -315,7 +329,7 @@ void sphere :: render(GemState *state)
       t -= dt;
     }
 
-    if (!state->texture) {
+    if (!texType) {
       /* draw -Z end as a triangle fan */
       glBegin(GL_TRIANGLE_FAN);
       glNormal3f(0.0, 0.0, -1.0);
@@ -323,7 +337,7 @@ void sphere :: render(GemState *state)
       s = 1.0;
       t = dt;
       for (j = slices; j >= 0; j--) {
-		if (normals)
+		if (lighting)
 			glNormal3f(m_x[src] * nsign, m_y[src] * nsign, m_z[src] * nsign);
 		s -= ds;
 		glVertex3f(m_x[src] * radius, m_y[src] * radius, m_z[src] * radius);
@@ -340,7 +354,7 @@ void sphere :: render(GemState *state)
           glBegin(GL_LINE_LOOP);
           for (j = 0; j < slices; j++) {
         
-              if (normals)
+              if (lighting)
                   glNormal3f(m_x[src] * nsign, m_y[src] * nsign, m_z[src] * nsign);
               glVertex3f(m_x[src] * radius, m_y[src] * radius, m_z[src] * radius);
               src++;
@@ -352,7 +366,7 @@ void sphere :: render(GemState *state)
           glBegin(GL_LINE_STRIP);
           for (i = 0; i <= stacks; i++) {
 
-              if (normals)
+              if (lighting)
                   glNormal3f(m_x[src] * nsign, m_y[src] * nsign, m_z[src] * nsign);
               glVertex3f(m_x[src] * radius, m_y[src] * radius, m_z[src] * radius);
               src++;
@@ -364,10 +378,10 @@ void sphere :: render(GemState *state)
   else if (m_drawType == GL_POINT) {
     /* top and bottom-most points */
     glBegin(GL_POINTS);
-    if (normals)
+    if (lighting)
       glNormal3f(0.0, 0.0, nsign);
     glVertex3d(0.0, 0.0, radius);
-    if (normals)
+    if (lighting)
       glNormal3f(0.0, 0.0, -nsign);
     glVertex3d(0.0, 0.0, -radius);
     
@@ -376,7 +390,7 @@ void sphere :: render(GemState *state)
     for (i = 1; i < stacks - 1; i++) {
         rho = i * drho;
         for (j = 0; j < slices; j++) {
-            if (normals)
+            if (lighting)
                 glNormal3f(m_x[src] * nsign, m_y[src] * nsign, m_z[src] * nsign);
             glVertex3f(m_x[src] * radius, m_y[src] * radius, m_z[src] * radius);
             src++;
