@@ -7,15 +7,15 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "teapot.h"
-
+#include "Gem/State.h"
 
 /* Rim, body, lid, and bottom data must be reflected in x and
    y; handle and spout data across the y axis only.  */
@@ -89,7 +89,7 @@ static float teapot_cpdata[][3] =
 };
 
 
-CPPEXTERN_NEW_WITH_TWO_ARGS(teapot, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS(teapot, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -103,7 +103,7 @@ teapot :: teapot(t_floatarg size, t_floatarg slice)
       : GemGluObj(size)
 {
   m_drawType=GL_FILL;
-  m_numSlices=(int)slice;
+  m_numSlices=static_cast<int>(slice);
   if(m_numSlices<=0)m_numSlices=14;
 
   m_texCoords[0][0]=0;m_texCoords[0][1]=0;
@@ -143,11 +143,20 @@ void teapot :: render(GemState *state)
   float p[4][4][3], q[4][4][3], r[4][4][3], s[4][4][3];
   long i, j, k, l;
 
-  if (state->texture && state->numTexCoords>=4) {
-    m_texCoords[0][0]=state->texCoords[0].s;m_texCoords[0][1]=state->texCoords[0].t;
-    m_texCoords[1][0]=state->texCoords[1].s;m_texCoords[1][1]=state->texCoords[1].t;
-    m_texCoords[2][0]=state->texCoords[2].s;m_texCoords[2][1]=state->texCoords[2].t;
-    m_texCoords[3][0]=state->texCoords[3].s;m_texCoords[3][1]=state->texCoords[3].t;  
+  TexCoord*texCoords=NULL;
+  int texType=0;
+  int texNum=0;
+  bool lighting=false;
+  state->get(GemState::_GL_TEX_COORDS, texCoords);
+  state->get(GemState::_GL_TEX_TYPE, texType);
+  state->get(GemState::_GL_TEX_NUMCOORDS, texNum);
+  state->get(GemState::_GL_LIGHTING, lighting);
+
+  if (texType && texNum>=4) {
+    m_texCoords[0][0]=texCoords[0].s;m_texCoords[0][1]=texCoords[0].t;
+    m_texCoords[1][0]=texCoords[1].s;m_texCoords[1][1]=texCoords[1].t;
+    m_texCoords[2][0]=texCoords[2].s;m_texCoords[2][1]=texCoords[2].t;
+    m_texCoords[3][0]=texCoords[3].s;m_texCoords[3][1]=texCoords[3].t;  
   }
 
   glPushAttrib(GL_ENABLE_BIT | GL_EVAL_BIT);
