@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2003 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2005 Georg Holzmann <grh@mur.at>
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -17,12 +17,12 @@
 
 #include "text2d.h"
 
-#ifdef FTGL
-#include "FTGLPixmapFont.h"
-#include "FTGLBitmapFont.h"
+#if defined FTGL && !defined HAVE_FTGL_FTGL_H
+# include "FTGLPixmapFont.h"
+# include "FTGLBitmapFont.h"
 #endif
 
-CPPEXTERN_NEW_WITH_GIMME(text2d)
+CPPEXTERN_NEW_WITH_GIMME(text2d);
 
 /////////////////////////////////////////////////////////
 //
@@ -67,10 +67,11 @@ FTFont *text2d :: makeFont(const char*fontfile){
 /////////////////////////////////////////////////////////
 void text2d :: setFontSize(t_float size){
   m_fontSize = size;
-  if (m_font)if (! m_font->FaceSize((int)m_fontSize) ) {
+  int isize=static_cast<int>(m_fontSize);
+  if (m_font)if (! m_font->FaceSize(isize) ) {
     error("GEMtext: unable set fontsize !");
   }
-  if (m_afont)if (! m_afont->FaceSize((int)m_fontSize) ) {
+  if (m_afont)if (! m_afont->FaceSize(isize) ) {
     error("GEMtext: unable set fontsize !");
   }
   setModified();
@@ -173,7 +174,7 @@ void text2d :: render(GemState*){}
 /////////////////////////////////////////////////////////
 void text2d :: obj_setupCallback(t_class *classPtr )
 { 
-  class_addmethod(classPtr, (t_method)&text2d::aliasMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&text2d::aliasMessCallback),
 		  gensym("alias"), A_FLOAT, A_NULL);
 }
 
@@ -183,5 +184,5 @@ void text2d :: aliasMess(int io)
 }
 void text2d :: aliasMessCallback(void *data, t_floatarg io)
 {
-  GetMyClass(data)->aliasMess((int)io);
+  GetMyClass(data)->aliasMess(static_cast<int>(io));
 }
