@@ -5,16 +5,16 @@ LOG
     A text3d
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     Copyright (c) 2005 Georg Holzmann <grh@mur.at>
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_TEXT3D_H_
-#define INCLUDE_TEXT3D_H_
+#ifndef _INCLUDE__GEM_GEOS_TEXT_D_H_
+#define _INCLUDE__GEM_GEOS_TEXT_D_H_
 
 #include "Base/TextBase.h"
 
@@ -31,7 +31,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN text3d : public TextBase
 {
-    CPPEXTERN_HEADER(text3d, TextBase)
+    CPPEXTERN_HEADER(text3d, TextBase);
 
     public:
 
