@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2003 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2005 Georg Holzmann <grh@mur.at>
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -17,11 +17,11 @@
 
 #include "textextruded.h"
 
-#ifdef FTGL
-#include "FTGLExtrdFont.h"
+#if defined FTGL && !defined HAVE_FTGL_FTGL_H
+# include "FTGLExtrdFont.h"
 #endif
 
-CPPEXTERN_NEW_WITH_GIMME(textextruded)
+CPPEXTERN_NEW_WITH_GIMME(textextruded);
 
 /////////////////////////////////////////////////////////
 //
@@ -57,7 +57,7 @@ void textextruded :: setDepth(float prec)
 {
   m_fontDepth = prec;
   if(!m_font)return;
-  m_font->Depth((int)m_fontDepth);
+  m_font->Depth(m_fontDepth);
   setFontSize();
   setModified();
 }
@@ -90,10 +90,10 @@ void textextruded :: setDepth(float prec)
 /////////////////////////////////////////////////////////
 void textextruded :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&textextruded::depthMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&textextruded::depthMessCallback),
 		  gensym("depth"), A_FLOAT, A_NULL);  
 }
 void textextruded :: depthMessCallback(void *data, t_floatarg depth)
 {
-  GetMyClass(data)->setDepth((float)depth);
+  GetMyClass(data)->setDepth(depth);
 }
