@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2003 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2005 Georg Holzmann <grh@mur.at>
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -17,11 +17,11 @@
 
 #include "textoutline.h"
 
-#ifdef FTGL
-#include "FTGLOutlineFont.h"
+#if defined FTGL && !defined HAVE_FTGL_FTGL_H
+# include "FTGLOutlineFont.h"
 #endif
 
-CPPEXTERN_NEW_WITH_GIMME(textoutline)
+CPPEXTERN_NEW_WITH_GIMME(textoutline);
 
 /////////////////////////////////////////////////////////
 //
