@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -17,9 +17,9 @@
 #include "triangle.h"
 #include <string.h>
 
-#include "Base/GemState.h"
+#include "Gem/State.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(triangle, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(triangle, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -53,19 +53,19 @@ void triangle :: renderShape(GemState *state)
     if (m_drawType == GL_LINE_LOOP)
         glLineWidth(m_linewidth);
 
-    if (state->texture && state->numTexCoords)
+    if (GemShape::m_texType && GemShape::m_texNum)
     {
         int curCoord = 0;
 	    glBegin(m_drawType);
-	        glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	        glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
    	        glVertex3f(-m_size, -m_size, 0.f);
 
-	        if (state->numTexCoords > 1) curCoord = 1;
-	    	glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	        if (GemShape::m_texNum > 1) curCoord = 1;
+	    	glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
    	        glVertex3f(m_size, -m_size, 0.f);
 
-	        if (state->numTexCoords > 2) curCoord = 2;
-	    	glTexCoord2f(state->texCoords[curCoord].s, state->texCoords[curCoord].t);
+	        if (GemShape::m_texNum > 2) curCoord = 2;
+	    	glTexCoord2f(GemShape::m_texCoords[curCoord].s, GemShape::m_texCoords[curCoord].t);
    	        glVertex3f(0.f,	m_size, 0.f);
 	    glEnd();
     }
