@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "accumrotate.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(accumrotate)
+CPPEXTERN_NEW_WITH_GIMME(accumrotate);
 
   /////////////////////////////////////////////////////////
 //
@@ -111,13 +112,13 @@ void accumrotate :: reset()
 /////////////////////////////////////////////////////////
 void accumrotate :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&accumrotate::xMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&accumrotate::xMessCallback),
 		  gensym("xVal"), A_FLOAT, A_NULL); 
-  class_addmethod(classPtr, (t_method)&accumrotate::yMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&accumrotate::yMessCallback),
 		  gensym("yVal"), A_FLOAT, A_NULL); 
-  class_addmethod(classPtr, (t_method)&accumrotate::zMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&accumrotate::zMessCallback),
 		  gensym("zVal"), A_FLOAT, A_NULL); 
-  class_addmethod(classPtr, (t_method)&accumrotate::resetCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&accumrotate::resetCallback),
 		  gensym("reset"), A_NULL); 
 }
 void accumrotate :: xMessCallback(void *data, t_floatarg val)
