@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "ambientRGB.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(ambientRGB)
+CPPEXTERN_NEW_WITH_GIMME(ambientRGB);
 
 /////////////////////////////////////////////////////////
 //
@@ -133,13 +134,13 @@ void ambientRGB :: aMess(float val)
 /////////////////////////////////////////////////////////
 void ambientRGB :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&ambientRGB::rMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&ambientRGB::rMessCallback),
     	    gensym("rVal"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&ambientRGB::gMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&ambientRGB::gMessCallback),
     	    gensym("gVal"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&ambientRGB::bMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&ambientRGB::bMessCallback),
     	    gensym("bVal"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&ambientRGB::aMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&ambientRGB::aMessCallback),
     	    gensym("aVal"), A_FLOAT, A_NULL); 
 }
 void ambientRGB :: rMessCallback(void *data, t_floatarg val)
