@@ -14,7 +14,7 @@
 
 #include "camera.h"
 
-CPPEXTERN_NEW_WITH_GIMME(camera)
+CPPEXTERN_NEW_WITH_GIMME(camera);
 
 /////////////////////////////////////////////////////////
 //
@@ -317,35 +317,35 @@ void camera :: SlideCamera(float speed)
 /////////////////////////////////////////////////////////
 void camera :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&camera::hAngleMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::hAngleMessCallback),
 		  gensym("hAngle"), A_FLOAT, A_NULL); 
-  class_addmethod(classPtr, (t_method)&camera::vAngleMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::vAngleMessCallback),
 		  gensym("vAngle"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::distanceMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::distanceMessCallback),
 		  gensym("distance"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::speedMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::speedMessCallback),
 		  gensym("speed"), A_FLOAT, A_NULL); 
-  class_addmethod(classPtr, (t_method)&camera::forwardMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::forwardMessCallback),
 		  gensym("forward"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::reverseMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::reverseMessCallback),
 		  gensym("reverse"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::leftMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::leftMessCallback),
 		  gensym("left"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::rightMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::rightMessCallback),
 		  gensym("right"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::upMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::upMessCallback),
 		  gensym("up"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::downMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::downMessCallback),
 		  gensym("down"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::resetMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::resetMessCallback),
 		  gensym("reset"), A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::modeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::modeMessCallback),
 		  gensym("mode"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::lookXMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::lookXMessCallback),
 		  gensym("lookX"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::lookYMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::lookYMessCallback),
 		  gensym("lookY"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&camera::lookZMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&camera::lookZMessCallback),
 		  gensym("lookZ"), A_FLOAT, A_NULL);
 }
 void camera :: hAngleMessCallback(void *data, t_floatarg val)
@@ -358,43 +358,43 @@ void camera :: vAngleMessCallback(void *data, t_floatarg val)
 }
 void camera :: distanceMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->distanceMess((float)val);
+  GetMyClass(data)->distanceMess(val);
 }
 void camera :: speedMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->m_speed=((float)val);
+  GetMyClass(data)->m_speed=(val);
 }
 void camera :: forwardMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->forward=(int)val;
+  GetMyClass(data)->forward=static_cast<int>(val);
 }
 void camera :: reverseMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->reverse=(int)val;
+  GetMyClass(data)->reverse=static_cast<int>(val);
 }
 void camera :: leftMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->left=(int)val;
+  GetMyClass(data)->left=static_cast<int>(val);
 }
 void camera :: rightMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->right=(int)val;
+  GetMyClass(data)->right=static_cast<int>(val);
 }
 void camera :: slideLeftMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->slideLeft=(int)val;
+  GetMyClass(data)->slideLeft=static_cast<int>(val);
 }
 void camera :: slideRightMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->slideRight=(int)val;
+  GetMyClass(data)->slideRight=static_cast<int>(val);
 }
 void camera :: upMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->up=(int)val;
+  GetMyClass(data)->up=static_cast<int>(val);
 }
 void camera :: downMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->down=(int)val;
+  GetMyClass(data)->down=static_cast<int>(val);
 }
 void camera :: resetMessCallback(void *data)
 {
@@ -402,7 +402,7 @@ void camera :: resetMessCallback(void *data)
 }
 void camera :: modeMessCallback(void *data, t_floatarg val)
 {
-  GetMyClass(data)->m_mode=(int)val;
+  GetMyClass(data)->m_mode=static_cast<int>(val);
 }
 void camera :: lookXMessCallback(void *data, t_floatarg val)
 {
