@@ -10,19 +10,19 @@ LOG
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_CAMERA_H_
-#define INCLUDE_CAMERA_H_
+#ifndef _INCLUDE__GEM_MANIPS_CAMERA_H_
+#define _INCLUDE__GEM_MANIPS_CAMERA_H_
 
 #include "Base/GemBase.h"
-#include "Base/GemMan.h"
+#include "Gem/Manager.h"
 #include <stdlib.h>
 #include <math.h>
 
-#include "Base/GemVector.h"
+#include "Utils/Vector.h"
 
 #define PI	3.1415926535897932384626433832795
 
-#ifndef __WIN32__
+#ifndef _WIN32
 using namespace std;
 #endif
 
@@ -41,8 +41,8 @@ DESCRIPTION
 class GEM_EXTERN camera : public GemBase
 //class GEM_EXTERN camera : public CPPExtern
 {
-    CPPEXTERN_HEADER(camera, GemBase)
-    //CPPEXTERN_HEADER(camera, CPPExtern)
+    CPPEXTERN_HEADER(camera, GemBase);
+    //CPPEXTERN_HEADER(camera, CPPExtern);
 
     public:
 
