@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "color.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(color)
+CPPEXTERN_NEW_WITH_GIMME(color);
 
 /////////////////////////////////////////////////////////
 //
@@ -77,16 +78,28 @@ void color :: colorMess(float red, float green, float blue, float alpha)
 /////////////////////////////////////////////////////////
 void color :: obj_setupCallback(t_class *classPtr)
 {
-  class_addcreator((t_newmethod)create_color, 
+  class_addcreator(reinterpret_cast<t_newmethod>(create_color), 
 		   gensym("colour"), A_GIMME, A_NULL);
-    class_addmethod(classPtr, (t_method)&color::colorMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&color::colorMessCallback),
     	    gensym("color"), A_GIMME, A_NULL); 
 }
 void color :: colorMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
 {
     float alpha = 1;
-    if (argc == 4) alpha = atom_getfloat(&argv[3]);
-    GetMyClass(data)->colorMess(atom_getfloat(&argv[0]), atom_getfloat(&argv[1]),
+    switch(argc) {
+    case(4):
+     alpha = atom_getfloat(&argv[3]);
+    case(3):
+     GetMyClass(data)->colorMess(atom_getfloat(&argv[0]), atom_getfloat(&argv[1]),
     	    	    	       atom_getfloat(&argv[2]), alpha);
+     break;
+    case(1):
+     alpha = atom_getfloat(argv);
+     GetMyClass(data)->colorMess(alpha, alpha, alpha, 1.);
+     break;
+    default:
+      GetMyClass(data)->error("need 3 or 4 arguments");
+      break;
+    }
 }
 
