@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "colorRGB.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(colorRGB)
+CPPEXTERN_NEW_WITH_GIMME(colorRGB);
 
 /////////////////////////////////////////////////////////
 //
@@ -123,15 +124,15 @@ void colorRGB :: aMess(float val)
 /////////////////////////////////////////////////////////
 void colorRGB :: obj_setupCallback(t_class *classPtr)
 {
-  class_addcreator((t_newmethod)create_colorRGB, 
+  class_addcreator(reinterpret_cast<t_newmethod>(create_colorRGB), 
 		   gensym("colourRGB"), A_GIMME, A_NULL);
-    class_addmethod(classPtr, (t_method)&colorRGB::rMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&colorRGB::rMessCallback),
     	    gensym("rVal"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&colorRGB::gMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&colorRGB::gMessCallback),
     	    gensym("gVal"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&colorRGB::bMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&colorRGB::bMessCallback),
     	    gensym("bVal"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&colorRGB::aMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&colorRGB::aMessCallback),
     	    gensym("aVal"), A_FLOAT, A_NULL); 
 }
 void colorRGB :: rMessCallback(void *data, t_floatarg val)
