@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "depth.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(depth)
+CPPEXTERN_NEW_WITH_GIMME(depth);
 
 /////////////////////////////////////////////////////////
 //
@@ -85,9 +86,9 @@ void depth :: depthMess(int state)
 /////////////////////////////////////////////////////////
 void depth :: obj_setupCallback(t_class *classPtr)
 {
-    class_addfloat(classPtr, (t_method)&depth::depthMessCallback);
+    class_addfloat(classPtr, reinterpret_cast<t_method>(&depth::depthMessCallback));
 }
 void depth :: depthMessCallback(void *data, t_floatarg state)
 {
-    GetMyClass(data)->depthMess((int)state);
+    GetMyClass(data)->depthMess(static_cast<int>(state));
 }
