@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "diffuse.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(diffuse)
+CPPEXTERN_NEW_WITH_GIMME(diffuse);
 
 /////////////////////////////////////////////////////////
 //
@@ -87,7 +88,7 @@ void diffuse :: diffuseMess(float red, float green, float blue, float alpha)
 /////////////////////////////////////////////////////////
 void diffuse :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&diffuse::diffuseMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&diffuse::diffuseMessCallback),
     	    gensym("diffuse"), A_GIMME, A_NULL); 
 }
 void diffuse :: diffuseMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
