@@ -7,18 +7,19 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
-// 1307:forum::fr::umlute:2000
+// 1307:forum::für::umläute:2000
 
 #include "emission.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(emission)
+CPPEXTERN_NEW_WITH_GIMME(emission);
 
 /////////////////////////////////////////////////////////
 //
@@ -89,7 +90,7 @@ void emission :: emissionMess(float red, float green, float blue, float alpha)
 /////////////////////////////////////////////////////////
 void emission :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&emission::emissionMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&emission::emissionMessCallback),
     	    gensym("emission"), A_GIMME, A_NULL); 
 }
 void emission :: emissionMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
