@@ -13,12 +13,90 @@
 /////////////////////////////////////////////////////////
 
 #include "glsl_program.h"
-#include "Base/GemGLUtil.h"
+#include "Utils/GLUtil.h"
 
 #include <string.h>
 #include <stdlib.h>
 
-CPPEXTERN_NEW(glsl_program)
+#include <map>
+
+namespace gem {
+  namespace utils {
+    namespace glsl {
+#define SHADERFLOAT_MIN 1e-7
+      static std::map<t_float, GLuint>s_f2imap;
+
+      static t_float nextfloat(void) {
+#if 1
+	static int seed=0;
+	t_float result=seed+0.5;
+	seed++;
+	seed%=16777216;
+#else
+        static int seed=308;
+        float result=((float)((seed & 0x7fffffff) - 0x40000000)) * (float)(1.0 / 0x40000000);
+        seed = seed * 435898247 + 382842987;
+        result=(1.+result)/2;
+        if(result<=SHADERFLOAT_MIN)result=nextfloat();
+#endif
+        return result;
+      }
+
+      void delshader(GLuint id) {
+        std::map<t_float,GLuint>::iterator it = s_f2imap.find(id);
+        if(s_f2imap.end() != it) {
+          s_f2imap.erase(it);
+        }
+      }
+
+      static t_float getshader(GLuint id) {
+        if(0==id)return 0.f;
+
+        // check whether we already have this shader
+        std::map<t_float,GLuint>::iterator it = s_f2imap.begin();
+        while(s_f2imap.end() != it) {
+          if(it->second==id)
+            return it->first;
+          ++it;
+        }
+        // this shader doesn't exist, return ILLEGAL
+        return 0.;
+      }
+
+      static t_float genshader(GLuint id) {
+        if(0==id)return 0.;
+
+        // check whether we already have this shader
+        t_float f=getshader(id);
+        if(f>SHADERFLOAT_MIN) {
+          return f;
+        }
+
+        // find a free slot for this shader
+        do {
+          f=nextfloat();
+        } while(0!=s_f2imap[f]);
+
+        s_f2imap[f]=id;
+        return f;
+      }
+
+      GLuint atom_getshader (t_atom&ap) {
+        t_float f=atom_getfloat(&ap);
+        GLuint i=s_f2imap[f];
+        return i;
+      };
+
+      void atom_setshader(t_atom&ap, GLuint i) {
+        t_float f=genshader(i);
+        SETFLOAT(&ap, f);
+      };
+
+    }; };
+};
+
+
+CPPEXTERN_NEW(glsl_program);
 
 /////////////////////////////////////////////////////////
 //
@@ -54,6 +132,9 @@ glsl_program :: glsl_program()  :
 /////////////////////////////////////////////////////////
 glsl_program :: ~glsl_program()
 {
+  gem::utils::glsl::delshader(m_program);
+  gem::utils::glsl::delshader(m_programARB);
+
   if(GLEW_VERSION_2_0 && m_program)
     glDeleteProgram( m_program ); m_program=0;
   if(GLEW_ARB_shader_objects && m_programARB)
@@ -130,63 +211,63 @@ void glsl_program :: renderGL2()
               {
 		/* float vectors */
               case GL_FLOAT:
-                glUniform1f( m_loc[i], (GLfloat)m_param[i][0] );
+                glUniform1f( m_loc[i], static_cast<GLfloat>(m_param[i][0]) );
 		break;
               case GL_FLOAT_VEC2:
-                glUniform2f( m_loc[i], (GLfloat)m_param[i][0], (GLfloat)m_param[i][1] );
+                glUniform2f( m_loc[i], static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]) );
 		break;
               case GL_FLOAT_VEC3:
-                glUniform3f( m_loc[i], (GLfloat)m_param[i][0], (GLfloat)m_param[i][1], 
-                                (GLfloat)m_param[i][2] );
+                glUniform3f( m_loc[i], static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]), 
+                                static_cast<GLfloat>(m_param[i][2]) );
 		break;
               case GL_FLOAT_VEC4:
-                glUniform4f( m_loc[i], (GLfloat)m_param[i][0], (GLfloat)m_param[i][1], 
-                                (GLfloat)m_param[i][2], (GLfloat)m_param[i][3] );
+                glUniform4f( m_loc[i], static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]), 
+                                static_cast<GLfloat>(m_param[i][2]), static_cast<GLfloat>(m_param[i][3]) );
 		break;
 		/* int vectors */
               case GL_INT:
-                glUniform1i( m_loc[i], (GLint)m_param[i][0] );
+                glUniform1i( m_loc[i], static_cast<GLint>(m_param[i][0]) );
 		break;
               case GL_INT_VEC2:
-                glUniform2i( m_loc[i], (GLint)m_param[i][0], (GLint)m_param[i][1] );
+                glUniform2i( m_loc[i], static_cast<GLint>(m_param[i][0]), static_cast<GLint>(m_param[i][1]) );
 		break;
               case GL_INT_VEC3:
                 glUniform3i(m_loc[i], 
-			    (GLint)m_param[i][0], (GLint)m_param[i][1], (GLint)m_param[i][2] );
+			    static_cast<GLint>(m_param[i][0]), static_cast<GLint>(m_param[i][1]), static_cast<GLint>(m_param[i][2]) );
 		break;
               case GL_INT_VEC4:
                 glUniform4i(m_loc[i], 
-			    (GLint)m_param[i][0], (GLint)m_param[i][1], 
-			    (GLint)m_param[i][2], (GLint)m_param[i][3] );
+			    static_cast<GLint>(m_param[i][0]), static_cast<GLint>(m_param[i][1]), 
+			    static_cast<GLint>(m_param[i][2]), static_cast<GLint>(m_param[i][3]) );
 		break;
 		/* bool vectors */
               case GL_BOOL:
-                glUniform1f( m_loc[i], (GLfloat)m_param[i][0] );
+                glUniform1f( m_loc[i], static_cast<GLfloat>(m_param[i][0]) );
 		break;
               case GL_BOOL_VEC2:
-                glUniform2f( m_loc[i], (GLfloat)m_param[i][0], (GLfloat)m_param[i][1] );
+                glUniform2f( m_loc[i], static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]) );
 		break;
               case GL_BOOL_VEC3:
                 glUniform3f( m_loc[i], 
-			     (GLfloat)m_param[i][0], (GLfloat)m_param[i][1], 
-			     (GLfloat)m_param[i][2] );
+			     static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]), 
+			     static_cast<GLfloat>(m_param[i][2]) );
 		break;
               case GL_BOOL_VEC4:
                 glUniform4f( m_loc[i], 
-			     (GLfloat)m_param[i][0], (GLfloat)m_param[i][1], 
-			     (GLfloat)m_param[i][2], (GLfloat)m_param[i][3] );
+			     static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]), 
+			     static_cast<GLfloat>(m_param[i][2]), static_cast<GLfloat>(m_param[i][3]) );
 		break;
 
 		/* float matrices */
               case GL_FLOAT_MAT2:
                 // GL_TRUE = row major order, GL_FALSE = column major
-                glUniformMatrix2fv( m_loc[i], 1, GL_FALSE, (GLfloat*)&m_param[i] );
+                glUniformMatrix2fv( m_loc[i], 1, GL_FALSE, m_param[i] );
 		break;
               case GL_FLOAT_MAT3:
-                glUniformMatrix3fv( m_loc[i], 1, GL_FALSE, (GLfloat*)&m_param[i] );
+                glUniformMatrix3fv( m_loc[i], 1, GL_FALSE, m_param[i] );
 		break;
               case GL_FLOAT_MAT4:
-                glUniformMatrix4fv( m_loc[i], 1, GL_FALSE, (GLfloat*)&m_param[i] );
+                glUniformMatrix4fv( m_loc[i], 1, GL_FALSE, m_param[i] );
 		break;
 
 		/* textures */
@@ -199,7 +280,7 @@ void glsl_program :: renderGL2()
 	      case GL_SAMPLER_1D_SHADOW: break;
 	      case GL_SAMPLER_2D_SHADOW: break;
 	      case GL_SAMPLER_2D_RECT_ARB:
-		glUniform1i(m_loc[i], (GLint)m_param[i][0]);
+		glUniform1i(m_loc[i], static_cast<GLint>(m_param[i][0]));
 		break;
               default:
 		;
@@ -228,63 +309,62 @@ void glsl_program :: renderARB()
               {
 		/* float vectors */
               case GL_FLOAT:
-                glUniform1fARB( m_loc[i], (GLfloat)m_param[i][0] );
+                glUniform1fARB( m_loc[i], static_cast<GLfloat>(m_param[i][0]) );
 		break;
               case GL_FLOAT_VEC2_ARB:
-                glUniform2fARB( m_loc[i], (GLfloat)m_param[i][0], (GLfloat)m_param[i][1] );
+                glUniform2fARB( m_loc[i], static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]) );
 		break;
               case GL_FLOAT_VEC3_ARB:
-                glUniform3fARB( m_loc[i], (GLfloat)m_param[i][0], (GLfloat)m_param[i][1], 
-                                (GLfloat)m_param[i][2] );
+                glUniform3fARB( m_loc[i], static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]), 
+                                static_cast<GLfloat>(m_param[i][2]) );
 		break;
               case GL_FLOAT_VEC4_ARB:
-                glUniform4fARB( m_loc[i], (GLfloat)m_param[i][0], (GLfloat)m_param[i][1], 
-                                (GLfloat)m_param[i][2], (GLfloat)m_param[i][3] );
+                glUniform4fARB( m_loc[i], static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]), 
+                                static_cast<GLfloat>(m_param[i][2]), static_cast<GLfloat>(m_param[i][3]) );
 		break;
 
 		/* int vectors */
               case GL_INT:
-                glUniform1iARB( m_loc[i], (GLint)m_param[i][0] );
+                glUniform1iARB( m_loc[i], static_cast<GLint>(m_param[i][0]) );
 		break;
               case GL_INT_VEC2_ARB:
-                glUniform2iARB( m_loc[i], (GLint)m_param[i][0], (GLint)m_param[i][1] );
+                glUniform2iARB( m_loc[i], static_cast<GLint>(m_param[i][0]), static_cast<GLint>(m_param[i][1]) );
 		break;
               case GL_INT_VEC3_ARB:
-                glUniform3iARB( m_loc[i], (GLint)m_param[i][0], (GLint)m_param[i][1], 
-                                (GLint)m_param[i][2] );
+                glUniform3iARB( m_loc[i], static_cast<GLint>(m_param[i][0]), static_cast<GLint>(m_param[i][1]), 
+                                static_cast<GLint>(m_param[i][2]) );
 		break;
               case GL_INT_VEC4_ARB:
-                glUniform4iARB( m_loc[i], (GLint)m_param[i][0], (GLint)m_param[i][1], 
-                                (GLint)m_param[i][2], (GLint)m_param[i][3] );
+                glUniform4iARB( m_loc[i], static_cast<GLint>(m_param[i][0]), static_cast<GLint>(m_param[i][1]), 
+                                static_cast<GLint>(m_param[i][2]), static_cast<GLint>(m_param[i][3]) );
 		break;
 
 		/* bool vectors */
 	      case GL_BOOL_ARB:
-                glUniform1fARB( m_loc[i], (GLfloat)m_param[i][0] );
+                glUniform1fARB( m_loc[i], static_cast<GLfloat>(m_param[i][0]) );
 		break;
               case GL_BOOL_VEC2_ARB:
-                glUniform2fARB( m_loc[i], (GLfloat)m_param[i][0], (GLfloat)m_param[i][1] );
+                glUniform2fARB( m_loc[i], static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]) );
 		break;
               case GL_BOOL_VEC3_ARB:
-                glUniform3fARB( m_loc[i], (GLfloat)m_param[i][0], (GLfloat)m_param[i][1], 
-                                (GLfloat)m_param[i][2] );
+                glUniform3fARB( m_loc[i], static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]), 
+                                static_cast<GLfloat>(m_param[i][2]) );
 		break;
               case GL_BOOL_VEC4_ARB:
-                glUniform4fARB( m_loc[i], (GLfloat)m_param[i][0], (GLfloat)m_param[i][1], 
-                                (GLfloat)m_param[i][2], (GLfloat)m_param[i][3] );
+                glUniform4fARB( m_loc[i], static_cast<GLfloat>(m_param[i][0]), static_cast<GLfloat>(m_param[i][1]), 
+                                static_cast<GLfloat>(m_param[i][2]), static_cast<GLfloat>(m_param[i][3]) );
 		break;
 
-
 		/* float matrices */
               case GL_FLOAT_MAT2_ARB:
                 // GL_TRUE = row major order, GL_FALSE = column major
-                glUniformMatrix2fvARB( m_loc[i], 1, GL_FALSE, (GLfloat*)&m_param[i] );
+                glUniformMatrix2fvARB( m_loc[i], 1, GL_FALSE, m_param[i] );
 		break;
               case GL_FLOAT_MAT3_ARB:
-                glUniformMatrix3fvARB( m_loc[i], 1, GL_FALSE, (GLfloat*)&m_param[i] );
+                glUniformMatrix3fvARB( m_loc[i], 1, GL_FALSE, m_param[i] );
 		break;
               case GL_FLOAT_MAT4_ARB:
-                glUniformMatrix4fvARB( m_loc[i], 1, GL_FALSE, (GLfloat*)&m_param[i] );
+                glUniformMatrix4fvARB( m_loc[i], 1, GL_FALSE, m_param[i] );
 		break;
 
 		/* textures */
@@ -316,7 +396,6 @@ void glsl_program :: renderARB()
 
 void glsl_program :: render(GemState *state)
 {
-  t_floatuint fi_id;
   if(m_wantLink){
     m_wantLink=0;
     LinkProgram();
@@ -326,15 +405,6 @@ void glsl_program :: render(GemState *state)
     renderGL2();
   else 
     renderARB();
-
-  // send program ID to outlet
-  /* JMZ: shouldn't this be only done, when we have a linked program? */
-  if(GLEW_VERSION_2_0)
-    fi_id.i=m_program;
-  else
-    fi_id.i=m_programARB;
-
-  outlet_float(m_outProgramID, (t_float)fi_id.f);
 }
 
 /////////////////////////////////////////////////////////
@@ -402,10 +472,9 @@ void glsl_program :: shaderMess(int argc, t_atom *argv)
     }
   for (i = 0; i < argc; i++)
     {
-      t_floatuint fi;
-      fi.f=atom_getfloat(&argv[i]);
-      m_shaderObj[i] = (GLuint)(fi.i);
-      m_shaderObjARB[i] = (GLhandleARB)(fi.i);
+      GLuint ui=gem::utils::glsl::atom_getshader(argv[i]);
+      m_shaderObj[i]    = ui;
+      m_shaderObjARB[i] = ui;//static_cast<GLhandleARB>(fi.i);
     }
   
   //  not sure what to do here:  we don't want to link & re-link every render cycle,
@@ -426,6 +495,7 @@ bool glsl_program :: LinkGL2()
 
   if(m_program) {
     glDeleteProgram( m_program );
+    gem::utils::glsl::delshader(m_program);
     m_program = 0;
   }
   m_program = glCreateProgram();
@@ -487,6 +557,7 @@ bool glsl_program :: LinkARB()
 
   if(m_programARB) {
     glDeleteObjectARB( m_programARB );
+    gem::utils::glsl::delshader(m_programARB);
     m_programARB = 0;
   }
   m_programARB = glCreateProgramObjectARB();
@@ -554,7 +625,6 @@ void glsl_program :: LinkProgram()
   getVariables();
 
 
-
 #ifdef __APPLE__
   // call API to check if linked program is running on hardware or in software emulation
   GemCGLint vertexGPUProcessing, fragmentGPUProcessing;
@@ -564,6 +634,14 @@ void glsl_program :: LinkProgram()
   post("vertex shader running in %sware", vertexGPUProcessing?"hard":"soft");
   post("fragment shader running in %sware", fragmentGPUProcessing?"hard":"soft");
 #endif //__APPLE__
+
+
+  // send program ID to outlet
+  /* JMZ: shouldn't this be only done, when we have a linked program? */
+  t_atom a;
+  gem::utils::glsl::atom_setshader(a, (GLEW_VERSION_2_0)?m_program:m_programARB);
+  outlet_list(m_outProgramID, 0, 1, &a);
+
 }
 
 /////////////////////////////////////////////////////////
@@ -633,9 +711,23 @@ void glsl_program :: printInfo()
       return;
     }
 
-  post("glsl_program info");
+  post("glsl_program Info");
   post("=================");
 	
+  if(GLEW_VERSION_2_0) {
+    startpost("linked shaders");
+    for (i = 0; i < m_num; i++)  {
+      startpost( " %d", m_shaderObj[i] );
+    } 
+    post(": %d", m_program);
+  } else {
+  startpost("linked ARB-shaders");
+   for (i = 0; i < m_num; i++)  {
+      startpost( " %d", m_shaderObjARB[i] );
+    } 
+    post(": %d", m_programARB);
+  }
+
   post("");
   for (i=0; i<m_uniformCount; i++)
     { 
@@ -737,23 +829,23 @@ void glsl_program:: outverticesMess(GLint vertices) {
 /////////////////////////////////////////////////////////
 void glsl_program :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&glsl_program::shaderMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&glsl_program::shaderMessCallback),
                   gensym("shader"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&glsl_program::linkCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&glsl_program::linkCallback),
                   gensym("link"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&glsl_program::printMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&glsl_program::printMessCallback),
                   gensym("print"), A_NULL);
 
-  class_addmethod(classPtr, (t_method)&glsl_program::intypeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&glsl_program::intypeMessCallback),
                   gensym("geometry_intype"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&glsl_program::outtypeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&glsl_program::outtypeMessCallback),
                   gensym("geometry_outtype"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&glsl_program::typeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&glsl_program::typeMessCallback),
                   gensym("geometry_type"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&glsl_program::outverticesMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&glsl_program::outverticesMessCallback),
                   gensym("geometry_outvertices"), A_FLOAT, A_NULL);
 
-  class_addanything(classPtr, (t_method)&glsl_program::paramMessCallback);
+  class_addanything(classPtr, reinterpret_cast<t_method>(&glsl_program::paramMessCallback));
 }
 void glsl_program :: shaderMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
 {
@@ -778,7 +870,7 @@ void glsl_program :: paramMessCallback(void *data, t_symbol *s, int argc, t_atom
 void glsl_program :: intypeMessCallback(void *data, t_symbol *s, int argc, t_atom *argv)
 {
   if(argc==1) {
-    GetMyClass(data)->intypeMess((GLenum)getGLdefine(argv));
+    GetMyClass(data)->intypeMess(static_cast<GLenum>(getGLdefine(argv)));
   } else {
     GetMyClass(data)->error("input-type must be exactly one parameter");
   }
@@ -787,7 +879,7 @@ void glsl_program :: intypeMessCallback(void *data, t_symbol *s, int argc, t_ato
 void glsl_program :: outtypeMessCallback(void *data, t_symbol *s, int argc, t_atom *argv)
 {
   if(argc==1) {
-    GetMyClass(data)->outtypeMess((GLenum)getGLdefine(argv));
+    GetMyClass(data)->outtypeMess(static_cast<GLenum>(getGLdefine(argv)));
   } else {
     GetMyClass(data)->error("output type must be exactly one parameter");
   }
@@ -796,8 +888,8 @@ void glsl_program :: outtypeMessCallback(void *data, t_symbol *s, int argc, t_at
 void glsl_program :: typeMessCallback(void *data, t_symbol *s, int argc, t_atom *argv)
 {
   if(argc==2) {
-    GetMyClass(data)->intypeMess ((GLenum)getGLdefine(argv+0));
-    GetMyClass(data)->outtypeMess((GLenum)getGLdefine(argv+1));
+    GetMyClass(data)->intypeMess (static_cast<GLenum>(getGLdefine(argv+0)));
+    GetMyClass(data)->outtypeMess(static_cast<GLenum>(getGLdefine(argv+1)));
   } else {
     GetMyClass(data)->error("type must have exactly two parameters (input-type & output-type)");
   }
