@@ -7,17 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "ortho.h"
-#include "Base/GemMan.h"
+#include "Gem/Manager.h"
 
-CPPEXTERN_NEW(ortho)
+CPPEXTERN_NEW(ortho);
 
 /////////////////////////////////////////////////////////
 //
@@ -50,7 +50,7 @@ void ortho :: render(GemState *)
       int width=1, height=1;
       GemMan::getDimen(&width, &height);
 
-      aspect = (m_compat)?1.f:(GLfloat)width / (GLfloat)height;
+      aspect = (m_compat)?1.f:static_cast<GLfloat>(width) / static_cast<GLfloat>(height);
       glPushAttrib(GL_VIEWPORT_BIT);
       glViewport(0, 0, width, height);
       glMatrixMode(GL_PROJECTION);
@@ -102,14 +102,14 @@ void ortho :: compatMess(int state)
 /////////////////////////////////////////////////////////
 void ortho :: obj_setupCallback(t_class *classPtr)
 {
-    class_addfloat (classPtr, (t_method)&ortho::orthoMessCallback);
-    class_addmethod(classPtr, (t_method)&ortho::compatMessCallback,
+    class_addfloat (classPtr, reinterpret_cast<t_method>(&ortho::orthoMessCallback));
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&ortho::compatMessCallback),
 		  gensym("compat"), A_FLOAT, A_NULL);}
 void ortho :: orthoMessCallback(void *data, t_floatarg state)
 {
-    GetMyClass(data)->orthoMess((int)state);
+    GetMyClass(data)->orthoMess(static_cast<int>(state));
 }
 void ortho :: compatMessCallback(void *data, t_floatarg state)
 {
-    GetMyClass(data)->compatMess((int)state);
+    GetMyClass(data)->compatMess(static_cast<int>(state));
 }
