@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "rotate.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(rotate)
+CPPEXTERN_NEW_WITH_GIMME(rotate);
 
 /////////////////////////////////////////////////////////
 //
@@ -100,9 +101,9 @@ void rotate :: vectorMess(float x, float y, float z)
 /////////////////////////////////////////////////////////
 void rotate :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&rotate::angleMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&rotate::angleMessCallback),
     	    gensym("ft1"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&rotate::vectorMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&rotate::vectorMessCallback),
     	    gensym("vector"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL); 
 }
 void rotate :: angleMessCallback(void *data, t_floatarg angle)
