@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "rotateXYZ.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(rotateXYZ)
+CPPEXTERN_NEW_WITH_GIMME(rotateXYZ);
 
 /////////////////////////////////////////////////////////
 //
@@ -105,11 +106,11 @@ void rotateXYZ :: zMess(float val)
 /////////////////////////////////////////////////////////
 void rotateXYZ :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&rotateXYZ::xMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&rotateXYZ::xMessCallback),
     	    gensym("xVal"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&rotateXYZ::yMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&rotateXYZ::yMessCallback),
     	    gensym("yVal"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&rotateXYZ::zMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&rotateXYZ::zMessCallback),
     	    gensym("zVal"), A_FLOAT, A_NULL); 
 }
 void rotateXYZ :: xMessCallback(void *data, t_floatarg val)
