@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "scale.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(scale)
+CPPEXTERN_NEW_WITH_GIMME(scale);
 
 /////////////////////////////////////////////////////////
 //
@@ -99,9 +100,9 @@ void scale :: vectorMess(float x, float y, float z)
 /////////////////////////////////////////////////////////
 void scale :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&scale::distanceMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&scale::distanceMessCallback),
     	    gensym("ft1"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&scale::vectorMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&scale::vectorMessCallback),
     	    gensym("vector"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL); 
 }
 void scale :: distanceMessCallback(void *data, t_floatarg distance)
