@@ -7,18 +7,19 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
-// 1307:forum::fr::umlute:20000
+// 1307:forum::für::umläute:20000
 
 #include "specularRGB.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(specularRGB)
+CPPEXTERN_NEW_WITH_GIMME(specularRGB);
 
 /////////////////////////////////////////////////////////
 //
@@ -135,13 +136,13 @@ void specularRGB :: aMess(float val)
 /////////////////////////////////////////////////////////
 void specularRGB :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&specularRGB::rMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&specularRGB::rMessCallback),
     	    gensym("rVal"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&specularRGB::gMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&specularRGB::gMessCallback),
     	    gensym("gVal"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&specularRGB::bMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&specularRGB::bMessCallback),
     	    gensym("bVal"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&specularRGB::aMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&specularRGB::aMessCallback),
     	    gensym("aVal"), A_FLOAT, A_NULL); 
 }
 void specularRGB :: rMessCallback(void *data, t_floatarg val)
