@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,9 +16,9 @@
 
 #include "spline_path.h"
 
-#include "Base/GemFuncUtil.h"
+#include "Utils/Functions.h"
 
-CPPEXTERN_NEW_WITH_GIMME(spline_path)
+CPPEXTERN_NEW_WITH_GIMME(spline_path);
 
 /////////////////////////////////////////////////////////
 //
