@@ -7,16 +7,17 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "translate.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME(translate)
+CPPEXTERN_NEW_WITH_GIMME(translate);
 
 /////////////////////////////////////////////////////////
 //
@@ -92,9 +93,9 @@ void translate :: vectorMess(float x, float y, float z)
 /////////////////////////////////////////////////////////
 void translate :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&translate::distanceMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&translate::distanceMessCallback),
     	    gensym("ft1"), A_FLOAT, A_NULL); 
-    class_addmethod(classPtr, (t_method)&translate::vectorMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&translate::vectorMessCallback),
     	    gensym("vector"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL); 
 }
 void translate :: distanceMessCallback(void *data, t_floatarg distance)
