@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,9 +16,9 @@
 
 #include "world_light.h"
 
-#include "Base/GemMan.h"
+#include "Gem/Manager.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(world_light, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(world_light, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -42,7 +42,7 @@ world_light :: world_light(t_floatarg lightNum)
   if (lightNum < 1.f)
     num = 0;
   else
-    num = (int)lightNum;
+    num = static_cast<int>(lightNum);
   m_light = GemMan::requestLight(num);
   m_on = 1;
   m_change = 1;
@@ -112,7 +112,7 @@ void world_light :: startRendering()
   if (m_thing)stopRendering();
   m_thing = gluNewQuadric();
   gluQuadricTexture(m_thing, GL_FALSE);
-  gluQuadricDrawStyle(m_thing, (GLenum) GLU_FILL);
+  gluQuadricDrawStyle(m_thing, static_cast<GLenum>(GLU_FILL));
   m_change = 1;
 }
 
@@ -179,11 +179,11 @@ void world_light :: render(GemState *state)
 /////////////////////////////////////////////////////////
 void world_light :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&world_light::lightColorMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&world_light::lightColorMessCallback),
                   gensym("clrlist"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&world_light::debugMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&world_light::debugMessCallback),
                   gensym("debug"), A_FLOAT, A_NULL);
-  class_addfloat(classPtr, (t_method)&world_light::lightOnOffMessCallback);
+  class_addfloat(classPtr, reinterpret_cast<t_method>(&world_light::lightOnOffMessCallback));
 }
 void world_light :: lightColorMessCallback(void *data, t_symbol*,int argc, t_atom*argv)
 {
@@ -203,9 +203,9 @@ void world_light :: lightColorMessCallback(void *data, t_symbol*,int argc, t_ato
 }
 void world_light :: lightOnOffMessCallback(void *data, t_floatarg n)
 {
-  GetMyClass(data)->lightOnOffMess((int)n);
+  GetMyClass(data)->lightOnOffMess(static_cast<int>(n));
 }
 void world_light :: debugMessCallback(void *data, t_floatarg n)
 {
-  GetMyClass(data)->debugMess((int)n);
+  GetMyClass(data)->debugMess(static_cast<int>(n));
 }
