@@ -5,7 +5,7 @@
 //
 // Include this file in all applications that use the Particle System API.
 //
-// (l) 3004:forum::fr::umlute:2003 modified for Gem
+// (l) 3004:forum::für::umläute:2003 modified for Gem
 //                                   added KillSlow again (like in 1.11)
 
 #ifndef _particle_api_h
@@ -16,7 +16,7 @@
 // This is the major and minor version number of this release of the API.
 #define P_VERSION 120
 
-#ifdef __WIN32__
+#ifdef _WIN32
 #include <windows.h>
 #define PARTICLEDLL_API
 #else
