@@ -5,17 +5,17 @@ LOG
 	Set the color for a particle system
 
     Copyright (c) 1997-2000 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PART_COLOR_H_
-#define INCLUDE_PART_COLOR_H_
+#ifndef _INCLUDE__GEM_PARTICLES_PART_COLOR_H_
+#define _INCLUDE__GEM_PARTICLES_PART_COLOR_H_
 
-#include "Base/GemBase.h"
+#include "Particles/partlib_base.h"
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
@@ -28,9 +28,9 @@ CLASS
 DESCRIPTION
 
 -----------------------------------------------------------------*/
-class GEM_EXTERN part_color : public GemBase
+class GEM_EXTERN part_color : public partlib_base
 {
-    CPPEXTERN_HEADER(part_color, GemBase)
+    CPPEXTERN_HEADER(part_color, partlib_base);
 
     public:
 
@@ -39,7 +39,7 @@ class GEM_EXTERN part_color : public GemBase
     	part_color();
     	
     	//////////
-    	virtual void 	render(GemState *state);
+    	virtual void 	renderParticles(GemState *state);
 
     protected:
     	
