@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,9 +16,10 @@
 
 #include "part_head.h"
 
+
 #include "papi.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(part_head, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(part_head, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -47,16 +48,16 @@ part_head :: ~part_head()
 }
 
 /////////////////////////////////////////////////////////
-// render
+// renderParticles
 //
 /////////////////////////////////////////////////////////
-void part_head :: render(GemState *state)
+void part_head :: renderParticles(GemState *state)
 {
 	if (m_particleGroup < 0)
 		return;
 	
 	// The original default was 50.f milliseconds (20 fps)
-	pTimeStep((state->tickTime / 50.f) * m_speed);
+	pTimeStep((m_tickTime / 50.f) * m_speed);
 
 	pCurrentGroup(m_particleGroup);
 }
@@ -76,7 +77,7 @@ void part_head :: speedMess(float speed)
 /////////////////////////////////////////////////////////
 void part_head :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&part_head::speedMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&part_head::speedMessCallback),
     	    gensym("speed"), A_FLOAT, A_NULL);
 }
 void part_head :: speedMessCallback(void *data, t_floatarg speed)
