@@ -5,8 +5,8 @@
 // zmoelnig@iem.kug.ac.at
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2003 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -15,11 +15,11 @@
 #include "part_info.h"
 
 #include <string.h>
-#include "Base/GemState.h"
+
 
 #include "papi.h"
 
-CPPEXTERN_NEW(part_info)
+CPPEXTERN_NEW(part_info);
 
 /////////////////////////////////////////////////////////
 //
@@ -66,12 +66,12 @@ part_info :: ~part_info()
 }
 
 /////////////////////////////////////////////////////////
-// render
+// renderParticles
 //
 /////////////////////////////////////////////////////////
-void part_info :: render(GemState *state)
+void part_info :: renderParticles(GemState *state)
 {
-  if (state->tickTime > 0.f)    {
+  if (m_tickTime > 0.f)    {
     pMove();
   }
   //	pDrawGroupp();
