@@ -5,8 +5,8 @@
 // zmoelnig@iem.kug.ac.at
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -14,9 +14,10 @@
 
 #include "part_killold.h"
 
+
 #include "papi.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(part_killold, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(part_killold, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -42,12 +43,12 @@ part_killold :: ~part_killold()
 { }
 
 /////////////////////////////////////////////////////////
-// render
+// renderParticles
 //
 /////////////////////////////////////////////////////////
-void part_killold :: render(GemState *state)
+void part_killold :: renderParticles(GemState *state)
 {
-	if (state->tickTime > 0.f)
+	if (m_tickTime > 0.f)
 	{
 		pKillOld(m_killAge);
 	}
@@ -59,7 +60,7 @@ void part_killold :: render(GemState *state)
 /////////////////////////////////////////////////////////
 void part_killold :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&part_killold::numberMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&part_killold::numberMessCallback),
     	    gensym("age"), A_FLOAT, A_NULL);
 }
 void part_killold :: numberMessCallback(void *data, t_floatarg num)
