@@ -5,8 +5,8 @@
 // zmoelnig@iem.kug.ac.at
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -15,11 +15,11 @@
 #include "part_render.h"
 
 #include <string.h>
-#include "Base/GemState.h"
+
 
 #include "papi.h"
 
-CPPEXTERN_NEW(part_render)
+CPPEXTERN_NEW(part_render);
 
 /////////////////////////////////////////////////////////
 //
@@ -34,9 +34,9 @@ part_render :: part_render()
   m_colorize=true;
   m_sizing  =true;
   m_number=1000;
-  m_colors = new float[m_number * 4];
-  m_sizes  = new float[m_number];
-  m_pos    = new float[m_number*3];
+  m_colors = new GLfloat[m_number*4];
+  m_sizes  = new GLfloat[m_number*3];
+  m_pos    = new GLfloat[m_number*3];
 }
 
 /////////////////////////////////////////////////////////
@@ -47,12 +47,12 @@ part_render :: ~part_render()
 { }
 
 /////////////////////////////////////////////////////////
-// render
+// renderParticles
 //
 /////////////////////////////////////////////////////////
-void part_render :: render(GemState *state)
+void part_render :: renderParticles(GemState *state)
 {
-  if (state->tickTime > 0.f)    {
+  if (m_tickTime > 0.f)    {
     pMove();
   }
   //	pDrawGroupp();
@@ -60,16 +60,17 @@ void part_render :: render(GemState *state)
   if(cnt < 1)return;
   if (cnt>m_number){
     if(m_colors)delete[]m_colors;
-    if(m_sizes)delete[]m_sizes;
-    if(m_pos)delete[]m_pos;
+    if(m_sizes) delete[]m_sizes;
+    if(m_pos)   delete[]m_pos;
     m_number = cnt;
-    m_colors = new float[m_number * 4];
-    m_sizes  = new float[m_number * 3];
-    m_pos    = new float[m_number * 3];
+
+    m_colors = new GLfloat[m_number * 4];
+    m_sizes  = new GLfloat[m_number * 3];
+    m_pos    = new GLfloat[m_number * 3];
   }
-  float *position = m_pos;
-  float *color = m_colorize ?  m_colors : NULL;
-  float *size = m_sizing ? m_sizes : NULL;
+  GLfloat *position = m_pos;
+  GLfloat *color = m_colorize ?  m_colors : NULL;
+  GLfloat *size = m_sizing ? m_sizes : NULL;
   pGetParticles(0, cnt, position, color, NULL, size);
   for(int i = 0; i < cnt; i++)	{
     glMatrixMode(GL_MODELVIEW);
@@ -115,9 +116,9 @@ void part_render :: sizeMess(int state)
 /////////////////////////////////////////////////////////
 void part_render :: obj_setupCallback(t_class *classPtr)
 {
-   class_addmethod(classPtr, (t_method)&part_render::colorMessCallback,
+   class_addmethod(classPtr, reinterpret_cast<t_method>(&part_render::colorMessCallback),
     	    gensym("colorize"), A_FLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&part_render::sizeMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&part_render::sizeMessCallback),
     	    gensym("size"), A_FLOAT, A_NULL);
 }
 void part_render :: colorMessCallback(void *data,  t_floatarg f)
