@@ -5,8 +5,8 @@
 // zmoelnig@iem.kug.ac.at
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -14,9 +14,11 @@
 
 #include "part_targetcolor.h"
 
+#include "Gem/Exception.h"
+
 #include "papi.h"
 
-CPPEXTERN_NEW_WITH_GIMME(part_targetcolor)
+CPPEXTERN_NEW_WITH_GIMME(part_targetcolor);
 
 /////////////////////////////////////////////////////////
 //
@@ -59,12 +61,12 @@ part_targetcolor :: ~part_targetcolor()
 { }
 
 /////////////////////////////////////////////////////////
-// render
+// renderParticles
 //
 /////////////////////////////////////////////////////////
-void part_targetcolor :: render(GemState *state)
+void part_targetcolor :: renderParticles(GemState *state)
 {
-  if (state->tickTime > 0.f)
+  if (m_tickTime > 0.f)
 	{
 		pTargetColor(m_color[0], m_color[1], m_color[2], m_color[3], m_scale);
 	}
@@ -99,9 +101,9 @@ void part_targetcolor :: colorMess(float red, float green, float blue, float alp
 /////////////////////////////////////////////////////////
 void part_targetcolor :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&part_targetcolor::colorMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&part_targetcolor::colorMessCallback),
     	    gensym("color"), A_GIMME, A_NULL); 
-    class_addmethod(classPtr, (t_method)&part_targetcolor::scaleMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&part_targetcolor::scaleMessCallback),
     	    gensym("ft1"), A_FLOAT, A_NULL); 
 }
 void part_targetcolor :: colorMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
