@@ -5,8 +5,8 @@
 // zmoelnig@iem.kug.ac.at
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -14,9 +14,10 @@
 
 #include "part_targetsize.h"
 
+
 #include "papi.h"
 
-CPPEXTERN_NEW_WITH_TWO_ARGS(part_targetsize, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS(part_targetsize, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -51,12 +52,12 @@ part_targetsize :: ~part_targetsize()
 { }
 
 /////////////////////////////////////////////////////////
-// render
+// renderParticles
 //
 /////////////////////////////////////////////////////////
-void part_targetsize :: render(GemState *state)
+void part_targetsize :: renderParticles(GemState *state)
 {
-  if (state->tickTime > 0.f)
+  if (m_tickTime > 0.f)
 	{
 		pTargetSize(m_size[0], m_size[1], m_size[2],
 			    m_scale[0], m_scale[1], m_scale[2]);
@@ -93,9 +94,9 @@ void part_targetsize :: scaleMess(float scaleX,float scaleY,float scaleZ)
 /////////////////////////////////////////////////////////
 void part_targetsize :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&part_targetsize::sizeMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&part_targetsize::sizeMessCallback),
 		    gensym("ft1"), A_GIMME, A_NULL); 
-    class_addmethod(classPtr, (t_method)&part_targetsize::scaleMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&part_targetsize::scaleMessCallback),
 		    gensym("ft2"), A_GIMME, A_NULL); 
 }
 void part_targetsize :: sizeMessCallback(void *data, t_symbol*s, int argc, t_atom *argv)
