@@ -5,19 +5,19 @@ LOG
 	Set the velocity domain for particles
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PART_VELCONE_H_
-#define INCLUDE_PART_VELCONE_H_
+#ifndef _INCLUDE__GEM_PARTICLES_PART_VELCONE_H_
+#define _INCLUDE__GEM_PARTICLES_PART_VELCONE_H_
 
 #include "papi.h"
 
-#include "Base/GemBase.h"
+#include "Particles/partlib_base.h"
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
@@ -30,9 +30,9 @@ CLASS
 DESCRIPTION
 
 -----------------------------------------------------------------*/
-class GEM_EXTERN part_velcone : public GemBase
+class GEM_EXTERN part_velcone : public partlib_base
 {
-    CPPEXTERN_HEADER(part_velcone, GemBase)
+    CPPEXTERN_HEADER(part_velcone, partlib_base);
 
     public:
 
@@ -41,7 +41,7 @@ class GEM_EXTERN part_velcone : public GemBase
     	part_velcone(t_floatarg val1, t_floatarg val2, t_floatarg val, t_floatarg radius);
     	
     	//////////
-    	virtual void 	render(GemState *state);
+    	virtual void 	renderParticles(GemState *state);
 
     protected:
     	
