@@ -7,17 +7,19 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "part_velocity.h"
+
+
 #include <string.h>
 
-CPPEXTERN_NEW_WITH_GIMME(part_velocity)
+CPPEXTERN_NEW_WITH_GIMME(part_velocity);
 
   /////////////////////////////////////////////////////////
 //
@@ -51,12 +53,12 @@ part_velocity :: ~part_velocity()
 { }
 
 /////////////////////////////////////////////////////////
-// render
+// renderParticles
 //
 /////////////////////////////////////////////////////////
-void part_velocity :: render(GemState *state)
+void part_velocity :: renderParticles(GemState *state)
 {
-  if (state->tickTime > 0.f)
+  if (m_tickTime > 0.f)
     pVelocityD(m_domain,
 	       m_arg[0],m_arg[1],m_arg[2],m_arg[3],m_arg[4],m_arg[5],m_arg[6],m_arg[7],m_arg[8]);
 }
@@ -87,9 +89,9 @@ void part_velocity :: vectorMess(int argc, t_atom*argv){
 /////////////////////////////////////////////////////////
 void part_velocity :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&part_velocity::vectorMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&part_velocity::vectorMessCallback),
 		  gensym("vector"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&part_velocity::domainMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&part_velocity::domainMessCallback),
 		  gensym("domain"), A_SYMBOL, A_NULL);
 }
 void part_velocity :: domainMessCallback(void *data, t_symbol*s)
