@@ -5,8 +5,8 @@
 // zmoelnig@iem.kug.ac.at
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -14,9 +14,10 @@
 
 #include "part_vertex.h"
 
+
 #include "papi.h"
 
-CPPEXTERN_NEW_WITH_THREE_ARGS(part_vertex, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_THREE_ARGS(part_vertex, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
   /////////////////////////////////////////////////////////
 //
@@ -40,12 +41,12 @@ part_vertex :: ~part_vertex()
 { }
 
 /////////////////////////////////////////////////////////
-// render
+// renderParticles
 //
 /////////////////////////////////////////////////////////
-void part_vertex :: render(GemState *state)
+void part_vertex :: renderParticles(GemState *state)
 {
-  if (state->tickTime > 0.f) {
+  if (m_tickTime > 0.f) {
     pVertex(m_x, m_y, m_z);
   }
 }
@@ -56,7 +57,7 @@ void part_vertex :: render(GemState *state)
 /////////////////////////////////////////////////////////
 void part_vertex :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&part_vertex::posMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&part_vertex::posMessCallback),
 		  gensym(""), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
 }
 void part_vertex :: posMessCallback(void *data, t_floatarg x, t_floatarg y, t_floatarg z)
