@@ -6,7 +6,7 @@
 // as an example in implenting this.
 //
 // This file implements the dynamics of particle actions.
-// (l) 3004:forum::fr::umlute:2003 modified for Gem
+// (l) 3004:forum::für::umläute:2003 modified for Gem
 //                                   added KillSlow again (like in 1.11)
 
 #include "partlib_general.h"
@@ -15,7 +15,7 @@
 #define SQRT2PI 2.506628274631000502415765284811045253006
 #define ONEOVERSQRT2PI (1. / SQRT2PI)
 
-#include "Base/GemMath.h"
+#include "Utils/GemMath.h"
 
 // To offset [0 .. 1] vectors to [-.5 .. .5]
 static pVector vHalf(0.5, 0.5, 0.5);
