@@ -4,11 +4,11 @@
 //
 // This file implements the API calls that draw particle groups in OpenGL.
 //
-// (l) 3004:forum::fr::umlute:2003 modified for Gem
+// (l) 3004:forum::für::umläute:2003 modified for Gem
 
 #include "partlib_general.h"
 
-#include "Base/GemGL.h"
+#include "Gem/GemGL.h"
 
 // Emit OpenGL calls to draw the particles. These are drawn with
 // whatever primitive type the user specified(GL_POINTS, for
