@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -16,9 +16,9 @@
 /////////////////////////////////////////////////////////
 
 #include "pix_a_2grey.h"
-#include "Base/GemPixConvert.h"
+#include "Gem/PixConvert.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(pix_a_2grey, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(pix_a_2grey, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -30,7 +30,7 @@ CPPEXTERN_NEW_WITH_ONE_ARG(pix_a_2grey, t_floatarg, A_DEFFLOAT)
 /////////////////////////////////////////////////////////
 pix_a_2grey :: pix_a_2grey(t_floatarg alpha)
 {
-	m_mode = (int)(alpha * 255.f);
+	m_mode = static_cast<int>(alpha * 255.f);
     inlet_new(this->x_obj, &this->x_obj->ob_pd, gensym("float"), gensym("ft1"));
 }
 
@@ -52,7 +52,7 @@ void pix_a_2grey :: alphaMess(float alphaval)
 	if (alphaval < -1.f)
 		alphaval = -1.f;
 
-	m_mode = (int)(alphaval*255.f);
+	m_mode = static_cast<int>(alphaval*255.f);
 
 	setPixModified();
 }
@@ -94,15 +94,15 @@ void pix_a_2grey :: processRGBAImage(imageStruct &image)
 /////////////////////////////////////////////////////////
 void pix_a_2grey :: obj_setupCallback(t_class *classPtr)
 {
-   class_addcreator((t_newmethod)create_pix_a_2grey, 
+   class_addcreator(reinterpret_cast<t_newmethod>(create_pix_a_2grey), 
 		   gensym("pix_a_2gray"), A_NULL);
-   class_addmethod(classPtr, (t_method)&pix_a_2grey::alphaMessCallback,
+   class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_a_2grey::alphaMessCallback),
     	    gensym("ft1"), A_FLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&pix_a_2grey::alphaMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_a_2grey::alphaMessCallback),
     	    gensym("alpha"), A_FLOAT, A_NULL);
 }
 
 void pix_a_2grey :: alphaMessCallback(void *data, t_floatarg alphaval)
 {
-    GetMyClass(data)->alphaMess((float)alphaval);
+    GetMyClass(data)->alphaMess(alphaval);
 }
