@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -17,7 +17,7 @@
 
 #include "pix_alpha.h"
 
-CPPEXTERN_NEW(pix_alpha)
+CPPEXTERN_NEW(pix_alpha);
 
 /////////////////////////////////////////////////////////
 //
@@ -119,14 +119,14 @@ void pix_alpha :: otheralphaMess(float alpha)
 /////////////////////////////////////////////////////////
 void pix_alpha :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&pix_alpha::alphaMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_alpha::alphaMessCallback),
     	    gensym("ft1"), A_FLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&pix_alpha::otheralphaMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_alpha::otheralphaMessCallback),
     	    gensym("ft2"), A_FLOAT, A_NULL);
 
-    class_addmethod(classPtr, (t_method)&pix_alpha::highThreshMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_alpha::highThreshMessCallback),
     	    gensym("high_val"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&pix_alpha::lowThreshMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_alpha::lowThreshMessCallback),
     	    gensym("low_val"), A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
 }
 void pix_alpha :: highThreshMessCallback(void *data, t_floatarg red, t_floatarg green, t_floatarg blue)
