@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -30,7 +30,7 @@
 #include <string.h>
 #include <math.h>
 
-CPPEXTERN_NEW_WITH_GIMME(pix_biquad)
+CPPEXTERN_NEW_WITH_GIMME(pix_biquad);
 
   /////////////////////////////////////////////////////////
 //
@@ -115,12 +115,12 @@ void pix_biquad :: processRGBAImage(imageStruct &image)
     // fast, because calculations are done in int !
     int ifb0,ifb1,ifb2,iff1,iff2,iff3;
     int ioutput;
-    ifb0 = (int)(256. * fb0);
-    ifb1 = (int)(256. * fb1);
-    ifb2 = (int)(256. * fb2);
-    iff1 = (int)(256. * ff1);
-    iff2 = (int)(256. * ff2);
-    iff3 = (int)(256. * ff3);
+    ifb0 = static_cast<int>(256. * fb0);
+    ifb1 = static_cast<int>(256. * fb1);
+    ifb2 = static_cast<int>(256. * fb2);
+    iff1 = static_cast<int>(256. * ff1);
+    iff2 = static_cast<int>(256. * ff2);
+    iff3 = static_cast<int>(256. * ff3);
     
     int max=0;//JMZ
 
@@ -173,12 +173,12 @@ void pix_biquad :: processYUVImage(imageStruct &image)
         // fast, because calculations are done in int !
         int ifb0,ifb1,ifb2,iff1,iff2,iff3;
         int Youtput,UVoutput,Youtput1,UVoutput1;
-        ifb0 = (int)(256. * fb0);
-        ifb1 = (int)(256. * fb1);
-        ifb2 = (int)(256. * fb2);
-        iff1 = (int)(256. * ff1);
-        iff2 = (int)(256. * ff2);
-        iff3 = (int)(256. * ff3);
+        ifb0 = static_cast<int>(256. * fb0);
+        ifb1 = static_cast<int>(256. * fb1);
+        ifb2 = static_cast<int>(256. * fb2);
+        iff1 = static_cast<int>(256. * ff1);
+        iff2 = static_cast<int>(256. * ff2);
+        iff3 = static_cast<int>(256. * ff3);
 
         //it's unrolled but GCC still can't schedule this well at all
         //needs some manual scheduling...
@@ -623,12 +623,12 @@ void pix_biquad :: faktorMess(int argc, t_atom*argv){
 /////////////////////////////////////////////////////////
 void pix_biquad :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&pix_biquad::setMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_biquad::setMessCallback),
 		  gensym("set"), A_NULL);
                   
-  class_addmethod(classPtr, (t_method)&pix_biquad::modeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_biquad::modeMessCallback),
 		  gensym("mode"), A_DEFFLOAT, A_NULL);
-  class_addlist(classPtr, (t_method)&pix_biquad::faktorMessCallback);
+  class_addlist(classPtr, reinterpret_cast<t_method>(&pix_biquad::faktorMessCallback));
 }
 
 void pix_biquad :: faktorMessCallback(void *data, t_symbol *s, int argc, t_atom* argv)
@@ -643,5 +643,5 @@ void pix_biquad :: setMessCallback(void *data)
 
 void pix_biquad :: modeMessCallback(void *data, float value)
 {
-  GetMyClass(data)->m_mode = (int)value;
+  GetMyClass(data)->m_mode = static_cast<int>(value);
 }
