@@ -7,18 +7,19 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "pix_buf.h"
+#include "Gem/State.h"
 
-#include "Base/GemCache.h"
+#include "Gem/Cache.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(pix_buf, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(pix_buf, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -46,15 +47,26 @@ pix_buf :: ~pix_buf()
 /////////////////////////////////////////////////////////
 void pix_buf :: render(GemState *state)
 {
-  m_banged|=m_auto;
+  if(!state)return;
+  bool doit=m_banged;
+  pixBlock*img=NULL;
+  state->get(GemState::_PIX, img);
+  orgPixBlock = img;
+
+  if (!img || !img->image.data) return;
+
+  doit|=m_auto;
+  doit|=img->newimage;
+
+  if (m_cache&&m_cache->resendImage)
+    doit=true;
+
   cachedPixBlock.newimage = 0;
-  if (!state || !state->image || !&state->image->image) return;
-  if (state->image->newimage || m_banged){
-    orgPixBlock = state->image;
-    state->image->image.copy2Image(&cachedPixBlock.image);
+  if (doit) {
+    img->image.copy2Image(&cachedPixBlock.image);
     cachedPixBlock.newimage = 1;
   }
-  state->image = &cachedPixBlock;
+  state->set(GemState::_PIX, &cachedPixBlock);
   m_banged = false;
 }
 
@@ -64,7 +76,7 @@ void pix_buf :: render(GemState *state)
 /////////////////////////////////////////////////////////
 void pix_buf :: postrender(GemState *state)
 {
-  state->image = orgPixBlock;
+  state->set(GemState::_PIX, orgPixBlock);
 }
 
 /////////////////////////////////////////////////////////
@@ -89,10 +101,10 @@ void pix_buf :: autoMess(int a)
 /////////////////////////////////////////////////////////
 void pix_buf :: obj_setupCallback(t_class *classPtr)
 { 
-  class_addcreator((t_newmethod)create_pix_buf, 
+  class_addcreator(reinterpret_cast<t_newmethod>(create_pix_buf), 
 		   gensym("pix_separator"), A_DEFFLOAT, A_NULL);
   class_addbang(classPtr, &pix_buf::bangMessCallback);
-  class_addmethod(classPtr, (t_method)&pix_buf::autoMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_buf::autoMessCallback),
 		  gensym("auto"), A_FLOAT, A_NULL);
 
 }
