@@ -5,19 +5,18 @@ LOG
     buffer a pixBlock
 
     Copyright (c) 1997-1998 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_BUF_H_
-#define INCLUDE_PIX_BUF_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_BUF_H_
+#define _INCLUDE__GEM_PIXES_PIX_BUF_H_
 
 #include "Base/GemBase.h"
-#include "Base/GemPixUtil.h"
-#include "Base/GemState.h"
+#include "Gem/Image.h"
 
 class GemCache;
 
@@ -38,7 +37,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_buf : public GemBase
 {
-    CPPEXTERN_HEADER(pix_buf, GemBase)
+    CPPEXTERN_HEADER(pix_buf, GemBase);
 
     public:
 
