@@ -1,4 +1,4 @@
-////////////////////////////////////////////////////////
+///////////////////////////////////////////////////////
 //
 // GEM - Graphics Environment for Multimedia
 //
@@ -6,7 +6,7 @@
 //
 // Implementation file
 //
-//    Copyleft  (l) 2002 IOhannes m zmlnig
+//    Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -17,8 +17,7 @@
 #define NO_STATIC_CLASS
 
 #include "pix_buffer.h"
-#include "Base/GemPixImageLoad.h"
-#include "Base/GemPixImageSave.h"
+#include "Gem/ImageIO.h"
 
 #include <string.h>
 #include <stdio.h>
@@ -29,7 +28,7 @@
 //
 /////////////////////////////////////////////////////////
 
-CPPEXTERN_NEW_WITH_TWO_ARGS(pix_buffer, t_symbol*,A_DEFSYM,t_float,A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS(pix_buffer, t_symbol*,A_DEFSYM,t_float,A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 // Constructor
@@ -43,7 +42,7 @@ pix_buffer :: pix_buffer(t_symbol *s,t_float f=100.0)
     buffercounter++;
     sprintf(cbuf, "pix_buffer_%04d", buffercounter);
     cbuf[15]=0;
-    post("defaulting to namne '%s'", cbuf);
+    post("defaulting to name '%s'", cbuf);
     s=gensym(cbuf);
   }
 
@@ -187,7 +186,6 @@ void pix_buffer :: openMess(t_symbol *filename, int pos)
   // GRH: muss i wie in pix_image die ganzen andern Sachen a machen ????
 
   // load an image into mem
-  char buf[MAXPDSTRING];
   imageStruct *image = NULL;
 
   // some checks
@@ -196,12 +194,12 @@ void pix_buffer :: openMess(t_symbol *filename, int pos)
     error("index %d out of range (0..%d)!", pos, m_numframes);
     return;
   }
+  std::string file=findFile(filename->s_name);
 
-  canvas_makefilename(getCanvas(), filename->s_name, buf, MAXPDSTRING);
-  image = image2mem(buf);
+  image = image2mem(file.c_str());
   if(!image)
   {
-    error("no valid image!");
+    error("'%s' is no valid image!", file.c_str());
     return;
   }
 
@@ -259,19 +257,21 @@ void pix_buffer :: copyMess(int src, int dst)
 /////////////////////////////////////////////////////////
 void pix_buffer :: obj_setupCallback(t_class *classPtr)
 {
-  class_addcreator((t_newmethod)create_pix_buffer,gensym("pix_depot"),A_DEFSYM,A_DEFFLOAT,A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_buffer::allocateMessCallback,
+  class_addcreator(reinterpret_cast<t_newmethod>(create_pix_buffer),
+                   gensym("pix_depot"),
+                   A_DEFSYM, A_DEFFLOAT, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_buffer::allocateMessCallback),
   		  gensym("allocate"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_buffer::resizeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_buffer::resizeMessCallback),
   		  gensym("resize"), A_FLOAT, A_NULL);
-  class_addbang(classPtr, (t_method)&pix_buffer::bangMessCallback);
-  class_addmethod(classPtr, (t_method)&pix_buffer::openMessCallback,
+  class_addbang(classPtr, reinterpret_cast<t_method>(&pix_buffer::bangMessCallback));
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_buffer::openMessCallback),
   		  gensym("open"), A_SYMBOL, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_buffer::openMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_buffer::openMessCallback),
   		  gensym("load"), A_SYMBOL, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_buffer::saveMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_buffer::saveMessCallback),
   		  gensym("save"), A_SYMBOL, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_buffer::copyMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_buffer::copyMessCallback),
   		  gensym("copy"), A_FLOAT, A_FLOAT, A_NULL);
 }
 void pix_buffer :: allocateMessCallback(void *data, t_symbol*s, int argc, t_atom*argv)
