@@ -5,18 +5,18 @@ LOG
 
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyleft  (l) 2001 IOhannes m zmlnig. zmoelnig@iem.kug.ac.at
-    Copyleft (l) 2002 James Tittle & Chris Clepper
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
+    Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_BUFFER_H_
-#define INCLUDE_PIX_BUFFER_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_BUFFER_H_
+#define _INCLUDE__GEM_PIXES_PIX_BUFFER_H_
 
 #include "Base/CPPExtern.h"
-#include "Base/GemPixUtil.h"
+#include "Gem/Image.h"
 
 #define DEFAULT_NUM_FRAMES 100
 
@@ -36,7 +36,7 @@ LOG
   -----------------------------------------------------------------*/
 class GEM_EXTERN pix_buffer : public CPPExtern
 {
-  CPPEXTERN_HEADER(pix_buffer, CPPExtern)
+  CPPEXTERN_HEADER(pix_buffer, CPPExtern);
 
     public:
 
