@@ -6,8 +6,8 @@
 //
 // Implementation file
 //
-//    Copyleft  (l) 2002 IOhannes m zmlnig
-//    Copyleft  (l) 2005 Georg Holzmann
+//    Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
+//    Copyright (c) 2005 Georg Holzmann
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -15,7 +15,7 @@
 
 #include "pix_buffer.h"
 #include "pix_buffer_read.h"
-
+#include "Gem/State.h"
 
 /*
  * we export the "pix_buffer_class"
@@ -34,7 +34,7 @@ extern t_class *pix_buffer_class;
 //
 /////////////////////////////////////////////////////////
 
-CPPEXTERN_NEW_WITH_ONE_ARG(pix_buffer_read, t_symbol*,A_DEFSYM)
+CPPEXTERN_NEW_WITH_ONE_ARG(pix_buffer_read, t_symbol*,A_DEFSYM);
 
 
 /////////////////////////////////////////////////////////
@@ -158,7 +158,7 @@ void pix_buffer_read :: render(GemState*state)
   if (!m_haveImage) return;
 
   /* push the incoming state->image into a temporary memory */
-  orgPixBlock = state->image;
+  state->get(GemState::_PIX, orgPixBlock);
 
   /*
     pd_findbyclass costs at least 2 if's
@@ -168,7 +168,7 @@ void pix_buffer_read :: render(GemState*state)
   */ 
   if (NULL==pd_findbyclass(m_bindname, pix_buffer_class)) return;
 
-  state->image = &m_pixBlock;
+  state->set(GemState::_PIX, &m_pixBlock);
 
 }
 
@@ -187,7 +187,7 @@ void pix_buffer_read :: postrender(GemState *state)
     }
 
   /* restore the original incoming image */
-  state->image = orgPixBlock;
+  state->set(GemState::_PIX, orgPixBlock);
 }
 
 /////////////////////////////////////////////////////////
@@ -204,14 +204,16 @@ void pix_buffer_read :: startRendering()
 /////////////////////////////////////////////////////////
 void pix_buffer_read :: obj_setupCallback(t_class *classPtr)
 {
-  class_addcreator((t_newmethod)create_pix_buffer_read,gensym("pix_get"),A_DEFSYM,A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_buffer_read::setMessCallback,
+  class_addcreator(reinterpret_cast<t_newmethod>(create_pix_buffer_read),
+                   gensym("pix_get"),
+                   A_DEFSYM, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_buffer_read::setMessCallback),
   		  gensym("set"), A_SYMBOL, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_buffer_read::frameMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_buffer_read::frameMessCallback),
   		  gensym("frame"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_buffer_read::autoMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_buffer_read::autoMessCallback),
   		  gensym("auto"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_buffer_read::loopMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_buffer_read::loopMessCallback),
   		  gensym("loop"), A_FLOAT, A_NULL);
 }
 void pix_buffer_read :: setMessCallback(void *data, t_symbol*s)
