@@ -8,8 +8,8 @@ LOG
     Copyright (c) 2002-2006 cgc. All rights reserved.
  
     Copyright (c) 1997-2000 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -17,7 +17,7 @@ LOG
 
 #include "pix_chroma_key.h"
 
-CPPEXTERN_NEW(pix_chroma_key)
+CPPEXTERN_NEW(pix_chroma_key);
 
 /////////////////////////////////////////////////////////
 //
@@ -677,16 +677,16 @@ register int h,w,i,j,width;
 /////////////////////////////////////////////////////////
 void pix_chroma_key :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&pix_chroma_key::directionCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_chroma_key::directionCallback),
 		  gensym("direction"), A_DEFFLOAT, A_NULL);
                   
-  class_addmethod(classPtr, (t_method)&pix_chroma_key::modeCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_chroma_key::modeCallback),
 		  gensym("mode"), A_DEFFLOAT, A_NULL);
                   
-    class_addmethod(classPtr, (t_method)&pix_chroma_key::rangeCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_chroma_key::rangeCallback),
 		  gensym("range"), A_DEFFLOAT, A_DEFFLOAT, A_DEFFLOAT, A_NULL);
                   
-    class_addmethod(classPtr, (t_method)&pix_chroma_key::valueCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_chroma_key::valueCallback),
 		  gensym("value"), A_DEFFLOAT, A_DEFFLOAT, A_DEFFLOAT, A_NULL);
 }
 
