@@ -8,11 +8,11 @@
  *
  */
 
-#ifndef INCLUDE_pix_chroma_key_H_ 
-#define INCLUDE_pix_chroma_key_H_ 
+#ifndef _INCLUDE__GEM_PIXES_PIX_CHROMA_KEY_H_ 
+#define _INCLUDE__GEM_PIXES_PIX_CHROMA_KEY_H_ 
 
 #include "Base/GemPixDualObj.h"
-#include "Base/GemFuncUtil.h"
+#include "Utils/Functions.h"
 
 
 /*-----------------------------------------------------------------
@@ -34,7 +34,7 @@ DESCRIPTION
 
 class GEM_EXTERN pix_chroma_key : public GemPixDualObj
 {
-CPPEXTERN_HEADER(pix_chroma_key, GemPixDualObj)
+CPPEXTERN_HEADER(pix_chroma_key, GemPixDualObj);
 
     public:
 
