@@ -5,16 +5,16 @@ LOG
     Change the overall color of a pix image
 
     Copyright (c) 1997-1998 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_COLOR_H_
-#define INCLUDE_PIX_COLOR_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_COLOR_H_
+#define _INCLUDE__GEM_PIXES_PIX_COLOR_H_
 
 #include "Base/GemPixObj.h"
 
@@ -37,7 +37,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class pix_color : public GemPixObj
 {
-    CPPEXTERN_HEADER(pix_color, GemPixObj)
+    CPPEXTERN_HEADER(pix_color, GemPixObj);
 
     public:
 
