@@ -12,9 +12,10 @@
 //
 /////////////////////////////////////////////////////////
 
+#include "Utils/PixPete.h"
 #include "pix_colorreduce.h"
 
-CPPEXTERN_NEW(pix_colorreduce)
+CPPEXTERN_NEW(pix_colorreduce);
 
 /////////////////////////////////////////////////////////
 //
@@ -101,16 +102,16 @@ void pix_colorreduce :: processRGBAImage(imageStruct &image)
 	Pete_ColorReduce_Init();
 	init = 1;
     }
-    pSource = (U32*)image.data;
+    pSource = reinterpret_cast<U32*>(image.data);
 
     myImage.xsize = image.xsize;
     myImage.ysize = image.ysize;
     myImage.csize = image.csize;
     myImage.type  = image.type;
     myImage.reallocate();
-    pOutput = (U32*)myImage.data;
+    pOutput = reinterpret_cast<U32*>(myImage.data);
 	
-    const int nColors=(int)m_TargetColorCount;
+    const int nColors=static_cast<int>(m_TargetColorCount);
     const float PalettePersistence=m_PalettePersistence;
     const float BoundarySmoothing=m_BoundarySmoothing;
 
@@ -278,15 +279,15 @@ inline U32 pix_colorreduce :: Pete_ColorReduce_GetClosestColor(U32 Color,SPete_C
 
 		const float OneMinusLerpValue=(1.0f-WeightedLerpValue);
 
-		const int nSmoothedRed=(int)(
+		const int nSmoothedRed=static_cast<int>(
 			(nClosestRed*WeightedLerpValue)+
 			(nNextClosestRed*OneMinusLerpValue));
 
-		const int nSmoothedGreen=(int)(
+		const int nSmoothedGreen=static_cast<int>(
 			(nClosestGreen*WeightedLerpValue)+
 			(nNextClosestGreen*OneMinusLerpValue));
 
-		const int nSmoothedBlue=(int)(
+		const int nSmoothedBlue=static_cast<int>(
 			(nClosestBlue*WeightedLerpValue)+
 			(nNextClosestBlue*OneMinusLerpValue));
 
@@ -499,13 +500,13 @@ void pix_colorreduce :: Pete_ColorReduce_SetupInverseColorMap(int** ppSortedColo
 /////////////////////////////////////////////////////////
 void pix_colorreduce :: obj_setupCallback(t_class *classPtr)
 {
-  class_addcreator((t_newmethod)create_pix_colorreduce, 
+  class_addcreator(reinterpret_cast<t_newmethod>(create_pix_colorreduce), 
 		   gensym("pix_colourreduce"), A_NULL);
-    class_addmethod(classPtr, (t_method)&pix_colorreduce::countCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_colorreduce::countCallback),
 		  gensym("count"), A_DEFFLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&pix_colorreduce::persistCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_colorreduce::persistCallback),
 		  gensym("persist"), A_DEFFLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&pix_colorreduce::smoothCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_colorreduce::smoothCallback),
 		  gensym("smooth"), A_DEFFLOAT, A_NULL);
 }
 void pix_colorreduce :: countCallback(void *data, t_floatarg m_TargetColorCount)
@@ -526,6 +527,6 @@ void pix_colorreduce :: persistCallback(void *data, t_floatarg m_PalettePersiste
 
 void pix_colorreduce :: smoothCallback(void *data, t_floatarg m_BoundarySmoothing)
 {
-  GetMyClass(data)->m_BoundarySmoothing=!(!(int)m_BoundarySmoothing);  
+  GetMyClass(data)->m_BoundarySmoothing=!(!static_cast<int>(m_BoundarySmoothing));  
   GetMyClass(data)->setPixModified();
 }
