@@ -8,13 +8,13 @@ LOG
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_COLORREDUCE_H_
-#define INCLUDE_PIX_COLORREDUCE_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_COLORREDUCE_H_
+#define _INCLUDE__GEM_PIXES_PIX_COLORREDUCE_H_
 
 #include "Base/GemPixObj.h"
 
 #ifdef __ppc__
-#include "Base/GemFuncUtil.h"
+#include "Utils/Functions.h"
 #undef sqrt
 #define sqrt fast_sqrtf
 #endif
@@ -38,7 +38,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_colorreduce : public GemPixObj
 {
-    CPPEXTERN_HEADER(pix_colorreduce, GemPixObj)
+    CPPEXTERN_HEADER(pix_colorreduce, GemPixObj);
 
     public:
 
