@@ -4,8 +4,8 @@ LOG
 
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyright (c) G¸nther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::f¸r::uml‰ute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) GÂžnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     Copyright (c) 2003 Daniel Heckenberg
 
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
@@ -13,8 +13,8 @@ LOG
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_pix_compare_H_ 
-#define INCLUDE_pix_compare_H_ 
+#ifndef _INCLUDE__GEM_PIXES_PIX_COMPARE_H_ 
+#define _INCLUDE__GEM_PIXES_PIX_COMPARE_H_ 
 
 #include "Base/GemPixDualObj.h"
 
@@ -37,7 +37,7 @@ DESCRIPTION
 
 class GEM_EXTERN pix_compare : public GemPixDualObj
 {
-CPPEXTERN_HEADER(pix_compare, GemPixDualObj)
+CPPEXTERN_HEADER(pix_compare, GemPixDualObj);
 
     public:
 
