@@ -7,15 +7,15 @@
  *
  */
 
-#ifndef INCLUDE_PIX_CONTRAST_H_
-#define INCLUDE_PIX_CONTRAST_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_CONTRAST_H_
+#define _INCLUDE__GEM_PIXES_PIX_CONTRAST_H_
 
 #include "Base/GemPixObj.h"
 
 
 class GEM_EXTERN pix_contrast : public GemPixObj
 {
-    CPPEXTERN_HEADER(pix_contrast, GemPixObj)
+    CPPEXTERN_HEADER(pix_contrast, GemPixObj);
 
     public:
 
