@@ -7,7 +7,7 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -19,7 +19,7 @@
 
 #include "pix_convert.h"
 
-CPPEXTERN_NEW(pix_convert)
+CPPEXTERN_NEW(pix_convert);
 
 /////////////////////////////////////////////////////////
 //
@@ -81,7 +81,7 @@ void pix_convert :: processImage(imageStruct &image)
 /////////////////////////////////////////////////////////
 void pix_convert :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&pix_convert::colorMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_convert::colorMessCallback),
 		  gensym("color"), A_SYMBOL, A_NULL);
 }
 void pix_convert :: colorMessCallback(void *data, t_symbol*s)
