@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,10 +16,10 @@
 
 #include "pix_coordinate.h"
 
-#include "Base/GemState.h"
-#include "Base/GemPixUtil.h"
+#include "Gem/State.h"
+#include "Gem/Image.h"
 
-CPPEXTERN_NEW(pix_coordinate)
+CPPEXTERN_NEW(pix_coordinate);
 
 /////////////////////////////////////////////////////////
 //
@@ -53,28 +53,32 @@ pix_coordinate :: ~pix_coordinate()
 /////////////////////////////////////////////////////////
 void pix_coordinate :: render(GemState *state)
 {
-  m_oldTexCoords=state->texCoords;
-  m_oldNumCoords=state->numTexCoords;
+  pixBlock*img=NULL;
+  state->get(GemState::_PIX, img);
 
-    if (state->texture && m_numCoords){
-        state->numTexCoords = m_numCoords;
+  state->get(GemState::_GL_TEX_COORDS, m_oldTexCoords);
+  state->get(GemState::_GL_TEX_NUMCOORDS, m_oldNumCoords);
+  state->get(GemState::_GL_TEX_TYPE, m_oldTexType);
 
-	if(state->texture==2 && state->image!=NULL){ 
+  if (m_oldTexType && m_numCoords){
+    state->set(GemState::_GL_TEX_NUMCOORDS, m_numCoords);
+
+	if(m_oldTexType==2 && img!=NULL){ 
 	  // since we are using rectangle-textures (state->texture==2), 
 	  // we want to scale the coordinates by the image-dimensions if they are available
-	  t_float xsize = (t_float)state->image->image.xsize;
-	  t_float ysize = (t_float)state->image->image.ysize;
+	  t_float xsize = (t_float)img->image.xsize;
+	  t_float ysize = (t_float)img->image.ysize;
 
 	  for (int i = 0; i <  m_numCoords; i++)
 	    {
 	      m_rectcoords[i].s = xsize*m_coords[i].s;
 	      m_rectcoords[i].t = ysize*m_coords[i].t;
 	    }
-	  state->texCoords=m_rectcoords;
+    state->set(GemState::_GL_TEX_COORDS, m_rectcoords);
 
 	} else
-        state->texCoords = m_coords;
-    }
+    state->set(GemState::_GL_TEX_COORDS, m_coords);
+  }
 }
 
 /////////////////////////////////////////////////////////
@@ -83,8 +87,9 @@ void pix_coordinate :: render(GemState *state)
 /////////////////////////////////////////////////////////
 void pix_coordinate :: postrender(GemState *state)
 {
-  state->texCoords= m_oldTexCoords;
-  state->numTexCoords=  m_oldNumCoords;
+  state->set(GemState::_GL_TEX_COORDS, m_oldTexCoords);
+  state->set(GemState::_GL_TEX_NUMCOORDS, m_oldNumCoords);
+  state->set(GemState::_GL_TEX_TYPE, m_oldTexType);
 }
 
 /////////////////////////////////////////////////////////
@@ -125,7 +130,7 @@ void pix_coordinate :: coordsMess(int argc, t_atom *argv)
 /////////////////////////////////////////////////////////
 void pix_coordinate :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&pix_coordinate::coordsMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_coordinate::coordsMessCallback),
     	    gensym("coords"), A_GIMME, A_NULL);
 }
 void pix_coordinate :: coordsMessCallback(void *data, t_symbol *, int argc, t_atom *argv)
