@@ -6,7 +6,7 @@
 //
 // Implementation file
 //
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -14,9 +14,9 @@
 
 #include "pix_crop.h"
 
-CPPEXTERN_NEW_WITH_FOUR_ARGS(pix_crop, t_float,A_DEFFLOAT,t_float, A_DEFFLOAT, t_float,A_DEFFLOAT,t_float, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_FOUR_ARGS(pix_crop, t_float,A_DEFFLOAT,t_float, A_DEFFLOAT, t_float,A_DEFFLOAT,t_float, A_DEFFLOAT);
 
-  /////////////////////////////////////////////////////////
+/////////////////////////////////////////////////////////
 //
 // pix_crop
 //
@@ -29,6 +29,10 @@ pix_crop :: pix_crop(t_floatarg x=0, t_floatarg y=0, t_floatarg w=64, t_floatarg
   m_data = NULL;
   m_size = 0;
 
+  if(w<=1. && h<=1.) {
+    w=h=64.;
+  }
+
   offsetMess((int)x,(int)y);
   dimenMess((int)w,(int)h);
 
@@ -125,17 +129,17 @@ void pix_crop :: offsetMess(int x, int y){
 //
 /////////////////////////////////////////////////////////
 void pix_crop :: obj_setupCallback(t_class *classPtr){
-  class_addmethod(classPtr, (t_method)&pix_crop::dimenMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_crop::dimenMessCallback), 
 		  gensym("dimen"), A_FLOAT, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_crop::offsetMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_crop::offsetMessCallback), 
 		  gensym("offset"), A_FLOAT, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_crop::dimXMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_crop::dimXMessCallback), 
 		  gensym("dimenX"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_crop::dimYMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_crop::dimYMessCallback), 
 		  gensym("dimenY"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_crop::offXMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_crop::offXMessCallback), 
 		  gensym("offsetX"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_crop::offYMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_crop::offYMessCallback), 
 		  gensym("offsetY"), A_FLOAT, A_NULL);}
 
 void pix_crop :: dimenMessCallback(void *data, t_float x, t_float y){
