@@ -5,16 +5,16 @@ LOG
     Get pixel information
 
     Copyright (c) 1997-1998 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_DATA_H_
-#define INCLUDE_PIX_DATA_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_DATA_H_
+#define _INCLUDE__GEM_PIXES_PIX_DATA_H_
 
 #include "Base/GemPixDualObj.h"
 
@@ -39,7 +39,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_data : public GemPixDualObj
 {
-    CPPEXTERN_HEADER(pix_data, GemPixDualObj)
+    CPPEXTERN_HEADER(pix_data, GemPixDualObj);
 
     public:
 
@@ -64,16 +64,20 @@ class GEM_EXTERN pix_data : public GemPixDualObj
     	virtual void 	processDualImage(imageStruct &, imageStruct &)	{}
 
         //////////
-        void			trigger();
+        void			trigger(void);
 
         //////////
-        void			xPos(float pos)			{ m_position[0] = pos; }
+        void			xPos(t_float pos);
 
         //////////
-        void			yPos(float pos)			{ m_position[1] = pos; }
+        void			yPos(t_float pos);
 
         //////////
-        float			m_position[2];
+        t_float			m_position[2];
+
+        //////////
+        void			qualityMess(int q);
+        int m_quality;
 
         //////////
         // The color outlet
