@@ -6,7 +6,7 @@
 //
 // Implementation file
 //
-//    Copyleft  (l) 2002 IOhannes m zmlnig
+//    Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -14,7 +14,7 @@
 #include "pix_delay.h"
 #include <string.h>
 
-CPPEXTERN_NEW_WITH_ONE_ARG(pix_delay, t_float,A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(pix_delay, t_float,A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -96,7 +96,7 @@ void pix_delay :: processImage(imageStruct &image)
 /////////////////////////////////////////////////////////
 void pix_delay :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&pix_delay::delayMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_delay::delayMessCallback),
   		  gensym("delay"), A_FLOAT, A_NULL);
 }
 
