@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,9 +16,10 @@
 
 #include "pix_draw.h"
 
-#include "Base/GemPixUtil.h"
+#include "Gem/Image.h"
+#include "Gem/State.h"
 
-CPPEXTERN_NEW(pix_draw)
+CPPEXTERN_NEW(pix_draw);
 
 /////////////////////////////////////////////////////////
 //
@@ -54,23 +55,25 @@ pix_draw :: ~pix_draw()
 void pix_draw :: render(GemState *state)
 {
   int orientation=1;
-    if ( !state->image || !&state->image->image ) return;
-    glRasterPos2i(0, 0);
-    // hack to center image at 0,0
-    if(state->image->image.upsidedown)
-      orientation=-1;
+  pixBlock*img=NULL;
+  state->get(GemState::_PIX, img);
+  if ( !img || !&img->image ) return;
+  glRasterPos2i(0, 0);
+  // hack to center image at 0,0
+  if(img->image.upsidedown)
+    orientation=-1;
 
-    glPixelZoom(1,orientation);
+  glPixelZoom(1,orientation);
 
-    glBitmap(0, 0, 0.f, 0.f, -(state->image->image.xsize)/2.f, 
-	     -orientation*(state->image->image.ysize)/2.f, 0);
+  glBitmap(0, 0, 0.f, 0.f, -(img->image.xsize)/2.f, 
+           -orientation*(img->image.ysize)/2.f, 0);
 
-    glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
-    glDrawPixels(state->image->image.xsize,
-		 state->image->image.ysize,
-		 state->image->image.format,
-		 state->image->image.type,
-		 state->image->image.data);
+  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
+  glDrawPixels(img->image.xsize,
+               img->image.ysize,
+               img->image.format,
+               img->image.type,
+               img->image.data);
 }
 
 /////////////////////////////////////////////////////////
