@@ -5,15 +5,15 @@ LOG
     A pix_draw
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_DRAW_H_
-#define INCLUDE_PIX_DRAW_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_DRAW_H_
+#define _INCLUDE__GEM_PIXES_PIX_DRAW_H_
 
 #include "Base/GemBase.h"
 
@@ -32,7 +32,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_draw : public GemBase
 {
-    CPPEXTERN_HEADER(pix_draw, GemBase)
+    CPPEXTERN_HEADER(pix_draw, GemBase);
 
     public:
 
