@@ -7,8 +7,8 @@
  *
  */
 
-#ifndef INCLUDE_PIX_EMBOSS_H_ 
-#define INCLUDE_PIX_EMBOSS_H_ 
+#ifndef _INCLUDE__GEM_PIXES_PIX_EMBOSS_H_ 
+#define _INCLUDE__GEM_PIXES_PIX_EMBOSS_H_ 
 
 #include "Base/GemPixObj.h"
 
@@ -32,7 +32,7 @@ DESCRIPTION
 
 class GEM_EXTERN pix_emboss : public GemPixObj
 {
-  CPPEXTERN_HEADER(pix_emboss, GemPixObj)
+  CPPEXTERN_HEADER(pix_emboss, GemPixObj);
 
     public:
 
