@@ -7,26 +7,27 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
-#ifndef __APPLE__
+#include "Gem/GemConfig.h"
+#ifndef GEM_FILMBACKEND
 
 #include "pix_film.h"
-#include <ctype.h>
+#include "Gem/Image.h"
 
-#include "Pixes/filmGMERLIN.h"
-#include "Pixes/filmQT4L.h"
-#include "Pixes/filmAVI.h"
-#include "Pixes/filmDS.h"
-#include "Pixes/filmAVIPLAY.h"
-#include "Pixes/filmMPEG1.h"
-#include "Pixes/filmMPEG3.h"
-#include "Pixes/filmQT.h"
+#include "Gem/State.h"
+#include "Gem/Cache.h"
+#include "Gem/Properties.h"
+
+#include "plugins/PluginFactory.h"
+#include "Gem/Exception.h"
+
+#include <ctype.h>
 #include <stdio.h>
 
 /***************************************
@@ -56,6 +57,10 @@
  *      will decode pretty everything on osX and (i guess) it is rock stable there
  *      on w32 it might well crash (at least when fed with an mpeg)
  *      should therefore be one of the last libraries for w23
+ * gmerlin: linux only (although there are ports to w32/osX (?))
+ *         should decode pretty much
+ *         API for a bunch of other decoding libraries (e.g. FFMPEG)
+ *         probems with mpeg files
  * MPEG1: linux only 
  *        no seeking support
  *        likely to crash
@@ -70,9 +75,6 @@
  *          stable (?)
  *          API for a bunch of other decoding libraries (e.g. FFMPEG)
  *          slow (?? but if it uses FFMPEG then it should be as fast as FFMPEG)
- *          FFMPEG support is better than the "native" one (see above)
- *             the keyframe-problem i had with the LOTR-trailer (SVQ3) did not appear 
- *             here, even though FFMPEG was used
  *
  * libraries which might be worth done:
  * 
@@ -83,7 +85,7 @@
  * *************************
  * proposed order:
  *
- * AVI, QT, QT4L, MPEG3, AVIPLAY, FFMPEG, MPEG1
+ * GMERLIN, AVI, QT, QT4L, MPEG3, AVIPLAY, MPEG1
  *
  * W32:
  *  the few movies that AVI can decode it will handle fine
@@ -94,11 +96,15 @@
  *  everything is handled by QT
  *
  * linux:
- *  few movies will be devoded by QT4L (but those are OK: seekable, stable)
+ *  most movies will be decoded by GMERLIN
+ *  few movies will be decoded by QT4L (but those are OK: seekable, stable)
  *  mpegs will be decoded by MPEG3 in a stable way
  *  everything else should be handled by AVIPLAY or FFMPEG (aviplay including ffmpeg)
  *  if there is no MPEG3 available at compile time, we have MPEG1 as a last fallback (unstable)
  *
+ * LATER:
+ *   think about the gmerlin+mpeg problem
+ *
  ***************************************/
 
 
@@ -109,28 +115,26 @@
 #endif
 
 
-CPPEXTERN_NEW_WITH_ONE_ARG(pix_film, t_symbol *, A_DEFSYM)
+CPPEXTERN_NEW_WITH_ONE_ARG(pix_film, t_symbol *, A_DEFSYM);
 
 #ifdef HAVE_PTHREADS
 /* the "capturing"-thread */
 void *pix_film :: grabThread(void*you)
 {
-  pix_film *me=(pix_film*)you;
-  pthread_mutex_t *mutex=me->m_mutex;
+  pix_film *me=reinterpret_cast<pix_film*>(you);
   struct timeval timout;
   me->m_thread_running=true;
   //me->post("using pthreads");
   while(me->m_thread_continue){
-    int reqFrame=(int)me->m_reqFrame;
-    int reqTrack=(int)me->m_reqTrack;
+    int reqFrame=static_cast<int>(me->m_reqFrame);
+    int reqTrack=static_cast<int>(me->m_reqTrack);
     timout.tv_sec = 0;
     timout.tv_usec=100;
 
     if(reqFrame!=me->m_curFrame || reqTrack!=me->m_curTrack){
 
       pthread_mutex_lock(me->m_mutex);
-
-      if (me->m_handle->changeImage(reqFrame, reqTrack)!=FILM_ERROR_FAILURE){
+      if (gem::plugins::film::FAILURE!=me->m_handle->changeImage(reqFrame, reqTrack)){
         me->m_frame=me->m_handle->getFrame();
       } else me->m_frame=0;
 
@@ -156,9 +160,12 @@ void *pix_film :: grabThread(void*you)
 //
 /////////////////////////////////////////////////////////
 pix_film :: pix_film(t_symbol *filename) :
+  m_haveMovie(0),
   m_auto(0), m_format(GL_RGBA),
   m_numFrames(0), m_reqFrame(0), m_curFrame(0),
   m_numTracks(0), m_reqTrack(0), m_curTrack(0),
+  m_handle(NULL),
+  m_outNumFrames(NULL), m_outEnd(NULL),
 #ifdef HAVE_PTHREADS
   m_thread_id(0), m_mutex(NULL), m_frame(NULL), m_thread_continue(false),
   m_thread_running(false), m_wantThread(true)
@@ -166,31 +173,43 @@ pix_film :: pix_film(t_symbol *filename) :
   m_thread_running(false), m_wantThread(false)
 #endif
 {
+  gem::PluginFactory<gem::plugins::film>::loadPlugins("film");
+
   // setting the current frame
   inlet_new(this->x_obj, &this->x_obj->ob_pd, gensym("float"), gensym("img_num"));
   // create an outlet to send out how many frames are in the movie + bang when we reached the end
   m_outNumFrames = outlet_new(this->x_obj, 0);
   m_outEnd       = outlet_new(this->x_obj, 0);
   
-  m_handle=0;
-  int i=MAX_FILM_HANDLES;
-  while(i--)m_handles[i]=0;
-  m_numHandles=0;
+  std::vector<std::string>available_ids=gem::PluginFactory<gem::plugins::film>::getIDs();
 
-#define DEBUG_HANDLE verbose(2, "handle %d\t%X", m_numHandles, m_handles[m_numHandles])
-#if defined(__WIN32__) && defined(HAVE_DIRECTSHOW)
-	m_handles[m_numHandles]=new filmDS();      DEBUG_HANDLE; m_numHandles++;
-#else
-  m_handles[m_numHandles]=new filmAVI();      DEBUG_HANDLE; m_numHandles++;
-#endif
-  m_handles[m_numHandles]=new filmGMERLIN();  DEBUG_HANDLE; m_numHandles++;
-  m_handles[m_numHandles]=new filmQT();       DEBUG_HANDLE; m_numHandles++;
-  m_handles[m_numHandles]=new filmQT4L();     DEBUG_HANDLE; m_numHandles++;
-  m_handles[m_numHandles]=new filmMPEG3();    DEBUG_HANDLE; m_numHandles++;
-  m_handles[m_numHandles]=new filmAVIPLAY();  DEBUG_HANDLE; m_numHandles++;
-  m_handles[m_numHandles]=new filmMPEG1();    DEBUG_HANDLE; m_numHandles++;
+  if(!addHandle(available_ids, "DirectShow"))
+    addHandle(available_ids, "AVI");
 
+  addHandle(available_ids, "gmerlin");
+  addHandle(available_ids, "QuickTime");
+  addHandle(available_ids, "quicktime4linux");
+  addHandle(available_ids, "MPEG3");
+  addHandle(available_ids, "aviplay");
+  addHandle(available_ids, "MPEG1");
+
+  // the rest
+  addHandle(available_ids);
   //openMess(filename);
+
+
+  if(m_handles.size()==0) {
+    error("no movie decoding backends found!");
+  }
+  unsigned int i;
+  static bool firsttime=true;
+  for(i=0; i<m_ids.size(); i++) {
+    if(firsttime)
+      post("%s support", m_ids[i].c_str());
+    else
+      verbose(1, "%s support", m_ids[i].c_str());
+  }
+  firsttime=false;
 }
 
 /////////////////////////////////////////////////////////
@@ -201,8 +220,65 @@ pix_film :: ~pix_film()
 {
   // Clean up the movie
   closeMess();
+
+  unsigned int i=0;
+  for(i=0; i<m_handles.size(); i++) {
+    delete m_handles[i];
+    m_handles[i]=NULL;
+  }
 }
 
+/////////////////////////////////////////////////////////
+// add backends
+//
+/////////////////////////////////////////////////////////
+bool pix_film :: addHandle( std::vector<std::string>available, std::string ID)
+{
+  int count=0;
+
+  std::vector<std::string>id;
+  if(!ID.empty()) {
+    // if requested 'cid' is in 'available' add it to the list of 'id's
+    if(std::find(available.begin(), available.end(), ID)!=available.end()) {
+      id.push_back(ID);
+    } else {
+      // request for an unavailable ID
+      verbose(2, "backend '%s' unavailable", ID.c_str());
+      return false;
+    }
+  } else {
+    // no 'ID' given: add all available IDs
+    id=available;
+  }
+
+  unsigned int i=0;
+  for(i=0; i<id.size(); i++) {
+    std::string key=id[i];
+    verbose(2, "trying to add '%s' as backend", key.c_str());
+    if(std::find(m_ids.begin(), m_ids.end(), key)==m_ids.end()) {
+      // not yet added, do so now!
+      gem::plugins::film*handle=NULL;
+      try {
+        handle=gem::PluginFactory<gem::plugins::film>::getInstance(key); 
+      } catch(GemException x) {
+        handle=NULL;
+        verbose(1, "cannot use film plugin '%s': %s", key.c_str(), x.what());
+      }
+      if(NULL==handle){
+        continue;
+      }
+      m_ids.push_back(key);
+      m_handles.push_back(handle);
+      count++;
+      verbose(2, "added backend#%d '%s' @ 0x%x", m_handles.size()-1, key.c_str(), handle);
+    }
+  }
+
+  return (count>0);
+}
+
+
+
 /////////////////////////////////////////////////////////
 // closeMess
 //
@@ -232,7 +308,7 @@ void pix_film :: closeMess(void){
 #endif
 
   // Clean up any open files
-  int i=MAX_FILM_HANDLES;
+  int i=m_handles.size();
   debug("closing %d handles", i);
   while(i--){
     debug("close %d", i);
@@ -249,9 +325,10 @@ void pix_film :: closeMess(void){
 // openMess
 //
 /////////////////////////////////////////////////////////
-
-    void pix_film :: openMess(t_symbol *filename, int format, int codec)
+void pix_film :: openMess(t_symbol *filename, int format, int codec)
 {
+  gem::Properties wantProps, gotProps;
+
   //  if (filename==x_filename)return;
   closeMess();
 
@@ -259,53 +336,87 @@ void pix_film :: closeMess(void){
   char*buf=buff;
   // we first try to find the file-to-open with canvas_makefilename
   // if this fails, we just pass the given filename (could be a stream)
-  canvas_makefilename(getCanvas(), filename->s_name, buff, MAXPDSTRING);
+  canvas_makefilename(const_cast<t_canvas*>(getCanvas()), filename->s_name, buff, MAXPDSTRING);
   if (FILE*fd=fopen(buff, "r"))fclose(fd);
   else buf=filename->s_name;
   m_handle=0;
 
   if (format==0)format=m_format;
-  if(codec>=0){
-    codec=codec%m_numHandles;
-    if (m_handles[codec] && m_handles[codec]->open(buf, format ))
-      m_handle = m_handles[codec];
+  double d=(double)format;
+  wantProps.set("colorspace", format);
+
+  if(m_auto!=0.f) {
+    double v=m_auto;
+    wantProps.set("auto", v);
   }
-  if(!m_handle && m_handles){
-    int i=-1;
+
+  if(codec>=0){
+    codec=codec%m_handles.size();
+    if (m_handles[codec] && m_handles[codec]->open(buf, wantProps )) {
+      m_handle = m_handles[codec];
+      verbose(1, "%s!: succeeded", m_ids[codec].c_str());
+    } else {
+      verbose(1, "%s!: failed", m_ids[codec].c_str());
+    }
+  }
+  debug("handle=%x of %d", m_handle, m_handles.size());
+  if(!m_handle && m_handles.size()>0){
+    unsigned int i=0;
     post("opening %s with format %X", buf, format);
-    while(i++<m_numHandles){
-      debug("trying handle %d: %X", i, m_handles[i]);
-      if (m_handles[i] && m_handles[i]->open(buf, format ))      {
+    while(i<m_handles.size()){
+      debug("trying handle %d: %x", i, m_handles[i]);
+      if (m_handles[i] && m_handles[i]->open(buf, wantProps ))      {
+	verbose(1, "%s: succeeded", m_ids[i].c_str());
         m_handle = m_handles[i];
         break;
+      } else {
+	verbose(1, "%s: failed", m_ids[i].c_str());
       }
-      post(" ... ");
+      i++;
     }
   }
 
   debug("got handle = %X", m_handle);
 
   if (!m_handle){
-    post(" ... giving up!");
+    //    post(" ... giving up!");
     error("unable to open file: %s", filename->s_name);
-	return;
+    return;
   }
 
+  double width=-1;
+  double height=-1;
+  double frames=-1;
+  double fps=-1;
+  gotProps.set("width", 0);
+  gotProps.set("height", 0);
+  gotProps.set("frames", 0);
+  gotProps.set("fps", 0);
+
+  m_handle->getProperties(gotProps);
+
+  gotProps.get("width", width);
+  gotProps.get("height", height);
+  gotProps.get("frames", frames);
+  gotProps.get("fps", fps);
+
   t_atom ap[4];
-  SETFLOAT(ap, m_handle->getFrameNum());
-  SETFLOAT(ap+1, m_handle->getWidth());
-  SETFLOAT(ap+2, m_handle->getHeight());
-  SETFLOAT(ap+3, (float)m_handle->getFPS());
-  m_numFrames=m_handle->getFrameNum();
+  SETFLOAT(ap, frames);
+  SETFLOAT(ap+1, width);
+  SETFLOAT(ap+2, height);
+  SETFLOAT(ap+3, fps);
+  m_numFrames=frames;
   post("loaded file: %s with %d frames (%dx%d) at %f fps", 
        buf, 
-       m_handle->getFrameNum(), 
-       m_handle->getWidth(), 
-       m_handle->getHeight(), (float)m_handle->getFPS());
+       (int)frames, 
+       (int)width, 
+       (int)height, 
+       fps);
   outlet_list(m_outNumFrames, 0, 4, ap);
 
 #ifdef HAVE_PTHREADS
-  if(m_wantThread){
+  bool canThread=m_handle->isThreadable();
+  if(canThread && m_wantThread){
     debug("creating thread");
     m_mutex = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
     if ( pthread_mutex_init(m_mutex, NULL) < 0 ) {
@@ -319,7 +430,6 @@ void pix_film :: closeMess(void){
     }
   }
 #endif
-
 }
 
 /////////////////////////////////////////////////////////
@@ -335,27 +445,37 @@ void pix_film :: render(GemState *state)
 #ifdef HAVE_PTHREADS
   if(m_thread_running) {
     pthread_mutex_lock(m_mutex);
-    state->image=m_frame;
+    state->set(GemState::_PIX, m_frame);
   } else
 #endif /* PTHREADS */
-    state->image=m_handle->getFrame();
-  m_handle->setAuto(m_auto);
-  frame=(int)m_reqFrame;
-  if (NULL==state->image){
-    outlet_float(m_outEnd,(m_numFrames>0 && (int)m_reqFrame<0)?(m_numFrames-1):0);
+    state->set(GemState::_PIX, m_handle->getFrame());
 
-    if(frame!=(int)m_reqFrame){
+  pixBlock*img=NULL;
+  state->get(GemState::_PIX, img);
+
+  // someone wants to process the image downstream, so make sure they get it
+  if (m_cache&&m_cache->resendImage&&img)
+    {
+      img->newimage=true;
+      m_cache->resendImage = 0;
+    }
+
+  frame=static_cast<int>(m_reqFrame);
+  if (NULL==img){
+    outlet_float(m_outEnd,(m_numFrames>0 && static_cast<int>(m_reqFrame)<0)?(m_numFrames-1):0);
+
+    if(frame!=static_cast<int>(m_reqFrame)){
       // someone responded immediately to the outlet_float and changed the requested frame
       // so get the newly requested frame:
 
       if(m_thread_running){
-	/* if we are threaded (currently locked!), we change the frame# and grab the frame immediately
-	 * (if we are not threaded, the frame# is already changed and the grabbing is always immediately)
-	 */
-	m_handle->changeImage((int)m_reqFrame, m_reqTrack);
+        /* if we are threaded (currently locked!), we change the frame# and grab the frame immediately
+         * (if we are not threaded, the frame# is already changed and the grabbing is always immediately)
+         */
+        m_handle->changeImage(static_cast<int>(m_reqFrame), m_reqTrack);
       }
-      
-      state->image=m_handle->getFrame();
+      state->set(GemState::_PIX, m_handle->getFrame());
+
     }
   }
 }
@@ -367,7 +487,12 @@ void pix_film :: render(GemState *state)
 void pix_film :: postrender(GemState *state)
 {
   if(!m_handle)return;
-  if (state && state->image)state->image->newimage = 0;
+  if (state) {
+    pixBlock*img=NULL;
+    state->get(GemState::_PIX, img);
+    if(img)
+      img->newimage = false;
+  }
 
 #ifdef HAVE_PTHREADS
   if(m_thread_running){
@@ -376,14 +501,13 @@ void pix_film :: postrender(GemState *state)
 #endif /* PTHREADS */
 
   // automatic proceeding
-  if (m_auto!=0){
-    if(m_thread_running){
-      m_reqFrame+=m_auto;
-    } else
-      if (m_handle->changeImage((int)(m_reqFrame+=m_auto))==FILM_ERROR_FAILURE){
-        //      m_reqFrame = m_numFrames;
-        outlet_bang(m_outEnd);
-      }
+  m_reqFrame+=m_auto;
+
+  if (m_auto!=0 && !m_thread_running){
+    if (gem::plugins::film::FAILURE==m_handle->changeImage(static_cast<int>(m_reqFrame+=m_auto))){
+      //      m_reqFrame = m_numFrames;
+      outlet_bang(m_outEnd);
+    }
   }
 }
 
@@ -397,13 +521,15 @@ void pix_film :: changeImage(int imgNum, int trackNum)
     error("selection number must be > 0");
     imgNum=0;
   }
+#if 0
   if (trackNum < 0){
     error("track number must be > 0");
     trackNum=0;
   }
+#endif
   if (m_handle){
     if(!m_thread_running){
-      if (m_handle->changeImage(imgNum, trackNum)==FILM_ERROR_FAILURE){
+      if (gem::plugins::film::FAILURE==m_handle->changeImage(imgNum, trackNum)){
         outlet_bang(m_outEnd);
       }
     }
@@ -430,7 +556,13 @@ void pix_film :: csMess(t_symbol *s, bool immediately)
   default:
     error("colorspace must be 'RGBA', 'YUV' or 'Gray'");
   }
-  if(immediately && m_handle)m_handle->requestColor(m_format);
+
+  gem::Properties props;
+  double d=(double)m_format;
+  gem::any value=d;
+  props.set("colorspace", value);
+  if(immediately && m_handle)
+    m_handle->setProperties(props);
 }
 /////////////////////////////////////////////////////////
 // threading
@@ -446,6 +578,18 @@ void pix_film :: threadMess(int state)
 #endif
 }
 
+void pix_film :: autoMess(double speed)
+{
+  m_auto=(t_float)speed;
+  gem::Properties props;
+  gem::any value=speed;
+  props.set("auto", value);
+  if(m_handle)
+    m_handle->setProperties(props);
+}
+
+
+
 
 /////////////////////////////////////////////////////////
 // static member function
@@ -453,24 +597,27 @@ void pix_film :: threadMess(int state)
 /////////////////////////////////////////////////////////
 void pix_film :: obj_setupCallback(t_class *classPtr)
 {
-#ifdef __GNUC__
-# warning the class_addcreator gets called twice: once by pix_film, once by pix_movie
-  /* but really: Pd shouldn't bail out,
+  /* really: Pd shouldn't bail out,
    * if a selector is bound to the same method of a class a 2nd time
    */
-#endif
-  class_addcreator((t_newmethod)create_pix_film, gensym("pix_filmQT"), A_DEFSYM, A_NULL);
+  if(pd_objectmaker && reinterpret_cast<t_gotfn>(create_pix_film)==zgetfn(&pd_objectmaker, gensym("pix_filmQT"))) {
+    ::verbose(2, "not registering [pix_filmQT] again...");
+  } else {
+    class_addcreator(reinterpret_cast<t_newmethod>(create_pix_film), gensym("pix_filmQT"), A_DEFSYM, A_NULL);
+  }
  
-  class_addmethod(classPtr, (t_method)&pix_film::openMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_film::openMessCallback),
 		  gensym("open"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_film::changeImageCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_film::changeImageCallback),
 		  gensym("img_num"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_film::autoCallback,
-		  gensym("auto"), A_DEFFLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_film::csCallback,
+
+  CPPEXTERN_MSG1(classPtr, "auto", autoMess, t_float);
+  CPPEXTERN_MSG1(classPtr, "colorspace", csMess, t_symbol*);
+#if 0
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_film::csCallback),
 		  gensym("colorspace"), A_DEFSYM, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_film::threadCallback,
-		  gensym("thread"), A_FLOAT, A_NULL);
+#endif
+  CPPEXTERN_MSG1(classPtr, "thread", threadMess, bool);
 }
 void pix_film :: openMessCallback(void *data, t_symbol*s,int argc, t_atom*argv)
 {
@@ -506,18 +653,9 @@ void pix_film :: changeImageCallback(void *data, t_symbol *, int argc, t_atom *a
     GetMyClass(data)->changeImage((argc<1)?0:atom_getint(argv), (argc<2)?0:atom_getint(argv+1));
 }
 
-void pix_film :: autoCallback(void *data, t_floatarg state)
-{
-  GetMyClass(data)->m_auto=state;
-}
-void pix_film :: csCallback(void *data, t_symbol*s)
-{
-  GetMyClass(data)->csMess(s);
-}
-
 void pix_film :: threadCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->threadMess((int)state);
+  GetMyClass(data)->threadMess(static_cast<int>(state));
 }
-#endif /*__APPLE__*/
+#endif /*OS-specific GEM_FILMBACKEND */
 
