@@ -6,38 +6,24 @@ Load an digital video (like AVI, Mpeg, Quicktime) into a pix block
 (OS independant parent-class)
 
 Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-Copyright (c) Gnther Geiger. geiger@epy.co.at
-Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+Copyright (c) Günther Geiger. geiger@epy.co.at
+Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 For information on usage and redistribution, and for a DISCLAIMER OF ALL
 WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_FILM_H_
-#define INCLUDE_PIX_FILM_H_
-#include "Base/config.h"
-
-#ifndef FILM_NEW
-# define NO_AUTO_REGISTER_CLASS
-#endif
-
-#define MAX_FILM_HANDLES 8
-
-#define GEM_MOVIE_NONE 0
-#define GEM_MOVIE_AVI  1
-#define GEM_MOVIE_MPG  2
-#define GEM_MOVIE_MOV  3
-
-#include <string.h>
-#include <stdio.h>
-
-#include "Pixes/film.h"
+#ifndef _INCLUDE__GEM_PIXES_PIX_FILM_H_
+#define _INCLUDE__GEM_PIXES_PIX_FILM_H_
 #include "Base/GemBase.h"
 
 #ifdef HAVE_PTHREADS
 # include <pthread.h>
 #endif
 
+#include "plugins/film.h"
+
+
 /*-----------------------------------------------------------------
   -------------------------------------------------------------------
   CLASS
@@ -53,7 +39,7 @@ WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
   -----------------------------------------------------------------*/
 class GEM_EXTERN pix_film : public GemBase
 {
-  CPPEXTERN_HEADER(pix_film, GemBase)
+  CPPEXTERN_HEADER(pix_film, GemBase);
     
     public:  
   //////////
@@ -100,6 +86,10 @@ class GEM_EXTERN pix_film : public GemBase
   // turn on/off threaded reading
   virtual void threadMess(int);
 
+
+  virtual void autoMess(double state);
+
+
   //-----------------------------------
   // GROUP:	Movie data
   //-----------------------------------
@@ -122,17 +112,16 @@ class GEM_EXTERN pix_film : public GemBase
   int           m_reqTrack;
   int           m_curTrack;
 
-
-  film         *m_handles[MAX_FILM_HANDLES];
-  film         *m_handle;
-  int           m_numHandles;
+  std::vector<gem::plugins::film*>m_handles;
+  std::vector<std::string>m_ids;
+  gem::plugins::film         *m_handle;
+  virtual bool addHandle(std::vector<std::string>available_ids, std::string id=std::string(""));
 
   //////////
   // a outlet for information like #frames and "reached end"
   t_outlet     *m_outNumFrames;
   t_outlet     *m_outEnd;
 
-
  
  protected:
  /* grab-thread */
@@ -143,19 +132,18 @@ class GEM_EXTERN pix_film : public GemBase
 
   pixBlock*m_frame;
 
-  int m_thread_continue;
+  bool m_thread_continue;
 #endif
   /* do we have a thread ? */
-  int m_thread_running;
+  bool m_thread_running;
 
   /* does the user request reading to be threaded */
-  int m_wantThread;
-	
+  bool m_wantThread;
+
   //////////
   // static member functions
   static void openMessCallback   (void *data, t_symbol*,int,t_atom*);
   static void changeImageCallback(void *data, t_symbol *, int argc, t_atom *argv);
-  static void autoCallback       (void *data, t_floatarg state);
   static void csCallback         (void *data, t_symbol*s);
   static void threadCallback     (void *data, t_floatarg state);
 };
