@@ -12,13 +12,24 @@
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
-#ifdef __APPLE__
+#include "Gem/GemConfig.h"
+
+#if defined __APPLE__ && !defined __x86_64__
+// with OSX10.6, apple has removed loads of Carbon functionality (in 64bit mode)
+// LATER make this a real check in configure
+# define HAVE_CARBONQUICKTIME
+#endif
+
+#if !defined HAVE_CARBONQUICKTIME  && defined GEM_FILMBACKEND && GEM_FILMBACKEND == GEM_FILMBACKEND_Darwin
+# undef GEM_FILMBACKEND
+#endif
+
+#if defined GEM_FILMBACKEND && GEM_FILMBACKEND == GEM_FILMBACKEND_Darwin
 
 #define HELPSYMBOL "pix_film"
-
 #include "pix_filmDarwin.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(pix_filmDarwin, t_symbol *, A_DEFSYM)
+CPPEXTERN_NEW_WITH_ONE_ARG(pix_filmDarwin, t_symbol *, A_DEFSYM);
 
 /////////////////////////////////////////////////////////
 //
@@ -97,11 +108,12 @@ void pix_filmDarwin :: realOpen(char *filename)
   if (!filename[0]) {
     error("no filename passed");
   } else {
-    err = ::FSPathMakeRef((UInt8*)filename, &ref, NULL);
+    UInt8*filename8=reinterpret_cast<UInt8*>(filename);
+    err = ::FSPathMakeRef(filename8, &ref, NULL);
     err = ::FSGetCatalogInfo(&ref, kFSCatInfoNone, NULL, NULL, &theFSSpec, NULL);
 
     if (err) {
-      error("unable to find file: %#s", theFSSpec.name);
+      error("unable to find file: %s", filename);
       return;
     }
     m_haveMovie = GEM_MOVIE_MOV;
@@ -122,27 +134,27 @@ void pix_filmDarwin :: realOpen(char *filename)
 
   m_reqFrame = 0;
   m_curFrame = -1;
-  m_numTracks = (int)GetMovieTrackCount(m_movie);
+  m_numTracks = static_cast<int>(GetMovieTrackCount(m_movie));
 	
-	movieTrack = GetMovieIndTrackType(m_movie,1,VideoMediaType,movieTrackMediaType);  //get first video track
+  movieTrack = GetMovieIndTrackType(m_movie,1,VideoMediaType,movieTrackMediaType);  //get first video track
 	
-	trackMedia = GetTrackMedia(movieTrack);
+  trackMedia = GetTrackMedia(movieTrack);
 	
-	sampleCount = GetMediaSampleCount(trackMedia);
+  sampleCount = GetMediaSampleCount(trackMedia);
 	
-	m_numFrames = sampleCount;
+  m_numFrames = sampleCount;
 	
-	audioTrack = GetMovieIndTrackType(m_movie,1,SoundMediaType,movieTrackMediaType);
+  audioTrack = GetMovieIndTrackType(m_movie,1,SoundMediaType,movieTrackMediaType);
 	
-	SetTrackEnabled(audioTrack, FALSE);
+  SetTrackEnabled(audioTrack, FALSE);
 	
   // Get the length of the movie
 
-  movieDur = (long)GetMovieDuration(m_movie);
-  movieScale = (long)GetMovieTimeScale(m_movie);
+  movieDur = static_cast<long>(GetMovieDuration(m_movie));
+  movieScale = static_cast<long>(GetMovieTimeScale(m_movie));
 
 	
-  durationf = (float)movieDur/(float)m_numFrames;
+  durationf = static_cast<double>(movieDur)/static_cast<double>(m_numFrames);
 
   // Get the bounds for the movie
   ::GetMovieBox(m_movie, &m_srcRect);
@@ -158,9 +170,9 @@ void pix_filmDarwin :: realOpen(char *filename)
 	
 	ImageDescriptionHandle desc = NULL;
 	
-	desc = (ImageDescriptionHandle)NewHandle(0);
+	desc = reinterpret_cast<ImageDescriptionHandle>(NewHandle(0));
 	
-	GetMediaSampleDescription(trackMedia,1,(SampleDescriptionHandle)desc);
+	GetMediaSampleDescription(trackMedia,1,reinterpret_cast<SampleDescriptionHandle>(desc));
 # ifdef kDVCPROHD720pCodecType
 	//DVCPRO720p
 	if ((*desc)->cType == kDVCPROHD720pCodecType){
@@ -416,7 +428,7 @@ void pix_filmDarwin :: getFrame()
       }else{
 
         m_movieTime = m_reqFrame * duration;
-        m_movieTime = (long)((float)m_reqFrame * durationf);
+        m_movieTime = static_cast<long>(static_cast<double>(m_reqFrame) * durationf);
 
         m_movieTime-=9; //total hack!! subtract an arbitrary amount and have nextinterestingtime find the exact place
         ::GetMovieNextInterestingTime(	m_movie,
@@ -445,7 +457,7 @@ void pix_filmDarwin :: postrender(GemState *state)
 void pix_filmDarwin :: startRendering()
 {
 	//bit of a hack related to stopRendering()
-	if (m_auto && m_haveMovie) SetMovieVolume(m_movie, (short)(m_volume * 255.f));
+	if (m_auto && m_haveMovie) SetMovieVolume(m_movie, static_cast<short>(m_volume * 255.f));
 }
 
 void pix_filmDarwin :: stopRendering()
@@ -473,17 +485,17 @@ void pix_filmDarwin :: LoadRam()
 
 void pix_filmDarwin :: MovRate(float rate)
 {
-  m_rate = (float)rate;
+  m_rate = static_cast<float>(rate);
   if (m_auto && m_haveMovie) {
-    SetMovieRate(m_movie,X2Fix((double)m_rate));
+    SetMovieRate(m_movie,X2Fix(static_cast<double>(m_rate)));
   }
 }
 
 void pix_filmDarwin :: MovVolume(float volume)
 {
-  m_volume = (float)volume;
+  m_volume = static_cast<float>(volume);
   if (m_auto && m_haveMovie) {
-    SetMovieVolume(m_movie,(short)(m_volume * 255.f));
+    SetMovieVolume(m_movie,static_cast<short>(m_volume * 255.f));
   }
 }
 
@@ -492,13 +504,13 @@ void pix_filmDarwin :: doDebug()
 {
   post("---------- pix_filmDarwin doDebug start----------");
   post("m_numTracks = %d",m_numTracks);
-  post("Movie duration = %d timescale = %d timebase = %d", movieDur, movieScale, (long)GetMovieTimeBase(m_movie));
+  post("Movie duration = %d timescale = %d timebase = %d", movieDur, movieScale, reinterpret_cast<long>(GetMovieTimeBase(m_movie)));
   post("rect rt:%d lt:%d", m_srcRect.right, m_srcRect.left);
   post("rect top:%d bottom:%d", m_srcRect.top, m_srcRect.bottom);
   post("movie size x:%d y:%d", m_xsize, m_ysize);
   if (m_colorspace == GL_BGRA_EXT) post("color space ARGB");
   else  post("color space YUV");
-  post("Preferred rate fixed: %d int: %d float %f", playRate, Fix2Long(playRate),(float) Fix2X(playRate));
+  post("Preferred rate fixed: %d int: %d float %f", playRate, Fix2Long(playRate),static_cast<float>(Fix2X(playRate)));
 
   post("---------- pix_filmDarwin doDebug end----------");
 }
@@ -509,20 +521,20 @@ void pix_filmDarwin :: doDebug()
 /////////////////////////////////////////////////////////
 void pix_filmDarwin :: obj_setupCallback(t_class *classPtr)
 {
-  class_addcreator((t_newmethod)create_pix_filmDarwin, gensym("pix_film"), A_DEFSYM, A_NULL);
+  class_addcreator(reinterpret_cast<t_newmethod>(create_pix_filmDarwin), gensym("pix_film"), A_DEFSYM, A_NULL);
   pix_filmOS::real_obj_setupCallback(classPtr);
 
-  class_addmethod(classPtr, (t_method)&pix_filmDarwin::openMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_filmDarwin::openMessCallback),
                   gensym("open"), A_SYMBOL, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_filmDarwin::ramCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_filmDarwin::ramCallback),
                   gensym("ram"),  A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_filmDarwin::hiqualityCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_filmDarwin::hiqualityCallback),
                   gensym("hiquality"), A_DEFFLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_filmDarwin::rateCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_filmDarwin::rateCallback),
                   gensym("rate"), A_DEFFLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_filmDarwin::debugCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_filmDarwin::debugCallback),
                   gensym("debug"),  A_NULL);
-	class_addmethod(classPtr, (t_method)&pix_filmDarwin::volumeCallback,
+	class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_filmDarwin::volumeCallback),
                   gensym("volume"), A_DEFFLOAT, A_NULL);
 
 }
@@ -539,21 +551,21 @@ void pix_filmDarwin :: ramCallback(void *data)
 
 void pix_filmDarwin :: hiqualityCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->m_hiquality=(int)state;
+  GetMyClass(data)->m_hiquality=static_cast<int>(state);
 }
 
 void pix_filmDarwin :: rateCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->MovRate((float)state);
+  GetMyClass(data)->MovRate(state);
 }
 
 void pix_filmDarwin :: volumeCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->MovVolume((float)state);
+  GetMyClass(data)->MovVolume(state);
 }
 
 void pix_filmDarwin :: debugCallback(void *data)
 {
   GetMyClass(data)->doDebug();
 }
-#endif // __APPLE__
+#endif // GEM_FILMBACKEND_Darwin
