@@ -5,7 +5,7 @@ LOG
     age an image
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -15,8 +15,8 @@ LOG
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_GREY_H_
-#define INCLUDE_PIX_GREY_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_GREY_H_
+#define _INCLUDE__GEM_PIXES_PIX_GREY_H_
 
 #include "Pixes/pix_rgba.h"
 
@@ -36,7 +36,7 @@ DESCRIPTION
 
 class GEM_EXTERN pix_grey : public pix_rgba
 {
-    CPPEXTERN_HEADER(pix_grey, GemPixObj)
+    CPPEXTERN_HEADER(pix_grey, GemPixObj);
 
     public:
 
