@@ -2,17 +2,17 @@
 LOG
     GEM - Graphics Environment for Multimedia
 
-	2003-2004 ported by tigital@mac.com from "Pete's_Plugins"
+    Copyright (C) 2003-2004 ported by tigital@mac.com from "Pete's_Plugins"
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_HALFTONE_H_
-#define INCLUDE_PIX_HALFTONE_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_HALFTONE_H_
+#define _INCLUDE__GEM_PIXES_PIX_HALFTONE_H_
 
 #include "Base/GemPixObj.h"
-#include "Base/GemMath.h"
+#include "Utils/GemMath.h"
 	
 enum {
     eRoundStyle,
@@ -44,7 +44,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_halftone : public GemPixObj
 {
-    CPPEXTERN_HEADER(pix_halftone, GemPixObj)
+    CPPEXTERN_HEADER(pix_halftone, GemPixObj);
 
     public:
 
