@@ -5,16 +5,16 @@
   Convert the HSV(A)-Channels of a pixBuf into RGB(A)
 
   Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-  Copyright (c) Gnther Geiger. geiger@epy.co.at
-  Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+  Copyright (c) Günther Geiger. geiger@epy.co.at
+  Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
   Copyright (c) 2002 James Tittle & Chris Clepper
   For information on usage and redistribution, and for a DISCLAIMER OF ALL
   WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
   -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_HSV2RGB_H_
-#define INCLUDE_PIX_HSV2RGB_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_HSV_RGB_H_
+#define _INCLUDE__GEM_PIXES_PIX_HSV_RGB_H_
 
 #include "Base/GemPixObj.h"
 
@@ -33,7 +33,7 @@
   -----------------------------------------------------------------*/
 class GEM_EXTERN pix_hsv2rgb : public GemPixObj
 {
-  CPPEXTERN_HEADER(pix_hsv2rgb, GemPixObj)
+  CPPEXTERN_HEADER(pix_hsv2rgb, GemPixObj);
 
     public:
 
