@@ -10,14 +10,14 @@ LOG
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_KALEIDOSCOPE_H_
-#define INCLUDE_PIX_KALEIDOSCOPE_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_KALEIDOSCOPE_H_
+#define _INCLUDE__GEM_PIXES_PIX_KALEIDOSCOPE_H_
 
 #include "Base/GemPixObj.h"
 #include <math.h>
 
 #ifdef __ppc__
-#include "Base/GemFuncUtil.h"
+#include "Utils/Functions.h"
 #undef sqrt
 #define sqrt fast_sqrtf
 #endif
@@ -31,7 +31,7 @@ typedef struct _SPete_Kaleidoscope_Line {
 } SPete_Kaleidoscope_Line;
 extern "C" int Pete_Kaleidoscope_LinesSortFunction(const void* pElem1,const void* pElem2);
 
-#ifdef __WIN32__
+#ifdef _WIN32
 # define NO_HACK
 #endif
 /*-----------------------------------------------------------------
@@ -51,7 +51,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_kaleidoscope : public GemPixObj
 {
-    CPPEXTERN_HEADER(pix_kaleidoscope, GemPixObj)
+    CPPEXTERN_HEADER(pix_kaleidoscope, GemPixObj);
 
     public:
 
