@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -16,9 +16,9 @@
 /////////////////////////////////////////////////////////
 
 #include "pix_mask.h"
-#include "Base/GemPixConvert.h"
+#include "Gem/PixConvert.h"
 
-CPPEXTERN_NEW(pix_mask)
+CPPEXTERN_NEW(pix_mask);
 
 /////////////////////////////////////////////////////////
 //
