@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -17,7 +17,7 @@
 
 #include "pix_mix.h"
 
-CPPEXTERN_NEW_WITH_GIMME(pix_mix)
+CPPEXTERN_NEW_WITH_GIMME(pix_mix);
 
 /////////////////////////////////////////////////////////
 //
@@ -433,7 +433,7 @@ void pix_mix :: gainMess (float X, float Y)
 /////////////////////////////////////////////////////////
 void pix_mix :: obj_setupCallback(t_class *classPtr)
 { 
-  class_addmethod(classPtr, (t_method)&pix_mix::gainCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_mix::gainCallback),
 		  gensym("gain"), A_GIMME, A_NULL);//A_DEFFLOAT, A_DEFFLOAT, A_NULL);
 }
 
