@@ -5,16 +5,16 @@ LOG
     Add two images together.
 
     Copyright (c) 1997-1998 Mark Danks. mark@danks.org
-    Copyright (c) G¸nther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::f¸r::uml‰ute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) GÂžnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_MIX_H_
-#define INCLUDE_PIX_MIX_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_MIX_H_
+#define _INCLUDE__GEM_PIXES_PIX_MIX_H_
 
 #include "Base/GemPixDualObj.h"
 
@@ -35,7 +35,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_mix : public GemPixDualObj
 {
-    CPPEXTERN_HEADER(pix_mix, GemPixDualObj)
+    CPPEXTERN_HEADER(pix_mix, GemPixDualObj);
 
     public:
 
