@@ -7,8 +7,8 @@
  *
  */
 
-#ifndef INCLUDE_PIX_MOTIONBLUR_H_ 
-#define INCLUDE_PIX_MOTIONBLUR_H_ 
+#ifndef _INCLUDE__GEM_PIXES_PIX_MOTIONBLUR_H_ 
+#define _INCLUDE__GEM_PIXES_PIX_MOTIONBLUR_H_ 
 
 #include "Base/GemPixObj.h"
 
@@ -31,7 +31,7 @@ DESCRIPTION
 
 class GEM_EXTERN pix_motionblur : public GemPixObj
 {
-CPPEXTERN_HEADER(pix_motionblur, GemPixObj)
+CPPEXTERN_HEADER(pix_motionblur, GemPixObj);
 
     public:
 
