@@ -5,8 +5,8 @@ GEM - Graphics Environment for Multimedia
 set the Alpha-channel of a pixBlock depending on the difference between the current and the last pixBlock
   
 Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-Copyright (c) Gnther Geiger. geiger@epy.co.at
-Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+Copyright (c) Günther Geiger. geiger@epy.co.at
+Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 For information on usage and redistribution, and for a DISCLAIMER OF ALL
 WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 	
@@ -18,9 +18,9 @@ pix_movement
   movement-transform a series of pictures (especially movies, videos,...)
   you have to use pix_film instead of pix_movie to make this work with prerecorded videos
  
-  2803:forum::fr::umlute:2000
-  0409:forum::fr::umlute:2000
-  1801:forum::fr::umlute:2001  added the second mode
+  2803:forum::für::umläute:2000
+  0409:forum::für::umläute:2000
+  1801:forum::für::umläute:2001  added the second mode
   IOhannes m zmoelnig
   mailto:zmoelnig@iem.kug.ac.at
   
@@ -28,8 +28,8 @@ pix_movement
 	  
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_MOVEMENT_H_
-#define INCLUDE_PIX_MOVEMENT_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_MOVEMENT_H_
+#define _INCLUDE__GEM_PIXES_PIX_MOVEMENT_H_
 
 #include "Base/GemPixObj.h"
 
@@ -46,7 +46,7 @@ pix_movement
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_movement : public GemPixObj
 {
-    CPPEXTERN_HEADER(pix_movement, GemPixObj)
+    CPPEXTERN_HEADER(pix_movement, GemPixObj);
 		
 public:
 	
@@ -79,14 +79,11 @@ protected:
 	imageStruct    buffer2; // (the difference image for greyscales)
 	//////////
 	// the movement-mode
-	unsigned char  treshold;
+	unsigned char  threshold;
 
-        int j,index, averageTime;
-	
 	//////////
 	// the methods
-	static void treshMessCallback(void *data, t_floatarg ftresh);
-	
+	static void threshMessCallback(void *data, t_floatarg fthresh);
 };
 
 #endif	// for header file
