@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle
 //
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
@@ -16,11 +16,14 @@
 //
 /////////////////////////////////////////////////////////
 
+#include "Gem/GemConfig.h"
+#ifndef GEM_FILMBACKEND
+
 #include "pix_movie.h"
+#include "Gem/State.h"
 
-#ifndef __APPLE__
 
-CPPEXTERN_NEW_WITH_ONE_ARG(pix_movie, t_symbol *, A_DEFSYM)
+CPPEXTERN_NEW_WITH_ONE_ARG(pix_movie, t_symbol *, A_DEFSYM);
 
 /////////////////////////////////////////////////////////
 //
@@ -59,30 +62,32 @@ void pix_movie :: render(GemState *state)
  /* get the current frame from the file */
 
   if (!state || !m_handle)return;
-
   // get the frame from the decoding-object: film[].cpp
 #ifdef HAVE_PTHREADS
   if(m_thread_running) {
     pthread_mutex_lock(m_mutex);
-    state->image=m_frame;
+    state->set(GemState::_PIX, m_frame);
   } else
 #endif /* PTHREADS */
-    state->image=m_handle->getFrame();
+    state->set(GemState::_PIX, m_handle->getFrame());
 
-  frame=(int)m_reqFrame;
-  if (state->image==0){
-    outlet_float(m_outEnd,(m_numFrames>0 && (int)m_reqFrame<0)?(m_numFrames-1):0);
+  pixBlock*img=NULL;
+  state->get(GemState::_PIX, img);
 
-    if(frame!=(int)m_reqFrame){
+  frame=static_cast<int>(m_reqFrame);
+  if (img==0){
+    outlet_float(m_outEnd,(m_numFrames>0 && static_cast<int>(m_reqFrame)<0)?(m_numFrames-1):0);
+
+    if(frame!=static_cast<int>(m_reqFrame)){
       // someone responded immediately to the outlet_float and changed the requested frame
       // so try to get the newly requested frame:
       if(m_thread_running){
 	/* the grabbing-thread is currently locked
 	 * we do the grabbing ourselfes
 	 */
-	m_handle->changeImage((int)m_reqFrame, m_reqTrack);
+	m_handle->changeImage(static_cast<int>(m_reqFrame), m_reqTrack);
       }
-      state->image=m_handle->getFrame();
+      state->set(GemState::_PIX, m_handle->getFrame());
     }
   }
 
@@ -96,7 +101,11 @@ void pix_movie :: render(GemState *state)
 void pix_movie :: postrender(GemState *state)
 {
   if(!m_handle)return;
-  if (state && state->image)state->image->newimage = 0;
+  if (state) {
+    pixBlock*img=NULL;
+    state->get(GemState::_PIX, img);
+    if(img)img->newimage = false;
+  }
 
 #ifdef HAVE_PTHREADS
   if(m_thread_running){
@@ -109,7 +118,7 @@ void pix_movie :: postrender(GemState *state)
     if(m_thread_running){
       m_reqFrame+=m_auto;
     } else
-    if (m_handle->changeImage((int)(m_reqFrame+=m_auto))==FILM_ERROR_FAILURE){
+      if (gem::plugins::film::FAILURE==m_handle->changeImage((int)(m_reqFrame+=m_auto))){
       //      m_reqFrame = m_numFrames;
       outlet_bang(m_outEnd);
     }
@@ -142,25 +151,34 @@ void pix_movie :: stopRendering()
 /////////////////////////////////////////////////////////
 void pix_movie :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&pix_movie::textureMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movie::textureMessCallback),
 		  gensym("quality"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_movie::repeatMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movie::repeatMessCallback),
 		  gensym("repeat"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_movie::modeCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movie::modeCallback),
 		  gensym("mode"), A_FLOAT, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movie::rectangleCallback),
+		  gensym("rectangle"), A_FLOAT, A_NULL);
 }
 
 void pix_movie :: textureMessCallback(void *data, t_floatarg quality)
 {
-  GetMyClass(data)->textureQuality((int)quality);
+  GetMyClass(data)->textureQuality(static_cast<int>(quality));
 }
 void pix_movie :: repeatMessCallback(void *data, t_floatarg quality)
 {
-  GetMyClass(data)->repeatMess((int)quality);
+  GetMyClass(data)->repeatMess(static_cast<int>(quality));
 }
 
 void pix_movie :: modeCallback(void *data, t_floatarg quality)
-{
-  GetMyClass(data)->modeMess((int)quality);
+{  
+	GetMyClass(data)->error("'mode' message is deprecated; please use 'rectangle' instead");
+    GetMyClass(data)->modeMess(static_cast<int>(quality));
 }
-#endif /*__APPLE__*/
+
+void pix_movie :: rectangleCallback(void *data, t_floatarg quality)
+{  
+    GetMyClass(data)->modeMess(static_cast<int>(quality));
+}
+
+#endif /* no OS-specific GEM_FILMBACKEND */
