@@ -1,6 +1,6 @@
-#include "Base/config.h"
+#include "Gem/GemConfig.h"
 
-#if defined(__WIN32__) && defined(HAVE_DIRECTSHOW)
+#if defined GEM_FILMBACKEND && GEM_FILMBACKEND == GEM_FILMBACKEND_DS
 
 #include <atlbase.h>
 #include <atlconv.h>
@@ -11,9 +11,9 @@
 #pragma comment(lib, "strmiids.lib")
 
 #include "pix_movieDS.h"
-#include "Base/GemMan.h"
+#include "Gem/Manager.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(pix_movieDS, t_symbol *, A_DEFSYM)
+CPPEXTERN_NEW_WITH_ONE_ARG(pix_movieDS, t_symbol *, A_DEFSYM);
 
 pix_movieDS :: pix_movieDS(t_symbol *filename) :
 	m_haveMovie(FALSE),
@@ -782,18 +782,18 @@ void pix_movieDS::changeImage(int imgNum, int trackNum)
 /////////////////////////////////////////////////////////
 void pix_movieDS::obj_setupCallback(t_class *classPtr)
 {
-	class_addcreator((t_newmethod)create_pix_movieDS,gensym("pix_movieDS"),A_DEFSYM,A_NULL);
+	class_addcreator(reinterpret_cast<t_newmethod>(create_pix_movieDS,gensym("pix_movieDS"),A_DEFSYM,A_NULL));
 	
-	class_addmethod(classPtr, (t_method)&pix_movieDS::openMessCallback,
+	class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDS::openMessCallback),
 		gensym("open"), A_SYMBOL, A_NULL);
 	
-	class_addmethod(classPtr, (t_method)&pix_movieDS::changeImageCallback,
+	class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDS::changeImageCallback),
 		gensym("img_num"), A_GIMME, A_NULL);
 	
-	class_addmethod(classPtr, (t_method)&pix_movieDS::autoCallback,
+	class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDS::autoCallback),
 		gensym("auto"), A_DEFFLOAT, A_NULL);
 	
-	class_addmethod(classPtr, (t_method)&pix_movieDS::rateCallback,
+	class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDS::rateCallback),
 		gensym("rate"), A_DEFFLOAT, A_NULL);
 }
 
@@ -923,5 +923,4 @@ HRESULT movieConnectFilters(IGraphBuilder *pGraph, IBaseFilter *pFirst, IBaseFil
 	return	RetVal;
 }
 
-
 #endif /* HAVE_DIRECTSHOW */
