@@ -13,16 +13,27 @@
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
- 
-#ifdef __APPLE__
+
+#include "Gem/GemConfig.h"
+#if defined __APPLE__ && !defined __x86_64__
+// with OSX10.6, apple has removed loads of Carbon functionality (in 64bit mode)
+// LATER make this a real check in configure
+# define HAVE_CARBONQUICKTIME
+#endif
+
+#if !defined HAVE_CARBONQUICKTIME  && defined GEM_FILMBACKEND && GEM_FILMBACKEND == GEM_FILMBACKEND_Darwin
+# undef GEM_FILMBACKEND
+#endif
+
+#if defined GEM_FILMBACKEND && GEM_FILMBACKEND == GEM_FILMBACKEND_Darwin
 
 // as long as there is no special help-file, fallback to the [pix_movie]
 #define HELPSYMBOL "pix_movie"
 
 #include "pix_movieDarwin.h"
-#include "Base/GemMan.h"
+#include "Gem/Manager.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG(pix_movieDarwin, t_symbol *, A_DEFSYM)
+CPPEXTERN_NEW_WITH_ONE_ARG(pix_movieDarwin, t_symbol *, A_DEFSYM);
 
 /////////////////////////////////////////////////////////
 //
@@ -163,7 +174,11 @@ void pix_movieDarwin :: openMess(t_symbol *filename, int format)
   if (format)m_colorspace=format;
 
   char buf[MAXPDSTRING];
+#if 0
   canvas_makefilename(getCanvas(), filename->s_name, buf, MAXPDSTRING);
+#else
+  snprintf(buf, MAXPDSTRING, "%s", findFile(filename->s_name).c_str());
+#endif
 
   // Clean up any open files
   closeMess();
@@ -178,7 +193,7 @@ void pix_movieDarwin :: openMess(t_symbol *filename, int format)
   SETFLOAT(ap+2, m_ysize);
 
   m_newFilm = 1;
-  //outlet_float(m_outNumFrames, (float)m_numFrames);
+  //outlet_float(m_outNumFrames, ((float)) *([a-zA-Z0-9._]));
   post("Loaded file: %s with %d frames (%dx%d)", buf, m_numFrames, m_xsize, m_ysize);
   outlet_list(m_outNumFrames, 0, 3, ap);
 }
@@ -205,11 +220,12 @@ void pix_movieDarwin :: realOpen(char *filename)
   if (!filename[0]) {
     error("no filename passed");
   } else {            
-    err = ::FSPathMakeRef((UInt8*)filename, &ref, NULL);
+    UInt8*filename8=reinterpret_cast<UInt8*>(filename);
+    err = ::FSPathMakeRef(filename8, &ref, NULL);
     err = ::FSGetCatalogInfo(&ref, kFSCatInfoNone, NULL, NULL, &theFSSpec, NULL);
             
     if (err) {
-      error("Unable to find file: %#s", theFSSpec.name);
+      error("Unable to find file: %s", filename);
       return;
     }
     m_haveMovie = GEM_MOVIE_MOV;
@@ -228,7 +244,7 @@ void pix_movieDarwin :: realOpen(char *filename)
 
 	m_reqFrame = 0;
 	m_curFrame = -1;
-  m_numTracks = (int)GetMovieTrackCount(m_movie);
+	m_numTracks = static_cast<int>(GetMovieTrackCount(m_movie));
 
 	// Get the length of the movie
 	
@@ -244,8 +260,8 @@ void pix_movieDarwin :: realOpen(char *filename)
 	
 	SetTrackEnabled(audioTrack, FALSE);
         
-	movieDur = (long)GetMovieDuration(m_movie);
-	movieScale = (long)GetMovieTimeScale(m_movie);
+	movieDur = static_cast<long>(GetMovieDuration(m_movie));
+	movieScale = static_cast<long>(GetMovieTimeScale(m_movie));
         
   /*  //old method for getting length                                      
       OSType		whichMediaType = VisualMediaCharacteristic;
@@ -269,7 +285,7 @@ void pix_movieDarwin :: realOpen(char *filename)
       flags = nextTimeMediaSample;
       }
   */
-  durationf = (float)movieDur/(float)m_numFrames;
+  durationf = static_cast<float>(movieDur)/static_cast<float>(m_numFrames);
 
 	// Get the bounds for the movie
 	::GetMovieBox(m_movie, &m_srcRect);
@@ -541,7 +557,7 @@ void pix_movieDarwin :: getFrame()
       }
         
       //m_movieTime = m_reqFrame * duration;
-      m_movieTime = (long)((float)m_reqFrame * durationf);
+      m_movieTime = static_cast<long>(static_cast<float>(m_reqFrame) * durationf);
         
       m_movieTime-=9; //total hack!! subtract an arbitrary amount and have nextinterestingtime find the exact place
       ::GetMovieNextInterestingTime(	m_movie,
@@ -804,7 +820,7 @@ void pix_movieDarwin :: stopRendering()
 
 void pix_movieDarwin :: MovRate(float rate)
 {
-  m_rate = (float)rate;
+  m_rate = rate;
   if (m_auto && m_haveMovie) {
 		SetMovieRate(m_movie,X2Fix((double)m_rate));
   }
@@ -812,7 +828,7 @@ void pix_movieDarwin :: MovRate(float rate)
 
 void pix_movieDarwin :: MovVolume(float volume)
 {
-  m_volume = (float)volume;
+  m_volume = volume;
   if (m_auto && m_haveMovie) {
     SetMovieVolume(m_movie,(short)(m_volume * 255.f));
   }
@@ -867,22 +883,24 @@ void pix_movieDarwin :: LoadRam()
 /////////////////////////////////////////////////////////
 void pix_movieDarwin :: obj_setupCallback(t_class *classPtr)
 {
-  class_addcreator((t_newmethod)create_pix_movieDarwin,gensym("pix_movie"),A_DEFSYM,A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_movieDarwin::openMessCallback,
+  class_addcreator(reinterpret_cast<t_newmethod>(create_pix_movieDarwin),
+                   gensym("pix_movie"),
+                   A_DEFSYM,A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDarwin::openMessCallback),
                   gensym("open"), A_SYMBOL, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_movieDarwin::changeImageCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDarwin::changeImageCallback),
                   gensym("img_num"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_movieDarwin::autoCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDarwin::autoCallback),
                   gensym("auto"), A_DEFFLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_movieDarwin::rateCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDarwin::rateCallback),
                   gensym("rate"), A_DEFFLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_movieDarwin::ramCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDarwin::ramCallback),
                   gensym("ram"),  A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_movieDarwin::hiqualityCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDarwin::hiqualityCallback),
                   gensym("hiquality"), A_DEFFLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_movieDarwin::rectangleCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDarwin::rectangleCallback),
                   gensym("rectangle"), A_DEFFLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_movieDarwin::volumeCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_movieDarwin::volumeCallback),
                   gensym("volume"), A_DEFFLOAT, A_NULL);
 }
 
@@ -893,13 +911,13 @@ void pix_movieDarwin :: openMessCallback(void *data, t_symbol *filename)
 
 void pix_movieDarwin :: changeImageCallback(void *data, t_symbol *, int argc, t_atom *argv)
 {
-  //  GetMyClass(data)->changeImage((int)imgNum);
+  //  GetMyClass(data)->changeImage(static_cast<int>imgNum);
   GetMyClass(data)->changeImage((argc<1)?0:atom_getint(argv), (argc<2)?0:atom_getint(argv+1));
 }
 
 void pix_movieDarwin :: autoCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->m_auto=!(!(int)state);
+  GetMyClass(data)->m_auto=!(!static_cast<int>(state));
 }
 
 void pix_movieDarwin :: rateCallback(void *data, t_floatarg state)
@@ -909,7 +927,7 @@ void pix_movieDarwin :: rateCallback(void *data, t_floatarg state)
 
 void pix_movieDarwin :: volumeCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->MovVolume((float)state);
+  GetMyClass(data)->MovVolume(state);
 }
 
 void pix_movieDarwin :: ramCallback(void *data)
@@ -919,12 +937,12 @@ void pix_movieDarwin :: ramCallback(void *data)
 
 void pix_movieDarwin :: hiqualityCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->m_hiquality=(int)state;
+  GetMyClass(data)->m_hiquality=static_cast<int>(state);
 }
 
 void pix_movieDarwin :: rectangleCallback(void *data, t_floatarg state)
 {
-  GetMyClass(data)->m_rectangle=(int)state;
+  GetMyClass(data)->m_rectangle=static_cast<int>(state);
 }
 
 
