@@ -11,19 +11,18 @@ WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_pix_movieDarwin_H_
-#define INCLUDE_pix_movieDarwin_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_MOVIEDARWIN_H_
+#define _INCLUDE__GEM_PIXES_PIX_MOVIEDARWIN_H_
 
-#ifdef __WIN32__
-#include "Pixes/pix_filmNT.h"
-#elif __linux__
-#include "Pixes/pix_filmLinux.h"
-#elif __APPLE__
-#include "pix_filmDarwin.h"
+
+#ifdef __APPLE__
+# include "pix_filmDarwin.h"
 #else
-#error Define pix_film for this OS
+# error Define pix_movieDarwin for this OS
 #endif
 
+#include "Gem/State.h"
+
 /*-----------------------------------------------------------------
   -------------------------------------------------------------------
   CLASS
@@ -41,7 +40,7 @@ WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 class GEM_EXTERN pix_movieDarwin : public GemBase
 {
 
-    CPPEXTERN_HEADER(pix_movieDarwin, GemBase)
+    CPPEXTERN_HEADER(pix_movieDarwin, GemBase);
 
    
     public:
