@@ -7,7 +7,7 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,7 +16,7 @@
 /////////////////////////////////////////////////////////
 //
 //  pix_multiblob
-// based on (c) 2004, Jakob Leiner & Theresa Rienmller
+// based on (c) 2004, Jakob Leiner & Theresa Rienmüller
 //
 /////////////////////////////////////////////////////////
 
@@ -73,7 +73,7 @@ void Blob:: ymax(double y){
   m_ymax=y;
 }
 
-CPPEXTERN_NEW_WITH_ONE_ARG(pix_multiblob,t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG(pix_multiblob,t_floatarg, A_DEFFLOAT);
   
 /*------------------------------------------------------------
   
@@ -87,9 +87,9 @@ Constructor
 initializes the pixBlocks and pixBlobs
 
 ------------------------------------------------------------*/
-  pix_multiblob :: pix_multiblob(t_floatarg f) : m_blobsize(0.001), m_treshold(10)
+  pix_multiblob :: pix_multiblob(t_floatarg f) : m_blobsize(0.001), m_threshold(10)
 {
-  m_blobNumber = (int)f;
+  m_blobNumber = static_cast<int>(f);
   if(m_blobNumber < 1)m_blobNumber = 6;
 
   // initialize blob-structures
@@ -126,9 +126,9 @@ void pix_multiblob :: makeBlob(Blob *pb, int x, int y){
   if(x>m_image.xsize || y>m_image.xsize)return;
 
   pb->area++;
-  t_float grey=((t_float)m_image.GetPixel(y, x, chGray))/255;
-  pb->m_xaccum +=grey*(t_float)x;
-  pb->m_yaccum +=grey*(t_float)y;
+  t_float grey=(static_cast<t_float>(m_image.GetPixel(y, x, chGray))/255);
+  pb->m_xaccum +=grey*static_cast<t_float>(x);
+  pb->m_yaccum +=grey*static_cast<t_float>(y);
   pb->m_xyaccum+=grey;
 
 
@@ -142,7 +142,7 @@ void pix_multiblob :: makeBlob(Blob *pb, int x, int y){
   if(pb->area > 10000){return;}
   for(int i = -1; i<= 1; i++){
     for(int j = -1; j <= 1; j++){
-      if (m_image.GetPixel(y+i, x+j, chGray) > m_treshold)
+      if (m_image.GetPixel(y+i, x+j, chGray) > m_threshold)
 	{
 	  makeBlob(pb, x+j, y+i);
 	}
@@ -178,7 +178,7 @@ render
 ------------------------------------------------------------*/
 void pix_multiblob :: doProcessing() {
   int blobNumber = 0;
-  int blobsize = (int)(m_blobsize * m_image.xsize * m_image.ysize);
+  int blobsize = static_cast<int>(m_blobsize * m_image.xsize * m_image.ysize);
 
   // reset the currentblobs array
 
@@ -214,7 +214,7 @@ void pix_multiblob :: doProcessing() {
   // no create a matrix of [blobNumber*3] elements
   // each row holds all information on our blob
   t_atom*ap = new t_atom[2+blobNumber*8];
-  SETFLOAT(ap, (t_float)blobNumber);
+  SETFLOAT(ap, static_cast<t_float>(blobNumber));
   SETFLOAT(ap+1, 8.0);
 
   int bn=blobNumber;
@@ -284,14 +284,14 @@ void pix_multiblob :: blobSizeMess(t_float blobSize){
 }
 
 /*------------------------------------------------------------
-treshMess
+threshMess
 ------------------------------------------------------------*/
-void pix_multiblob :: treshMess(t_float tresh){
-  if((tresh < 0.0)||(tresh > 1.0))
+void pix_multiblob :: threshMess(t_float thresh){
+  if((thresh < 0.0)||(thresh > 1.0))
     {
-      error("treshold %f out of range (0..1)!", tresh);
+      error("threshold %f out of range (0..1)!", thresh);
     }
-  m_treshold = CLAMP(tresh*255);
+  m_threshold = CLAMP(thresh*255);
 }
 
 
@@ -301,24 +301,24 @@ void pix_multiblob :: treshMess(t_float tresh){
 //
 /////////////////////////////////////////////////////////
 void pix_multiblob :: obj_setupCallback(t_class *classPtr){
-  class_addmethod(classPtr, (t_method)&pix_multiblob :: blobSizeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_multiblob::blobSizeMessCallback),
 		  gensym("blobSize"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_multiblob :: treshMessCallback,
-		  gensym("tresh"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_multiblob :: treshMessCallback,
-		  gensym("treshold"), A_FLOAT, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_multiblob::threshMessCallback),
+		  gensym("thresh"), A_FLOAT, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_multiblob::threshMessCallback),
+		  gensym("threshold"), A_FLOAT, A_NULL);
 }
 
 /*------------------------------------------------------------
 blobSizeMessCallback
 ------------------------------------------------------------*/
 void pix_multiblob :: blobSizeMessCallback(void *data, t_floatarg blobSize){
-  GetMyClass(data)->blobSizeMess((t_float) blobSize);
+  GetMyClass(data)->blobSizeMess(blobSize);
 }
 
 /*------------------------------------------------------------
-treshMessCallback
+threshMessCallback
 ------------------------------------------------------------*/
-void pix_multiblob :: treshMessCallback(void *data, t_floatarg tresh){
-  GetMyClass(data)->treshMess((t_float) tresh);
+void pix_multiblob :: threshMessCallback(void *data, t_floatarg thresh){
+  GetMyClass(data)->threshMess(thresh);
 }
