@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -18,9 +18,11 @@
 
 #include <stdio.h>
 
-#include "Base/GemCache.h"
+#include "Gem/Cache.h"
+#include "Gem/State.h"
+#include "Gem/ImageIO.h"
 
-CPPEXTERN_NEW_WITH_FOUR_ARGS(pix_multiimage, t_symbol *, A_DEFSYM, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_FOUR_ARGS(pix_multiimage, t_symbol *, A_DEFSYM, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 pix_multiimage::multiImageCache *pix_multiimage::s_imageCache = NULL;
 
@@ -142,7 +144,7 @@ void pix_multiimage :: openMess(t_symbol *filename, int baseImage, int topImage,
 
     int realNum = baseImage;
     char bufName[MAXPDSTRING];
-    canvas_makefilename(getCanvas(), preName, bufName, MAXPDSTRING);
+    canvas_makefilename(const_cast<t_canvas*>(getCanvas()), preName, bufName, MAXPDSTRING);
 
     // allocate texture bindings for OpenGL
     newCache->textBind = new unsigned int[m_numImages];
@@ -201,7 +203,7 @@ void pix_multiimage :: render(GemState *state)
     	m_cache->resendImage = 0;
     }
     
-    state->image = &m_pixBlock;
+    state->set(GemState::_PIX, &m_pixBlock);
 }
 
 /////////////////////////////////////////////////////////
@@ -210,8 +212,8 @@ void pix_multiimage :: render(GemState *state)
 /////////////////////////////////////////////////////////
 void pix_multiimage :: postrender(GemState *state)
 {
-    m_pixBlock.newimage = 0;
-    state->image = NULL;
+  m_pixBlock.newimage = 0;
+  state->set(GemState::_PIX, static_cast<pixBlock*>(NULL));
 }
 
 /////////////////////////////////////////////////////////
@@ -297,9 +299,9 @@ void pix_multiimage :: cleanImages()
 /////////////////////////////////////////////////////////
 void pix_multiimage :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&pix_multiimage::openMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_multiimage::openMessCallback),
     	    gensym("open"), A_SYMBOL, A_FLOAT, A_DEFFLOAT, A_DEFFLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&pix_multiimage::changeImageCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_multiimage::changeImageCallback),
     	    gensym("img_num"), A_FLOAT, A_NULL);
 }
 void pix_multiimage :: openMessCallback(void *data, t_symbol *filename, t_floatarg baseImage,
