@@ -5,16 +5,16 @@ LOG
     add offset-values to the RGBA-Channels (without clamping to 0..255)
 
     Copyright (c) 1997-1998 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_OFFSET_H_
-#define INCLUDE_PIX_OFFSET_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_OFFSET_H_
+#define _INCLUDE__GEM_PIXES_PIX_OFFSET_H_
 
 #include "Base/GemPixObj.h"
 
@@ -39,7 +39,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_offset : public GemPixObj
 {
-    CPPEXTERN_HEADER(pix_offset, GemPixObj)
+    CPPEXTERN_HEADER(pix_offset, GemPixObj);
 
     public:
 
