@@ -7,7 +7,7 @@
 // Implementation file
 //
 //    Copyright (c) 2000 Guenter Geiger geiger@epy.co.at
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -18,7 +18,7 @@
 
 #include "pix_pix2sig.h"
 
-CPPEXTERN_NEW(pix_pix2sig)
+CPPEXTERN_NEW(pix_pix2sig);
 
 /////////////////////////////////////////////////////////
 //
@@ -149,8 +149,8 @@ void pix_pix2sig :: dspMess(void *data, t_signal** sp)
 
 void pix_pix2sig :: obj_setupCallback(t_class *classPtr)
 {
-  class_addcreator((t_newmethod)create_pix_pix2sig, gensym("pix_pix2sig~"), A_NULL);
-  class_addmethod(classPtr, (t_method)pix_pix2sig::dspMessCallback, 
+  class_addcreator(reinterpret_cast<t_newmethod>(create_pix_pix2sig), gensym("pix_pix2sig~"), A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(pix_pix2sig::dspMessCallback), 
 		  gensym("dsp"), A_NULL);
 }
 
