@@ -3,12 +3,12 @@
  *  gem_darwin
  *
  *  Created by James Tittle on Fri Oct 18 2002.
- *  Copyleft (l) 2002 tigital. All rights reserved.
+ *  Copyright (c) 2002 tigital. All rights reserved.
  *
  */
 
-#ifndef INCLUDE_PIX_POSTERIZE_H_ 
-#define INCLUDE_PIX_POSTERIZE_H_ 
+#ifndef _INCLUDE__GEM_PIXES_PIX_POSTERIZE_H_ 
+#define _INCLUDE__GEM_PIXES_PIX_POSTERIZE_H_ 
 
 #include "Base/GemPixObj.h"
 
@@ -29,7 +29,7 @@ DESCRIPTION
 
 class GEM_EXTERN pix_posterize : public GemPixObj
 {
-CPPEXTERN_HEADER(pix_posterize, GemPixObj)
+CPPEXTERN_HEADER(pix_posterize, GemPixObj);
 
     public:
 
