@@ -10,7 +10,7 @@
 //
 // Implementation file
 //
-//    Copyleft (l) 2003 James Tittle
+//    Copyright (c) 2003 James Tittle
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -18,7 +18,7 @@
 #include "pix_rds.h"
 #include <stdlib.h>
 
-CPPEXTERN_NEW(pix_rds)
+CPPEXTERN_NEW(pix_rds);
 
 #define inline_fastrand() (fastrand_val=fastrand_val*1103515245+12345)
 
@@ -349,12 +349,12 @@ void pix_rds :: processYUVImage(imageStruct &image)
 /////////////////////////////////////////////////////////
 void pix_rds :: obj_setupCallback(t_class *classPtr)
 {
-  //  class_addfloat(classPtr, (t_method)&pix_rds::methMessCallback);
-  class_addmethod(classPtr, (t_method)&pix_rds::methMessCallback,
+  //  class_addfloat(classPtr, reinterpret_cast<t_method>(&pix_rds::methMessCallback));
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_rds::methMessCallback),
 		  gensym("method"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_rds::strideMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_rds::strideMessCallback),
 		  gensym("stride"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_rds::seedMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_rds::seedMessCallback),
 		  gensym("seed"), A_FLOAT, A_NULL);
 }
 
