@@ -9,14 +9,14 @@ LOG
 
     ported by tigital@mac.com
     
-    Copyleft  (l) 2003 James Tittle tigital@mac.com
+    Copyright (c) 2003 James Tittle tigital@mac.com
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_RDS_H_
-#define INCLUDE_PIX_RDS_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_RDS_H_
+#define _INCLUDE__GEM_PIXES_PIX_RDS_H_
 
 #include "Base/GemPixObj.h"
 
@@ -38,7 +38,7 @@ LOG
   -----------------------------------------------------------------*/
 class GEM_EXTERN pix_rds : public GemPixObj
 {
-  CPPEXTERN_HEADER(pix_rds, GemPixObj)
+  CPPEXTERN_HEADER(pix_rds, GemPixObj);
 
     public:
 
