@@ -6,7 +6,7 @@
  *  Copyright 2005 __MyCompanyName__. All rights reserved.
  *
  */
-
+#include "Gem/GemConfig.h"
 //original pix_record for Mac/Windows - very well tested (at least 100,000 recorded clips)
 
 #if 0
@@ -20,11 +20,11 @@
 
 
 #include "pix_recordQT.h"
-#include "Base/GemMan.h"
-#include "Base/GemCache.h"
+#include "Gem/Manager.h"
+#include "Gem/Cache.h"
 
 
-CPPEXTERN_NEW_WITH_GIMME(pix_recordQT)
+CPPEXTERN_NEW_WITH_GIMME(pix_recordQT);
  
   /////////////////////////////////////////////////////////
 //
@@ -41,13 +41,13 @@ pix_recordQT :: pix_recordQT(int argc, t_atom *argv)
   m_width = m_height = 0;
   m_prevHeight = m_prevWidth = 0;
   if (argc == 4) {
-    m_xoff = (int)atom_getfloat(&argv[0]);
-    m_yoff = (int)atom_getfloat(&argv[1]);
-    m_width = (int)atom_getfloat(&argv[2]);
-    m_height = (int)atom_getfloat(&argv[3]);
+    m_xoff = atom_getint(&argv[0]);
+    m_yoff = atom_getint(&argv[1]);
+    m_width = atom_getint(&argv[2]);
+    m_height = atom_getint(&argv[3]);
   } else if (argc == 2) {
-    m_width = (int)atom_getfloat(&argv[0]);
-    m_height = (int)atom_getfloat(&argv[1]);
+    m_width = atom_getint(&argv[0]);
+    m_height = atom_getint(&argv[1]);
   } else if (argc != 0){
     error("needs 0, 2, or 4 values");
     m_xoff = m_yoff = 0;
@@ -70,7 +70,7 @@ pix_recordQT :: pix_recordQT(int argc, t_atom *argv)
   m_banged = false;
   
 
-# ifdef __WIN32__
+# ifdef _WIN32
   // Initialize QuickTime Media Layer
 
   
@@ -165,7 +165,7 @@ pix_recordQT :: ~pix_recordQT()
 //most likely a dumb thing to do
 	/*
 	#ifdef HAVE_QUICKTIME
-# ifdef __WIN32__
+# ifdef _WIN32
 	
 	post("exiting QT");
   // Initialize QuickTime
@@ -346,7 +346,7 @@ void pix_recordQT :: setupQT() //this only needs to be done when codec info chan
 	
 	SetMovieGWorld(m_movie,m_srcGWorld,GetGWorldDevice(m_srcGWorld));
 
-#ifdef __WIN32__
+#ifdef _WIN32
 	MatrixRecord	aMatrix;
 	GetMovieMatrix(m_movie,&aMatrix);
 	//RotateMatrix(&aMatrix,Long2Fix(180),0,0);//should be ScaleMatrix
@@ -564,16 +564,16 @@ void pix_recordQT :: compressFrame()
 	}
 	::Microseconds(&endTime);
 	
-	seconds = (float)(endTime.lo - startTime.lo) / 1000000.f;
+	seconds = static_cast<float>(endTime.lo - startTime.lo) / 1000000.f;
 	
-	m_ticks = (int)(600 * seconds);
+	m_ticks = static_cast<int>(600 * seconds);
 	
 	if (m_ticks < 20) m_ticks = 20;
 	
 	#endif //timers
 	
 
-#ifdef __WIN32__
+#ifdef _WIN32
   static int firstTime = 1;
   static float countFreq = 0;
   if (m_firstRun)
@@ -582,18 +582,18 @@ void pix_recordQT :: compressFrame()
       if (!QueryPerformanceFrequency(&freq))
 	countFreq = 0;
       else
-	countFreq = (float)(freq.QuadPart);
+	countFreq = static_cast<float>(freq.QuadPart);
 	QueryPerformanceCounter(&startTime);//fakes the time of the first frame
 	m_ticks = 20;
       m_firstRun = 0;
 	}else{
 
   QueryPerformanceCounter(&endTime);
-	float fps = 1000 / ((float)(endTime.QuadPart - startTime.QuadPart)/countFreq * 1000.f);
-	seconds = ((float)(endTime.QuadPart - startTime.QuadPart)/countFreq * 1.f);
+	float fps = 1000 / (static_cast<float>(endTime.QuadPart - startTime.QuadPart)/countFreq * 1000.f);
+	seconds = (static_cast<float>(endTime.QuadPart - startTime.QuadPart)/countFreq * 1.f);
  // post("freq %f countFreq %f startTime %d endTime %d fps %f seconds %f ",freq, countFreq,(int)startTime.QuadPart,(int)endTime.QuadPart,fps,seconds);
 
-	m_ticks = (int)(600 * seconds);
+	m_ticks = static_cast<int>(600 * seconds);
 	
 	if (m_ticks < 20) m_ticks = 20;
 	}
@@ -644,7 +644,7 @@ void pix_recordQT :: compressFrame()
 					
 	#endif //timer		
 
-#ifdef __WIN32__
+#ifdef _WIN32
 
       QueryPerformanceCounter(&startTime);
 //	  post("startTime %d",startTime.QuadPart);
@@ -874,26 +874,26 @@ void pix_recordQT :: cleanImage()
 /////////////////////////////////////////////////////////
 void pix_recordQT :: obj_setupCallback(t_class *classPtr)
 {
-  class_addcreator((t_newmethod)create_pix_recordQT,gensym("pix_record"),A_DEFSYM,A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_recordQT::fileMessCallback,
+  class_addcreator(reinterpret_cast<t_newmethod>(create_pix_recordQT,gensym("pix_record"),A_DEFSYM,A_NULL));
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_recordQT::fileMessCallback),
 		  gensym("file"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_recordQT::autoMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_recordQT::autoMessCallback),
 		  gensym("auto"), A_FLOAT, A_NULL);
-  class_addbang(classPtr, (t_method)&pix_recordQT::bangMessCallback);
+  class_addbang(classPtr, reinterpret_cast<t_method>(&pix_recordQT::bangMessCallback));
 
-  class_addmethod(classPtr, (t_method)&pix_recordQT::sizeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_recordQT::sizeMessCallback),
 		  gensym("size"), A_FLOAT, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_recordQT::posMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_recordQT::posMessCallback),
 		  gensym("vert_pos"), A_FLOAT, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_recordQT::recordMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_recordQT::recordMessCallback),
 		  gensym("record"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_recordQT::dialogMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_recordQT::dialogMessCallback),
 		  gensym("dialog"),  A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_recordQT::codeclistMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_recordQT::codeclistMessCallback),
 		  gensym("codeclist"),  A_NULL);
-	class_addmethod(classPtr, (t_method)&pix_recordQT::codecMessCallback,
+	class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_recordQT::codecMessCallback),
 		  gensym("codec"), A_GIMME, A_NULL);
-	class_addmethod(classPtr, (t_method)&pix_recordQT::colorspaceCallback,
+	class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_recordQT::colorspaceCallback),
 		  gensym("colorspace"), A_SYMBOL, A_NULL);
 }
 
@@ -912,16 +912,16 @@ void pix_recordQT :: bangMessCallback(void *data)
 
 void pix_recordQT :: sizeMessCallback(void *data, t_floatarg width, t_floatarg height)
 {
-  GetMyClass(data)->sizeMess((int)width, (int)height);
+  GetMyClass(data)->sizeMess(static_cast<int>(width), static_cast<int>(height));
 }
 void pix_recordQT :: posMessCallback(void *data, t_floatarg x, t_floatarg y)
 {
-  GetMyClass(data)->posMess((int)x, (int)y);
+  GetMyClass(data)->posMess(static_cast<int>(x), static_cast<int>(y));
 }
 
 void pix_recordQT :: recordMessCallback(void *data, t_floatarg on)
 {
-	if (!(!(int)on)) {
+	if (!(!static_cast<int>(on))) {
 		GetMyClass(data)->m_recordStart=1;
 		GetMyClass(data)->m_recordStop=0;
 		GetMyClass(data)->post("recording on!");
