@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -18,7 +18,7 @@
 //
 //  pix_rectangle
 //
-//  2002:forum::fr::umlute:2000
+//  2002:forum::für::umläute:2000
 //  iohannes m zmoelnig
 //  mailto:zmoelnig@iem.mhsg.ac.at
 //
@@ -26,9 +26,9 @@
 
 
 #include "pix_rectangle.h"
-#include "Base/GemPixConvert.h"
+#include "Gem/PixConvert.h"
 
-CPPEXTERN_NEW(pix_rectangle)
+CPPEXTERN_NEW(pix_rectangle);
 
 /////////////////////////////////////////////////////////
 //
@@ -168,10 +168,10 @@ void pix_rectangle :: vecColorMess(int argc, t_atom *argv)
   green = atom_getfloat(&argv[1]);
   blue  = atom_getfloat(&argv[2]);
 
-  m_color[chRed]   = (unsigned char)(255.*red);
-  m_color[chGreen] = (unsigned char)(255.*green);
-  m_color[chBlue]  = (unsigned char)(255.*blue);
-  m_color[chAlpha] = (unsigned char)(255.*alpha);
+  m_color[chRed]   = static_cast<unsigned char>(255.*red);
+  m_color[chGreen] = static_cast<unsigned char>(255.*green);
+  m_color[chBlue]  = static_cast<unsigned char>(255.*blue);
+  m_color[chAlpha] = static_cast<unsigned char>(255.*alpha);
 
   setPixModified();
 }
@@ -188,10 +188,10 @@ void pix_rectangle :: vecCoordMess(int argc, t_atom *argv)
     error("not enough coordinates");
     return;
   }
-  X1 = (int)atom_getfloat(&argv[0]);
-  Y1 = (int)atom_getfloat(&argv[1]);
-  X2 = (int)atom_getfloat(&argv[2]);
-  Y2 = (int)atom_getfloat(&argv[3]);
+  X1 = atom_getint(&argv[0]);
+  Y1 = atom_getint(&argv[1]);
+  X2 = atom_getint(&argv[2]);
+  Y2 = atom_getint(&argv[3]);
   
   // check if within range
   if (X1 < 0)X1 = 0;
@@ -215,9 +215,9 @@ void pix_rectangle :: vecCoordMess(int argc, t_atom *argv)
 /////////////////////////////////////////////////////////
 void pix_rectangle :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&pix_rectangle::vecCoordMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_rectangle::vecCoordMessCallback),
     	    gensym("coord"), A_GIMME, A_NULL);
-    class_addmethod(classPtr, (t_method)&pix_rectangle::vecColorMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_rectangle::vecColorMessCallback),
     	    gensym("color"), A_GIMME, A_NULL);
 
 }
