@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -19,7 +19,7 @@
 
 #include <math.h>
 
-CPPEXTERN_NEW_WITH_TWO_ARGS(pix_resize, t_float,A_DEFFLOAT,t_float, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS(pix_resize, t_float,A_DEFFLOAT,t_float, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -60,6 +60,7 @@ void pix_resize :: processImage(imageStruct &image)
       m_image.ysize=hN;
       m_image.setCsizeByFormat(image.format);
       m_image.reallocate();
+      m_image.reallocate(wN*hN*4); // just for safety: it seems like gluScaleImage needs more memory then just the x*y*c
       
       gluError = gluScaleImage(image.format,
 			       image.xsize, image.ysize,
@@ -86,6 +87,8 @@ void pix_resize :: dimenMess(int width, int height) {
 
   m_width =width;
   m_height=height;
+
+  setPixModified();
 }
 
 /////////////////////////////////////////////////////////
@@ -94,7 +97,7 @@ void pix_resize :: dimenMess(int width, int height) {
 /////////////////////////////////////////////////////////
 void pix_resize :: obj_setupCallback(t_class *classPtr)
 { 
-  class_addmethod(classPtr, (t_method)pix_resize::dimenMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(pix_resize::dimenMessCallback), 
 		  gensym("dimen"), A_DEFFLOAT,A_DEFFLOAT, A_NULL);
 }
 
