@@ -7,8 +7,8 @@
  *
  */
 
-#ifndef INCLUDE_pix_scanline_H_ 
-#define INCLUDE_pix_scanline_H_ 
+#ifndef _INCLUDE__GEM_PIXES_PIX_SCANLINE_H_ 
+#define _INCLUDE__GEM_PIXES_PIX_SCANLINE_H_ 
 
 #include "Base/GemPixObj.h"
 
@@ -31,7 +31,7 @@ DESCRIPTION
 
 class GEM_EXTERN pix_scanline : public GemPixObj
 {
-CPPEXTERN_HEADER(pix_scanline, GemPixObj)
+CPPEXTERN_HEADER(pix_scanline, GemPixObj);
 
     public:
 
