@@ -5,8 +5,8 @@
  interprete a (long) list of floats as a pixBlock
   
  Copyright (c) 1997-1999 Mark Danks. mark@danks.org
- Copyright (c) Gnther Geiger. geiger@epy.co.at
- Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+ Copyright (c) Günther Geiger. geiger@epy.co.at
+ Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
  For information on usage and redistribution, and for a DISCLAIMER OF ALL
  WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
    
@@ -15,19 +15,19 @@
 /*-----------------------------------------------------------------
 pix_set
 
-  0409:forum::fr::umlute:2000
+  0409:forum::für::umläute:2000
   IOhannes m zmoelnig
   mailto:zmoelnig@iem.kug.ac.at
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_SET_H_
-#define INCLUDE_PIX_SET_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_SET_H_
+#define _INCLUDE__GEM_PIXES_PIX_SET_H_
 
 #include "Base/GemPixObj.h"
 
 #include "Base/GemBase.h"
-#include "Base/GemPixUtil.h"
-#include "Base/GemCache.h"
+#include "Gem/Image.h"
+#include "Gem/Cache.h"
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
@@ -48,7 +48,7 @@ pix_set
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_set : public GemPixObj
 {
-    CPPEXTERN_HEADER(pix_set, GemPixObj)
+    CPPEXTERN_HEADER(pix_set, GemPixObj);
 		
 public:
 	
