@@ -6,11 +6,13 @@
  *  Copyright 2005 __MyCompanyName__. All rights reserved.
  *
  */
-#include "Base/GemPixUtil.h"
+#include "Gem/Image.h"
 #include "pix_share_read.h"
+#include "Gem/State.h"
+
 #include <errno.h>
 
-CPPEXTERN_NEW_WITH_GIMME(pix_share_read)
+CPPEXTERN_NEW_WITH_GIMME(pix_share_read);
   
   
   pix_share_read :: pix_share_read(int argc, t_atom*argv):pix_share_write(argc,argv)
@@ -26,7 +28,7 @@ pix_share_read :: ~pix_share_read()
 
 void pix_share_read :: render(GemState *state)
 {	
-#ifndef __WIN32__
+#ifndef _WIN32
   if(shm_id>0){
     if (shm_addr) {
       t_pixshare_header *h=(t_pixshare_header *)shm_addr;
@@ -41,8 +43,8 @@ void pix_share_read :: render(GemState *state)
         
         memcpy(pix.image.data,data,imgsize);
 
-        state->image = &pix;
-        state->image->newimage = 1;
+        pix.newimage = true;
+        state->set(GemState::_PIX, &pix);
       }
     }
     else{
