@@ -8,14 +8,14 @@
  */
 
 
-#ifndef INCLUDE_PIX_SHARE_READ_H
-#define INCLUDE_PIX_SHARE_READ_H
+#ifndef _INCLUDE__GEM_PIXES_PIX_SHARE_READ_H_
+#define _INCLUDE__GEM_PIXES_PIX_SHARE_READ_H_
 
 #include "pix_share_write.h"
 
 class GEM_EXTERN pix_share_read : public pix_share_write
 {
-  CPPEXTERN_HEADER(pix_share_read, pix_share_write)
+  CPPEXTERN_HEADER(pix_share_read, pix_share_write);
 
     public:
   pix_share_read(int,t_atom*);
