@@ -7,14 +7,14 @@
  *
  */
 
-#ifndef INCLUDE_PIX_SHARE_WRITE_H
-#define INCLUDE_PIX_SHARE_WRITE_H
+#ifndef _INCLUDE__GEM_PIXES_PIX_SHARE_WRITE_H_
+#define _INCLUDE__GEM_PIXES_PIX_SHARE_WRITE_H_
 
 #include "pix_share.h"
 
 class GEM_EXTERN pix_share_write : public GemBase
 {
-  CPPEXTERN_HEADER(pix_share_write, GemBase)
+  CPPEXTERN_HEADER(pix_share_write, GemBase);
 
     public:
   pix_share_write(int, t_atom*);
@@ -26,7 +26,7 @@ class GEM_EXTERN pix_share_write : public GemBase
   int getShm(int,t_atom*);
 
   virtual void render(GemState *state);
-#ifndef __WIN32__
+#ifndef _WIN32
   int	shm_id;
   unsigned char *shm_addr;
   struct shmid_ds shm_desc;
