@@ -7,7 +7,7 @@
 // Implementation file
 //
 //    Copyright (c) 2000 Guenter Geiger geiger@epy.co.at
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -17,8 +17,9 @@
 #define HELPSYMBOL "pix_sig2pix~"
 
 #include "pix_sig2pix.h"
+#include "Gem/State.h"
 
-CPPEXTERN_NEW_WITH_TWO_ARGS(pix_sig2pix, t_float,A_DEFFLOAT,t_float, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS(pix_sig2pix, t_float,A_DEFFLOAT,t_float, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -81,7 +82,7 @@ void pix_sig2pix :: csMess(GLint cs) {
 /////////////////////////////////////////////////////////
 void pix_sig2pix :: render(GemState *state)
 {
-  state->image = &m_pixBlock;
+  state->set(GemState::_PIX,&m_pixBlock);
 }
 
 /////////////////////////////////////////////////////////
@@ -91,7 +92,7 @@ void pix_sig2pix :: render(GemState *state)
 void pix_sig2pix :: postrender(GemState *state)
 {
   m_pixBlock.newimage = 0;
-  state->image = NULL;
+  state->set(GemState::_PIX, static_cast<pixBlock*>(NULL));
 }
 
 /////////////////////////////////////////////////////////
@@ -173,14 +174,14 @@ void pix_sig2pix :: dspMess(void *data, t_signal** sp)
 
 void pix_sig2pix :: obj_setupCallback(t_class *classPtr)
 {
-  class_addcreator((t_newmethod)create_pix_sig2pix, gensym("pix_sig2pix~"), A_DEFFLOAT, A_DEFFLOAT, A_NULL);
+  class_addcreator(reinterpret_cast<t_newmethod>(create_pix_sig2pix), gensym("pix_sig2pix~"), A_DEFFLOAT, A_DEFFLOAT, A_NULL);
 
   class_addmethod(classPtr, nullfn, gensym("signal"), A_NULL);
-  class_addmethod(classPtr, (t_method)pix_sig2pix::dspMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(pix_sig2pix::dspMessCallback), 
 		  gensym("dsp"), A_NULL);
-  class_addmethod(classPtr, (t_method)pix_sig2pix::dimenMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(pix_sig2pix::dimenMessCallback), 
 		  gensym("dimen"), A_DEFFLOAT,A_DEFFLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)pix_sig2pix::csMessCallback, 
+  class_addmethod(classPtr, reinterpret_cast<t_method>(pix_sig2pix::csMessCallback), 
 		  gensym("colorspace"), A_DEFSYMBOL, A_NULL);
 }
 
