@@ -4,18 +4,18 @@
 
   Convert 4 signals (R~, G~, B~, A~) into a pixBuf
 
-  Copyright (c) 2000 Gnther Geiger. geiger@epy.co.at
-  Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+  Copyright (c) 2000 Günther Geiger. geiger@epy.co.at
+  Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
   For information on usage and redistribution, and for a DISCLAIMER OF ALL
   WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
   -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_SIG2PIX_H_
-#define INCLUDE_PIX_SIG2PIX_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_SIG_PIX_H_
+#define _INCLUDE__GEM_PIXES_PIX_SIG_PIX_H_
 
 #include "Base/GemBase.h"
-#include "Base/GemPixUtil.h"
+#include "Gem/Image.h"
 
 /*-----------------------------------------------------------------
   -------------------------------------------------------------------
@@ -36,7 +36,7 @@
   -----------------------------------------------------------------*/
 class GEM_EXTERN pix_sig2pix : public GemBase
 {
-  CPPEXTERN_HEADER(pix_sig2pix, GemBase)
+  CPPEXTERN_HEADER(pix_sig2pix, GemBase);
 
     public:
 
