@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,10 +16,11 @@
 
 #include "pix_snap.h"
 
-#include "Base/GemMan.h"
-#include "Base/GemCache.h"
+#include "Gem/Manager.h"
+#include "Gem/Cache.h"
+#include "Gem/State.h"
 
-CPPEXTERN_NEW_WITH_GIMME(pix_snap)
+CPPEXTERN_NEW_WITH_GIMME(pix_snap);
 
 /////////////////////////////////////////////////////////
 //
@@ -35,14 +36,14 @@ pix_snap :: pix_snap(int argc, t_atom *argv)
   m_pixBlock.image = m_imageStruct;
   m_pixBlock.image.data = NULL;
   if (argc == 4){
-    m_x = (int)atom_getfloat(&argv[0]);
-    m_y = (int)atom_getfloat(&argv[1]);
-    m_width = (int)atom_getfloat(&argv[2]);
-    m_height = (int)atom_getfloat(&argv[3]);
+    m_x = atom_getint(&argv[0]);
+    m_y = atom_getint(&argv[1]);
+    m_width = atom_getint(&argv[2]);
+    m_height = atom_getint(&argv[3]);
   } else if (argc == 2)	{
     m_x = m_y = 0;
-    m_width = (int)atom_getfloat(&argv[0]);
-    m_height = (int)atom_getfloat(&argv[1]);
+    m_width = atom_getint(&argv[0]);
+    m_height = atom_getint(&argv[1]);
   } else if (argc == 0)	{
     m_x = m_y = 0;
     m_width = m_height = 128;
@@ -143,7 +144,7 @@ void pix_snap :: render(GemState *state)
     	m_cache->resendImage = 0;
     }
     
-    state->image = &m_pixBlock;
+    state->set(GemState::_PIX, &m_pixBlock);
 }
 
 /////////////////////////////////////////////////////////
@@ -153,7 +154,7 @@ void pix_snap :: render(GemState *state)
 void pix_snap :: postrender(GemState *state)
 {
     m_pixBlock.newimage = 0;
-    state->image = NULL;
+    state->set(GemState::_PIX, static_cast<pixBlock*>(NULL));
 }
 
 /////////////////////////////////////////////////////////
@@ -198,13 +199,13 @@ void pix_snap :: cleanImage()
 /////////////////////////////////////////////////////////
 void pix_snap :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&pix_snap::snapMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_snap::snapMessCallback),
     	    gensym("snap"), A_NULL);
-    class_addbang(classPtr, (t_method)&pix_snap::snapMessCallback);
+    class_addbang(classPtr, reinterpret_cast<t_method>(&pix_snap::snapMessCallback));
 
-    class_addmethod(classPtr, (t_method)&pix_snap::sizeMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_snap::sizeMessCallback),
     	    gensym("vert_size"), A_FLOAT, A_FLOAT, A_NULL);
-    class_addmethod(classPtr, (t_method)&pix_snap::posMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_snap::posMessCallback),
     	    gensym("vert_pos"), A_FLOAT, A_FLOAT, A_NULL);
 }
 void pix_snap :: snapMessCallback(void *data)
@@ -213,9 +214,9 @@ void pix_snap :: snapMessCallback(void *data)
 }
 void pix_snap :: sizeMessCallback(void *data, t_floatarg width, t_floatarg height)
 {
-    GetMyClass(data)->sizeMess((int)width, (int)height);
+    GetMyClass(data)->sizeMess(static_cast<int>(width), static_cast<int>(height));
 }
 void pix_snap :: posMessCallback(void *data, t_floatarg x, t_floatarg y)
 {
-    GetMyClass(data)->posMess((int)x, (int)y);
+    GetMyClass(data)->posMess(static_cast<int>(x), static_cast<int>(y));
 }
