@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2003 Daniel Heckenberg
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -17,10 +17,10 @@
 
 #include "pix_snap2tex.h"
 
-#include "Base/GemMan.h"
-#include "Base/GemFuncUtil.h"
+#include "Gem/Manager.h"
+#include "Utils/Functions.h"
 
-CPPEXTERN_NEW_WITH_GIMME(pix_snap2tex)
+CPPEXTERN_NEW_WITH_GIMME(pix_snap2tex);
 
 /////////////////////////////////////////////////////////
 //
@@ -42,16 +42,16 @@ pix_snap2tex :: pix_snap2tex(int argc, t_atom *argv)
 {
   if (argc == 4)
     {
-      m_x = (int)atom_getfloat(&argv[0]);
-      m_y = (int)atom_getfloat(&argv[1]);
-      m_width = (int)atom_getfloat(&argv[2]);
-      m_height = (int)atom_getfloat(&argv[3]);
+      m_x = atom_getint(&argv[0]);
+      m_y = atom_getint(&argv[1]);
+      m_width = atom_getint(&argv[2]);
+      m_height = atom_getint(&argv[3]);
     }
   else if (argc == 2)
     {
       m_x = m_y = 0;
-      m_width = (int)atom_getfloat(&argv[0]);
-      m_height = (int)atom_getfloat(&argv[1]);
+      m_width = atom_getint(&argv[0]);
+      m_height = atom_getint(&argv[1]);
     }
   else if (argc == 0)
     {
@@ -166,7 +166,7 @@ void pix_snap2tex :: snapMess()
       m_texHeight = y_2;
 		
       glCopyTexImage2D(	m_textureType, 0,
-			GL_RGB,
+			GL_RGBA16,
 			m_x, m_y,
 			m_texWidth, m_texHeight, 
 			0);
@@ -193,16 +193,15 @@ void pix_snap2tex :: snapMess()
 void pix_snap2tex :: render(GemState *state)
 {
   m_didTexture=false;
-
-  m_oldTexCoords=state->texCoords;
-  m_oldNumCoords=state->numTexCoords;
-  m_oldTexture  =state->texture;
+  state->get(GemState::_GL_TEX_COORDS, m_oldTexCoords);
+  state->get(GemState::_GL_TEX_NUMCOORDS, m_oldNumCoords);
+  state->get(GemState::_GL_TEX_TYPE, m_oldTexture);
 
   if (!m_textureOnOff) return;
 
-  state->texture = 1;
-  state->texCoords = m_coords;
-  state->numTexCoords = 4;
+  state->set(GemState::_GL_TEX_COORDS, static_cast<TexCoord*>(m_coords));
+  state->set(GemState::_GL_TEX_NUMCOORDS, 4);
+  state->set(GemState::_GL_TEX_TYPE, 1);
 
   glEnable(m_textureType);
 
@@ -230,9 +229,9 @@ void pix_snap2tex :: render(GemState *state)
 /////////////////////////////////////////////////////////
 void pix_snap2tex :: postrender(GemState *state)
 {
-  state->texCoords= m_oldTexCoords;
-  state->numTexCoords=  m_oldNumCoords;
-  state->texture     = m_oldTexture;
+  state->set(GemState::_GL_TEX_COORDS, m_oldTexCoords);
+  state->set(GemState::_GL_TEX_NUMCOORDS, m_oldNumCoords);
+  state->set(GemState::_GL_TEX_TYPE, m_oldTexture);
 
   if (m_didTexture){
     glDisable(m_textureType);
@@ -380,21 +379,21 @@ void pix_snap2tex :: repeatMess(int type)
 /////////////////////////////////////////////////////////
 void pix_snap2tex :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&pix_snap2tex::snapMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_snap2tex::snapMessCallback),
 		  gensym("snap"), A_NULL);
-  class_addbang(classPtr, (t_method)&pix_snap2tex::snapMessCallback);
+  class_addbang(classPtr, reinterpret_cast<t_method>(&pix_snap2tex::snapMessCallback));
 
-  class_addmethod(classPtr, (t_method)&pix_snap2tex::sizeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_snap2tex::sizeMessCallback),
 		  gensym("vert_size"), A_FLOAT, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_snap2tex::posMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_snap2tex::posMessCallback),
 		  gensym("vert_pos"), A_FLOAT, A_FLOAT, A_NULL);
 
-  class_addfloat(classPtr, (t_method)&pix_snap2tex::floatMessCallback);    
-  class_addmethod(classPtr, (t_method)&pix_snap2tex::textureMessCallback,
+  class_addfloat(classPtr, reinterpret_cast<t_method>(&pix_snap2tex::floatMessCallback));    
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_snap2tex::textureMessCallback),
 		  gensym("quality"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_snap2tex::repeatMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_snap2tex::repeatMessCallback),
 		  gensym("repeat"), A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_snap2tex::modeCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_snap2tex::modeCallback),
 		  gensym("mode"), A_FLOAT, A_NULL);
 }
 void pix_snap2tex :: snapMessCallback(void *data)
@@ -403,25 +402,25 @@ void pix_snap2tex :: snapMessCallback(void *data)
 }
 void pix_snap2tex :: sizeMessCallback(void *data, t_floatarg width, t_floatarg height)
 {
-  GetMyClass(data)->sizeMess((int)width, (int)height);
+  GetMyClass(data)->sizeMess(static_cast<int>(width), static_cast<int>(height));
 }
 void pix_snap2tex :: posMessCallback(void *data, t_floatarg x, t_floatarg y)
 {
-  GetMyClass(data)->posMess((int)x, (int)y);
+  GetMyClass(data)->posMess(static_cast<int>(x), static_cast<int>(y));
 }
 void pix_snap2tex :: floatMessCallback(void *data, float n)
 {
-  GetMyClass(data)->textureOnOff((int)n);
+  GetMyClass(data)->textureOnOff(static_cast<int>(n));
 }
 void pix_snap2tex :: textureMessCallback(void *data, t_floatarg quality)
 {
-  GetMyClass(data)->textureQuality((int)quality);
+  GetMyClass(data)->textureQuality(static_cast<int>(quality));
 }
 void pix_snap2tex :: repeatMessCallback(void *data, t_floatarg quality)
 {
-  GetMyClass(data)->repeatMess((int)quality);
+  GetMyClass(data)->repeatMess(static_cast<int>(quality));
 }
 void pix_snap2tex :: modeCallback(void *data, t_floatarg quality)
 {
-  GetMyClass(data)->m_mode=((int)quality);
+  GetMyClass(data)->m_mode=(static_cast<int>(quality));
 }
