@@ -5,8 +5,8 @@ LOG
     Snap a pix of the render buffer into a texture
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     Copyright (c) 2003 Daniel Heckenberg
 
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
@@ -14,10 +14,11 @@ LOG
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_SNAP2TEX_H_
-#define INCLUDE_PIX_SNAP2TEX_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_SNAP_TEX_H_
+#define _INCLUDE__GEM_PIXES_PIX_SNAP_TEX_H_
 
 #include "Base/GemBase.h"
+#include "Gem/State.h"
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
@@ -43,7 +44,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class pix_snap2tex : public GemBase
 {
-    CPPEXTERN_HEADER(pix_snap2tex, GemBase)
+    CPPEXTERN_HEADER(pix_snap2tex, GemBase);
 
     public:
 
