@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -17,7 +17,7 @@
 
 #include "pix_subtract.h"
 
-CPPEXTERN_NEW(pix_subtract)
+CPPEXTERN_NEW(pix_subtract);
 
 /////////////////////////////////////////////////////////
 //
@@ -71,9 +71,9 @@ void pix_subtract :: processRGBA_Gray(imageStruct &image, imageStruct &right)
   
   while(datasize--)    {
     register int alpha = *rightPix++;
-    leftPix[chRed]   = CLAMP_LOW((int)leftPix[chRed]   - alpha);
-    leftPix[chGreen] = CLAMP_LOW((int)leftPix[chGreen] - alpha);
-    leftPix[chBlue]  = CLAMP_LOW((int)leftPix[chBlue]  - alpha);
+    leftPix[chRed]   = CLAMP_LOW(static_cast<int>(leftPix[chRed])   - alpha);
+    leftPix[chGreen] = CLAMP_LOW(static_cast<int>(leftPix[chGreen]) - alpha);
+    leftPix[chBlue]  = CLAMP_LOW(static_cast<int>(leftPix[chBlue])  - alpha);
     leftPix += 4;
     }
 }
@@ -318,7 +318,7 @@ void pix_subtract :: processDualImage(imageStruct &image, imageStruct &right){
     leftPix+=8;rightPix+=8;
   }
   while(restsize--){
-    *leftPix = CLAMP_LOW((int)(*leftPix - *rightPix));
+    *leftPix = CLAMP_LOW(static_cast<int>(*leftPix - *rightPix));
     leftPix++; rightPix++;
   }
 }
