@@ -5,8 +5,8 @@
   apply a 2p2z-filter on a sequence of pixBlocks
   
   Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-  Copyright (c) Gnther Geiger. geiger@epy.co.at
-  Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+  Copyright (c) Günther Geiger. geiger@epy.co.at
+  Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
   For information on usage and redistribution, and for a DISCLAIMER OF ALL
   WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 	
@@ -23,8 +23,8 @@
 	  
   -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_TIIR_H_
-#define INCLUDE_PIX_TIIR_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_TIIR_H_
+#define _INCLUDE__GEM_PIXES_PIX_TIIR_H_
 
 #include "Base/GemPixObj.h"
 
@@ -41,7 +41,7 @@
   -----------------------------------------------------------------*/
 class GEM_EXTERN pix_tIIR : public GemPixObj
 {
-  CPPEXTERN_HEADER(pix_tIIR, GemPixObj)
+  CPPEXTERN_HEADER(pix_tIIR, GemPixObj);
 		
     public:
 	
