@@ -5,16 +5,16 @@ LOG
     replace the alpha-channel of the 1st image by that of the 2nd image 
 
     Copyright (c) 1997-1998 Mark Danks
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_TAKEALPHA_H_
-#define INCLUDE_PIX_TAKEALPHA_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_TAKEALPHA_H_
+#define _INCLUDE__GEM_PIXES_PIX_TAKEALPHA_H_
 
 #include "Base/GemPixDualObj.h"
 
@@ -33,7 +33,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_takealpha : public GemPixDualObj
 {
-    CPPEXTERN_HEADER(pix_takealpha, GemPixDualObj)
+    CPPEXTERN_HEADER(pix_takealpha, GemPixDualObj);
 
     public:
 
