@@ -8,10 +8,10 @@
  */
 
  
-#ifndef INCLUDE_PIX_VIDEODARWIN_H_
-#define INCLUDE_PIX_VIDEODARWIN_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_VIDEODARWIN_H_
+#define _INCLUDE__GEM_PIXES_PIX_VIDEODARWIN_H_
 
-#include "Base/GemGL.h"
+#include "Gem/GemGL.h"
 
 #include <Carbon/Carbon.h>
 #include <QuickTime/QuickTime.h>
@@ -40,7 +40,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_videoDarwin : public pix_videoOS
 {
-    CPPEXTERN_HEADER(pix_videoDarwin, GemBase)
+    CPPEXTERN_HEADER(pix_videoDarwin, GemBase);
 
     public:
 
