@@ -7,24 +7,30 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
-
 #include "pix_write.h"
 
-#include "Base/GemMan.h"
-#include "Base/GemCache.h"
+#include "Gem/Manager.h"
+#include "Gem/Cache.h"
+#include "Gem/ImageIO.h"
 
 #include <stdio.h>
 #include <string.h>
 
-CPPEXTERN_NEW_WITH_GIMME(pix_write)
+#ifdef _MSC_VER  /* This is only for Microsoft's compiler, not cygwin, e.g. */
+# define snprintf _snprintf
+# define vsnprintf _vsnprintf
+#endif
+
+
+CPPEXTERN_NEW_WITH_GIMME(pix_write);
 
   /////////////////////////////////////////////////////////
 //
@@ -40,13 +46,13 @@ pix_write :: pix_write(int argc, t_atom *argv)
   m_xoff = m_yoff = 0;
   m_width = m_height = 0;
   if (argc == 4) {
-    m_xoff = (int)atom_getfloat(&argv[0]);
-    m_yoff = (int)atom_getfloat(&argv[1]);
-    m_width = (int)atom_getfloat(&argv[2]);
-    m_height = (int)atom_getfloat(&argv[3]);
+    m_xoff = atom_getint(&argv[0]);
+    m_yoff = atom_getint(&argv[1]);
+    m_width = atom_getint(&argv[2]);
+    m_height = atom_getint(&argv[3]);
   } else if (argc == 2) {
-    m_width = (int)atom_getfloat(&argv[0]);
-    m_height = (int)atom_getfloat(&argv[1]);
+    m_width = atom_getint(&argv[0]);
+    m_height = atom_getint(&argv[1]);
   } else if (argc != 0){
     error("needs 0, 2, or 4 values");
     m_xoff = m_yoff = 0;
@@ -225,15 +231,15 @@ void pix_write :: cleanImage()
 /////////////////////////////////////////////////////////
 void pix_write :: obj_setupCallback(t_class *classPtr)
 {
-  class_addmethod(classPtr, (t_method)&pix_write::fileMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_write::fileMessCallback),
 		  gensym("file"), A_GIMME, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_write::autoMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_write::autoMessCallback),
 		  gensym("auto"), A_FLOAT, A_NULL);
-  class_addbang(classPtr, (t_method)&pix_write::bangMessCallback);
+  class_addbang(classPtr, reinterpret_cast<t_method>(&pix_write::bangMessCallback));
 
-  class_addmethod(classPtr, (t_method)&pix_write::sizeMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_write::sizeMessCallback),
 		  gensym("vert_size"), A_FLOAT, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&pix_write::posMessCallback,
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_write::posMessCallback),
 		  gensym("vert_pos"), A_FLOAT, A_FLOAT, A_NULL);
 }
 
@@ -252,9 +258,9 @@ void pix_write :: bangMessCallback(void *data)
 
 void pix_write :: sizeMessCallback(void *data, t_floatarg width, t_floatarg height)
 {
-  GetMyClass(data)->sizeMess((int)width, (int)height);
+  GetMyClass(data)->sizeMess(static_cast<int>(width), static_cast<int>(height));
 }
 void pix_write :: posMessCallback(void *data, t_floatarg x, t_floatarg y)
 {
-  GetMyClass(data)->posMess((int)x, (int)y);
+  GetMyClass(data)->posMess(static_cast<int>(x), static_cast<int>(y));
 }
