@@ -5,19 +5,18 @@ LOG
     Snap a pix of the render buffer and write it to a file
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
-    Copyright (c) Gnther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) Günther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_PIX_WRITE_H_
-#define INCLUDE_PIX_WRITE_H_
+#ifndef _INCLUDE__GEM_PIXES_PIX_WRITE_H_
+#define _INCLUDE__GEM_PIXES_PIX_WRITE_H_
 
 #include "Base/GemBase.h"
-#include "Base/GemPixUtil.h"
-#include "Base/GemPixImageSave.h"
+#include "Gem/Image.h"
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
@@ -44,7 +43,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN pix_write : public GemBase
 {
-    CPPEXTERN_HEADER(pix_write, GemBase)
+    CPPEXTERN_HEADER(pix_write, GemBase);
 
     public:
 
