@@ -7,7 +7,7 @@
 // Implementation file
 //
 //    Copyright (c) 1997-2000 Mark Danks.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
@@ -19,7 +19,7 @@
 
 #include "pix_yuv.h"
 
-CPPEXTERN_NEW(pix_yuv)
+CPPEXTERN_NEW(pix_yuv);
 
 /////////////////////////////////////////////////////////
 //
