@@ -7,8 +7,8 @@
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
-//    Copyright (c) Gnther Geiger.
-//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) Günther Geiger.
+//    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,7 +16,7 @@
 
 #include "pix_zoom.h"
 
-CPPEXTERN_NEW(pix_zoom)
+CPPEXTERN_NEW(pix_zoom);
 
 /////////////////////////////////////////////////////////
 //
@@ -76,7 +76,7 @@ void pix_zoom :: zoomMess(float xZoom, float yZoom)
 /////////////////////////////////////////////////////////
 void pix_zoom :: obj_setupCallback(t_class *classPtr)
 {
-    class_addmethod(classPtr, (t_method)&pix_zoom::zoomMessCallback,
+    class_addmethod(classPtr, reinterpret_cast<t_method>(&pix_zoom::zoomMessCallback),
     	    gensym("zoom"), A_FLOAT, A_FLOAT, A_NULL);
 }
 void pix_zoom :: zoomMessCallback(void *data, t_floatarg xMag, t_floatarg yMag)
