@@ -5,15 +5,15 @@ LOG
     A vertex_set
 
     Copyright (c) 1997-2000 Mark Danks. mark@danks.org
-    Copyright (c) G¸nther Geiger. geiger@epy.co.at
-    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::f¸r::uml‰ute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) GÂžnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
 -----------------------------------------------------------------*/
 
-#ifndef INCLUDE_VERTEX_SET_H_
-#define INCLUDE_VERTEX_SET_H_
+#ifndef _INCLUDE__GEM_VERTEX_VERTEX_SET_H_
+#define _INCLUDE__GEM_VERTEX_VERTEX_SET_H_
 
 #include "vertex_scale.h"
 
@@ -32,7 +32,7 @@ DESCRIPTION
 -----------------------------------------------------------------*/
 class GEM_EXTERN vertex_set : public vertex_scale
 {
-  CPPEXTERN_HEADER(vertex_set, vertex_scale)
+  CPPEXTERN_HEADER(vertex_set, vertex_scale);
 
     public:
 
@@ -44,7 +44,7 @@ class GEM_EXTERN vertex_set : public vertex_scale
     	
   //////////
   // Destructor
-  virtual ~vertex_set();
+  virtual ~vertex_set(void);
 
   virtual void paramMess(int,t_atom*);
   float	m_x,m_y,m_z,m_w;
