@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglAreTexturesResident.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglAreTexturesResident )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglAreTexturesResident );
 
 /////////////////////////////////////////////////////////
 //
@@ -83,7 +83,7 @@ void GEMglAreTexturesResident :: texturesMess (int argc, t_atom*argv) {
 //
 
 void GEMglAreTexturesResident :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglAreTexturesResident::texturesMessCallback,  	gensym("textures"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglAreTexturesResident::texturesMessCallback),  	gensym("textures"), A_GIMME, A_NULL);
 }
 void GEMglAreTexturesResident :: texturesMessCallback (void* data, t_symbol*,int argc, t_atom*argv){
 	GetMyClass(data)->texturesMess (argc,argv);
