@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -13,8 +13,8 @@
 ////////////////////////////////////////////////////////
 
 #include "GEMglBlendFunc.h"
-
-CPPEXTERN_NEW_WITH_GIMME ( GEMglBlendFunc )
+#include "Gem/Exception.h"
+CPPEXTERN_NEW_WITH_GIMME ( GEMglBlendFunc );
 
 /////////////////////////////////////////////////////////
 //
@@ -51,12 +51,12 @@ void GEMglBlendFunc :: render(GemState *state) {
 // Variables
 //
 void GEMglBlendFunc :: sfactorMess (t_atom arg) {	// FUN
-	sfactor = (GLenum)getGLdefine(&arg);
+	sfactor = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
 void GEMglBlendFunc :: dfactorMess (t_atom arg) {	// FUN
-	dfactor = (GLenum)getGLdefine(&arg);
+	dfactor = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
@@ -66,8 +66,8 @@ void GEMglBlendFunc :: dfactorMess (t_atom arg) {	// FUN
 //
 
 void GEMglBlendFunc :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglBlendFunc::sfactorMessCallback,  	gensym("sfactor"), A_GIMME, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglBlendFunc::dfactorMessCallback,  	gensym("dfactor"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglBlendFunc::sfactorMessCallback),  	gensym("sfactor"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglBlendFunc::dfactorMessCallback),  	gensym("dfactor"), A_GIMME, A_NULL);
 };
 
 void GEMglBlendFunc :: sfactorMessCallback (void* data, t_symbol*, int argc, t_atom*argv){
