@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglClearDepth.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglClearDepth , t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglClearDepth , t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -24,7 +24,7 @@ CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglClearDepth , t_floatarg, A_DEFFLOAT)
 // Constructor
 //
 GEMglClearDepth :: GEMglClearDepth	(t_floatarg arg0=0) :
-		depth((GLclampd)arg0)
+		depth(static_cast<GLclampd>(arg0))
 {
 	m_inlet[0] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("depth"));
 }
@@ -40,7 +40,7 @@ inlet_free(m_inlet[0]);
 //
 void GEMglClearDepth :: render(GemState *state) {
 
-	glClearDepth ((GLclampd)depth);
+	glClearDepth (static_cast<GLclampd>(depth));
 
 }
 
@@ -49,7 +49,7 @@ void GEMglClearDepth :: render(GemState *state) {
 //
 void GEMglClearDepth :: depthMess (float arg1) {	// FUN
 
-	depth = (float)arg1;
+	depth = arg1;
 	setModified();
 }
 
@@ -59,9 +59,9 @@ void GEMglClearDepth :: depthMess (float arg1) {	// FUN
 //
 
 void GEMglClearDepth :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglClearDepth::depthMessCallback,  	gensym("depth"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglClearDepth::depthMessCallback),  	gensym("depth"), A_DEFFLOAT, A_NULL);
 };
 
 void GEMglClearDepth :: depthMessCallback (void* data, float arg0){
-	GetMyClass(data)->depthMess ( (float)    arg0);
+	GetMyClass(data)->depthMess ( arg0);
 }
