@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -13,8 +13,9 @@
 ////////////////////////////////////////////////////////
 
 #include "GEMglColorMaterial.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglColorMaterial )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglColorMaterial );
 
 /////////////////////////////////////////////////////////
 //
@@ -51,12 +52,12 @@ void GEMglColorMaterial :: render(GemState *state) {
 // Variables
 //
 void GEMglColorMaterial :: faceMess (t_atom arg) {	// FUN
-	face = (GLenum)getGLdefine(&arg);
+	face = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
 void GEMglColorMaterial :: modeMess (t_atom arg) {	// FUN
-	mode = (GLenum)getGLdefine(&arg);
+	mode = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
@@ -66,8 +67,8 @@ void GEMglColorMaterial :: modeMess (t_atom arg) {	// FUN
 //
 
 void GEMglColorMaterial :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglColorMaterial::faceMessCallback,  	gensym("face"), A_GIMME, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglColorMaterial::modeMessCallback,  	gensym("mode"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglColorMaterial::faceMessCallback),  	gensym("face"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglColorMaterial::modeMessCallback),  	gensym("mode"), A_GIMME, A_NULL);
 };
 
 void GEMglColorMaterial :: faceMessCallback (void* data, t_symbol*, int argc, t_atom*argv){
