@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglCopyTexSubImage2D.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglCopyTexSubImage2D )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglCopyTexSubImage2D );
 
 /////////////////////////////////////////////////////////
 //
@@ -78,42 +78,42 @@ void GEMglCopyTexSubImage2D :: render(GemState *state) {
 // Variables
 //
 void GEMglCopyTexSubImage2D :: targetMess (t_float arg1) {	// FUN
-	target = (GLenum)arg1;
+	target = static_cast<GLenum>(arg1);
 	setModified();
 }
 
 void GEMglCopyTexSubImage2D :: levelMess (t_float arg1) {	// FUN
-	level = (GLint)arg1;
+	level = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglCopyTexSubImage2D :: xoffsetMess (t_float arg1) {	// FUN
-	xoffset = (GLint)arg1;
+	xoffset = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglCopyTexSubImage2D :: yoffsetMess (t_float arg1) {	// FUN
-	yoffset = (GLint)arg1;
+	yoffset = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglCopyTexSubImage2D :: xMess (t_float arg1) {	// FUN
-	x = (GLint)arg1;
+	x = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglCopyTexSubImage2D :: yMess (t_float arg1) {	// FUN
-	y = (GLint)arg1;
+	y = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglCopyTexSubImage2D :: widthMess (t_float arg1) {	// FUN
-	width = (GLsizei)arg1;
+	width = static_cast<GLsizei>(arg1);
 	setModified();
 }
 
 void GEMglCopyTexSubImage2D :: heightMess (t_float arg1) {	// FUN
-	height = (GLsizei)arg1;
+	height = static_cast<GLsizei>(arg1);
 	setModified();
 }
 
@@ -123,37 +123,37 @@ void GEMglCopyTexSubImage2D :: heightMess (t_float arg1) {	// FUN
 //
 
 void GEMglCopyTexSubImage2D :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglCopyTexSubImage2D::targetMessCallback,  	gensym("target"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglCopyTexSubImage2D::levelMessCallback,  	gensym("level"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglCopyTexSubImage2D::xoffsetMessCallback,  	gensym("xoffset"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglCopyTexSubImage2D::yoffsetMessCallback,  	gensym("yoffset"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglCopyTexSubImage2D::xMessCallback,  	gensym("x"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglCopyTexSubImage2D::yMessCallback,  	gensym("y"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglCopyTexSubImage2D::widthMessCallback,  	gensym("width"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglCopyTexSubImage2D::heightMessCallback,  	gensym("height"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglCopyTexSubImage2D::targetMessCallback),  	gensym("target"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglCopyTexSubImage2D::levelMessCallback),  	gensym("level"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglCopyTexSubImage2D::xoffsetMessCallback),  	gensym("xoffset"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglCopyTexSubImage2D::yoffsetMessCallback),  	gensym("yoffset"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglCopyTexSubImage2D::xMessCallback),  	gensym("x"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglCopyTexSubImage2D::yMessCallback),  	gensym("y"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglCopyTexSubImage2D::widthMessCallback),  	gensym("width"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglCopyTexSubImage2D::heightMessCallback),  	gensym("height"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglCopyTexSubImage2D :: targetMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->targetMess ( (t_float)    arg0);
+	GetMyClass(data)->targetMess ( static_cast<t_float>(arg0));
 }
 void GEMglCopyTexSubImage2D :: levelMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->levelMess ( (t_float)    arg0);
+	GetMyClass(data)->levelMess ( static_cast<t_float>(arg0));
 }
 void GEMglCopyTexSubImage2D :: xoffsetMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->xoffsetMess ( (t_float)    arg0);
+	GetMyClass(data)->xoffsetMess ( static_cast<t_float>(arg0));
 }
 void GEMglCopyTexSubImage2D :: yoffsetMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->yoffsetMess ( (t_float)    arg0);
+	GetMyClass(data)->yoffsetMess ( static_cast<t_float>(arg0));
 }
 void GEMglCopyTexSubImage2D :: xMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->xMess ( (t_float)    arg0);
+	GetMyClass(data)->xMess ( static_cast<t_float>(arg0));
 }
 void GEMglCopyTexSubImage2D :: yMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->yMess ( (t_float)    arg0);
+	GetMyClass(data)->yMess ( static_cast<t_float>(arg0));
 }
 void GEMglCopyTexSubImage2D :: widthMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->widthMess ( (t_float)    arg0);
+	GetMyClass(data)->widthMess ( static_cast<t_float>(arg0));
 }
 void GEMglCopyTexSubImage2D :: heightMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->heightMess ( (t_float)    arg0);
+	GetMyClass(data)->heightMess ( static_cast<t_float>(arg0));
 }
