@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglDeleteTextures.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglDeleteTextures )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglDeleteTextures );
 
 /////////////////////////////////////////////////////////
 //
@@ -57,7 +57,7 @@ void GEMglDeleteTextures :: texturesMess (int argc, t_atom*argv) {	// FUN
   delete [] textures;
   textures = new GLuint[argc];
   while(argc--){
-    if(argv->a_type == A_FLOAT)textures[n++] = (GLuint)atom_getint(argv);
+    if(argv->a_type == A_FLOAT)textures[n++] = static_cast<GLuint>(atom_getint(argv));
     argv++;
   }
   setModified();
@@ -69,7 +69,7 @@ void GEMglDeleteTextures :: texturesMess (int argc, t_atom*argv) {	// FUN
 //
 
 void GEMglDeleteTextures :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglDeleteTextures::texturesMessCallback,  	gensym("textures"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglDeleteTextures::texturesMessCallback),  	gensym("textures"), A_GIMME, A_NULL);
 }
 void GEMglDeleteTextures :: texturesMessCallback (void* data, t_symbol*, int argc, t_atom*argv){
 	GetMyClass(data)->texturesMess (argc, argv);
