@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglDrawArrays.h"
 
-CPPEXTERN_NEW_WITH_THREE_ARGS ( GEMglDrawArrays , t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_THREE_ARGS ( GEMglDrawArrays , t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -24,9 +24,9 @@ CPPEXTERN_NEW_WITH_THREE_ARGS ( GEMglDrawArrays , t_floatarg, A_DEFFLOAT, t_floa
 // Constructor
 //
 GEMglDrawArrays :: GEMglDrawArrays	(t_floatarg arg0=0, t_floatarg arg1=0, t_floatarg arg2=0) :
-		mode((GLenum)arg0), 
-		first((GLint)arg1), 
-		count((GLsizei)arg2)
+		mode(static_cast<GLenum>(arg0)), 
+		first(static_cast<GLint>(arg1)), 
+		count(static_cast<GLsizei>(arg2))
 {
 	m_inlet[0] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("mode"));
 	m_inlet[1] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("first"));
@@ -58,17 +58,17 @@ void GEMglDrawArrays :: render(GemState *state) {
 // Variables
 //
 void GEMglDrawArrays :: modeMess (t_float arg1) {	// FUN
-	mode = (GLenum)arg1;
+	mode = static_cast<GLenum>(arg1);
 	setModified();
 }
 
 void GEMglDrawArrays :: firstMess (t_float arg1) {	// FUN
-	first = (GLint)arg1;
+	first = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglDrawArrays :: countMess (t_float arg1) {	// FUN
-	count = (GLsizei)arg1;
+	count = static_cast<GLsizei>(arg1);
 	setModified();
 }
 
@@ -78,17 +78,17 @@ void GEMglDrawArrays :: countMess (t_float arg1) {	// FUN
 //
 
 void GEMglDrawArrays :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglDrawArrays::modeMessCallback,  	gensym("mode"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglDrawArrays::firstMessCallback,  	gensym("first"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglDrawArrays::countMessCallback,  	gensym("count"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglDrawArrays::modeMessCallback),  	gensym("mode"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglDrawArrays::firstMessCallback),  	gensym("first"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglDrawArrays::countMessCallback),  	gensym("count"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglDrawArrays :: modeMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->modeMess ( (t_float)    arg0);
+	GetMyClass(data)->modeMess ( static_cast<t_float>(arg0));
 }
 void GEMglDrawArrays :: firstMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->firstMess ( (t_float)    arg0);
+	GetMyClass(data)->firstMess ( static_cast<t_float>(arg0));
 }
 void GEMglDrawArrays :: countMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->countMess ( (t_float)    arg0);
+	GetMyClass(data)->countMess ( static_cast<t_float>(arg0));
 }
