@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -13,8 +13,9 @@
 ////////////////////////////////////////////////////////
 
 #include "GEMglDrawBuffer.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglDrawBuffer )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglDrawBuffer );
 
 /////////////////////////////////////////////////////////
 //
@@ -47,7 +48,7 @@ void GEMglDrawBuffer :: render(GemState *state) {
 // Variables
 //
 void GEMglDrawBuffer :: modeMess (t_atom arg) {	// FUN
-	mode = (GLenum)getGLdefine(&arg);
+	mode = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
@@ -57,7 +58,7 @@ void GEMglDrawBuffer :: modeMess (t_atom arg) {	// FUN
 //
 
 void GEMglDrawBuffer :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglDrawBuffer::modeMessCallback,  	gensym("mode"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglDrawBuffer::modeMessCallback),  	gensym("mode"), A_GIMME, A_NULL);
 };
 
 void GEMglDrawBuffer :: modeMessCallback (void* data, t_symbol*, int argc, t_atom*argv){
