@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -13,8 +13,9 @@
 ////////////////////////////////////////////////////////
 
 #include "GEMglEnable.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglEnable )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglEnable );
 
 /////////////////////////////////////////////////////////
 //
@@ -47,7 +48,7 @@ void GEMglEnable :: render(GemState *state) {
 // Variables
 //
 void GEMglEnable :: capMess (t_atom arg) {	// FUN
-	cap = (GLenum)getGLdefine(&arg);
+	cap = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
@@ -57,7 +58,7 @@ void GEMglEnable :: capMess (t_atom arg) {	// FUN
 //
 
 void GEMglEnable :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglEnable::capMessCallback,  	gensym("cap"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEnable::capMessCallback),  	gensym("cap"), A_GIMME, A_NULL);
 };
 
 void GEMglEnable :: capMessCallback (void* data, t_symbol*, int argc, t_atom*argv){
