@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -13,8 +13,9 @@
 ////////////////////////////////////////////////////////
 
 #include "GEMglEnableClientState.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglEnableClientState )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglEnableClientState );
 
 /////////////////////////////////////////////////////////
 //
@@ -53,7 +54,7 @@ void GEMglEnableClientState :: render(GemState *state) {
 // Variables
 //
 void GEMglEnableClientState :: arrayMess (t_atom arg) {	// FUN
-	array = (GLenum)getGLdefine(&arg);
+	array = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
@@ -63,7 +64,7 @@ void GEMglEnableClientState :: arrayMess (t_atom arg) {	// FUN
 //
 
 void GEMglEnableClientState :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglEnableClientState::arrayMessCallback,  	gensym("array"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEnableClientState::arrayMessCallback),  	gensym("array"), A_GIMME, A_NULL);
 }
 
 void GEMglEnableClientState :: arrayMessCallback (void* data, t_symbol*, int argc, t_atom*argv){
