@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglEvalCoord1d.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglEvalCoord1d , t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglEvalCoord1d , t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -24,7 +24,7 @@ CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglEvalCoord1d , t_floatarg, A_DEFFLOAT)
 // Constructor
 //
 GEMglEvalCoord1d :: GEMglEvalCoord1d	(t_floatarg arg0=0) :
-		u((GLdouble)arg0)
+		u(static_cast<GLdouble>(arg0))
 {
 	m_inlet[0] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("u"));
 }
@@ -52,7 +52,7 @@ void GEMglEvalCoord1d :: render(GemState *state) {
 // Variables
 //
 void GEMglEvalCoord1d :: uMess (t_float arg1) {	// FUN
-	u = (GLdouble)arg1;
+	u = static_cast<GLdouble>(arg1);
 	setModified();
 }
 
@@ -62,9 +62,9 @@ void GEMglEvalCoord1d :: uMess (t_float arg1) {	// FUN
 //
 
 void GEMglEvalCoord1d :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglEvalCoord1d::uMessCallback,  	gensym("u"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEvalCoord1d::uMessCallback),  	gensym("u"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglEvalCoord1d :: uMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->uMess ( (t_float)    arg0);
+	GetMyClass(data)->uMess ( static_cast<t_float>(arg0));
 }
