@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglEvalCoord1dv.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglEvalCoord1dv , t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglEvalCoord1dv , t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -51,7 +51,7 @@ void GEMglEvalCoord1dv :: render(GemState *state) {
 // variable
 //
 void GEMglEvalCoord1dv :: vMess (t_float arg0) {	// FUN
-	v[0]=(GLdouble )arg0;
+	v[0]=static_cast<GLdouble>(arg0);
 	setModified();
 }
 
@@ -60,7 +60,7 @@ void GEMglEvalCoord1dv :: vMess (t_float arg0) {	// FUN
 //
 
 void GEMglEvalCoord1dv :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglEvalCoord1dv::vMessCallback,  	gensym("v"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEvalCoord1dv::vMessCallback),  	gensym("v"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglEvalCoord1dv :: vMessCallback (void* data, t_floatarg arg0) {
