@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglEvalCoord2d.h"
 
-CPPEXTERN_NEW_WITH_TWO_ARGS ( GEMglEvalCoord2d , t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS ( GEMglEvalCoord2d , t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -24,8 +24,8 @@ CPPEXTERN_NEW_WITH_TWO_ARGS ( GEMglEvalCoord2d , t_floatarg, A_DEFFLOAT, t_float
 // Constructor
 //
 GEMglEvalCoord2d :: GEMglEvalCoord2d	(t_floatarg arg0=0, t_floatarg arg1=0) :
-		u((GLdouble)arg0), 
-		v((GLdouble)arg1)
+		u(static_cast<GLdouble>(arg0)), 
+		v(static_cast<GLdouble>(arg1))
 {
 	m_inlet[0] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("u"));
 	m_inlet[1] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("v"));
@@ -55,12 +55,12 @@ void GEMglEvalCoord2d :: render(GemState *state) {
 // Variables
 //
 void GEMglEvalCoord2d :: uMess (t_float arg1) {	// FUN
-	u = (GLdouble)arg1;
+	u = static_cast<GLdouble>(arg1);
 	setModified();
 }
 
 void GEMglEvalCoord2d :: vMess (t_float arg1) {	// FUN
-	v = (GLdouble)arg1;
+	v = static_cast<GLdouble>(arg1);
 	setModified();
 }
 
@@ -70,13 +70,13 @@ void GEMglEvalCoord2d :: vMess (t_float arg1) {	// FUN
 //
 
 void GEMglEvalCoord2d :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglEvalCoord2d::uMessCallback,  	gensym("u"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglEvalCoord2d::vMessCallback,  	gensym("v"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEvalCoord2d::uMessCallback),  	gensym("u"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEvalCoord2d::vMessCallback),  	gensym("v"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglEvalCoord2d :: uMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->uMess ( (t_float)    arg0);
+	GetMyClass(data)->uMess ( static_cast<t_float>(arg0));
 }
 void GEMglEvalCoord2d :: vMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->vMess ( (t_float)    arg0);
+	GetMyClass(data)->vMess ( static_cast<t_float>(arg0));
 }
