@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglEvalCoord2fv.h"
 
-CPPEXTERN_NEW_WITH_TWO_ARGS ( GEMglEvalCoord2fv , t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS ( GEMglEvalCoord2fv , t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -51,8 +51,8 @@ void GEMglEvalCoord2fv :: render(GemState *state) {
 // variable
 //
 void GEMglEvalCoord2fv :: vMess (t_float arg0, t_float arg1) {	// FUN
-	v[0]=(GLfloat )arg0;
-	v[1]=(GLfloat )arg1;
+	v[0]=static_cast<GLfloat>(arg0);
+	v[1]=static_cast<GLfloat>(arg1);
 	setModified();
 }
 
@@ -61,7 +61,7 @@ void GEMglEvalCoord2fv :: vMess (t_float arg0, t_float arg1) {	// FUN
 //
 
 void GEMglEvalCoord2fv :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglEvalCoord2fv::vMessCallback,  	gensym("v"), A_DEFFLOAT, A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEvalCoord2fv::vMessCallback),  	gensym("v"), A_DEFFLOAT, A_DEFFLOAT, A_NULL);
 }
 
 void GEMglEvalCoord2fv :: vMessCallback (void* data, t_floatarg arg0, t_floatarg arg1) {
