@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglEvalMesh2.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglEvalMesh2 )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglEvalMesh2 );
 
 /////////////////////////////////////////////////////////
 //
@@ -66,27 +66,27 @@ void GEMglEvalMesh2 :: render(GemState *state) {
 // Variables
 //
 void GEMglEvalMesh2 :: modeMess (t_float arg1) {	// FUN
-	mode = (GLenum)arg1;
+	mode = static_cast<GLenum>(arg1);
 	setModified();
 }
 
 void GEMglEvalMesh2 :: i1Mess (t_float arg1) {	// FUN
-	i1 = (GLint)arg1;
+	i1 = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglEvalMesh2 :: i2Mess (t_float arg1) {	// FUN
-	i2 = (GLint)arg1;
+	i2 = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglEvalMesh2 :: j1Mess (t_float arg1) {	// FUN
-	j1 = (GLint)arg1;
+	j1 = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglEvalMesh2 :: j2Mess (t_float arg1) {	// FUN
-	j2 = (GLint)arg1;
+	j2 = static_cast<GLint>(arg1);
 	setModified();
 }
 
@@ -96,25 +96,25 @@ void GEMglEvalMesh2 :: j2Mess (t_float arg1) {	// FUN
 //
 
 void GEMglEvalMesh2 :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglEvalMesh2::modeMessCallback,  	gensym("mode"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglEvalMesh2::i1MessCallback,  	gensym("i1"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglEvalMesh2::i2MessCallback,  	gensym("i2"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglEvalMesh2::j1MessCallback,  	gensym("j1"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglEvalMesh2::j2MessCallback,  	gensym("j2"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEvalMesh2::modeMessCallback),  	gensym("mode"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEvalMesh2::i1MessCallback),  	gensym("i1"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEvalMesh2::i2MessCallback),  	gensym("i2"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEvalMesh2::j1MessCallback),  	gensym("j1"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEvalMesh2::j2MessCallback),  	gensym("j2"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglEvalMesh2 :: modeMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->modeMess ( (t_float)    arg0);
+	GetMyClass(data)->modeMess ( static_cast<t_float>(arg0));
 }
 void GEMglEvalMesh2 :: i1MessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->i1Mess ( (t_float)    arg0);
+	GetMyClass(data)->i1Mess ( static_cast<t_float>(arg0));
 }
 void GEMglEvalMesh2 :: i2MessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->i2Mess ( (t_float)    arg0);
+	GetMyClass(data)->i2Mess ( static_cast<t_float>(arg0));
 }
 void GEMglEvalMesh2 :: j1MessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->j1Mess ( (t_float)    arg0);
+	GetMyClass(data)->j1Mess ( static_cast<t_float>(arg0));
 }
 void GEMglEvalMesh2 :: j2MessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->j2Mess ( (t_float)    arg0);
+	GetMyClass(data)->j2Mess ( static_cast<t_float>(arg0));
 }
