@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglEvalPoint1.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglEvalPoint1 , t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglEvalPoint1 , t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -24,7 +24,7 @@ CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglEvalPoint1 , t_floatarg, A_DEFFLOAT)
 // Constructor
 //
 GEMglEvalPoint1 :: GEMglEvalPoint1	(t_floatarg arg0=0) :
-		i((GLint)arg0)
+		i(static_cast<GLint>(arg0))
 {
 	m_inlet[0] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("i"));
 }
@@ -52,7 +52,7 @@ void GEMglEvalPoint1 :: render(GemState *state) {
 // Variables
 //
 void GEMglEvalPoint1 :: iMess (t_float arg1) {	// FUN
-	i = (GLint)arg1;
+	i = static_cast<GLint>(arg1);
 	setModified();
 }
 
@@ -62,9 +62,9 @@ void GEMglEvalPoint1 :: iMess (t_float arg1) {	// FUN
 //
 
 void GEMglEvalPoint1 :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglEvalPoint1::iMessCallback,  	gensym("i"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglEvalPoint1::iMessCallback),  	gensym("i"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglEvalPoint1 :: iMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->iMess ( (t_float)    arg0);
+	GetMyClass(data)->iMess ( static_cast<t_float>(arg0));
 }
