@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglFogiv.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglFogiv )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglFogiv );
 
 /////////////////////////////////////////////////////////
 //
@@ -60,7 +60,7 @@ void GEMglFogiv :: render(GemState *state) {
 // variable
 //
 void GEMglFogiv :: pnameMess (t_float arg0) {	// FUN
-  pname=(GLenum)arg0;
+  pname=static_cast<GLenum>(arg0);
   setModified();
 }
 void GEMglFogiv :: paramsMess (int argc, t_atom*argv) {	// FUN
@@ -74,8 +74,8 @@ void GEMglFogiv :: paramsMess (int argc, t_atom*argv) {	// FUN
 //
 
 void GEMglFogiv :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglFogiv::pnameMessCallback,  	gensym("pname"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglFogiv::paramsMessCallback,  	gensym("params"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglFogiv::pnameMessCallback),  	gensym("pname"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglFogiv::paramsMessCallback),  	gensym("params"), A_GIMME, A_NULL);
 }
 
 void GEMglFogiv :: pnameMessCallback (void* data, t_floatarg arg0) {
