@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglGenTextures.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglGenTextures)
+CPPEXTERN_NEW_WITH_GIMME ( GEMglGenTextures);
 
 /////////////////////////////////////////////////////////
 //
@@ -65,7 +65,7 @@ void GEMglGenTextures :: texturesMess (int argc, t_atom*argv) {	// FUN
   if(textures) delete [] textures;
   textures = new GLuint[argc];
   while(argc--){
-    if(argv->a_type == A_FLOAT)textures[n++] = (GLuint)atom_getint(argv);
+    if(argv->a_type == A_FLOAT)textures[n++] = static_cast<GLuint>(atom_getint(argv));
     argv++;
   }
   setModified();
@@ -78,7 +78,7 @@ void GEMglGenTextures :: texturesMess (int argc, t_atom*argv) {	// FUN
 //
 
 void GEMglGenTextures :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglGenTextures::texturesMessCallback,  	gensym("textures"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglGenTextures::texturesMessCallback),  	gensym("textures"), A_GIMME, A_NULL);
 }
 void GEMglGenTextures :: texturesMessCallback (void* data, t_symbol*, int argc, t_atom*argv){
 	GetMyClass(data)->texturesMess (argc,argv);
