@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglGetError.h"
 
-CPPEXTERN_NEW ( GEMglGetError )
+CPPEXTERN_NEW ( GEMglGetError );
 
 /////////////////////////////////////////////////////////
 //
@@ -38,7 +38,7 @@ GEMglGetError :: ~GEMglGetError () {
 //
 void GEMglGetError :: render(GemState *state) {
   GLenum i=glGetError();
-  outlet_float(m_outlet, (t_float)i);
+  outlet_float(m_outlet, static_cast<t_float>(i));
 }
 
 /////////////////////////////////////////////////////////
