@@ -1,7 +1,7 @@
 /* ------------------------------------------------------------------
  * GEM - Graphics Environment for Multimedia
  *
- *  Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+ *  Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
  *	zmoelnig@iem.kug.ac.at
  *  For information on usage and redistribution, and for a DISCLAIMER
  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -10,10 +10,10 @@
  * ------------------------------------------------------------------
  */
 
-#ifndef INCLUDE_GEM_GLGETPOINTERV_H_
-#define INCLUDE_GEM_GLGETPOINTERV_H_
+#ifndef _INCLUDE__GEM_OPENGL_GEMGLGETFLOATV_H_
+#define _INCLUDE__GEM_OPENGL_GEMGLGETFLOATV_H_
 
-#include "GemGLBase.h"
+#include "Base/GemGLBase.h"
 
 /*
   CLASS
@@ -27,7 +27,7 @@
 
 class GEM_EXTERN GEMglGetFloatv : public GemGLBase
 {
-  CPPEXTERN_HEADER(GEMglGetFloatv, GemGLBase)
+  CPPEXTERN_HEADER(GEMglGetFloatv, GemGLBase);
 
     public:
   // Constructor
@@ -53,6 +53,6 @@ class GEM_EXTERN GEMglGetFloatv : public GemGLBase
   t_outlet    	*m_outlet;
 
   // static member functions
-  static void    pnameMessCallback (void*,int,t_atom*);
+  static void    pnameMessCallback (void*,t_symbol*,int,t_atom*);
 };
 #endif // for header file
