@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglGetMapdv.h"
 
-CPPEXTERN_NEW_WITH_TWO_ARGS ( GEMglGetMapdv, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS ( GEMglGetMapdv, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -57,11 +57,11 @@ void GEMglGetMapdv :: render(GemState *state) {
 // variable
 //
 void GEMglGetMapdv :: targetMess (t_float arg0) {	// FUN
-  target=(GLenum)arg0;
+  target=static_cast<GLenum>(arg0);
   setModified();
 }
 void GEMglGetMapdv :: queryMess (t_float arg0) {	// FUN
-  query=(GLenum)arg0;
+  query=static_cast<GLenum>(arg0);
   setModified();
 }
 /////////////////////////////////////////////////////////
@@ -69,8 +69,8 @@ void GEMglGetMapdv :: queryMess (t_float arg0) {	// FUN
 //
 
 void GEMglGetMapdv :: obj_setupCallback(t_class *classPtr) {
-  class_addmethod(classPtr, (t_method)&GEMglGetMapdv::targetMessCallback, gensym("target"), A_DEFFLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&GEMglGetMapdv::queryMessCallback, gensym("query"), A_DEFFLOAT, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglGetMapdv::targetMessCallback), gensym("target"), A_DEFFLOAT, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglGetMapdv::queryMessCallback), gensym("query"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglGetMapdv :: targetMessCallback (void* data, t_floatarg arg0) {
