@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglGetMapfv.h"
 
-CPPEXTERN_NEW_WITH_TWO_ARGS ( GEMglGetMapfv, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_TWO_ARGS ( GEMglGetMapfv, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -58,11 +58,11 @@ void GEMglGetMapfv :: render(GemState *state) {
 // variable
 //
 void GEMglGetMapfv :: targetMess (t_float arg0) {	// FUN
-  target=(GLenum)arg0;
+  target=static_cast<GLenum>(arg0);
   setModified();
 }
 void GEMglGetMapfv :: queryMess (t_float arg0) {	// FUN
-  query=(GLenum)arg0;
+  query=static_cast<GLenum>(arg0);
   setModified();
 }
 
@@ -71,8 +71,8 @@ void GEMglGetMapfv :: queryMess (t_float arg0) {	// FUN
 //
 
 void GEMglGetMapfv :: obj_setupCallback(t_class *classPtr) {
-  class_addmethod(classPtr, (t_method)&GEMglGetMapfv::targetMessCallback, gensym("target"), A_DEFFLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&GEMglGetMapfv::queryMessCallback, gensym("query"), A_DEFFLOAT, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglGetMapfv::targetMessCallback), gensym("target"), A_DEFFLOAT, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglGetMapfv::queryMessCallback), gensym("query"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglGetMapfv :: targetMessCallback (void* data, t_floatarg arg0) {
