@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglGetPointerv.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglGetPointerv , t_floatarg, A_DEFFLOAT )
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglGetPointerv , t_floatarg, A_DEFFLOAT );
 
 /////////////////////////////////////////////////////////
 //
@@ -54,7 +54,7 @@ void GEMglGetPointerv :: render(GemState *state) {
 // variable
 //
 void GEMglGetPointerv :: pnameMess (t_float arg0) {	// FUN
-  pname=(GLenum)arg0;
+  pname=static_cast<GLenum>(arg0);
   setModified();
 }
 
@@ -63,7 +63,7 @@ void GEMglGetPointerv :: pnameMess (t_float arg0) {	// FUN
 //
 
 void GEMglGetPointerv :: obj_setupCallback(t_class *classPtr) {
-  class_addmethod(classPtr, (t_method)&GEMglGetPointerv::pnameMessCallback,  	gensym("pname"), A_DEFFLOAT, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglGetPointerv::pnameMessCallback),  	gensym("pname"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglGetPointerv :: pnameMessCallback (void* data, t_floatarg arg0) {
