@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -13,8 +13,9 @@
 ////////////////////////////////////////////////////////
 
 #include "GEMglHint.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglHint )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglHint );
 
 /////////////////////////////////////////////////////////
 //
@@ -50,12 +51,12 @@ void GEMglHint :: render(GemState *state) {
 // Variables
 //
 void GEMglHint :: targetMess (t_atom arg) {	// FUN
-	target = (GLenum)getGLdefine(&arg);
+	target = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
 void GEMglHint :: modeMess (t_atom arg) {	// FUN
-	mode = (GLenum)getGLdefine(&arg);
+	mode = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
@@ -65,8 +66,8 @@ void GEMglHint :: modeMess (t_atom arg) {	// FUN
 //
 
 void GEMglHint :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglHint::targetMessCallback,  	gensym("target"), A_GIMME, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglHint::modeMessCallback,  	gensym("mode"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglHint::targetMessCallback),  	gensym("target"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglHint::modeMessCallback),  	gensym("mode"), A_GIMME, A_NULL);
 };
 
 void GEMglHint :: targetMessCallback (void* data, t_symbol*, int argc, t_atom*argv){
