@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglIndexub.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglIndexub , t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglIndexub , t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -24,7 +24,7 @@ CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglIndexub , t_floatarg, A_DEFFLOAT)
 // Constructor
 //
 GEMglIndexub :: GEMglIndexub	(t_floatarg arg0=0) :
-		c((GLubyte)arg0)
+		c(static_cast<GLubyte>(arg0))
 {
 	m_inlet[0] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("c"));
 }
@@ -54,7 +54,7 @@ void GEMglIndexub :: render(GemState *state) {
 // Variables
 //
 void GEMglIndexub :: cMess (t_float arg1) {	// FUN
-	c = (GLubyte)arg1;
+	c = static_cast<GLubyte>(arg1);
 	setModified();
 }
 
@@ -64,9 +64,9 @@ void GEMglIndexub :: cMess (t_float arg1) {	// FUN
 //
 
 void GEMglIndexub :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglIndexub::cMessCallback,  	gensym("c"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglIndexub::cMessCallback),  	gensym("c"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglIndexub :: cMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->cMess ( (t_float)    arg0);
+	GetMyClass(data)->cMess ( static_cast<t_float>(arg0));
 }
