@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglIndexubv.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglIndexubv , t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglIndexubv , t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -53,7 +53,7 @@ void GEMglIndexubv :: render(GemState *state) {
 // variable
 //
 void GEMglIndexubv :: cMess (t_float arg0) {	// FUN
-  c[0]=(GLubyte)arg0;
+  c[0]=static_cast<GLubyte>(arg0);
   setModified();
 }
 
@@ -62,7 +62,7 @@ void GEMglIndexubv :: cMess (t_float arg0) {	// FUN
 //
 
 void GEMglIndexubv :: obj_setupCallback(t_class *classPtr) {
-  class_addmethod(classPtr, (t_method)&GEMglIndexubv::cMessCallback,  	gensym("c"), A_DEFFLOAT, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglIndexubv::cMessCallback),  	gensym("c"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglIndexubv :: cMessCallback (void* data, t_floatarg arg0) {
