@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -13,8 +13,9 @@
 ////////////////////////////////////////////////////////
 
 #include "GEMglIsEnabled.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglIsEnabled )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglIsEnabled );
 
 /////////////////////////////////////////////////////////
 //
@@ -58,7 +59,7 @@ void GEMglIsEnabled :: render(GemState *state) {
 // Variables
 //
 void GEMglIsEnabled :: capMess (t_atom arg) {	// FUN
-  cap = (GLenum)getGLdefine(&arg);
+  cap = static_cast<GLenum>(getGLdefine(&arg));
   setModified();
 }
 
@@ -67,7 +68,7 @@ void GEMglIsEnabled :: capMess (t_atom arg) {	// FUN
 // static member functions
 //
 void GEMglIsEnabled :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglIsEnabled::capMessCallback, gensym("cap"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglIsEnabled::capMessCallback), gensym("cap"), A_GIMME, A_NULL);
 }
 
 void GEMglIsEnabled :: capMessCallback (void* data, t_symbol*, int argc, t_atom*argv){
