@@ -8,10 +8,10 @@
   * ------------------------------------------------------------------
   */
 
-#ifndef INCLUDE_GEM_GLLOADMATRIXD_H_
-#define INCLUDE_GEM_GLLOADMATRIXD_H_
+#ifndef _INCLUDE__GEM_OPENGL_GEMGLLOADMATRIXD_H_
+#define _INCLUDE__GEM_OPENGL_GEMGLLOADMATRIXD_H_
 
-#include "GemGLBase.h"
+#include "Base/GemGLBase.h"
 
 /*
  CLASS
@@ -25,7 +25,7 @@
 
 class GEM_EXTERN GEMglLoadMatrixd : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglLoadMatrixd, GemGLBase)
+	CPPEXTERN_HEADER(GEMglLoadMatrixd, GemGLBase);
 
 	public:
 	  // Constructor
