@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglLoadName.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglLoadName , t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglLoadName , t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -24,7 +24,7 @@ CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglLoadName , t_floatarg, A_DEFFLOAT)
 // Constructor
 //
 GEMglLoadName :: GEMglLoadName	(t_floatarg arg0=0) :
-		name((GLuint)arg0)
+		name(static_cast<GLuint>(arg0))
 {
 	m_inlet[0] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("name"));
 }
@@ -54,7 +54,7 @@ void GEMglLoadName :: render(GemState *state) {
 // Variables
 //
 void GEMglLoadName :: nameMess (t_float arg1) {	// FUN
-	name = (GLuint)arg1;
+	name = static_cast<GLuint>(arg1);
 	setModified();
 }
 
@@ -64,9 +64,9 @@ void GEMglLoadName :: nameMess (t_float arg1) {	// FUN
 //
 
 void GEMglLoadName :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglLoadName::nameMessCallback,  	gensym("name"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglLoadName::nameMessCallback),  	gensym("name"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglLoadName :: nameMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->nameMess ( (t_float)    arg0);
+	GetMyClass(data)->nameMess ( static_cast<t_float>(arg0));
 }
