@@ -8,10 +8,10 @@
   * ------------------------------------------------------------------
   */
 
-#ifndef INCLUDE_GEM_GLLOADTRANSPOSEMATRIXF_H_
-#define INCLUDE_GEM_GLLOADTRANSPOSEMATRIXF_H_
+#ifndef _INCLUDE__GEM_OPENGL_GEMGLLOADTRANSPOSEMATRIXF_H_
+#define _INCLUDE__GEM_OPENGL_GEMGLLOADTRANSPOSEMATRIXF_H_
 
-#include "GemGLBase.h"
+#include "Base/GemGLBase.h"
 
 /*
  CLASS
@@ -25,7 +25,7 @@
 
 class GEM_EXTERN GEMglLoadTransposeMatrixf : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglLoadTransposeMatrixf, GemGLBase)
+	CPPEXTERN_HEADER(GEMglLoadTransposeMatrixf, GemGLBase);
 
 	public:
 	  // Constructor
