@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglMap1d.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglMap1d )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglMap1d );
 
 /////////////////////////////////////////////////////////
 //
@@ -24,11 +24,11 @@ CPPEXTERN_NEW_WITH_GIMME ( GEMglMap1d )
 // Constructor
 //
 GEMglMap1d :: GEMglMap1d	(int argc, t_atom*argv){
-	if (argc>0)target=(GLenum  )atom_getint(argv+0);
-	if (argc>1)u1    =(GLdouble)atom_getint(argv+1);
-	if (argc>2)u2    =(GLdouble)atom_getint(argv+2);
-	if (argc>3)stride=(GLint   )atom_getint(argv+3);
-	if (argc>4)order =(GLint   )atom_getint(argv+4);
+	if (argc>0)target=static_cast<GLenum>(atom_getint(argv+0));
+	if (argc>1)u1    =static_cast<GLdouble>(atom_getfloat(argv+1));
+	if (argc>2)u2    =static_cast<GLdouble>(atom_getfloat(argv+2));
+	if (argc>3)stride=static_cast<GLint>(atom_getint(argv+3));
+	if (argc>4)order =static_cast<GLint>(atom_getint(argv+4));
 
 	m_inlet[0] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("target"));
 	m_inlet[1] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("u1"));
@@ -72,27 +72,27 @@ void GEMglMap1d :: render(GemState *state) {
 // Variables
 //
 void GEMglMap1d :: targetMess (t_float arg1) {	// FUN
-	target = (GLenum)arg1;
+	target = static_cast<GLenum>(arg1);
 	setModified();
 }
 
 void GEMglMap1d :: u1Mess (t_float arg1) {	// FUN
-	u1 = (GLdouble)arg1;
+	u1 = static_cast<GLdouble>(arg1);
 	setModified();
 }
 
 void GEMglMap1d :: u2Mess (t_float arg1) {	// FUN
-	u2 = (GLdouble)arg1;
+	u2 = static_cast<GLdouble>(arg1);
 	setModified();
 }
 
 void GEMglMap1d :: strideMess (t_float arg1) {	// FUN
-	stride = (GLint)arg1;
+	stride = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglMap1d :: orderMess (t_float arg1) {	// FUN
-	order = (GLint)arg1;
+	order = static_cast<GLint>(arg1);
 	setModified();
 }
 
@@ -112,12 +112,12 @@ void GEMglMap1d :: pointsMess (int argc, t_atom*argv) {	// FUN
 //
 
 void GEMglMap1d :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglMap1d::targetMessCallback,  	gensym("target"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMap1d::u1MessCallback,  	gensym("u1"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMap1d::u2MessCallback,  	gensym("u2"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMap1d::strideMessCallback,  	gensym("stride"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMap1d::orderMessCallback,  	gensym("order"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMap1d::pointsMessCallback,  	gensym("points"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1d::targetMessCallback),  	gensym("target"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1d::u1MessCallback),  	gensym("u1"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1d::u2MessCallback),  	gensym("u2"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1d::strideMessCallback),  	gensym("stride"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1d::orderMessCallback),  	gensym("order"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1d::pointsMessCallback),  	gensym("points"), A_GIMME, A_NULL);
 }
 
 void GEMglMap1d :: targetMessCallback (void* data, t_floatarg arg0){
