@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,21 +14,21 @@
 
 #include "GEMglMap1f.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglMap1f )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglMap1f );
 
 /////////////////////////////////////////////////////////
 //
-// GEMglViewport
+// GEMglMap1f
 //
 /////////////////////////////////////////////////////////
 // Constructor
 //
 GEMglMap1f :: GEMglMap1f	(int argc, t_atom*argv){
-	if (argc>0)target=(GLenum  )atom_getint(argv+0);
-	if (argc>1)u1    =(GLfloat)atom_getint(argv+1);
-	if (argc>2)u2    =(GLfloat)atom_getint(argv+2);
-	if (argc>3)stride=(GLint   )atom_getint(argv+3);
-	if (argc>4)order =(GLint   )atom_getint(argv+4);
+	if (argc>0)target=static_cast<GLenum>(atom_getint(argv+0));
+	if (argc>1)u1    =static_cast<GLfloat>(atom_getfloat(argv+1));
+	if (argc>2)u2    =static_cast<GLfloat>(atom_getfloat(argv+2));
+	if (argc>3)stride=static_cast<GLint>(atom_getint(argv+3));
+	if (argc>4)order =static_cast<GLint>(atom_getint(argv+4));
 	
 	len=128;
 	points = new GLfloat[len];
@@ -72,27 +72,27 @@ void GEMglMap1f :: render(GemState *state) {
 // Variables
 //
 void GEMglMap1f :: targetMess (t_float arg1) {	// FUN
-	target = (GLenum)arg1;
+	target = static_cast<GLenum>(arg1);
 	setModified();
 }
 
 void GEMglMap1f :: u1Mess (t_float arg1) {	// FUN
-	u1 = (GLfloat)arg1;
+	u1 = static_cast<GLfloat>(arg1);
 	setModified();
 }
 
 void GEMglMap1f :: u2Mess (t_float arg1) {	// FUN
-	u2 = (GLfloat)arg1;
+	u2 = static_cast<GLfloat>(arg1);
 	setModified();
 }
 
 void GEMglMap1f :: strideMess (t_float arg1) {	// FUN
-	stride = (GLint)arg1;
+	stride = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglMap1f :: orderMess (t_float arg1) {	// FUN
-	order = (GLint)arg1;
+	order = static_cast<GLint>(arg1);
 	setModified();
 }
 
@@ -112,12 +112,12 @@ void GEMglMap1f :: pointsMess (int argc, t_atom*argv) {	// FUN
 //
 
 void GEMglMap1f :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglMap1f::targetMessCallback,  	gensym("target"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMap1f::u1MessCallback,  	gensym("u1"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMap1f::u2MessCallback,  	gensym("u2"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMap1f::strideMessCallback,  	gensym("stride"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMap1f::orderMessCallback,  	gensym("order"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMap1f::pointsMessCallback,  	gensym("points"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1f::targetMessCallback),  	gensym("target"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1f::u1MessCallback),  	gensym("u1"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1f::u2MessCallback),  	gensym("u2"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1f::strideMessCallback),  	gensym("stride"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1f::orderMessCallback),  	gensym("order"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMap1f::pointsMessCallback),  	gensym("points"), A_GIMME, A_NULL);
 }
 
 void GEMglMap1f :: targetMessCallback (void* data, t_floatarg arg0){
