@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglMapGrid2f.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglMapGrid2f )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglMapGrid2f );
 
 /////////////////////////////////////////////////////////
 //
@@ -71,32 +71,32 @@ void GEMglMapGrid2f :: render(GemState *state) {
 // Variables
 //
 void GEMglMapGrid2f :: unMess (t_float arg1) {	// FUN
-	un = (GLint)arg1;
+	un = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglMapGrid2f :: u1Mess (t_float arg1) {	// FUN
-	u1 = (GLfloat)arg1;
+	u1 = static_cast<GLfloat>(arg1);
 	setModified();
 }
 
 void GEMglMapGrid2f :: u2Mess (t_float arg1) {	// FUN
-	u2 = (GLfloat)arg1;
+	u2 = static_cast<GLfloat>(arg1);
 	setModified();
 }
 
 void GEMglMapGrid2f :: vnMess (t_float arg1) {	// FUN
-	vn = (GLint)arg1;
+	vn = static_cast<GLint>(arg1);
 	setModified();
 }
 
 void GEMglMapGrid2f :: v1Mess (t_float arg1) {	// FUN
-	v1 = (GLfloat)arg1;
+	v1 = static_cast<GLfloat>(arg1);
 	setModified();
 }
 
 void GEMglMapGrid2f :: v2Mess (t_float arg1) {	// FUN
-	v2 = (GLfloat)arg1;
+	v2 = static_cast<GLfloat>(arg1);
 	setModified();
 }
 
@@ -106,29 +106,29 @@ void GEMglMapGrid2f :: v2Mess (t_float arg1) {	// FUN
 //
 
 void GEMglMapGrid2f :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglMapGrid2f::unMessCallback,  	gensym("un"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMapGrid2f::u1MessCallback,  	gensym("u1"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMapGrid2f::u2MessCallback,  	gensym("u2"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMapGrid2f::vnMessCallback,  	gensym("vn"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMapGrid2f::v1MessCallback,  	gensym("v1"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglMapGrid2f::v2MessCallback,  	gensym("v2"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMapGrid2f::unMessCallback),  	gensym("un"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMapGrid2f::u1MessCallback),  	gensym("u1"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMapGrid2f::u2MessCallback),  	gensym("u2"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMapGrid2f::vnMessCallback),  	gensym("vn"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMapGrid2f::v1MessCallback),  	gensym("v1"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglMapGrid2f::v2MessCallback),  	gensym("v2"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglMapGrid2f :: unMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->unMess ( (t_float)    arg0);
+	GetMyClass(data)->unMess ( static_cast<t_float>(arg0));
 }
 void GEMglMapGrid2f :: u1MessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->u1Mess ( (t_float)    arg0);
+	GetMyClass(data)->u1Mess ( static_cast<t_float>(arg0));
 }
 void GEMglMapGrid2f :: u2MessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->u2Mess ( (t_float)    arg0);
+	GetMyClass(data)->u2Mess ( static_cast<t_float>(arg0));
 }
 void GEMglMapGrid2f :: vnMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->vnMess ( (t_float)    arg0);
+	GetMyClass(data)->vnMess ( static_cast<t_float>(arg0));
 }
 void GEMglMapGrid2f :: v1MessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->v1Mess ( (t_float)    arg0);
+	GetMyClass(data)->v1Mess ( static_cast<t_float>(arg0));
 }
 void GEMglMapGrid2f :: v2MessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->v2Mess ( (t_float)    arg0);
+	GetMyClass(data)->v2Mess ( static_cast<t_float>(arg0));
 }
