@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglPassThrough.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglPassThrough , t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglPassThrough , t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -24,7 +24,7 @@ CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglPassThrough , t_floatarg, A_DEFFLOAT)
 // Constructor
 //
 GEMglPassThrough :: GEMglPassThrough	(t_floatarg arg0=0) :
-		token((GLfloat)arg0)
+		token(static_cast<GLfloat>(arg0))
 {
 	m_inlet[0] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("token"));
 }
@@ -55,7 +55,7 @@ void GEMglPassThrough :: render(GemState *state) {
 // Variables
 //
 void GEMglPassThrough :: tokenMess (t_float arg1) {	// FUN
-	token = (GLfloat)arg1;
+	token = static_cast<GLfloat>(arg1);
 	setModified();
 }
 
@@ -65,9 +65,9 @@ void GEMglPassThrough :: tokenMess (t_float arg1) {	// FUN
 //
 
 void GEMglPassThrough :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglPassThrough::tokenMessCallback,  	gensym("token"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglPassThrough::tokenMessCallback),  	gensym("token"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglPassThrough :: tokenMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->tokenMess ( (t_float)    arg0);
+	GetMyClass(data)->tokenMess ( static_cast<t_float>(arg0));
 }
