@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglPrioritizeTextures.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglPrioritizeTextures , t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglPrioritizeTextures , t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -24,7 +24,7 @@ CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglPrioritizeTextures , t_floatarg, A_DEFFLOAT)
 // Constructor
 //
 GEMglPrioritizeTextures :: GEMglPrioritizeTextures	(t_floatarg arg0=16) :
-		n((GLsizei)arg0) {
+		n(static_cast<GLsizei>(arg0)) {
 	if (n>0) t_len=p_len=n;
 	else t_len=p_len=16;
 
@@ -66,7 +66,7 @@ void GEMglPrioritizeTextures :: render(GemState *state) {
 // Variables
 //
 void GEMglPrioritizeTextures :: nMess (t_float arg1) {	// FUN
-	n = (GLsizei)arg1;
+	n = static_cast<GLsizei>(arg1);
 	setModified();
 }
 
@@ -76,7 +76,7 @@ void GEMglPrioritizeTextures :: texturesMess (int argc,t_atom*argv) {	// FUN
     delete [] textures;
     textures = new GLuint[t_len];
   }
-  while(argc--)textures[argc]=(GLuint)atom_getint(argv+argc);
+  while(argc--)textures[argc]=static_cast<GLuint>(atom_getint(argv+argc));
   setModified();
 }
 
@@ -86,7 +86,7 @@ void GEMglPrioritizeTextures :: prioritiesMess (int argc, t_atom*argv) {	// FUN
     delete [] priorities;
     priorities = new GLclampf[p_len];
   }
-  while(argc--)priorities[argc]=(GLclampf)atom_getfloat(argv+argc);
+  while(argc--)priorities[argc]=static_cast<GLclampf>(atom_getfloat(argv+argc));
   setModified();
 }
 
@@ -96,9 +96,9 @@ void GEMglPrioritizeTextures :: prioritiesMess (int argc, t_atom*argv) {	// FUN
 //
 
 void GEMglPrioritizeTextures :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglPrioritizeTextures::nMessCallback,  	gensym("n"), A_DEFFLOAT, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglPrioritizeTextures::texturesMessCallback,  	gensym("textures"), A_GIMME, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglPrioritizeTextures::prioritiesMessCallback,  	gensym("priorities"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglPrioritizeTextures::nMessCallback),  	gensym("n"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglPrioritizeTextures::texturesMessCallback),  	gensym("textures"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglPrioritizeTextures::prioritiesMessCallback),  	gensym("priorities"), A_GIMME, A_NULL);
 }
 
 void GEMglPrioritizeTextures :: nMessCallback (void* data, t_floatarg arg0){
