@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglPushClientAttrib.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglPushClientAttrib , t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglPushClientAttrib , t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -24,7 +24,7 @@ CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglPushClientAttrib , t_floatarg, A_DEFFLOAT)
 // Constructor
 //
 GEMglPushClientAttrib :: GEMglPushClientAttrib	(t_floatarg arg0=0) :
-		mask((GLbitfield)arg0)
+		mask(static_cast<GLbitfield>(arg0))
 {
 	m_inlet[0] = inlet_new(this->x_obj, &this->x_obj->ob_pd, &s_float, gensym("mask"));
 }
@@ -55,7 +55,7 @@ void GEMglPushClientAttrib :: render(GemState *state) {
 // Variables
 //
 void GEMglPushClientAttrib :: maskMess (t_float arg1) {	// FUN
-	mask = (GLbitfield)arg1;
+	mask = static_cast<GLbitfield>(arg1);
 	setModified();
 }
 
@@ -65,9 +65,9 @@ void GEMglPushClientAttrib :: maskMess (t_float arg1) {	// FUN
 //
 
 void GEMglPushClientAttrib :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglPushClientAttrib::maskMessCallback,  	gensym("mask"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglPushClientAttrib::maskMessCallback),  	gensym("mask"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglPushClientAttrib :: maskMessCallback (void* data, t_floatarg arg0){
-	GetMyClass(data)->maskMess ( (t_float)    arg0);
+	GetMyClass(data)->maskMess ( static_cast<t_float>(arg0));
 }
