@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -13,8 +13,9 @@
 ////////////////////////////////////////////////////////
 
 #include "GEMglRenderMode.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglRenderMode )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglRenderMode );
 
 /////////////////////////////////////////////////////////
 //
@@ -44,14 +45,14 @@ GEMglRenderMode :: ~GEMglRenderMode () {
 //
 void GEMglRenderMode :: render(GemState *state) {
   GLint i = glRenderMode (mode);
-  outlet_float(m_outlet, (t_float)i);
+  outlet_float(m_outlet, static_cast<t_float>(i));
 }
 
 /////////////////////////////////////////////////////////
 // Variables
 //
 void GEMglRenderMode :: modeMess (t_atom arg) {	// FUN
-  mode = (GLenum)getGLdefine(&arg);
+  mode = static_cast<GLenum>(getGLdefine(&arg));
   setModified();
 }
 
@@ -61,7 +62,7 @@ void GEMglRenderMode :: modeMess (t_atom arg) {	// FUN
 //
 
 void GEMglRenderMode :: obj_setupCallback(t_class *classPtr) {
-  class_addmethod(classPtr, (t_method)&GEMglRenderMode::modeMessCallback, gensym("mode"), A_GIMME, A_NULL);
+  class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglRenderMode::modeMessCallback), gensym("mode"), A_GIMME, A_NULL);
 }
 
 void GEMglRenderMode :: modeMessCallback (void* data, t_symbol*s, int argc, t_atom*argv){
