@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002-2004 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -13,10 +13,10 @@
 ////////////////////////////////////////////////////////
 
 #include "GEMglReportError.h"
-#include "Base/GemGLUtil.h"
+#include "Utils/GLUtil.h"
 
 
-CPPEXTERN_NEW( GEMglReportError)
+CPPEXTERN_NEW( GEMglReportError);
 
 /////////////////////////////////////////////////////////
 //
@@ -40,7 +40,7 @@ GEMglReportError :: ~GEMglReportError () {
 //
 void GEMglReportError :: render(GemState *state) {
   GLenum err=glReportError();  
-  outlet_float(m_outlet, (t_float)err);
+  outlet_float(m_outlet, static_cast<t_float>(err));
 }
 
 
