@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GEMglSelectBuffer.h"
 
-CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglSelectBuffer , t_floatarg, A_DEFFLOAT)
+CPPEXTERN_NEW_WITH_ONE_ARG ( GEMglSelectBuffer , t_floatarg, A_DEFFLOAT);
 
 /////////////////////////////////////////////////////////
 //
@@ -57,7 +57,7 @@ void GEMglSelectBuffer :: postrender(GemState *state) {
   t_atom*ap=new t_atom[size];
   int i=0;
   for(i=0; i<size; i++) {
-    SETFLOAT(ap+i, (t_float)buffer[i]);
+    SETFLOAT(ap+i, static_cast<t_float>(buffer[i]));
   }
   outlet_list(m_bufout, gensym("list"), size, ap);
 }
@@ -68,7 +68,7 @@ void GEMglSelectBuffer :: postrender(GemState *state) {
 void GEMglSelectBuffer :: sizeMess (t_float arg1) {	// FUN
   int i;
   if (arg1<1)return;
-  size = (GLsizei)arg1;
+  size = static_cast<GLsizei>(arg1);
   if (len<size){
     len=size;
     delete[]buffer;
@@ -86,7 +86,7 @@ void GEMglSelectBuffer :: sizeMess (t_float arg1) {	// FUN
 //
 
 void GEMglSelectBuffer :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglSelectBuffer::sizeMessCallback,  	gensym("size"), A_DEFFLOAT, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglSelectBuffer::sizeMessCallback),  	gensym("size"), A_DEFFLOAT, A_NULL);
 }
 
 void GEMglSelectBuffer :: sizeMessCallback (void* data, t_floatarg arg0){
