@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -13,8 +13,9 @@
 ////////////////////////////////////////////////////////
 
 #include "GEMglStencilOp.h"
+#include "Gem/Exception.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GEMglStencilOp )
+CPPEXTERN_NEW_WITH_GIMME ( GEMglStencilOp );
 
 /////////////////////////////////////////////////////////
 //
@@ -54,17 +55,17 @@ void GEMglStencilOp :: render(GemState *state) {
 // Variables
 //
 void GEMglStencilOp :: failMess (t_atom arg) {	// FUN
-	fail = (GLenum)getGLdefine(&arg);
+	fail = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
 void GEMglStencilOp :: zfailMess (t_atom arg) {	// FUN
-	zfail = (GLenum)getGLdefine(&arg);
+	zfail = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
 void GEMglStencilOp :: zpassMess (t_atom arg) {	// FUN
-	zpass = (GLenum)getGLdefine(&arg);
+	zpass = static_cast<GLenum>(getGLdefine(&arg));
 	setModified();
 }
 
@@ -74,9 +75,9 @@ void GEMglStencilOp :: zpassMess (t_atom arg) {	// FUN
 //
 
 void GEMglStencilOp :: obj_setupCallback(t_class *classPtr) {
-	 class_addmethod(classPtr, (t_method)&GEMglStencilOp::failMessCallback,  	gensym("fail"), A_GIMME, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglStencilOp::zfailMessCallback,  	gensym("zfail"), A_GIMME, A_NULL);
-	 class_addmethod(classPtr, (t_method)&GEMglStencilOp::zpassMessCallback,  	gensym("zpass"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglStencilOp::failMessCallback),  	gensym("fail"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglStencilOp::zfailMessCallback),  	gensym("zfail"), A_GIMME, A_NULL);
+	 class_addmethod(classPtr, reinterpret_cast<t_method>(&GEMglStencilOp::zpassMessCallback),  	gensym("zpass"), A_GIMME, A_NULL);
 };
 
 void GEMglStencilOp :: failMessCallback (void* data, t_symbol*, int argc, t_atom*argv){
