@@ -2,7 +2,7 @@
   * GEM - Graphics Environment for Multimedia
   *
   *  Copyright (c) 2005 James Tittle. tigital @ mac.com
-  *  Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+  *  Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
   *	zmoelnig@iem.kug.ac.at
   *  For information on usage and redistribution, and for a DISCLAIMER
   *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -10,10 +10,10 @@
   * ------------------------------------------------------------------
   */
 
-#ifndef INCLUDE_GEM_GLUNIFORM1FARB_H_
-#define INCLUDE_GEM_GLUNIFORM1FARB_H_
+#ifndef _INCLUDE__GEM_OPENGL_GEMGLUNIFORM_FARB_H_
+#define _INCLUDE__GEM_OPENGL_GEMGLUNIFORM_FARB_H_
 
-#include "GemGLBase.h"
+#include "Base/GemGLBase.h"
 
 /*
  CLASS
@@ -27,7 +27,7 @@
 
 class GEM_EXTERN GEMglUniform1fARB : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglUniform1fARB, GemGLBase)
+	CPPEXTERN_HEADER(GEMglUniform1fARB, GemGLBase);
 
 	public:
 	  // Constructor
