@@ -7,10 +7,10 @@
   * ------------------------------------------------------------------
   */
 
-#ifndef INCLUDE_GEM_GLUSEPROGRAMOBJECTARB_H_
-#define INCLUDE_GEM_GLUSEPROGRAMOBJECTARB_H_
+#ifndef _INCLUDE__GEM_OPENGL_GEMGLUSEPROGRAMOBJECTARB_H_
+#define _INCLUDE__GEM_OPENGL_GEMGLUSEPROGRAMOBJECTARB_H_
 
-#include "GemGLBase.h"
+#include "Base/GemGLBase.h"
 
 /*
  CLASS
@@ -24,7 +24,7 @@
 
 class GEM_EXTERN GEMglUseProgramObjectARB : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglUseProgramObjectARB, GemGLBase)
+	CPPEXTERN_HEADER(GEMglUseProgramObjectARB, GemGLBase);
 
 	public:
 	  // Constructor
