@@ -4,7 +4,7 @@
 //
 // Implementation file
 //
-// Copyright (c) 2002-2004 IOhannes m zmoelnig. forum::fr::umlute. IEM
+// Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
 //	zmoelnig@iem.kug.ac.at
 //  For information on usage and redistribution, and for a DISCLAIMER
 //  *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -14,7 +14,7 @@
 
 #include "GLdefine.h"
 
-CPPEXTERN_NEW_WITH_GIMME ( GLdefine )
+CPPEXTERN_NEW_WITH_GIMME ( GLdefine );
 
 /////////////////////////////////////////////////////////
 //
