@@ -1,7 +1,7 @@
  /* ------------------------------------------------------------------
   * GEM - Graphics Environment for Multimedia
   *
-  *  Copyright (c) 2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+  *  Copyright (c) 2002-2011 IOhannes m zmölnig. forum::für::umläute. IEM. zmoelnig@iem.at
   *	zmoelnig@iem.kug.ac.at
   *  For information on usage and redistribution, and for a DISCLAIMER
   *  OF ALL WARRANTIES, see the file, "GEM.LICENSE.TERMS"
@@ -10,11 +10,11 @@
   * ------------------------------------------------------------------
   */
 
-#ifndef INCLUDE_GEM_GLBEGIN_H_
-#define INCLUDE_GEM_GLBEGIN_H_
+#ifndef _INCLUDE__GEM_OPENGL_GLDEFINE_H_
+#define _INCLUDE__GEM_OPENGL_GLDEFINE_H_
 
 #include "Base/CPPExtern.h"
-#include "Base/GemGLUtil.h"
+#include "Utils/GLUtil.h"
 
 
 /*
@@ -28,7 +28,7 @@
 
 class GEM_EXTERN GLdefine : public CPPExtern
 {
-	CPPEXTERN_HEADER(GLdefine, CPPExtern)
+	CPPEXTERN_HEADER(GLdefine, CPPExtern);
 
 	public:
 	  // Constructor
